AboutDialogBuilder

Struct AboutDialogBuilder 

pub struct AboutDialogBuilder { /* private fields */ }
A builder-pattern type to construct AboutDialog objects.

Implementations

Source

impl AboutDialogBuilder

pub fn artists(self, artists: impl Into<StrV>) -> Self

The people who contributed artwork to the program, as a None-terminated array of strings. Each string may contain email addresses and URLs, which will be displayed as links, see the introduction for more details.

pub fn authors(self, authors: impl Into<StrV>) -> Self

The authors of the program, as a None-terminated array of strings. Each string may contain email addresses and URLs, which will be displayed as links, see the introduction for more details.

pub fn comments(self, comments: impl Into<GString>) -> Self

Comments about the program. This string is displayed in a label in the main dialog, thus it should be a short explanation of the main purpose of the program, not a detailed list of features.

pub fn copyright(self, copyright: impl Into<GString>) -> Self

Copyright information for the program.

pub fn documenters(self, documenters: impl Into<StrV>) -> Self

The people documenting the program, as a None-terminated array of strings. Each string may contain email addresses and URLs, which will be displayed as links, see the introduction for more details.

pub fn license(self, license: impl Into<GString>) -> Self

The license of the program. This string is displayed in a text view in a secondary dialog, therefore it is fine to use a long multi-paragraph text. Note that the text is only wrapped in the text view if the “wrap-license” property is set to true; otherwise the text itself must contain the intended linebreaks. When setting this property to a non-None value, the license-type property is set to License::Custom as a side effect.

pub fn license_type(self, license_type: License) -> Self

The license of the program, as a value of the License enumeration.

The AboutDialog will automatically fill out a standard disclaimer and link the user to the appropriate online resource for the license text.

If License::Unknown is used, the link used will be the same specified in the website property.

If License::Custom is used, the current contents of the license property are used.

For any other License value, the contents of the license property are also set by this property as a side effect.

A logo for the about box. If it is None, the default window icon set with Window::set_default_icon() will be used.

pub fn logo_icon_name(self, logo_icon_name: impl Into<GString>) -> Self

A named icon to use as the logo for the about box. This property overrides the logo property.

pub fn program_name(self, program_name: impl Into<GString>) -> Self

The name of the program. If this is not set, it defaults to g_get_application_name().

pub fn translator_credits(self, translator_credits: impl Into<GString>) -> Self

Credits to the translators. This string should be marked as translatable. The string may contain email addresses and URLs, which will be displayed as links, see the introduction for more details.

pub fn version(self, version: impl Into<GString>) -> Self

The version of the program.

pub fn website(self, website: impl Into<GString>) -> Self

The URL for the link to the website of the program. This should be a string starting with “http://.

pub fn website_label(self, website_label: impl Into<GString>) -> Self

The label for the link to the website of the program.

pub fn wrap_license(self, wrap_license: bool) -> Self

Whether to wrap the text in the license dialog.

pub fn use_header_bar(self, use_header_bar: i32) -> Self

true if the dialog uses a HeaderBar for action buttons instead of the action-area.

For technical reasons, this property is declared as an integer property, but you should only set it to true or false.

pub fn accept_focus(self, accept_focus: bool) -> Self

Whether the window should receive the input focus.

pub fn application(self, application: &impl IsA<Application>) -> Self

The Application associated with the window.

The application will be kept alive for at least as long as it has any windows associated with it (see ApplicationExtManual::hold() for a way to keep it alive without windows).

Normally, the connection between the application and the window will remain until the window is destroyed, but you can explicitly remove it by setting the :application property to None.

pub fn attached_to(self, attached_to: &impl IsA<Widget>) -> Self

The widget to which this window is attached. See GtkWindowExt::set_attached_to().

Examples of places where specifying this relation is useful are for instance a Menu created by a ComboBox, a completion popup window created by Entry or a typeahead search entry created by TreeView.

pub fn decorated(self, decorated: bool) -> Self

Whether the window should be decorated by the window manager.

pub fn default_height(self, default_height: i32) -> Self

pub fn default_width(self, default_width: i32) -> Self

pub fn deletable(self, deletable: bool) -> Self

Whether the window frame should have a close button.

pub fn destroy_with_parent(self, destroy_with_parent: bool) -> Self

pub fn focus_on_map(self, focus_on_map: bool) -> Self

Whether the window should receive the input focus when mapped.

pub fn focus_visible(self, focus_visible: bool) -> Self

Whether ‘focus rectangles’ are currently visible in this window.

This property is maintained by GTK+ based on user input and should not be set by applications.

pub fn gravity(self, gravity: Gravity) -> Self

The window gravity of the window. See GtkWindowExt::move_() and gdk::Gravity for more details about window gravity.

pub fn hide_titlebar_when_maximized( self, hide_titlebar_when_maximized: bool, ) -> Self

Whether the titlebar should be hidden during maximization.

pub fn icon(self, icon: &Pixbuf) -> Self

pub fn icon_name(self, icon_name: impl Into<GString>) -> Self

The :icon-name property specifies the name of the themed icon to use as the window icon. See IconTheme for more details.

pub fn mnemonics_visible(self, mnemonics_visible: bool) -> Self

Whether mnemonics are currently visible in this window.

This property is maintained by GTK+ based on user input, and should not be set by applications.

pub fn modal(self, modal: bool) -> Self

pub fn resizable(self, resizable: bool) -> Self

pub fn role(self, role: impl Into<GString>) -> Self

pub fn screen(self, screen: &Screen) -> Self

pub fn skip_pager_hint(self, skip_pager_hint: bool) -> Self

pub fn skip_taskbar_hint(self, skip_taskbar_hint: bool) -> Self

pub fn startup_id(self, startup_id: impl Into<GString>) -> Self

The :startup-id is a write-only property for setting window’s startup notification identifier. See GtkWindowExt::set_startup_id() for more details.

pub fn title(self, title: impl Into<GString>) -> Self

pub fn transient_for(self, transient_for: &impl IsA<Window>) -> Self

The transient parent of the window. See GtkWindowExt::set_transient_for() for more details about transient windows.

pub fn type_(self, type_: WindowType) -> Self

pub fn type_hint(self, type_hint: WindowTypeHint) -> Self

pub fn urgency_hint(self, urgency_hint: bool) -> Self

pub fn window_position(self, window_position: WindowPosition) -> Self

pub fn border_width(self, border_width: u32) -> Self

pub fn child(self, child: &impl IsA<Widget>) -> Self

pub fn resize_mode(self, resize_mode: ResizeMode) -> Self

pub fn app_paintable(self, app_paintable: bool) -> Self

pub fn can_default(self, can_default: bool) -> Self

pub fn can_focus(self, can_focus: bool) -> Self

pub fn events(self, events: EventMask) -> Self

pub fn expand(self, expand: bool) -> Self

Whether to expand in both directions. Setting this sets both hexpand and vexpand

pub fn focus_on_click(self, focus_on_click: bool) -> Self

Whether the widget should grab focus when it is clicked with the mouse.

This property is only relevant for widgets that can take focus.

Before 3.20, several widgets (GtkButton, GtkFileChooserButton, GtkComboBox) implemented this property individually.

pub fn halign(self, halign: Align) -> Self

How to distribute horizontal space if widget gets extra space, see Align

pub fn has_default(self, has_default: bool) -> Self

pub fn has_focus(self, has_focus: bool) -> Self

pub fn has_tooltip(self, has_tooltip: bool) -> Self

Enables or disables the emission of query-tooltip on widget. A value of true indicates that widget can have a tooltip, in this case the widget will be queried using query-tooltip to determine whether it will provide a tooltip or not.

Note that setting this property to true for the first time will change the event masks of the GdkWindows of this widget to include leave-notify and motion-notify events. This cannot and will not be undone when the property is set to false again.

pub fn height_request(self, height_request: i32) -> Self

pub fn hexpand(self, hexpand: bool) -> Self

Whether to expand horizontally. See WidgetExt::set_hexpand().

pub fn hexpand_set(self, hexpand_set: bool) -> Self

Whether to use the hexpand property. See WidgetExt::is_hexpand_set().

pub fn is_focus(self, is_focus: bool) -> Self

pub fn margin(self, margin: i32) -> Self

Sets all four sides’ margin at once. If read, returns max margin on any side.

pub fn margin_bottom(self, margin_bottom: i32) -> Self

Margin on bottom side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_end(self, margin_end: i32) -> Self

Margin on end of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_start(self, margin_start: i32) -> Self

Margin on start of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_top(self, margin_top: i32) -> Self

Margin on top side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn name(self, name: impl Into<GString>) -> Self

pub fn no_show_all(self, no_show_all: bool) -> Self

pub fn opacity(self, opacity: f64) -> Self

The requested opacity of the widget. See WidgetExt::set_opacity() for more details about window opacity.

Before 3.8 this was only available in GtkWindow

pub fn parent(self, parent: &impl IsA<Container>) -> Self

pub fn receives_default(self, receives_default: bool) -> Self

pub fn sensitive(self, sensitive: bool) -> Self

pub fn tooltip_markup(self, tooltip_markup: impl Into<GString>) -> Self

Sets the text of tooltip to be the given string, which is marked up with the [Pango text markup language][PangoMarkupFormat]. Also see Tooltip::set_markup().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn tooltip_text(self, tooltip_text: impl Into<GString>) -> Self

Sets the text of tooltip to be the given string.

Also see Tooltip::set_text().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn valign(self, valign: Align) -> Self

How to distribute vertical space if widget gets extra space, see Align

pub fn vexpand(self, vexpand: bool) -> Self

Whether to expand vertically. See WidgetExt::set_vexpand().

pub fn vexpand_set(self, vexpand_set: bool) -> Self

Whether to use the vexpand property. See WidgetExt::is_vexpand_set().

pub fn visible(self, visible: bool) -> Self

pub fn width_request(self, width_request: i32) -> Self

pub fn build(self) -> AboutDialog

Build the AboutDialog.