AccelLabelBuilder

Struct AccelLabelBuilder 

pub struct AccelLabelBuilder { /* private fields */ }
A builder-pattern type to construct AccelLabel objects.

Implementations

Source

impl AccelLabelBuilder

pub fn accel_closure(self, accel_closure: &Closure) -> Self

pub fn accel_widget(self, accel_widget: &impl IsA<Widget>) -> Self

pub fn angle(self, angle: f64) -> Self

The angle that the baseline of the label makes with the horizontal, in degrees, measured counterclockwise. An angle of 90 reads from from bottom to top, an angle of 270, from top to bottom. Ignored if the label is selectable.

pub fn attributes(self, attributes: &AttrList) -> Self

pub fn ellipsize(self, ellipsize: EllipsizeMode) -> Self

The preferred place to ellipsize the string, if the label does not have enough room to display the entire string, specified as a pango::EllipsizeMode.

Note that setting this property to a value other than pango::EllipsizeMode::None has the side-effect that the label requests only enough space to display the ellipsis “…”. In particular, this means that ellipsizing labels do not work well in notebook tabs, unless the Notebook tab-expand child property is set to true. Other ways to set a label’s width are WidgetExt::set_size_request() and LabelExt::set_width_chars().

pub fn justify(self, justify: Justification) -> Self

pub fn label(self, label: impl Into<GString>) -> Self

The contents of the label.

If the string contains [Pango XML markup][PangoMarkupFormat], you will have to set the use-markup property to true in order for the label to display the markup attributes. See also LabelExt::set_markup() for a convenience function that sets both this property and the use-markup property at the same time.

If the string contains underlines acting as mnemonics, you will have to set the use-underline property to true in order for the label to display them.

pub fn lines(self, lines: i32) -> Self

The number of lines to which an ellipsized, wrapping label should be limited. This property has no effect if the label is not wrapping or ellipsized. Set this property to -1 if you don’t want to limit the number of lines.

pub fn max_width_chars(self, max_width_chars: i32) -> Self

The desired maximum width of the label, in characters. If this property is set to -1, the width will be calculated automatically.

See the section on [text layout][label-text-layout] for details of how width-chars and max-width-chars determine the width of ellipsized and wrapped labels.

pub fn mnemonic_widget(self, mnemonic_widget: &impl IsA<Widget>) -> Self

pub fn pattern(self, pattern: impl Into<GString>) -> Self

pub fn selectable(self, selectable: bool) -> Self

pub fn single_line_mode(self, single_line_mode: bool) -> Self

Whether the label is in single line mode. In single line mode, the height of the label does not depend on the actual text, it is always set to ascent + descent of the font. This can be an advantage in situations where resizing the label because of text changes would be distracting, e.g. in a statusbar.

Set this property to true to make the label track which links have been visited. It will then apply the StateFlags::VISITED when rendering this link, in addition to StateFlags::LINK.

pub fn use_markup(self, use_markup: bool) -> Self

pub fn use_underline(self, use_underline: bool) -> Self

pub fn width_chars(self, width_chars: i32) -> Self

The desired width of the label, in characters. If this property is set to -1, the width will be calculated automatically.

See the section on [text layout][label-text-layout] for details of how width-chars and max-width-chars determine the width of ellipsized and wrapped labels.

pub fn wrap(self, wrap: bool) -> Self

pub fn wrap_mode(self, wrap_mode: WrapMode) -> Self

If line wrapping is on (see the wrap property) this controls how the line wrapping is done. The default is pango::WrapMode::Word, which means wrap on word boundaries.

pub fn xalign(self, xalign: f32) -> Self

The xalign property determines the horizontal aligment of the label text inside the labels size allocation. Compare this to halign, which determines how the labels size allocation is positioned in the space available for the label.

pub fn yalign(self, yalign: f32) -> Self

The yalign property determines the vertical aligment of the label text inside the labels size allocation. Compare this to valign, which determines how the labels size allocation is positioned in the space available for the label.

pub fn app_paintable(self, app_paintable: bool) -> Self

pub fn can_default(self, can_default: bool) -> Self

pub fn can_focus(self, can_focus: bool) -> Self

pub fn events(self, events: EventMask) -> Self

pub fn expand(self, expand: bool) -> Self

Whether to expand in both directions. Setting this sets both hexpand and vexpand

pub fn focus_on_click(self, focus_on_click: bool) -> Self

Whether the widget should grab focus when it is clicked with the mouse.

This property is only relevant for widgets that can take focus.

Before 3.20, several widgets (GtkButton, GtkFileChooserButton, GtkComboBox) implemented this property individually.

pub fn halign(self, halign: Align) -> Self

How to distribute horizontal space if widget gets extra space, see Align

pub fn has_default(self, has_default: bool) -> Self

pub fn has_focus(self, has_focus: bool) -> Self

pub fn has_tooltip(self, has_tooltip: bool) -> Self

Enables or disables the emission of query-tooltip on widget. A value of true indicates that widget can have a tooltip, in this case the widget will be queried using query-tooltip to determine whether it will provide a tooltip or not.

Note that setting this property to true for the first time will change the event masks of the GdkWindows of this widget to include leave-notify and motion-notify events. This cannot and will not be undone when the property is set to false again.

pub fn height_request(self, height_request: i32) -> Self

pub fn hexpand(self, hexpand: bool) -> Self

Whether to expand horizontally. See WidgetExt::set_hexpand().

pub fn hexpand_set(self, hexpand_set: bool) -> Self

Whether to use the hexpand property. See WidgetExt::is_hexpand_set().

pub fn is_focus(self, is_focus: bool) -> Self

pub fn margin(self, margin: i32) -> Self

Sets all four sides’ margin at once. If read, returns max margin on any side.

pub fn margin_bottom(self, margin_bottom: i32) -> Self

Margin on bottom side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_end(self, margin_end: i32) -> Self

Margin on end of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_start(self, margin_start: i32) -> Self

Margin on start of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_top(self, margin_top: i32) -> Self

Margin on top side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn name(self, name: impl Into<GString>) -> Self

pub fn no_show_all(self, no_show_all: bool) -> Self

pub fn opacity(self, opacity: f64) -> Self

The requested opacity of the widget. See WidgetExt::set_opacity() for more details about window opacity.

Before 3.8 this was only available in GtkWindow

pub fn parent(self, parent: &impl IsA<Container>) -> Self

pub fn receives_default(self, receives_default: bool) -> Self

pub fn sensitive(self, sensitive: bool) -> Self

pub fn tooltip_markup(self, tooltip_markup: impl Into<GString>) -> Self

Sets the text of tooltip to be the given string, which is marked up with the [Pango text markup language][PangoMarkupFormat]. Also see Tooltip::set_markup().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn tooltip_text(self, tooltip_text: impl Into<GString>) -> Self

Sets the text of tooltip to be the given string.

Also see Tooltip::set_text().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn valign(self, valign: Align) -> Self

How to distribute vertical space if widget gets extra space, see Align

pub fn vexpand(self, vexpand: bool) -> Self

Whether to expand vertically. See WidgetExt::set_vexpand().

pub fn vexpand_set(self, vexpand_set: bool) -> Self

Whether to use the vexpand property. See WidgetExt::is_vexpand_set().

pub fn visible(self, visible: bool) -> Self

pub fn width_request(self, width_request: i32) -> Self

pub fn build(self) -> AccelLabel

Build the AccelLabel.