AppChooserButtonBuilder

Struct AppChooserButtonBuilder 

pub struct AppChooserButtonBuilder { /* private fields */ }
A builder-pattern type to construct AppChooserButton objects.

Implementations

Source

impl AppChooserButtonBuilder

pub fn heading(self, heading: impl Into<GString>) -> Self

The text to show at the top of the dialog that can be opened from the button. The string may contain Pango markup.

pub fn show_default_item(self, show_default_item: bool) -> Self

The show-default-item property determines whether the dropdown menu should show the default application on top for the provided content type.

pub fn show_dialog_item(self, show_dialog_item: bool) -> Self

The show-dialog-item property determines whether the dropdown menu should show an item that triggers a AppChooserDialog when clicked.

pub fn active(self, active: i32) -> Self

The item which is currently active. If the model is a non-flat treemodel, and the active item is not an immediate child of the root of the tree, this property has the value gtk_tree_path_get_indices (path)[0], where path is the TreePath of the active item.

pub fn active_id(self, active_id: impl Into<GString>) -> Self

The value of the ID column of the active row.

pub fn button_sensitivity(self, button_sensitivity: SensitivityType) -> Self

Whether the dropdown button is sensitive when the model is empty.

pub fn cell_area(self, cell_area: &impl IsA<CellArea>) -> Self

The CellArea used to layout cell renderers for this combo box.

If no area is specified when creating the combo box with ComboBox::with_area() a horizontally oriented CellAreaBox will be used.

pub fn column_span_column(self, column_span_column: i32) -> Self

If this is set to a non-negative value, it must be the index of a column of type G_TYPE_INT in the model. The value in that column for each item will determine how many columns that item will span in the popup. Therefore, values in this column must be greater than zero, and the sum of an item’s column position + span should not exceed wrap-width.

pub fn entry_text_column(self, entry_text_column: i32) -> Self

The column in the combo box’s model to associate with strings from the entry if the combo was created with has-entry = true.

pub fn has_entry(self, has_entry: bool) -> Self

Whether the combo box has an entry.

pub fn has_frame(self, has_frame: bool) -> Self

The has-frame property controls whether a frame is drawn around the entry.

pub fn id_column(self, id_column: i32) -> Self

The column in the combo box’s model that provides string IDs for the values in the model, if != -1.

pub fn model(self, model: &impl IsA<TreeModel>) -> Self

The model from which the combo box takes the values shown in the list.

pub fn popup_fixed_width(self, popup_fixed_width: bool) -> Self

Whether the popup’s width should be a fixed width matching the allocated width of the combo box.

pub fn row_span_column(self, row_span_column: i32) -> Self

If this is set to a non-negative value, it must be the index of a column of type G_TYPE_INT in the model. The value in that column for each item will determine how many rows that item will span in the popup. Therefore, values in this column must be greater than zero.

pub fn wrap_width(self, wrap_width: i32) -> Self

If wrap-width is set to a positive value, items in the popup will be laid out along multiple columns, starting a new row on reaching the wrap width.

pub fn border_width(self, border_width: u32) -> Self

pub fn child(self, child: &impl IsA<Widget>) -> Self

pub fn resize_mode(self, resize_mode: ResizeMode) -> Self

pub fn app_paintable(self, app_paintable: bool) -> Self

pub fn can_default(self, can_default: bool) -> Self

pub fn can_focus(self, can_focus: bool) -> Self

pub fn events(self, events: EventMask) -> Self

pub fn expand(self, expand: bool) -> Self

Whether to expand in both directions. Setting this sets both hexpand and vexpand

pub fn focus_on_click(self, focus_on_click: bool) -> Self

Whether the widget should grab focus when it is clicked with the mouse.

This property is only relevant for widgets that can take focus.

Before 3.20, several widgets (GtkButton, GtkFileChooserButton, GtkComboBox) implemented this property individually.

pub fn halign(self, halign: Align) -> Self

How to distribute horizontal space if widget gets extra space, see Align

pub fn has_default(self, has_default: bool) -> Self

pub fn has_focus(self, has_focus: bool) -> Self

pub fn has_tooltip(self, has_tooltip: bool) -> Self

Enables or disables the emission of query-tooltip on widget. A value of true indicates that widget can have a tooltip, in this case the widget will be queried using query-tooltip to determine whether it will provide a tooltip or not.

Note that setting this property to true for the first time will change the event masks of the GdkWindows of this widget to include leave-notify and motion-notify events. This cannot and will not be undone when the property is set to false again.

pub fn height_request(self, height_request: i32) -> Self

pub fn hexpand(self, hexpand: bool) -> Self

Whether to expand horizontally. See WidgetExt::set_hexpand().

pub fn hexpand_set(self, hexpand_set: bool) -> Self

Whether to use the hexpand property. See WidgetExt::is_hexpand_set().

pub fn is_focus(self, is_focus: bool) -> Self

pub fn margin(self, margin: i32) -> Self

Sets all four sides’ margin at once. If read, returns max margin on any side.

pub fn margin_bottom(self, margin_bottom: i32) -> Self

Margin on bottom side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_end(self, margin_end: i32) -> Self

Margin on end of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_start(self, margin_start: i32) -> Self

Margin on start of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_top(self, margin_top: i32) -> Self

Margin on top side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn name(self, name: impl Into<GString>) -> Self

pub fn no_show_all(self, no_show_all: bool) -> Self

pub fn opacity(self, opacity: f64) -> Self

The requested opacity of the widget. See WidgetExt::set_opacity() for more details about window opacity.

Before 3.8 this was only available in GtkWindow

pub fn parent(self, parent: &impl IsA<Container>) -> Self

pub fn receives_default(self, receives_default: bool) -> Self

pub fn sensitive(self, sensitive: bool) -> Self

pub fn tooltip_markup(self, tooltip_markup: impl Into<GString>) -> Self

Sets the text of tooltip to be the given string, which is marked up with the [Pango text markup language][PangoMarkupFormat]. Also see Tooltip::set_markup().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn tooltip_text(self, tooltip_text: impl Into<GString>) -> Self

Sets the text of tooltip to be the given string.

Also see Tooltip::set_text().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn valign(self, valign: Align) -> Self

How to distribute vertical space if widget gets extra space, see Align

pub fn vexpand(self, vexpand: bool) -> Self

Whether to expand vertically. See WidgetExt::set_vexpand().

pub fn vexpand_set(self, vexpand_set: bool) -> Self

Whether to use the vexpand property. See WidgetExt::is_vexpand_set().

pub fn visible(self, visible: bool) -> Self

pub fn width_request(self, width_request: i32) -> Self

pub fn editing_canceled(self, editing_canceled: bool) -> Self

Indicates whether editing on the cell has been canceled.

pub fn content_type(self, content_type: impl Into<GString>) -> Self

The content type of the AppChooser object.

See [GContentType][gio-GContentType] for more information about content types.

pub fn build(self) -> AppChooserButton

Build the AppChooserButton.