pub struct CellRendererPixbufBuilder { /* private fields */ }Expand description
A builder-pattern type to construct CellRendererPixbuf objects.
Implementations
Sourceimpl CellRendererPixbufBuilder
impl CellRendererPixbufBuilder
Sourcepub fn gicon(self, gicon: &impl IsA<Icon>) -> Self
pub fn gicon(self, gicon: &impl IsA<Icon>) -> Self
The GIcon representing the icon to display. If the icon theme is changed, the image will be updated automatically.
Sourcepub fn icon_name(self, icon_name: impl Into<GString>) -> Self
pub fn icon_name(self, icon_name: impl Into<GString>) -> Self
The name of the themed icon to display. This property only has an effect if not overridden by “stock_id” or “pixbuf” properties.
pub fn pixbuf(self, pixbuf: &Pixbuf) -> Self
pub fn pixbuf_expander_closed(self, pixbuf_expander_closed: &Pixbuf) -> Self
pub fn pixbuf_expander_open(self, pixbuf_expander_open: &Pixbuf) -> Self
pub fn stock_detail(self, stock_detail: impl Into<GString>) -> Self
Sourcepub fn stock_size(self, stock_size: u32) -> Self
pub fn stock_size(self, stock_size: u32) -> Self
The IconSize value that specifies the size of the rendered icon.
pub fn surface(self, surface: &Surface) -> Self
pub fn cell_background(self, cell_background: impl Into<GString>) -> Self
Sourcepub fn cell_background_rgba(self, cell_background_rgba: &RGBA) -> Self
pub fn cell_background_rgba(self, cell_background_rgba: &RGBA) -> Self
Cell background as a gdk::RGBA
pub fn cell_background_set(self, cell_background_set: bool) -> Self
pub fn height(self, height: i32) -> Self
pub fn is_expanded(self, is_expanded: bool) -> Self
pub fn is_expander(self, is_expander: bool) -> Self
pub fn mode(self, mode: CellRendererMode) -> Self
pub fn sensitive(self, sensitive: bool) -> Self
pub fn visible(self, visible: bool) -> Self
pub fn width(self, width: i32) -> Self
pub fn xalign(self, xalign: f32) -> Self
pub fn xpad(self, xpad: u32) -> Self
pub fn yalign(self, yalign: f32) -> Self
pub fn ypad(self, ypad: u32) -> Self
Sourcepub fn build(self) -> CellRendererPixbuf
pub fn build(self) -> CellRendererPixbuf
Build the CellRendererPixbuf.