pub struct GestureStylusBuilder { /* private fields */ }Available on crate feature
v3_24 only.Expand description
A builder-pattern type to construct GestureStylus objects.
Implementations
Sourceimpl GestureStylusBuilder
impl GestureStylusBuilder
Mouse button number to listen to, or 0 to listen for any button.
Sourcepub fn exclusive(self, exclusive: bool) -> Self
pub fn exclusive(self, exclusive: bool) -> Self
Whether the gesture is exclusive. Exclusive gestures only listen to pointer and pointer emulated events.
Sourcepub fn touch_only(self, touch_only: bool) -> Self
pub fn touch_only(self, touch_only: bool) -> Self
Whether the gesture handles only touch events.
Sourcepub fn n_points(self, n_points: u32) -> Self
pub fn n_points(self, n_points: u32) -> Self
The number of touch points that trigger recognition on this gesture,
Sourcepub fn window(self, window: &Window) -> Self
pub fn window(self, window: &Window) -> Self
If non-None, the gesture will only listen for events that happen on
this gdk::Window, or a child of it.
Sourcepub fn propagation_phase(self, propagation_phase: PropagationPhase) -> Self
pub fn propagation_phase(self, propagation_phase: PropagationPhase) -> Self
The propagation phase at which this controller will handle events.
Sourcepub fn widget(self, widget: &impl IsA<Widget>) -> Self
pub fn widget(self, widget: &impl IsA<Widget>) -> Self
The widget receiving the GdkEvents that the controller will handle.
Sourcepub fn build(self) -> GestureStylus
pub fn build(self) -> GestureStylus
Build the GestureStylus.