LevelBarBuilder

Struct LevelBarBuilder 

pub struct LevelBarBuilder { /* private fields */ }
A builder-pattern type to construct LevelBar objects.

Implementations

Source

impl LevelBarBuilder

pub fn inverted(self, inverted: bool) -> Self

Level bars normally grow from top to bottom or left to right. Inverted level bars grow in the opposite direction.

pub fn max_value(self, max_value: f64) -> Self

The max-value property determaxes the maximum value of the interval that can be displayed by the bar.

pub fn min_value(self, min_value: f64) -> Self

The min-value property determines the minimum value of the interval that can be displayed by the bar.

pub fn mode(self, mode: LevelBarMode) -> Self

The mode property determines the way LevelBar interprets the value properties to draw the level fill area. Specifically, when the value is LevelBarMode::Continuous, LevelBar will draw a single block representing the current value in that area; when the value is LevelBarMode::Discrete, the widget will draw a succession of separate blocks filling the draw area, with the number of blocks being equal to the units separating the integral roundings of min-value and max-value.

pub fn value(self, value: f64) -> Self

The value property determines the currently filled value of the level bar.

pub fn app_paintable(self, app_paintable: bool) -> Self

pub fn can_default(self, can_default: bool) -> Self

pub fn can_focus(self, can_focus: bool) -> Self

pub fn events(self, events: EventMask) -> Self

pub fn expand(self, expand: bool) -> Self

Whether to expand in both directions. Setting this sets both hexpand and vexpand

pub fn focus_on_click(self, focus_on_click: bool) -> Self

Whether the widget should grab focus when it is clicked with the mouse.

This property is only relevant for widgets that can take focus.

Before 3.20, several widgets (GtkButton, GtkFileChooserButton, GtkComboBox) implemented this property individually.

pub fn halign(self, halign: Align) -> Self

How to distribute horizontal space if widget gets extra space, see Align

pub fn has_default(self, has_default: bool) -> Self

pub fn has_focus(self, has_focus: bool) -> Self

pub fn has_tooltip(self, has_tooltip: bool) -> Self

Enables or disables the emission of query-tooltip on widget. A value of true indicates that widget can have a tooltip, in this case the widget will be queried using query-tooltip to determine whether it will provide a tooltip or not.

Note that setting this property to true for the first time will change the event masks of the GdkWindows of this widget to include leave-notify and motion-notify events. This cannot and will not be undone when the property is set to false again.

pub fn height_request(self, height_request: i32) -> Self

pub fn hexpand(self, hexpand: bool) -> Self

Whether to expand horizontally. See WidgetExt::set_hexpand().

pub fn hexpand_set(self, hexpand_set: bool) -> Self

Whether to use the hexpand property. See WidgetExt::is_hexpand_set().

pub fn is_focus(self, is_focus: bool) -> Self

pub fn margin(self, margin: i32) -> Self

Sets all four sides’ margin at once. If read, returns max margin on any side.

pub fn margin_bottom(self, margin_bottom: i32) -> Self

Margin on bottom side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_end(self, margin_end: i32) -> Self

Margin on end of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_start(self, margin_start: i32) -> Self

Margin on start of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_top(self, margin_top: i32) -> Self

Margin on top side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn name(self, name: impl Into<GString>) -> Self

pub fn no_show_all(self, no_show_all: bool) -> Self

pub fn opacity(self, opacity: f64) -> Self

The requested opacity of the widget. See WidgetExt::set_opacity() for more details about window opacity.

Before 3.8 this was only available in GtkWindow

pub fn parent(self, parent: &impl IsA<Container>) -> Self

pub fn receives_default(self, receives_default: bool) -> Self

pub fn sensitive(self, sensitive: bool) -> Self

pub fn tooltip_markup(self, tooltip_markup: impl Into<GString>) -> Self

Sets the text of tooltip to be the given string, which is marked up with the [Pango text markup language][PangoMarkupFormat]. Also see Tooltip::set_markup().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn tooltip_text(self, tooltip_text: impl Into<GString>) -> Self

Sets the text of tooltip to be the given string.

Also see Tooltip::set_text().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn valign(self, valign: Align) -> Self

How to distribute vertical space if widget gets extra space, see Align

pub fn vexpand(self, vexpand: bool) -> Self

Whether to expand vertically. See WidgetExt::set_vexpand().

pub fn vexpand_set(self, vexpand_set: bool) -> Self

Whether to use the vexpand property. See WidgetExt::is_vexpand_set().

pub fn visible(self, visible: bool) -> Self

pub fn width_request(self, width_request: i32) -> Self

pub fn orientation(self, orientation: Orientation) -> Self

The orientation of the orientable.

pub fn build(self) -> LevelBar

Build the LevelBar.