ModelButtonBuilder

Struct ModelButtonBuilder 

pub struct ModelButtonBuilder { /* private fields */ }
A builder-pattern type to construct ModelButton objects.

Implementations

Source

impl ModelButtonBuilder

pub fn active(self, active: bool) -> Self

The state of the button. This is reflecting the state of the associated GAction.

pub fn centered(self, centered: bool) -> Self

Whether to render the button contents centered instead of left-aligned. This property should be set for title-like items.

pub fn icon(self, icon: &impl IsA<Icon>) -> Self

A gio::Icon that will be used if iconic appearance for the button is desired.

pub fn iconic(self, iconic: bool) -> Self

If this property is set, the button will show an icon if one is set. If no icon is set, the text will be used. This is typically used for horizontal sections of linked buttons.

pub fn inverted(self, inverted: bool) -> Self

Whether to show the submenu indicator at the opposite side than normal. This property should be set for model buttons that ‘go back’ to a parent menu.

pub fn menu_name(self, menu_name: impl Into<GString>) -> Self

The name of a submenu to open when the button is activated. If this is set, the button should not have an action associated with it.

pub fn role(self, role: ButtonRole) -> Self

Specifies whether the button is a plain, check or radio button. When action-name is set, the role will be determined from the action and does not have to be set explicitly.

pub fn text(self, text: impl Into<GString>) -> Self

The label for the button.

pub fn use_markup(self, use_markup: bool) -> Self

Available on crate feature v3_24 only.

If true, XML tags in the text of the button are interpreted as by pango_parse_markup() to format the enclosed spans of text. If false, the text will be displayed verbatim.

pub fn always_show_image(self, always_show_image: bool) -> Self

If true, the button will ignore the gtk-button-images setting and always show the image, if available.

Use this property if the button would be useless or hard to use without the image.

pub fn image(self, image: &impl IsA<Widget>) -> Self

The child widget to appear next to the button text.

pub fn image_position(self, image_position: PositionType) -> Self

The position of the image relative to the text inside the button.

pub fn label(self, label: impl Into<GString>) -> Self

pub fn relief(self, relief: ReliefStyle) -> Self

pub fn use_underline(self, use_underline: bool) -> Self

pub fn border_width(self, border_width: u32) -> Self

pub fn child(self, child: &impl IsA<Widget>) -> Self

pub fn resize_mode(self, resize_mode: ResizeMode) -> Self

pub fn app_paintable(self, app_paintable: bool) -> Self

pub fn can_default(self, can_default: bool) -> Self

pub fn can_focus(self, can_focus: bool) -> Self

pub fn events(self, events: EventMask) -> Self

pub fn expand(self, expand: bool) -> Self

Whether to expand in both directions. Setting this sets both hexpand and vexpand

pub fn focus_on_click(self, focus_on_click: bool) -> Self

Whether the widget should grab focus when it is clicked with the mouse.

This property is only relevant for widgets that can take focus.

Before 3.20, several widgets (GtkButton, GtkFileChooserButton, GtkComboBox) implemented this property individually.

pub fn halign(self, halign: Align) -> Self

How to distribute horizontal space if widget gets extra space, see Align

pub fn has_default(self, has_default: bool) -> Self

pub fn has_focus(self, has_focus: bool) -> Self

pub fn has_tooltip(self, has_tooltip: bool) -> Self

Enables or disables the emission of query-tooltip on widget. A value of true indicates that widget can have a tooltip, in this case the widget will be queried using query-tooltip to determine whether it will provide a tooltip or not.

Note that setting this property to true for the first time will change the event masks of the GdkWindows of this widget to include leave-notify and motion-notify events. This cannot and will not be undone when the property is set to false again.

pub fn height_request(self, height_request: i32) -> Self

pub fn hexpand(self, hexpand: bool) -> Self

Whether to expand horizontally. See WidgetExt::set_hexpand().

pub fn hexpand_set(self, hexpand_set: bool) -> Self

Whether to use the hexpand property. See WidgetExt::is_hexpand_set().

pub fn is_focus(self, is_focus: bool) -> Self

pub fn margin(self, margin: i32) -> Self

Sets all four sides’ margin at once. If read, returns max margin on any side.

pub fn margin_bottom(self, margin_bottom: i32) -> Self

Margin on bottom side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_end(self, margin_end: i32) -> Self

Margin on end of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_start(self, margin_start: i32) -> Self

Margin on start of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_top(self, margin_top: i32) -> Self

Margin on top side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn name(self, name: impl Into<GString>) -> Self

pub fn no_show_all(self, no_show_all: bool) -> Self

pub fn opacity(self, opacity: f64) -> Self

The requested opacity of the widget. See WidgetExt::set_opacity() for more details about window opacity.

Before 3.8 this was only available in GtkWindow

pub fn parent(self, parent: &impl IsA<Container>) -> Self

pub fn receives_default(self, receives_default: bool) -> Self

pub fn sensitive(self, sensitive: bool) -> Self

pub fn tooltip_markup(self, tooltip_markup: impl Into<GString>) -> Self

Sets the text of tooltip to be the given string, which is marked up with the [Pango text markup language][PangoMarkupFormat]. Also see Tooltip::set_markup().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn tooltip_text(self, tooltip_text: impl Into<GString>) -> Self

Sets the text of tooltip to be the given string.

Also see Tooltip::set_text().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn valign(self, valign: Align) -> Self

How to distribute vertical space if widget gets extra space, see Align

pub fn vexpand(self, vexpand: bool) -> Self

Whether to expand vertically. See WidgetExt::set_vexpand().

pub fn vexpand_set(self, vexpand_set: bool) -> Self

Whether to use the vexpand property. See WidgetExt::is_vexpand_set().

pub fn visible(self, visible: bool) -> Self

pub fn width_request(self, width_request: i32) -> Self

pub fn action_name(self, action_name: impl Into<GString>) -> Self

pub fn action_target(self, action_target: &Variant) -> Self

pub fn build(self) -> ModelButton

Build the ModelButton.