PlugAccessibleBuilder

Struct PlugAccessibleBuilder 

pub struct PlugAccessibleBuilder { /* private fields */ }
Available on gdk_backend=x11 and crate feature v3_24_30 only.
A builder-pattern type to construct PlugAccessible objects.

Implementations

Source

impl PlugAccessibleBuilder

pub fn accessible_description( self, accessible_description: impl Into<GString>, ) -> Self

pub fn accessible_help_text( self, accessible_help_text: impl Into<GString>, ) -> Self

pub fn accessible_id(self, accessible_id: impl Into<GString>) -> Self

pub fn accessible_name(self, accessible_name: impl Into<GString>) -> Self

pub fn accessible_parent(self, accessible_parent: &impl IsA<Object>) -> Self

pub fn accessible_role(self, accessible_role: Role) -> Self

pub fn accessible_table_caption( self, accessible_table_caption: impl Into<GString>, ) -> Self

Table caption. Since 1.3. Use table-caption-object instead.

pub fn accessible_table_caption_object( self, accessible_table_caption_object: &impl IsA<Object>, ) -> Self

pub fn accessible_table_column_description( self, accessible_table_column_description: impl Into<GString>, ) -> Self

Accessible table column description. Since 2.12. Use atk_table_get_column_description() and atk_table_set_column_description() instead.

pub fn accessible_table_column_header( self, accessible_table_column_header: &impl IsA<Object>, ) -> Self

Accessible table column header. Since 2.12. Use atk_table_get_column_header() and atk_table_set_column_header() instead.

pub fn accessible_table_row_description( self, accessible_table_row_description: impl Into<GString>, ) -> Self

Accessible table row description. Since 2.12. Use atk_table_get_row_description() and atk_table_set_row_description() instead.

pub fn accessible_table_row_header( self, accessible_table_row_header: &impl IsA<Object>, ) -> Self

Accessible table row header. Since 2.12. Use atk_table_get_row_header() and atk_table_set_row_header() instead.

pub fn accessible_table_summary( self, accessible_table_summary: &impl IsA<Object>, ) -> Self

pub fn accessible_value(self, accessible_value: f64) -> Self

Numeric value of this object, in case being and AtkValue. Since 2.12. Use atk_value_get_value_and_text() to get the value, and value-changed signal to be notified on their value changes.

pub fn build(self) -> PlugAccessible

Build the PlugAccessible.