pub struct RecentManagerBuilder { /* private fields */ }Expand description
A builder-pattern type to construct RecentManager objects.
Implementations
Sourceimpl RecentManagerBuilder
impl RecentManagerBuilder
Sourcepub fn filename(self, filename: impl Into<GString>) -> Self
pub fn filename(self, filename: impl Into<GString>) -> Self
The full path to the file to be used to store and read the recently used resources list
Sourcepub fn build(self) -> RecentManager
pub fn build(self) -> RecentManager
Build the RecentManager.