ShortcutsShortcutBuilder

Struct ShortcutsShortcutBuilder 

pub struct ShortcutsShortcutBuilder { /* private fields */ }
A builder-pattern type to construct ShortcutsShortcut objects.

Implementations

Source

impl ShortcutsShortcutBuilder

pub fn accel_size_group(self, accel_size_group: &impl IsA<SizeGroup>) -> Self

The size group for the accelerator portion of this shortcut.

This is used internally by GTK+, and must not be modified by applications.

pub fn accelerator(self, accelerator: impl Into<GString>) -> Self

The accelerator(s) represented by this object. This property is used if shortcut-type is set to ShortcutType::Accelerator.

The syntax of this property is (an extension of) the syntax understood by accelerator_parse(). Multiple accelerators can be specified by separating them with a space, but keep in mind that the available width is limited. It is also possible to specify ranges of shortcuts, using ... between the keys. Sequences of keys can be specified using a + or & between the keys.

Examples:

  • A single shortcut: <ctl>delete
  • Two alternative shortcuts: ``a Home
  • A range of shortcuts: ``1...9
  • Several keys pressed together: Control_L&Control_R
  • A sequence of shortcuts or keys: ``c+x

Use + instead of & when the keys may (or have to be) pressed sequentially (e.g use t+t for ‘press the t key twice’).

Note that <, > and & need to be escaped as <, > and & when used in .ui files.

pub fn action_name(self, action_name: impl Into<GString>) -> Self

A detailed action name. If this is set for a shortcut of type ShortcutType::Accelerator, then GTK+ will use the accelerators that are associated with the action via GtkApplicationExt::set_accels_for_action(), and setting accelerator is not necessary.

pub fn direction(self, direction: TextDirection) -> Self

The text direction for which this shortcut is active. If the shortcut is used regardless of the text direction, set this property to TextDirection::None.

pub fn icon(self, icon: &impl IsA<Icon>) -> Self

An icon to represent the shortcut or gesture. This property is used if shortcut-type is set to ShortcutType::Gesture. For the other predefined gesture types, GTK+ provides an icon on its own.

pub fn icon_set(self, icon_set: bool) -> Self

true if an icon has been set.

pub fn shortcut_type(self, shortcut_type: ShortcutType) -> Self

The type of shortcut that is represented.

pub fn subtitle(self, subtitle: impl Into<GString>) -> Self

The subtitle for the shortcut or gesture.

This is typically used for gestures and should be a short, one-line text that describes the gesture itself. For the predefined gesture types, GTK+ provides a subtitle on its own.

pub fn subtitle_set(self, subtitle_set: bool) -> Self

true if a subtitle has been set.

pub fn title(self, title: impl Into<GString>) -> Self

The textual description for the shortcut or gesture represented by this object. This should be a short string that can fit in a single line.

pub fn title_size_group(self, title_size_group: &impl IsA<SizeGroup>) -> Self

The size group for the textual portion of this shortcut.

This is used internally by GTK+, and must not be modified by applications.

pub fn baseline_position(self, baseline_position: BaselinePosition) -> Self

pub fn homogeneous(self, homogeneous: bool) -> Self

pub fn spacing(self, spacing: i32) -> Self

pub fn border_width(self, border_width: u32) -> Self

pub fn child(self, child: &impl IsA<Widget>) -> Self

pub fn resize_mode(self, resize_mode: ResizeMode) -> Self

pub fn app_paintable(self, app_paintable: bool) -> Self

pub fn can_default(self, can_default: bool) -> Self

pub fn can_focus(self, can_focus: bool) -> Self

pub fn events(self, events: EventMask) -> Self

pub fn expand(self, expand: bool) -> Self

Whether to expand in both directions. Setting this sets both hexpand and vexpand

pub fn focus_on_click(self, focus_on_click: bool) -> Self

Whether the widget should grab focus when it is clicked with the mouse.

This property is only relevant for widgets that can take focus.

Before 3.20, several widgets (GtkButton, GtkFileChooserButton, GtkComboBox) implemented this property individually.

pub fn halign(self, halign: Align) -> Self

How to distribute horizontal space if widget gets extra space, see Align

pub fn has_default(self, has_default: bool) -> Self

pub fn has_focus(self, has_focus: bool) -> Self

pub fn has_tooltip(self, has_tooltip: bool) -> Self

Enables or disables the emission of query-tooltip on widget. A value of true indicates that widget can have a tooltip, in this case the widget will be queried using query-tooltip to determine whether it will provide a tooltip or not.

Note that setting this property to true for the first time will change the event masks of the GdkWindows of this widget to include leave-notify and motion-notify events. This cannot and will not be undone when the property is set to false again.

pub fn height_request(self, height_request: i32) -> Self

pub fn hexpand(self, hexpand: bool) -> Self

Whether to expand horizontally. See WidgetExt::set_hexpand().

pub fn hexpand_set(self, hexpand_set: bool) -> Self

Whether to use the hexpand property. See WidgetExt::is_hexpand_set().

pub fn is_focus(self, is_focus: bool) -> Self

pub fn margin(self, margin: i32) -> Self

Sets all four sides’ margin at once. If read, returns max margin on any side.

pub fn margin_bottom(self, margin_bottom: i32) -> Self

Margin on bottom side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_end(self, margin_end: i32) -> Self

Margin on end of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_start(self, margin_start: i32) -> Self

Margin on start of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_top(self, margin_top: i32) -> Self

Margin on top side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn name(self, name: impl Into<GString>) -> Self

pub fn no_show_all(self, no_show_all: bool) -> Self

pub fn opacity(self, opacity: f64) -> Self

The requested opacity of the widget. See WidgetExt::set_opacity() for more details about window opacity.

Before 3.8 this was only available in GtkWindow

pub fn parent(self, parent: &impl IsA<Container>) -> Self

pub fn receives_default(self, receives_default: bool) -> Self

pub fn sensitive(self, sensitive: bool) -> Self

pub fn tooltip_markup(self, tooltip_markup: impl Into<GString>) -> Self

Sets the text of tooltip to be the given string, which is marked up with the [Pango text markup language][PangoMarkupFormat]. Also see Tooltip::set_markup().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn tooltip_text(self, tooltip_text: impl Into<GString>) -> Self

Sets the text of tooltip to be the given string.

Also see Tooltip::set_text().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn valign(self, valign: Align) -> Self

How to distribute vertical space if widget gets extra space, see Align

pub fn vexpand(self, vexpand: bool) -> Self

Whether to expand vertically. See WidgetExt::set_vexpand().

pub fn vexpand_set(self, vexpand_set: bool) -> Self

Whether to use the vexpand property. See WidgetExt::is_vexpand_set().

pub fn visible(self, visible: bool) -> Self

pub fn width_request(self, width_request: i32) -> Self

pub fn orientation(self, orientation: Orientation) -> Self

The orientation of the orientable.

pub fn build(self) -> ShortcutsShortcut

Build the ShortcutsShortcut.