TextViewBuilder

Struct TextViewBuilder 

pub struct TextViewBuilder { /* private fields */ }
A builder-pattern type to construct TextView objects.

Implementations

Source

impl TextViewBuilder

pub fn accepts_tab(self, accepts_tab: bool) -> Self

pub fn bottom_margin(self, bottom_margin: i32) -> Self

The bottom margin for text in the text view.

Note that this property is confusingly named. In CSS terms, the value set here is padding, and it is applied in addition to the padding from the theme.

Don’t confuse this property with margin-bottom.

pub fn buffer(self, buffer: &impl IsA<TextBuffer>) -> Self

pub fn cursor_visible(self, cursor_visible: bool) -> Self

pub fn editable(self, editable: bool) -> Self

pub fn im_module(self, im_module: impl Into<GString>) -> Self

Which IM (input method) module should be used for this text_view. See IMContext.

Setting this to a non-None value overrides the system-wide IM module setting. See the GtkSettings gtk-im-module property.

pub fn indent(self, indent: i32) -> Self

pub fn input_hints(self, input_hints: InputHints) -> Self

Additional hints (beyond input-purpose) that allow input methods to fine-tune their behaviour.

pub fn input_purpose(self, input_purpose: InputPurpose) -> Self

The purpose of this text field.

This property can be used by on-screen keyboards and other input methods to adjust their behaviour.

pub fn justification(self, justification: Justification) -> Self

pub fn left_margin(self, left_margin: i32) -> Self

The default left margin for text in the text view. Tags in the buffer may override the default.

Note that this property is confusingly named. In CSS terms, the value set here is padding, and it is applied in addition to the padding from the theme.

Don’t confuse this property with margin-left.

pub fn monospace(self, monospace: bool) -> Self

pub fn overwrite(self, overwrite: bool) -> Self

pub fn pixels_above_lines(self, pixels_above_lines: i32) -> Self

pub fn pixels_below_lines(self, pixels_below_lines: i32) -> Self

pub fn pixels_inside_wrap(self, pixels_inside_wrap: i32) -> Self

pub fn populate_all(self, populate_all: bool) -> Self

If :populate-all is true, the populate-popup signal is also emitted for touch popups.

pub fn right_margin(self, right_margin: i32) -> Self

The default right margin for text in the text view. Tags in the buffer may override the default.

Note that this property is confusingly named. In CSS terms, the value set here is padding, and it is applied in addition to the padding from the theme.

Don’t confuse this property with margin-right.

pub fn tabs(self, tabs: &TabArray) -> Self

pub fn top_margin(self, top_margin: i32) -> Self

The top margin for text in the text view.

Note that this property is confusingly named. In CSS terms, the value set here is padding, and it is applied in addition to the padding from the theme.

Don’t confuse this property with margin-top.

pub fn wrap_mode(self, wrap_mode: WrapMode) -> Self

pub fn border_width(self, border_width: u32) -> Self

pub fn child(self, child: &impl IsA<Widget>) -> Self

pub fn resize_mode(self, resize_mode: ResizeMode) -> Self

pub fn app_paintable(self, app_paintable: bool) -> Self

pub fn can_default(self, can_default: bool) -> Self

pub fn can_focus(self, can_focus: bool) -> Self

pub fn events(self, events: EventMask) -> Self

pub fn expand(self, expand: bool) -> Self

Whether to expand in both directions. Setting this sets both hexpand and vexpand

pub fn focus_on_click(self, focus_on_click: bool) -> Self

Whether the widget should grab focus when it is clicked with the mouse.

This property is only relevant for widgets that can take focus.

Before 3.20, several widgets (GtkButton, GtkFileChooserButton, GtkComboBox) implemented this property individually.

pub fn halign(self, halign: Align) -> Self

How to distribute horizontal space if widget gets extra space, see Align

pub fn has_default(self, has_default: bool) -> Self

pub fn has_focus(self, has_focus: bool) -> Self

pub fn has_tooltip(self, has_tooltip: bool) -> Self

Enables or disables the emission of query-tooltip on widget. A value of true indicates that widget can have a tooltip, in this case the widget will be queried using query-tooltip to determine whether it will provide a tooltip or not.

Note that setting this property to true for the first time will change the event masks of the GdkWindows of this widget to include leave-notify and motion-notify events. This cannot and will not be undone when the property is set to false again.

pub fn height_request(self, height_request: i32) -> Self

pub fn hexpand(self, hexpand: bool) -> Self

Whether to expand horizontally. See WidgetExt::set_hexpand().

pub fn hexpand_set(self, hexpand_set: bool) -> Self

Whether to use the hexpand property. See WidgetExt::is_hexpand_set().

pub fn is_focus(self, is_focus: bool) -> Self

pub fn margin(self, margin: i32) -> Self

Sets all four sides’ margin at once. If read, returns max margin on any side.

pub fn margin_bottom(self, margin_bottom: i32) -> Self

Margin on bottom side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_end(self, margin_end: i32) -> Self

Margin on end of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_start(self, margin_start: i32) -> Self

Margin on start of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_top(self, margin_top: i32) -> Self

Margin on top side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn name(self, name: impl Into<GString>) -> Self

pub fn no_show_all(self, no_show_all: bool) -> Self

pub fn opacity(self, opacity: f64) -> Self

The requested opacity of the widget. See WidgetExt::set_opacity() for more details about window opacity.

Before 3.8 this was only available in GtkWindow

pub fn parent(self, parent: &impl IsA<Container>) -> Self

pub fn receives_default(self, receives_default: bool) -> Self

pub fn sensitive(self, sensitive: bool) -> Self

pub fn tooltip_markup(self, tooltip_markup: impl Into<GString>) -> Self

Sets the text of tooltip to be the given string, which is marked up with the [Pango text markup language][PangoMarkupFormat]. Also see Tooltip::set_markup().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn tooltip_text(self, tooltip_text: impl Into<GString>) -> Self

Sets the text of tooltip to be the given string.

Also see Tooltip::set_text().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn valign(self, valign: Align) -> Self

How to distribute vertical space if widget gets extra space, see Align

pub fn vexpand(self, vexpand: bool) -> Self

Whether to expand vertically. See WidgetExt::set_vexpand().

pub fn vexpand_set(self, vexpand_set: bool) -> Self

Whether to use the vexpand property. See WidgetExt::is_vexpand_set().

pub fn visible(self, visible: bool) -> Self

pub fn width_request(self, width_request: i32) -> Self

pub fn hadjustment(self, hadjustment: &impl IsA<Adjustment>) -> Self

Horizontal Adjustment of the scrollable widget. This adjustment is shared between the scrollable widget and its parent.

pub fn hscroll_policy(self, hscroll_policy: ScrollablePolicy) -> Self

Determines whether horizontal scrolling should start once the scrollable widget is allocated less than its minimum width or less than its natural width.

pub fn vadjustment(self, vadjustment: &impl IsA<Adjustment>) -> Self

Verical Adjustment of the scrollable widget. This adjustment is shared between the scrollable widget and its parent.

pub fn vscroll_policy(self, vscroll_policy: ScrollablePolicy) -> Self

Determines whether vertical scrolling should start once the scrollable widget is allocated less than its minimum height or less than its natural height.

pub fn build(self) -> TextView

Build the TextView.