#[non_exhaustive]pub enum ButtonBoxStyle {
Spread,
Edge,
Start,
End,
Center,
Expand,
}Expand description
Used to dictate the style that a ButtonBox uses to layout the buttons it
contains.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Spread
Buttons are evenly spread across the box.
Edge
Buttons are placed at the edges of the box.
Start
Buttons are grouped towards the start of the box, (on the left for a HBox, or the top for a VBox).
End
Buttons are grouped towards the end of the box, (on the right for a HBox, or the bottom for a VBox).
Center
Buttons are centered in the box. Since 2.12.
Expand
Buttons expand to fill the box. This entails giving
buttons a “linked” appearance, making button sizes homogeneous, and
setting spacing to 0 (same as calling BoxExt::set_homogeneous() and
BoxExt::set_spacing() manually). Since 3.12.