#[non_exhaustive]pub enum CssSectionType {
Document,
Import,
ColorDefinition,
BindingSet,
Ruleset,
Selector,
Declaration,
Value,
Keyframes,
}Expand description
The different types of sections indicate parts of a CSS document as parsed by GTK’s CSS parser. They are oriented towards the CSS Grammar, but may contain extensions.
More types might be added in the future as the parser incorporates more features.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Document
The section describes a complete document.
This section time is the only one where CssSection::parent()
might return None.
Import
The section defines an import rule.
ColorDefinition
The section defines a color. This is a GTK extension to CSS.
BindingSet
The section defines a binding set. This is a GTK extension to CSS.
Ruleset
The section defines a CSS ruleset.
Selector
The section defines a CSS selector.
Declaration
The section defines the declaration of a CSS variable.
Value
The section defines the value of a CSS declaration.
Keyframes
The section defines keyframes. See CSS Animations for details. Since 3.6