#[non_exhaustive]pub enum DragResult {
Success,
NoTarget,
UserCancelled,
TimeoutExpired,
GrabBroken,
Error,
}Expand description
Gives an indication why a drag operation failed.
The value can by obtained by connecting to the
drag-failed signal.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Success
The drag operation was successful.
NoTarget
No suitable drag target.
UserCancelled
The user cancelled the drag operation.
TimeoutExpired
The drag operation timed out.
GrabBroken
The pointer or keyboard grab used for the drag operation was broken.
Error
The drag operation failed due to some unspecified error.