#[non_exhaustive]pub enum ImageType {
Empty,
Pixbuf,
Stock,
IconSet,
Animation,
IconName,
Gicon,
Surface,
}Expand description
Describes the image data representation used by a Image. If you
want to get the image from the widget, you can only get the
currently-stored representation. e.g. if the
ImageExt::storage_type() returns Pixbuf, then you can
call ImageExt::pixbuf() but not gtk_image_get_stock(). For empty
images, you can request any storage type (call any of the “get”
functions), but they will all return None values.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Empty
there is no image displayed by the widget
Pixbuf
the widget contains a gdk_pixbuf::Pixbuf
Stock
the widget contains a [stock item name][gtkstock]
IconSet
the widget contains a GtkIconSet
Animation
the widget contains a gdk_pixbuf::PixbufAnimation
IconName
the widget contains a named icon. This image type was added in GTK+ 2.6
Gicon
the widget contains a gio::Icon.
This image type was added in GTK+ 2.14
Surface
the widget contains a cairo::Surface.
This image type was added in GTK+ 3.10