#[non_exhaustive]pub enum PopoverConstraint {
None,
Window,
}Expand description
Describes constraints to positioning of popovers. More values may be added to this enumeration in the future.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
Don’t constrain the popover position beyond what is imposed by the implementation
Window
Constrain the popover to the boundaries of the window that it is attached to