#[non_exhaustive]pub enum ShortcutType {
Accelerator,
GesturePinch,
GestureStretch,
GestureRotateClockwise,
GestureRotateCounterclockwise,
GestureTwoFingerSwipeLeft,
GestureTwoFingerSwipeRight,
Gesture,
}Expand description
GtkShortcutType specifies the kind of shortcut that is being described. More values may be added to this enumeration over time.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Accelerator
The shortcut is a keyboard accelerator. The accelerator
property will be used.
GesturePinch
The shortcut is a pinch gesture. GTK+ provides an icon and subtitle.
GestureStretch
The shortcut is a stretch gesture. GTK+ provides an icon and subtitle.
GestureRotateClockwise
The shortcut is a clockwise rotation gesture. GTK+ provides an icon and subtitle.
GestureRotateCounterclockwise
The shortcut is a counterclockwise rotation gesture. GTK+ provides an icon and subtitle.
GestureTwoFingerSwipeLeft
The shortcut is a two-finger swipe gesture. GTK+ provides an icon and subtitle.
GestureTwoFingerSwipeRight
The shortcut is a two-finger swipe gesture. GTK+ provides an icon and subtitle.
Gesture
The shortcut is a gesture. The icon property will be
used.