#[non_exhaustive]pub enum StackTransitionType {
Show 20 variants
None,
Crossfade,
SlideRight,
SlideLeft,
SlideUp,
SlideDown,
SlideLeftRight,
SlideUpDown,
OverUp,
OverDown,
OverLeft,
OverRight,
UnderUp,
UnderDown,
UnderLeft,
UnderRight,
OverUpDown,
OverDownUp,
OverLeftRight,
OverRightLeft,
}Expand description
These enumeration values describe the possible transitions
between pages in a Stack widget.
New values may be added to this enumeration over time.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
None
No transition
Crossfade
A cross-fade
SlideRight
Slide from left to right
SlideLeft
Slide from right to left
SlideUp
Slide from bottom up
SlideDown
Slide from top down
SlideLeftRight
Slide from left or right according to the children order
SlideUpDown
Slide from top down or bottom up according to the order
OverUp
Cover the old page by sliding up. Since 3.12
OverDown
Cover the old page by sliding down. Since: 3.12
OverLeft
Cover the old page by sliding to the left. Since: 3.12
OverRight
Cover the old page by sliding to the right. Since: 3.12
UnderUp
Uncover the new page by sliding up. Since 3.12
UnderDown
Uncover the new page by sliding down. Since: 3.12
UnderLeft
Uncover the new page by sliding to the left. Since: 3.12
UnderRight
Uncover the new page by sliding to the right. Since: 3.12
OverUpDown
Cover the old page sliding up or uncover the new page sliding down, according to order. Since: 3.12
OverDownUp
Cover the old page sliding down or uncover the new page sliding up, according to order. Since: 3.14
OverLeftRight
Cover the old page sliding left or uncover the new page sliding right, according to order. Since: 3.14
OverRightLeft
Cover the old page sliding right or uncover the new page sliding left, according to order. Since: 3.14