accelerator_key
accelerator_mods
pub fn accelerator_get_label( accelerator_key: u32, accelerator_mods: ModifierType, ) -> Option<GString>
Converts an accelerator keyval and modifier mask into a string which can be used to represent the accelerator to the user.
accelerator keyval
accelerator modifier mask
a newly-allocated string representing the accelerator.