accelerator_get_label_with_keycode

Function accelerator_get_label_with_keycode 

pub fn accelerator_get_label_with_keycode(
    display: Option<&Display>,
    accelerator_key: u32,
    keycode: u32,
    accelerator_mods: ModifierType,
) -> Option<GString>
Converts an accelerator keyval and modifier mask into a (possibly translated) string that can be displayed to a user, similarly to accelerator_get_label(), but handling keycodes.

This is only useful for system-level components, applications should use accelerator_parse() instead.

display

a gdk::Display or None to use the default display

accelerator_key

accelerator keyval

keycode

accelerator keycode

accelerator_mods

accelerator modifier mask

Returns

a newly-allocated string representing the accelerator.