accelerator_parse_with_keycode

Function accelerator_parse_with_keycode 

pub fn accelerator_parse_with_keycode(
    accelerator: &str,
) -> Option<(u32, Slice<u32>, ModifierType)>
Parses a string representing an accelerator, similarly to accelerator_parse() but handles keycodes as well. This is only useful for system-level components, applications should use accelerator_parse() instead.

If accelerator_codes is given and the result stored in it is non-None, the result must be freed with g_free().

If a keycode is present in the accelerator and no accelerator_codes is given, the parse will fail.

If the parse fails, accelerator_key, accelerator_mods and accelerator_codes will be set to 0 (zero).

accelerator

string representing an accelerator

Returns

accelerator_key

return location for accelerator keyval, or None

accelerator_codes

return location for accelerator keycodes, or None

accelerator_mods

return location for accelerator modifier mask, None