bindings_activate_event

Function bindings_activate_event 

pub fn bindings_activate_event(
    object: &impl IsA<Object>,
    event: &mut EventKey,
) -> bool
Looks up key bindings for object to find one matching event, and if one was found, activate it.

object

a glib::Object (generally must be a widget)

event

a gdk::EventKey

Returns

true if a matching key binding was found