cairo_transform_to_window

Function cairo_transform_to_window 

pub fn cairo_transform_to_window(
    cr: &Context,
    widget: &impl IsA<Widget>,
    window: &Window,
)
Transforms the given cairo context cr that from widget-relative coordinates to window-relative coordinates. If the widget’s window is not an ancestor of window, no modification will be applied.

This is the inverse to the transformation GTK applies when preparing an expose event to be emitted with the draw signal. It is intended to help porting multiwindow widgets from GTK+ 2 to the rendering architecture of GTK+ 3.

cr

the cairo context to transform

widget

the widget the context is currently centered for

window

the window to transform the context to