pub fn current_event() -> Option<Event>Expand description
Obtains a copy of the event currently being processed by GTK+.
For example, if you are handling a clicked signal,
the current event will be the gdk::EventButton that triggered
the ::clicked signal.
Returns
a copy of the current event, or
None if there is no current event. The returned event must be
freed with gdk_event_free().