current_event_device

Function current_event_device 

pub fn current_event_device() -> Option<Device>
If there is a current event and it has a device, return that device, otherwise return None.

Returns

a gdk::Device, or None