device_grab_add

Function device_grab_add 

pub fn device_grab_add(
    widget: &impl IsA<Widget>,
    device: &Device,
    block_others: bool,
)
Adds a GTK+ grab on device, so all the events on device and its associated pointer or keyboard (if any) are delivered to widget. If the block_others parameter is true, any other devices will be unable to interact with widget during the grab.

widget

a Widget

device

a gdk::Device to grab on.

block_others

true to prevent other devices to interact with widget.