event_widget

Function event_widget 

pub fn event_widget(event: &mut Event) -> Option<Widget>
If event is None or the event was not associated with any widget, returns None, otherwise returns the widget that received the event originally.

event

a GdkEvent

Returns

the widget that originally received event, or None