grab_get_current

Function grab_get_current 

pub fn grab_get_current() -> Option<Widget>
Queries the current grab of the default window group.

Returns

The widget which currently has the grab or None if no grab is active