render_expander

Function render_expander 

pub fn render_expander(
    context: &impl IsA<StyleContext>,
    cr: &Context,
    x: f64,
    y: f64,
    width: f64,
    height: f64,
)
Renders an expander (as used in TreeView and Expander) in the area defined by x, y, width, height. The state StateFlags::CHECKED determines whether the expander is collapsed or expanded.

Typical expander rendering:

context

a StyleContext

cr

a cairo::Context

x

X origin of the rectangle

y

Y origin of the rectangle

width

rectangle width

height

rectangle height