render_extension

Function render_extension 

pub fn render_extension(
    context: &impl IsA<StyleContext>,
    cr: &Context,
    x: f64,
    y: f64,
    width: f64,
    height: f64,
    gap_side: PositionType,
)
Renders a extension (as in a Notebook tab) in the rectangle defined by x, y, width, height. The side where the extension connects to is defined by gap_side.

Typical extension rendering:

context

a StyleContext

cr

a cairo::Context

x

X origin of the rectangle

y

Y origin of the rectangle

width

rectangle width

height

rectangle height

gap_side

side where the gap is