render_frame_gap

Function render_frame_gap 

pub fn render_frame_gap(
    context: &impl IsA<StyleContext>,
    cr: &Context,
    x: f64,
    y: f64,
    width: f64,
    height: f64,
    gap_side: PositionType,
    xy0_gap: f64,
    xy1_gap: f64,
)
👎Deprecated:

Since 3.24

Renders a frame around the rectangle defined by (x, y, width, height), leaving a gap on one side. xy0_gap and xy1_gap will mean X coordinates for PositionType::Top and PositionType::Bottom gap sides, and Y coordinates for PositionType::Left and PositionType::Right.

Typical rendering of a frame with a gap:

Deprecated since 3.24

Use render_frame() instead. Themes can create gaps by omitting borders via CSS.

context

a StyleContext

cr

a cairo::Context

x

X origin of the rectangle

y

Y origin of the rectangle

width

rectangle width

height

rectangle height

gap_side

side where the gap is

xy0_gap

initial coordinate (X or Y depending on gap_side) for the gap

xy1_gap

end coordinate (X or Y depending on gap_side) for the gap