render_slider

Function render_slider 

pub fn render_slider(
    context: &impl IsA<StyleContext>,
    cr: &Context,
    x: f64,
    y: f64,
    width: f64,
    height: f64,
    orientation: Orientation,
)
Renders a slider (as in Scale) in the rectangle defined by x, y, width, height. orientation defines whether the slider is vertical or horizontal.

Typical slider rendering:

context

a StyleContext

cr

a cairo::Context

x

X origin of the rectangle

y

Y origin of the rectangle

width

rectangle width

height

rectangle height

orientation

orientation of the slider