selection_add_target

Function selection_add_target 

pub fn selection_add_target(
    widget: &impl IsA<Widget>,
    selection: &Atom,
    target: &Atom,
    info: u32,
)
Appends a specified target to the list of supported targets for a given widget and selection.

widget

a Widget

selection

the selection

target

target to add.

info

A unsigned integer which will be passed back to the application.