selection_owner_set

Function selection_owner_set 

pub fn selection_owner_set(
    widget: Option<&impl IsA<Widget>>,
    selection: &Atom,
    time_: u32,
) -> bool
Claims ownership of a given selection for a particular widget, or, if widget is None, release ownership of the selection.

widget

a Widget, or None.

selection

an interned atom representing the selection to claim

time_

timestamp with which to claim the selection

Returns

true if the operation succeeded