selection_remove_all

Function selection_remove_all 

pub fn selection_remove_all(widget: &impl IsA<Widget>)
Removes all handlers and unsets ownership of all selections for a widget. Called when widget is being destroyed. This function will not generally be called by applications.

widget

a Widget