pub fn targets_include_image(targets: &[Atom], writable: bool) -> boolExpand description
Determines if any of the targets in targets can be used to
provide a gdk_pixbuf::Pixbuf.
targets
an array of GdkAtoms
writable
whether to accept only targets for which GTK+ knows how to convert a pixbuf into the format
Returns
true if targets include a suitable target for images,
otherwise false.