targets_include_text

Function targets_include_text 

pub fn targets_include_text(targets: &[Atom]) -> bool
Determines if any of the targets in targets can be used to provide text.

targets

an array of GdkAtoms

Returns

true if targets include a suitable target for text, otherwise false.