ActionBarExt

Trait ActionBarExt 

pub trait ActionBarExt: IsA<ActionBar> + 'static {
    // Provided methods
    fn center_widget(&self) -> Option<Widget> { ... }
    fn pack_end(&self, child: &impl IsA<Widget>) { ... }
    fn pack_start(&self, child: &impl IsA<Widget>) { ... }
    fn set_center_widget(&self, center_widget: Option<&impl IsA<Widget>>) { ... }
    fn child_pack_type<T: IsA<Widget>>(&self, item: &T) -> PackType { ... }
    fn set_child_pack_type<T: IsA<Widget>>(&self, item: &T, pack_type: PackType) { ... }
    fn child_position<T: IsA<Widget>>(&self, item: &T) -> i32 { ... }
    fn set_child_position<T: IsA<Widget>>(&self, item: &T, position: i32) { ... }
}
Trait containing all ActionBar methods.

Implementors

ActionBar

Provided Methods

fn center_widget(&self) -> Option<Widget>

Retrieves the center bar widget of the bar.

Returns

the center Widget or None.

fn pack_end(&self, child: &impl IsA<Widget>)

Adds child to self, packed with reference to the end of the self.

child

the Widget to be added to self

fn pack_start(&self, child: &impl IsA<Widget>)

Adds child to self, packed with reference to the start of the self.

child

the Widget to be added to self

fn set_center_widget(&self, center_widget: Option<&impl IsA<Widget>>)

Sets the center widget for the ActionBar.

center_widget

a widget to use for the center

fn child_pack_type<T: IsA<Widget>>(&self, item: &T) -> PackType

fn set_child_pack_type<T: IsA<Widget>>(&self, item: &T, pack_type: PackType)

fn child_position<T: IsA<Widget>>(&self, item: &T) -> i32

fn set_child_position<T: IsA<Widget>>(&self, item: &T, position: i32)

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors