AppChooserDialogExt

Trait AppChooserDialogExt 

pub trait AppChooserDialogExt: IsA<AppChooserDialog> + 'static {
    // Provided methods
    fn heading(&self) -> Option<GString> { ... }
    fn widget(&self) -> Widget { ... }
    fn set_heading(&self, heading: &str) { ... }
    fn gfile(&self) -> Option<File> { ... }
    fn connect_heading_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
}
Trait containing all AppChooserDialog methods.

Implementors

AppChooserDialog

Provided Methods

fn heading(&self) -> Option<GString>

Returns the text to display at the top of the dialog.

Returns

the text to display at the top of the dialog, or None, in which case a default text is displayed

fn widget(&self) -> Widget

Returns the AppChooserWidget of this dialog.

Returns

the AppChooserWidget of self

fn set_heading(&self, heading: &str)

Sets the text to display at the top of the dialog. If the heading is not set, the dialog displays a default text.

heading

a string containing Pango markup

fn gfile(&self) -> Option<File>

The GFile used by the AppChooserDialog. The dialog’s AppChooserWidget content type will be guessed from the file, if present.

fn connect_heading_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors