BinExt

Trait BinExt 

pub trait BinExt: IsA<Bin> + 'static {
    // Provided method
    fn child(&self) -> Option<Widget> { ... }
}
Provided Methods

fn child(&self) -> Option<Widget>

Gets the child of the Bin, or None if the bin contains no child widget. The returned widget does not have a reference added, so you do not need to unref it.

Returns

the child of self, or None if it does not have a child.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<O: IsA<Bin>> BinExt for O