pub trait CellAreaBoxExt: IsA<CellAreaBox> + 'static {
// Provided methods
fn spacing(&self) -> i32 { ... }
fn pack_end(
&self,
renderer: &impl IsA<CellRenderer>,
expand: bool,
align: bool,
fixed: bool,
) { ... }
fn pack_start(
&self,
renderer: &impl IsA<CellRenderer>,
expand: bool,
align: bool,
fixed: bool,
) { ... }
fn set_spacing(&self, spacing: i32) { ... }
fn connect_spacing_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn spacing(&self) -> i32
fn spacing(&self) -> i32
Gets the spacing added between cell renderers.
Returns
the space added between cell renderers in self.
Sourcefn pack_end(
&self,
renderer: &impl IsA<CellRenderer>,
expand: bool,
align: bool,
fixed: bool,
)
fn pack_end( &self, renderer: &impl IsA<CellRenderer>, expand: bool, align: bool, fixed: bool, )
Adds renderer to self, packed with reference to the end of self.
The renderer is packed after (away from end of) any other
CellRenderer packed with reference to the end of self.
renderer
the CellRenderer to add
expand
whether renderer should receive extra space when the area receives
more than its natural size
align
whether renderer should be aligned in adjacent rows
fixed
whether renderer should have the same size in all rows
Sourcefn pack_start(
&self,
renderer: &impl IsA<CellRenderer>,
expand: bool,
align: bool,
fixed: bool,
)
fn pack_start( &self, renderer: &impl IsA<CellRenderer>, expand: bool, align: bool, fixed: bool, )
Adds renderer to self, packed with reference to the start of self.
The renderer is packed after any other CellRenderer packed
with reference to the start of self.
renderer
the CellRenderer to add
expand
whether renderer should receive extra space when the area receives
more than its natural size
align
whether renderer should be aligned in adjacent rows
fixed
whether renderer should have the same size in all rows
Sourcefn set_spacing(&self, spacing: i32)
fn set_spacing(&self, spacing: i32)
Sets the spacing to add between cell renderers in self.
spacing
the space to add between GtkCellRenderers
fn connect_spacing_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".