CellViewExt

Trait CellViewExt 

pub trait CellViewExt: IsA<CellView> + 'static {
Show 21 methods // Provided methods fn displayed_row(&self) -> Option<TreePath> { ... } fn draws_sensitive(&self) -> bool { ... } fn fits_model(&self) -> bool { ... } fn model(&self) -> Option<TreeModel> { ... } fn set_background_rgba(&self, rgba: &RGBA) { ... } fn set_displayed_row(&self, path: &mut TreePath) { ... } fn set_draw_sensitive(&self, draw_sensitive: bool) { ... } fn set_fit_model(&self, fit_model: bool) { ... } fn set_model(&self, model: Option<&impl IsA<TreeModel>>) { ... } fn set_background(&self, background: Option<&str>) { ... } fn background_rgba(&self) -> Option<RGBA> { ... } fn is_background_set(&self) -> bool { ... } fn set_background_set(&self, background_set: bool) { ... } fn cell_area(&self) -> Option<CellArea> { ... } fn cell_area_context(&self) -> Option<CellAreaContext> { ... } fn connect_background_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_background_rgba_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_background_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_draw_sensitive_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_fit_model_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_model_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all CellView methods.

Implementors

CellView

Provided Methods

fn displayed_row(&self) -> Option<TreePath>

Returns a TreePath referring to the currently displayed row. If no row is currently displayed, None is returned.

Returns

the currently displayed row or None

fn draws_sensitive(&self) -> bool

Gets whether self is configured to draw all of its cells in a sensitive state.

Returns

whether self draws all of its cells in a sensitive state

fn fits_model(&self) -> bool

Gets whether self is configured to request space to fit the entire TreeModel.

Returns

whether self requests space to fit the entire TreeModel.

fn model(&self) -> Option<TreeModel>

Returns the model for self. If no model is used None is returned.

Returns

a TreeModel used or None

fn set_background_rgba(&self, rgba: &RGBA)

Sets the background color of self.

rgba

the new background color

fn set_displayed_row(&self, path: &mut TreePath)

Sets the row of the model that is currently displayed by the CellView. If the path is unset, then the contents of the cellview “stick” at their last value; this is not normally a desired result, but may be a needed intermediate state if say, the model for the CellView becomes temporarily empty.

path

a TreePath or None to unset.

fn set_draw_sensitive(&self, draw_sensitive: bool)

Sets whether self should draw all of its cells in a sensitive state, this is used by ComboBox menus to ensure that rows with insensitive cells that contain children appear sensitive in the parent menu item.

draw_sensitive

whether to draw all cells in a sensitive state.

fn set_fit_model(&self, fit_model: bool)

Sets whether self should request space to fit the entire TreeModel.

This is used by ComboBox to ensure that the cell view displayed on the combo box’s button always gets enough space and does not resize when selection changes.

fit_model

whether self should request space for the whole model.

fn set_model(&self, model: Option<&impl IsA<TreeModel>>)

Sets the model for self. If self already has a model set, it will remove it before setting the new model. If model is None, then it will unset the old model.

model

a TreeModel

fn set_background(&self, background: Option<&str>)

fn background_rgba(&self) -> Option<RGBA>

The background color as a gdk::RGBA

fn is_background_set(&self) -> bool

fn set_background_set(&self, background_set: bool)

fn cell_area(&self) -> Option<CellArea>

The CellArea rendering cells

If no area is specified when creating the cell view with CellView::with_context() a horizontally oriented CellAreaBox will be used.

since 3.0

fn cell_area_context(&self) -> Option<CellAreaContext>

The CellAreaContext used to compute the geometry of the cell view.

A group of cell views can be assigned the same context in order to ensure the sizes and cell alignments match across all the views with the same context.

ComboBox menus uses this to assign the same context to all cell views in the menu items for a single menu (each submenu creates its own context since the size of each submenu does not depend on parent or sibling menus).

since 3.0

fn connect_background_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_background_rgba_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_background_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_draw_sensitive_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_fit_model_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_model_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors