ColorChooserWidgetExt

Trait ColorChooserWidgetExt 

pub trait ColorChooserWidgetExt:
    IsA<ColorChooserWidget>
    + Sealed
    + 'static {
    // Provided methods
    fn shows_editor(&self) -> bool { ... }
    fn set_show_editor(&self, show_editor: bool) { ... }
    fn connect_show_editor_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
}
Trait containing all ColorChooserWidget methods.

Implementors

ColorChooserWidget

Provided Methods

fn shows_editor(&self) -> bool

The ::show-editor property is true when the color chooser is showing the single-color editor. It can be set to switch the color chooser into single-color editing mode.

fn set_show_editor(&self, show_editor: bool)

The ::show-editor property is true when the color chooser is showing the single-color editor. It can be set to switch the color chooser into single-color editing mode.

fn connect_show_editor_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors