EventControllerExt

Trait EventControllerExt 

pub trait EventControllerExt: IsA<EventController> + 'static {
    // Provided methods
    fn propagation_phase(&self) -> PropagationPhase { ... }
    fn widget(&self) -> Option<Widget> { ... }
    fn handle_event(&self, event: &Event) -> bool { ... }
    fn reset(&self) { ... }
    fn set_propagation_phase(&self, phase: PropagationPhase) { ... }
    fn connect_propagation_phase_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
}
Provided Methods

fn propagation_phase(&self) -> PropagationPhase

Gets the propagation phase at which self handles events.

Returns

the propagation phase

fn widget(&self) -> Option<Widget>

Returns the Widget this controller relates to.

Returns

a Widget

fn handle_event(&self, event: &Event) -> bool

Feeds an events into self, so it can be interpreted and the controller actions triggered.

event

a GdkEvent

Returns

true if the event was potentially useful to trigger the controller action

fn reset(&self)

Resets the self to a clean state. Every interaction the controller did through handle-event will be dropped at this point.

fn set_propagation_phase(&self, phase: PropagationPhase)

Sets the propagation phase at which a controller handles events.

If phase is PropagationPhase::None, no automatic event handling will be performed, but other additional gesture maintenance will. In that phase, the events can be managed by calling handle_event().

phase

a propagation phase

fn connect_propagation_phase_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors