FixedExt

Trait FixedExt 

pub trait FixedExt: IsA<Fixed> + 'static {
    // Provided methods
    fn move_(&self, widget: &impl IsA<Widget>, x: i32, y: i32) { ... }
    fn put(&self, widget: &impl IsA<Widget>, x: i32, y: i32) { ... }
}
Trait containing all Fixed methods.

Implementors

Fixed

Provided Methods

fn move_(&self, widget: &impl IsA<Widget>, x: i32, y: i32)

Moves a child of a Fixed container to the given position.

widget

the child widget.

x

the horizontal position to move the widget to.

y

the vertical position to move the widget to.

fn put(&self, widget: &impl IsA<Widget>, x: i32, y: i32)

Adds a widget to a Fixed container at the given position.

widget

the widget to add.

x

the horizontal position to place the widget at.

y

the vertical position to place the widget at.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<O: IsA<Fixed>> FixedExt for O