GtkMountOperationExt

Trait GtkMountOperationExt 

pub trait GtkMountOperationExt: IsA<MountOperation> + 'static {
    // Provided methods
    fn parent(&self) -> Option<Window> { ... }
    fn screen(&self) -> Option<Screen> { ... }
    fn is_showing(&self) -> bool { ... }
    fn set_parent(&self, parent: Option<&impl IsA<Window>>) { ... }
    fn set_screen(&self, screen: &Screen) { ... }
    fn connect_is_showing_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
    fn connect_parent_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
    fn connect_screen_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
}
Trait containing all MountOperation methods.

Implementors

MountOperation

Provided Methods

fn parent(&self) -> Option<Window>

Gets the transient parent used by the MountOperation

Returns

the transient parent for windows shown by self

fn screen(&self) -> Option<Screen>

Gets the screen on which windows of the MountOperation will be shown.

Returns

the screen on which windows of self are shown

fn is_showing(&self) -> bool

Returns whether the MountOperation is currently displaying a window.

Returns

true if self is currently displaying a window

fn set_parent(&self, parent: Option<&impl IsA<Window>>)

Sets the transient parent for windows shown by the MountOperation.

parent

transient parent of the window, or None

fn set_screen(&self, screen: &Screen)

Sets the screen to show windows of the MountOperation on.

screen

a gdk::Screen

fn connect_is_showing_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_parent_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_screen_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors