pub trait IMMulticontextExt: IsA<IMMulticontext> + 'static {
// Provided methods
fn context_id(&self) -> Option<GString> { ... }
fn set_context_id(&self, context_id: &str) { ... }
}Expand description
Provided Methods
Sourcefn context_id(&self) -> Option<GString>
fn context_id(&self) -> Option<GString>
Gets the id of the currently active slave of the self.
Returns
the id of the currently active slave
Sourcefn set_context_id(&self, context_id: &str)
fn set_context_id(&self, context_id: &str)
Sets the context id for self.
This causes the currently active slave of self to be
replaced by the slave corresponding to the new context id.
context_id
the id to use
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".