MenuBarExt

Trait MenuBarExt 

pub trait MenuBarExt: IsA<MenuBar> + 'static {
    // Provided methods
    fn child_pack_direction(&self) -> PackDirection { ... }
    fn pack_direction(&self) -> PackDirection { ... }
    fn set_child_pack_direction(&self, child_pack_dir: PackDirection) { ... }
    fn set_pack_direction(&self, pack_dir: PackDirection) { ... }
    fn connect_child_pack_direction_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
    fn connect_pack_direction_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
}
Trait containing all MenuBar methods.

Implementors

MenuBar

Provided Methods

fn child_pack_direction(&self) -> PackDirection

Retrieves the current child pack direction of the menubar. See set_child_pack_direction().

Returns

the child pack direction

fn pack_direction(&self) -> PackDirection

Retrieves the current pack direction of the menubar. See set_pack_direction().

Returns

the pack direction

fn set_child_pack_direction(&self, child_pack_dir: PackDirection)

Sets how widgets should be packed inside the children of a menubar.

child_pack_dir

a new PackDirection

fn set_pack_direction(&self, pack_dir: PackDirection)

Sets how items should be packed inside a menubar.

pack_dir

a new PackDirection

fn connect_child_pack_direction_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_pack_direction_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors