MessageDialogExtManual

Trait MessageDialogExtManual 

pub trait MessageDialogExtManual: IsA<MessageDialog> + 'static {
    // Provided methods
    fn format_secondary_markup(&self, message: Option<&str>) { ... }
    fn format_secondary_text(&self, message: Option<&str>) { ... }
}

Provided Methods

fn format_secondary_markup(&self, message: Option<&str>)

Sets the secondary text of the message dialog to be message_format (with printf()-style), which is marked up with the [Pango text markup language][PangoMarkupFormat].

Due to an oversight, this function does not escape special XML characters like MessageDialog::with_markup() does. Thus, if the arguments may contain special XML characters, you should use g_markup_printf_escaped() to escape it.

⚠️ The following code is in C ⚠️

gchar *msg;

msg = g_markup_printf_escaped (message_format, ...);
gtk_message_dialog_format_secondary_markup (message_dialog,
                                            "%s", msg);
g_free (msg);
message_format

printf()-style markup string (see [Pango markup format][PangoMarkupFormat]), or None

fn format_secondary_text(&self, message: Option<&str>)

Sets the secondary text of the message dialog to be message_format (with printf()-style).

message_format

printf()-style format string, or None

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors