pub trait RecentChooserMenuExt: IsA<RecentChooserMenu> + 'static {
// Provided methods
fn shows_numbers(&self) -> bool { ... }
fn set_show_numbers(&self, show_numbers: bool) { ... }
fn connect_show_numbers_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn shows_numbers(&self) -> bool
fn shows_numbers(&self) -> bool
Sourcefn set_show_numbers(&self, show_numbers: bool)
fn set_show_numbers(&self, show_numbers: bool)
Sets whether a number should be added to the items of self. The
numbers are shown to provide a unique character for a mnemonic to
be used inside ten menu item’s label. Only the first the items
get a number to avoid clashes.
show_numbers
whether to show numbers
fn connect_show_numbers_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".