StackSidebarExt

Trait StackSidebarExt 

pub trait StackSidebarExt: IsA<StackSidebar> + 'static {
    // Provided methods
    fn stack(&self) -> Option<Stack> { ... }
    fn set_stack(&self, stack: &impl IsA<Stack>) { ... }
    fn connect_stack_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
}
Trait containing all StackSidebar methods.

Implementors

StackSidebar

Provided Methods

fn stack(&self) -> Option<Stack>

Retrieves the stack. See set_stack().

Returns

the associated Stack or None if none has been set explicitly

fn set_stack(&self, stack: &impl IsA<Stack>)

Set the Stack associated with this StackSidebar.

The sidebar widget will automatically update according to the order (packing) and items within the given Stack.

stack

a Stack

fn connect_stack_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors