StyleProviderExt

Trait StyleProviderExt 

pub trait StyleProviderExt: IsA<StyleProvider> + 'static {
    // Provided method
    fn style_property(
        &self,
        path: &WidgetPath,
        state: StateFlags,
        pspec: impl AsRef<ParamSpec>,
    ) -> Option<Value> { ... }
}
Trait containing all StyleProvider methods.

Implementors

CssProvider, Settings, StyleProperties, StyleProvider

Provided Methods

fn style_property( &self, path: &WidgetPath, state: StateFlags, pspec: impl AsRef<ParamSpec>, ) -> Option<Value>

Looks up a widget style property as defined by self for the widget represented by path.

path

WidgetPath to query

state

state to query the style property for

pspec

The glib::ParamSpec to query

Returns

true if the property was found and has a value, false otherwise

value

return location for the property value

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors