ToolShellExt

Trait ToolShellExt 

pub trait ToolShellExt: IsA<ToolShell> + 'static {
    // Provided methods
    fn ellipsize_mode(&self) -> EllipsizeMode { ... }
    fn icon_size(&self) -> IconSize { ... }
    fn orientation(&self) -> Orientation { ... }
    fn relief_style(&self) -> ReliefStyle { ... }
    fn style(&self) -> ToolbarStyle { ... }
    fn text_alignment(&self) -> f32 { ... }
    fn text_orientation(&self) -> Orientation { ... }
    fn text_size_group(&self) -> Option<SizeGroup> { ... }
    fn rebuild_menu(&self) { ... }
}
Trait containing all ToolShell methods.

Implementors

ToolItemGroup, ToolShell, Toolbar

Provided Methods

fn ellipsize_mode(&self) -> EllipsizeMode

Retrieves the current ellipsize mode for the tool shell. Tool items must not call this function directly, but rely on ToolItemExt::ellipsize_mode() instead.

Returns

the current ellipsize mode of self

fn icon_size(&self) -> IconSize

Retrieves the icon size for the tool shell. Tool items must not call this function directly, but rely on ToolItemExt::icon_size() instead.

Returns

the current size (IconSize) for icons of self

fn orientation(&self) -> Orientation

Retrieves the current orientation for the tool shell. Tool items must not call this function directly, but rely on ToolItemExt::orientation() instead.

Returns

the current orientation of self

fn relief_style(&self) -> ReliefStyle

Returns the relief style of buttons on self. Tool items must not call this function directly, but rely on ToolItemExt::relief_style() instead.

Returns

The relief style of buttons on self.

fn style(&self) -> ToolbarStyle

Retrieves whether the tool shell has text, icons, or both. Tool items must not call this function directly, but rely on ToolItemExt::toolbar_style() instead.

Returns

the current style of self

fn text_alignment(&self) -> f32

Retrieves the current text alignment for the tool shell. Tool items must not call this function directly, but rely on ToolItemExt::text_alignment() instead.

Returns

the current text alignment of self

fn text_orientation(&self) -> Orientation

Retrieves the current text orientation for the tool shell. Tool items must not call this function directly, but rely on ToolItemExt::text_orientation() instead.

Returns

the current text orientation of self

fn text_size_group(&self) -> Option<SizeGroup>

Retrieves the current text size group for the tool shell. Tool items must not call this function directly, but rely on ToolItemExt::text_size_group() instead.

Returns

the current text size group of self

fn rebuild_menu(&self)

Calling this function signals the tool shell that the overflow menu item for tool items have changed. If there is an overflow menu and if it is visible when this function it called, the menu will be rebuilt.

Tool items must not call this function directly, but rely on ToolItemExt::rebuild_menu() instead.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors