VolumeButtonExt

Trait VolumeButtonExt 

pub trait VolumeButtonExt: IsA<VolumeButton> + 'static {
    // Provided methods
    fn uses_symbolic(&self) -> bool { ... }
    fn set_use_symbolic(&self, use_symbolic: bool) { ... }
    fn connect_use_symbolic_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
}
Trait containing all VolumeButton methods.

Implementors

VolumeButton

Provided Methods

fn uses_symbolic(&self) -> bool

Whether to use symbolic icons as the icons. Note that if the symbolic icons are not available in your installed theme, then the normal (potentially colorful) icons will be used.

fn set_use_symbolic(&self, use_symbolic: bool)

Whether to use symbolic icons as the icons. Note that if the symbolic icons are not available in your installed theme, then the normal (potentially colorful) icons will be used.

fn connect_use_symbolic_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors