Struct gtk::AboutDialogClass
source · [−]#[repr(C)]pub struct AboutDialogClass(_);Trait Implementations
sourceimpl Deref for AboutDialogClass
impl Deref for AboutDialogClass
type Target = <Dialog as ObjectType>::RustClassType
type Target = <Dialog as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for AboutDialogClass
impl DerefMut for AboutDialogClass
sourceimpl IsClassFor for AboutDialogClass
impl IsClassFor for AboutDialogClass
type Instance = AboutDialog
type Instance = AboutDialog
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for AboutDialogClass
impl Sync for AboutDialogClass