Struct gtk::AccelFlags
source · [−]pub struct AccelFlags { /* private fields */ }Implementations
sourceimpl AccelFlags
impl AccelFlags
pub const VISIBLE: AccelFlags = _
pub const LOCKED: AccelFlags = _
pub const MASK: AccelFlags = _
sourcepub const fn empty() -> AccelFlags
pub const fn empty() -> AccelFlags
Returns an empty set of flags
sourcepub const fn all() -> AccelFlags
pub const fn all() -> AccelFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<AccelFlags>
pub fn from_bits(bits: u32) -> Option<AccelFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> AccelFlags
pub const fn from_bits_truncate(bits: u32) -> AccelFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> AccelFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> AccelFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: AccelFlags) -> bool
pub const fn intersects(&self, other: AccelFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: AccelFlags) -> bool
pub const fn contains(&self, other: AccelFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: AccelFlags)
pub fn insert(&mut self, other: AccelFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: AccelFlags)
pub fn remove(&mut self, other: AccelFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: AccelFlags)
pub fn toggle(&mut self, other: AccelFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: AccelFlags, value: bool)
pub fn set(&mut self, other: AccelFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.