AccelGroup

Struct AccelGroup 

pub struct AccelGroup { /* private fields */ }
A AccelGroup represents a group of keyboard accelerators, typically attached to a toplevel Window (with GtkWindowExt::add_accel_group()). Usually you won’t need to create a AccelGroup directly; instead, when using GtkUIManager, GTK+ automatically sets up the accelerators for your menus in the ui manager’s AccelGroup.

Note that “accelerators” are different from “mnemonics”. Accelerators are shortcuts for activating a menu item; they appear alongside the menu item they’re a shortcut for. For example “Ctrl+Q” might appear alongside the “Quit” menu item. Mnemonics are shortcuts for GUI elements such as text entries or buttons; they appear as underlined characters. See Label::with_mnemonic(). Menu items can have both accelerators and mnemonics, of course.

Properties

is-locked

Readable

modifier-mask

Readable

Signals

accel-activate

The accel-activate signal is an implementation detail of AccelGroup and not meant to be used by applications.

Detailed

accel-changed

The accel-changed signal is emitted when an entry is added to or removed from the accel group.

Widgets like AccelLabel which display an associated accelerator should connect to this signal, and rebuild their visual representation if the accel_closure is theirs.

Detailed

Implements

AccelGroupExt, [trait@glib::ObjectExt], AccelGroupExtManual

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl AccelGroup

pub const NONE: Option<&'static AccelGroup> = None

pub fn new() -> AccelGroup

Creates a new AccelGroup.

Returns

a new AccelGroup object

pub fn from_accel_closure(closure: &Closure) -> Option<AccelGroup>

Finds the AccelGroup to which closure is connected; see AccelGroupExtManual::connect_accel_group().

closure

a glib::Closure

Returns

the AccelGroup to which closure is connected, or None