Struct gtk::ActionBarClass
source · [−]#[repr(C)]pub struct ActionBarClass(_);Trait Implementations
sourceimpl Deref for ActionBarClass
impl Deref for ActionBarClass
type Target = <Bin as ObjectType>::RustClassType
type Target = <Bin as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ActionBarClass
impl DerefMut for ActionBarClass
sourceimpl IsClassFor for ActionBarClass
impl IsClassFor for ActionBarClass
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ActionBarClass
impl Sync for ActionBarClass