pub struct AppChooserButton { /* private fields */ }Expand description
The AppChooserButton is a widget that lets the user select
an application. It implements the AppChooser interface.
Initially, a AppChooserButton selects the first application
in its list, which will either be the most-recently used application
or, if show-default-item is true, the
default application.
The list of applications shown in a AppChooserButton includes
the recommended applications for the given content type. When
show-default-item is set, the default application
is also included. To let the user chooser other applications,
you can set the show-dialog-item property,
which allows to open a full AppChooserDialog.
It is possible to add custom items to the list, using
AppChooserButtonExt::append_custom_item(). These items cause
the custom-item-activated signal to be
emitted when they are selected.
To track changes in the selected application, use the
changed signal.
Properties
heading
The text to show at the top of the dialog that can be opened from the button. The string may contain Pango markup.
Readable | Writable
show-default-item
The show-default-item property determines
whether the dropdown menu should show the default application
on top for the provided content type.
Readable | Writable | Construct
show-dialog-item
The show-dialog-item property determines
whether the dropdown menu should show an item that triggers
a AppChooserDialog when clicked.
Readable | Writable | Construct
ComboBox
active
The item which is currently active. If the model is a non-flat treemodel,
and the active item is not an immediate child of the root of the tree,
this property has the value
gtk_tree_path_get_indices (path)[0],
where path is the TreePath of the active item.
Readable | Writable
active-id
The value of the ID column of the active row.
Readable | Writable
add-tearoffs
The add-tearoffs property controls whether generated menus have tearoff menu items.
Note that this only affects menu style combo boxes.
Readable | Writable
button-sensitivity
Whether the dropdown button is sensitive when the model is empty.
Readable | Writable
cell-area
The CellArea used to layout cell renderers for this combo box.
If no area is specified when creating the combo box with ComboBox::with_area()
a horizontally oriented CellAreaBox will be used.
Readable | Writable | Construct Only
column-span-column
If this is set to a non-negative value, it must be the index of a column
of type G_TYPE_INT in the model. The value in that column for each item
will determine how many columns that item will span in the popup.
Therefore, values in this column must be greater than zero, and the sum of
an item’s column position + span should not exceed wrap-width.
Readable | Writable
entry-text-column
The column in the combo box’s model to associate with strings from the entry
if the combo was created with has-entry = true.
Readable | Writable
has-entry
Whether the combo box has an entry.
Readable | Writable | Construct Only
has-frame
The has-frame property controls whether a frame is drawn around the entry.
Readable | Writable
id-column
The column in the combo box’s model that provides string IDs for the values in the model, if != -1.
Readable | Writable
model
The model from which the combo box takes the values shown in the list.
Readable | Writable
popup-fixed-width
Whether the popup’s width should be a fixed width matching the allocated width of the combo box.
Readable | Writable
popup-shown
Whether the combo boxes dropdown is popped up. Note that this property is mainly useful, because it allows you to connect to notify::popup-shown.
Readable
row-span-column
If this is set to a non-negative value, it must be the index of a column
of type G_TYPE_INT in the model. The value in that column for each item
will determine how many rows that item will span in the popup. Therefore,
values in this column must be greater than zero.
Readable | Writable
tearoff-title
A title that may be displayed by the window manager when the popup is torn-off.
Readable | Writable
wrap-width
If wrap-width is set to a positive value, items in the popup will be laid out along multiple columns, starting a new row on reaching the wrap width.
Readable | Writable
Widget
app-paintable
Readable | Writable
can-default
Readable | Writable
can-focus
Readable | Writable
composite-child
Readable
double-buffered
Whether the widget is double buffered.
Readable | Writable
events
Readable | Writable
expand
Whether to expand in both directions. Setting this sets both hexpand and vexpand
Readable | Writable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Before 3.20, several widgets (GtkButton, GtkFileChooserButton, GtkComboBox) implemented this property individually.
Readable | Writable
halign
How to distribute horizontal space if widget gets extra space, see Align
Readable | Writable
has-default
Readable | Writable
has-focus
Readable | Writable
has-tooltip
Enables or disables the emission of query-tooltip on widget.
A value of true indicates that widget can have a tooltip, in this case
the widget will be queried using query-tooltip to determine
whether it will provide a tooltip or not.
Note that setting this property to true for the first time will change
the event masks of the GdkWindows of this widget to include leave-notify
and motion-notify events. This cannot and will not be undone when the
property is set to false again.
Readable | Writable
height-request
Readable | Writable
hexpand
Whether to expand horizontally. See WidgetExt::set_hexpand().
Readable | Writable
hexpand-set
Whether to use the hexpand property. See WidgetExt::is_hexpand_set().
Readable | Writable
is-focus
Readable | Writable
margin
Sets all four sides’ margin at once. If read, returns max margin on any side.
Readable | Writable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-end
Margin on end of widget, horizontally. This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-left
Margin on left side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-right
Margin on right side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-start
Margin on start of widget, horizontally. This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
name
Readable | Writable
no-show-all
Readable | Writable
opacity
The requested opacity of the widget. See WidgetExt::set_opacity() for
more details about window opacity.
Before 3.8 this was only available in GtkWindow
Readable | Writable
parent
Readable | Writable
receives-default
Readable | Writable
scale-factor
The scale factor of the widget. See WidgetExt::scale_factor() for
more details about widget scaling.
Readable
sensitive
Readable | Writable
style
The style of the widget, which contains information about how it will look (colors, etc).
Readable | Writable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up
with the [Pango text markup language][PangoMarkupFormat].
Also see Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not None: has-tooltip
will automatically be set to true and there will be taken care of
query-tooltip in the default signal handler.
Note that if both tooltip-text and tooltip-markup
are set, the last one wins.
Readable | Writable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not None: has-tooltip
will automatically be set to true and there will be taken care of
query-tooltip in the default signal handler.
Note that if both tooltip-text and tooltip-markup
are set, the last one wins.
Readable | Writable
valign
How to distribute vertical space if widget gets extra space, see Align
Readable | Writable
vexpand
Whether to expand vertically. See WidgetExt::set_vexpand().
Readable | Writable
vexpand-set
Whether to use the vexpand property. See WidgetExt::is_vexpand_set().
Readable | Writable
visible
Readable | Writable
width-request
Readable | Writable
window
The widget’s window if it is realized, None otherwise.
Readable
CellEditable
editing-canceled
Indicates whether editing on the cell has been canceled.
Readable | Writable
AppChooser
content-type
The content type of the AppChooser object.
See [GContentType][gio-GContentType] for more information about content types.
Readable | Writable | Construct Only
Signals
custom-item-activated
Emitted when a custom item, previously added with
AppChooserButtonExt::append_custom_item(), is activated from the
dropdown menu.
Detailed
ComboBox
changed
The changed signal is emitted when the active
item is changed. The can be due to the user selecting
a different item from the list, or due to a
call to ComboBoxExt::set_active_iter().
It will also be emitted while typing into the entry of a combo box
with an entry.
format-entry-text
value, -1);
return g_strdup_printf (“g”, value);
}
]|
move-active
The ::move-active signal is a [keybinding signal][GtkBindingSignal] which gets emitted to move the active selection.
Action
popdown
The ::popdown signal is a [keybinding signal][GtkBindingSignal] which gets emitted to popdown the combo box list.
The default bindings for this signal are Alt+Up and Escape.
Action
popup
The ::popup signal is a [keybinding signal][GtkBindingSignal] which gets emitted to popup the combo box list.
The default binding for this signal is Alt+Down.
Action
Widget
accel-closures-changed
button-press-event
The ::button-press-event signal will be emitted when a button (typically from a mouse) is pressed.
To receive this signal, the gdk::Window associated to the
widget needs to enable the gdk::EventMask::BUTTON_PRESS_MASK mask.
This signal will be sent to the grab widget if there is one.
button-release-event
The ::button-release-event signal will be emitted when a button (typically from a mouse) is released.
To receive this signal, the gdk::Window associated to the
widget needs to enable the gdk::EventMask::BUTTON_RELEASE_MASK mask.
This signal will be sent to the grab widget if there is one.
can-activate-accel
Determines whether an accelerator that activates the signal
identified by signal_id can currently be activated.
This signal is present to allow applications and derived
widgets to override the default Widget handling
for determining whether an accelerator can be activated.
child-notify
The ::child-notify signal is emitted for each [child property][child-properties] that has changed on an object. The signal’s detail holds the property name.
Detailed
composited-changed
The ::composited-changed signal is emitted when the composited
status of widgets screen changes.
See Screen::is_composited().
Action
configure-event
The ::configure-event signal will be emitted when the size, position or
stacking of the widget’s window has changed.
To receive this signal, the gdk::Window associated to the widget needs
to enable the gdk::EventMask::STRUCTURE_MASK mask. GDK will enable this mask
automatically for all new windows.
damage-event
Emitted when a redirected window belonging to widget gets drawn into.
The region/area members of the event shows what area of the redirected
drawable was drawn into.
delete-event
The ::delete-event signal is emitted if a user requests that
a toplevel window is closed. The default handler for this signal
destroys the window. Connecting WidgetExtManual::hide_on_delete() to
this signal will cause the window to be hidden instead, so that
it can later be shown again without reconstructing it.
destroy
Signals that all holders of a reference to the widget should release the reference that they hold. May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
destroy-event
The ::destroy-event signal is emitted when a gdk::Window is destroyed.
You rarely get this signal, because most widgets disconnect themselves
from their window before they destroy it, so no widget owns the
window at destroy time.
To receive this signal, the gdk::Window associated to the widget needs
to enable the gdk::EventMask::STRUCTURE_MASK mask. GDK will enable this mask
automatically for all new windows.
direction-changed
The ::direction-changed signal is emitted when the text direction of a widget changes.
drag-begin
The ::drag-begin signal is emitted on the drag source when a drag is
started. A typical reason to connect to this signal is to set up a
custom drag icon with e.g. WidgetExt::drag_source_set_icon_pixbuf().
Note that some widgets set up a drag icon in the default handler of
this signal, so you may have to use g_signal_connect_after() to
override what the default handler did.
drag-data-delete
The ::drag-data-delete signal is emitted on the drag source when a drag
with the action gdk::DragAction::MOVE is successfully completed. The signal
handler is responsible for deleting the data that has been dropped. What
“delete” means depends on the context of the drag operation.
drag-data-get
The ::drag-data-get signal is emitted on the drag source when the drop
site requests the data which is dragged. It is the responsibility of
the signal handler to fill data with the data in the format which
is indicated by info. See SelectionData::set() and
SelectionData::set_text().
drag-data-received
format == 8)) { GdkDragAction action;
// handle data here
action = gdk_drag_context_get_selected_action (context); if (action == GDK_ACTION_ASK) { GtkWidget *dialog; gint response;
dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_INFO, GTK_BUTTONS_YES_NO, “Move the data ?\n”); response = gtk_dialog_run (GTK_DIALOG (dialog)); gtk_widget_destroy (dialog);
if (response == GTK_RESPONSE_YES) action = GDK_ACTION_MOVE; else action = GDK_ACTION_COPY; }
gtk_drag_finish (context, TRUE, action == GDK_ACTION_MOVE, time); } else gtk_drag_finish (context, FALSE, FALSE, time); } ]|
drag-drop
The ::drag-drop signal is emitted on the drop site when the user drops
the data onto the widget. The signal handler must determine whether
the cursor position is in a drop zone or not. If it is not in a drop
zone, it returns false and no further processing is necessary.
Otherwise, the handler returns true. In this case, the handler must
ensure that gtk_drag_finish() is called to let the source know that
the drop is done. The call to gtk_drag_finish() can be done either
directly or in a drag-data-received handler which gets
triggered by calling WidgetExt::drag_get_data() to receive the data for one
or more of the supported targets.
drag-end
The ::drag-end signal is emitted on the drag source when a drag is
finished. A typical reason to connect to this signal is to undo
things done in drag-begin.
drag-failed
The ::drag-failed signal is emitted on the drag source when a drag has
failed. The signal handler may hook custom code to handle a failed DnD
operation based on the type of error, it returns true is the failure has
been already handled (not showing the default “drag operation failed”
animation), otherwise it returns false.
drag-leave
The ::drag-leave signal is emitted on the drop site when the cursor
leaves the widget. A typical reason to connect to this signal is to
undo things done in drag-motion, e.g. undo highlighting
with WidgetExt::drag_unhighlight().
Likewise, the drag-leave signal is also emitted before the
::drag-drop signal, for instance to allow cleaning up of a preview item
created in the drag-motion signal handler.
drag-motion
suggested_action, time); } else { // accept the drop } } ]|
draw
This signal is emitted when a widget is supposed to render itself.
The widget’s top left corner must be painted at the origin of
the passed in context and be sized to the values returned by
WidgetExt::allocated_width() and
WidgetExt::allocated_height().
Signal handlers connected to this signal can modify the cairo
context passed as cr in any way they like and don’t need to
restore it. The signal emission takes care of calling cairo_save()
before and cairo_restore() after invoking the handler.
The signal handler will get a cr with a clip region already set to the
widget’s dirty region, i.e. to the area that needs repainting. Complicated
widgets that want to avoid redrawing themselves completely can get the full
extents of the clip region with gdk_cairo_get_clip_rectangle(), or they can
get a finer-grained representation of the dirty region with
cairo_copy_clip_rectangle_list().
enter-notify-event
The ::enter-notify-event will be emitted when the pointer enters
the widget’s window.
To receive this signal, the gdk::Window associated to the widget needs
to enable the gdk::EventMask::ENTER_NOTIFY_MASK mask.
This signal will be sent to the grab widget if there is one.
event
The GTK+ main loop will emit three signals for each GDK event delivered
to a widget: one generic ::event signal, another, more specific,
signal that matches the type of event delivered (e.g.
key-press-event) and finally a generic
event-after signal.
event-after
After the emission of the event signal and (optionally)
the second more specific signal, ::event-after will be emitted
regardless of the previous two signals handlers return values.
focus
focus-in-event
The ::focus-in-event signal will be emitted when the keyboard focus
enters the widget’s window.
To receive this signal, the gdk::Window associated to the widget needs
to enable the gdk::EventMask::FOCUS_CHANGE_MASK mask.
focus-out-event
The ::focus-out-event signal will be emitted when the keyboard focus
leaves the widget’s window.
To receive this signal, the gdk::Window associated to the widget needs
to enable the gdk::EventMask::FOCUS_CHANGE_MASK mask.
grab-broken-event
Emitted when a pointer or keyboard grab on a window belonging
to widget gets broken.
On X11, this happens when the grab window becomes unviewable (i.e. it or one of its ancestors is unmapped), or if the same application grabs the pointer or keyboard again.
grab-focus
Action
grab-notify
The ::grab-notify signal is emitted when a widget becomes shadowed by a GTK+ grab (not a pointer or keyboard grab) on another widget, or when it becomes unshadowed due to a grab being removed.
A widget is shadowed by a WidgetExt::grab_add() when the topmost
grab widget in the grab stack of its window group is not
its ancestor.
hide
The ::hide signal is emitted when widget is hidden, for example with
WidgetExt::hide().
hierarchy-changed
The ::hierarchy-changed signal is emitted when the
anchored state of a widget changes. A widget is
“anchored” when its toplevel
ancestor is a Window. This signal is emitted when
a widget changes from un-anchored to anchored or vice-versa.
key-press-event
The ::key-press-event signal is emitted when a key is pressed. The signal emission will reoccur at the key-repeat rate when the key is kept pressed.
To receive this signal, the gdk::Window associated to the widget needs
to enable the gdk::EventMask::KEY_PRESS_MASK mask.
This signal will be sent to the grab widget if there is one.
key-release-event
The ::key-release-event signal is emitted when a key is released.
To receive this signal, the gdk::Window associated to the widget needs
to enable the gdk::EventMask::KEY_RELEASE_MASK mask.
This signal will be sent to the grab widget if there is one.
keynav-failed
Gets emitted if keyboard navigation fails.
See WidgetExt::keynav_failed() for details.
leave-notify-event
The ::leave-notify-event will be emitted when the pointer leaves
the widget’s window.
To receive this signal, the gdk::Window associated to the widget needs
to enable the gdk::EventMask::LEAVE_NOTIFY_MASK mask.
This signal will be sent to the grab widget if there is one.
map
The ::map signal is emitted when widget is going to be mapped, that is
when the widget is visible (which is controlled with
WidgetExt::set_visible()) and all its parents up to the toplevel widget
are also visible. Once the map has occurred, map-event will
be emitted.
The ::map signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of unmap.
map-event
The ::map-event signal will be emitted when the widget’s window is
mapped. A window is mapped when it becomes visible on the screen.
To receive this signal, the gdk::Window associated to the widget needs
to enable the gdk::EventMask::STRUCTURE_MASK mask. GDK will enable this mask
automatically for all new windows.
mnemonic-activate
The default handler for this signal activates widget if group_cycling
is false, or just makes widget grab focus if group_cycling is true.
motion-notify-event
The ::motion-notify-event signal is emitted when the pointer moves
over the widget’s gdk::Window.
To receive this signal, the gdk::Window associated to the widget
needs to enable the gdk::EventMask::POINTER_MOTION_MASK mask.
This signal will be sent to the grab widget if there is one.
move-focus
Action
parent-set
The ::parent-set signal is emitted when a new parent has been set on a widget.
popup-menu
This signal gets emitted whenever a widget should pop up a context
menu. This usually happens through the standard key binding mechanism;
by pressing a certain key while a widget is focused, the user can cause
the widget to pop up a menu. For example, the Entry widget creates
a menu with clipboard commands. See the
[Popup Menu Migration Checklist][checklist-popup-menu]
for an example of how to use this signal.
Action
property-notify-event
The ::property-notify-event signal will be emitted when a property on
the widget’s window has been changed or deleted.
To receive this signal, the gdk::Window associated to the widget needs
to enable the gdk::EventMask::PROPERTY_CHANGE_MASK mask.
proximity-in-event
To receive this signal the gdk::Window associated to the widget needs
to enable the gdk::EventMask::PROXIMITY_IN_MASK mask.
This signal will be sent to the grab widget if there is one.
proximity-out-event
To receive this signal the gdk::Window associated to the widget needs
to enable the gdk::EventMask::PROXIMITY_OUT_MASK mask.
This signal will be sent to the grab widget if there is one.
query-tooltip
Emitted when has-tooltip is true and the hover timeout
has expired with the cursor hovering “above” widget; or emitted when widget got
focus in keyboard mode.
Using the given coordinates, the signal handler should determine
whether a tooltip should be shown for widget. If this is the case
true should be returned, false otherwise. Note that if
keyboard_mode is true, the values of x and y are undefined and
should not be used.
The signal handler is free to manipulate tooltip with the therefore
destined function calls.
realize
The ::realize signal is emitted when widget is associated with a
gdk::Window, which means that WidgetExt::realize() has been called or the
widget has been mapped (that is, it is going to be drawn).
screen-changed
The ::screen-changed signal gets emitted when the screen of a widget has changed.
scroll-event
The ::scroll-event signal is emitted when a button in the 4 to 7 range is pressed. Wheel mice are usually configured to generate button press events for buttons 4 and 5 when the wheel is turned.
To receive this signal, the gdk::Window associated to the widget needs
to enable the gdk::EventMask::SCROLL_MASK mask.
This signal will be sent to the grab widget if there is one.
selection-clear-event
The ::selection-clear-event signal will be emitted when the
the widget’s window has lost ownership of a selection.
selection-get
selection-notify-event
selection-received
selection-request-event
The ::selection-request-event signal will be emitted when
another client requests ownership of the selection owned by
the widget’s window.
show
The ::show signal is emitted when widget is shown, for example with
WidgetExt::show().
show-help
Action
size-allocate
state-changed
The ::state-changed signal is emitted when the widget state changes.
See gtk_widget_get_state().
state-flags-changed
The ::state-flags-changed signal is emitted when the widget state
changes, see WidgetExt::state_flags().
style-set
The ::style-set signal is emitted when a new style has been set
on a widget. Note that style-modifying functions like
gtk_widget_modify_base() also cause this signal to be emitted.
Note that this signal is emitted for changes to the deprecated
GtkStyle. To track changes to the StyleContext associated
with a widget, use the style-updated signal.
style-updated
The ::style-updated signal is a convenience signal that is emitted when the
changed signal is emitted on the widget’s associated
StyleContext as returned by WidgetExt::style_context().
Note that style-modifying functions like gtk_widget_override_color() also
cause this signal to be emitted.
touch-event
unmap
The ::unmap signal is emitted when widget is going to be unmapped, which
means that either it or any of its parents up to the toplevel widget have
been set as hidden.
As ::unmap indicates that a widget will not be shown any longer, it can be used to, for example, stop an animation on the widget.
unmap-event
The ::unmap-event signal will be emitted when the widget’s window is
unmapped. A window is unmapped when it becomes invisible on the screen.
To receive this signal, the gdk::Window associated to the widget needs
to enable the gdk::EventMask::STRUCTURE_MASK mask. GDK will enable this mask
automatically for all new windows.
unrealize
The ::unrealize signal is emitted when the gdk::Window associated with
widget is destroyed, which means that WidgetExt::unrealize() has been
called or the widget has been unmapped (that is, it is going to be
hidden).
visibility-notify-event
The ::visibility-notify-event will be emitted when the widget’s
window is obscured or unobscured.
To receive this signal the gdk::Window associated to the widget needs
to enable the gdk::EventMask::VISIBILITY_NOTIFY_MASK mask.
window-state-event
The ::window-state-event will be emitted when the state of the
toplevel window associated to the widget changes.
To receive this signal the gdk::Window associated to the widget
needs to enable the gdk::EventMask::STRUCTURE_MASK mask. GDK will enable
this mask automatically for all new windows.
CellEditable
editing-done
This signal is a sign for the cell renderer to update its
value from the cell_editable.
Implementations of CellEditable are responsible for
emitting this signal when they are done editing, e.g.
Entry emits this signal when the user presses Enter. Typical things to
do in a handler for ::editing-done are to capture the edited value,
disconnect the cell_editable from signals on the CellRenderer, etc.
CellEditableExt::editing_done() is a convenience method
for emitting editing-done.
remove-widget
This signal is meant to indicate that the cell is finished
editing, and the cell_editable widget is being removed and may
subsequently be destroyed.
Implementations of CellEditable are responsible for
emitting this signal when they are done editing. It must
be emitted after the editing-done signal,
to give the cell renderer a chance to update the cell’s value
before the widget is removed.
CellEditableExt::remove_widget() is a convenience method
for emitting remove-widget.
Implements
AppChooserButtonExt, ComboBoxExt, BinExt, ContainerExt, WidgetExt, [trait@glib::ObjectExt], BuildableExt, CellEditableExt, CellLayoutExt, AppChooserExt, ComboBoxExtManual, ContainerExtManual, WidgetExtManual, BuildableExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl AppChooserButton
impl AppChooserButton
pub const NONE: Option<&'static AppChooserButton> = None
Sourcepub fn new(content_type: &str) -> AppChooserButton
pub fn new(content_type: &str) -> AppChooserButton
Creates a new AppChooserButton for applications
that can handle content of the given type.
content_type
the content type to show applications for
Returns
a newly created AppChooserButton
Sourcepub fn builder() -> AppChooserButtonBuilder
pub fn builder() -> AppChooserButtonBuilder
Creates a new builder-pattern struct instance to construct AppChooserButton objects.
This method returns an instance of AppChooserButtonBuilder which can be used to create AppChooserButton objects.