pub struct AppChooserDialog { /* private fields */ }Expand description
AppChooserDialog shows a AppChooserWidget inside a Dialog.
Note that AppChooserDialog does not have any interesting methods
of its own. Instead, you should get the embedded AppChooserWidget
using AppChooserDialogExt::widget() and call its methods if
the generic AppChooser interface is not sufficient for your needs.
To set the heading that is shown above the AppChooserWidget,
use AppChooserDialogExt::set_heading().
Properties
gfile
The GFile used by the AppChooserDialog.
The dialog’s AppChooserWidget content type will be guessed from the
file, if present.
Readable | Writable | Construct Only
heading
The text to show at the top of the dialog. The string may contain Pango markup.
Readable | Writable
Dialog
use-header-bar
true if the dialog uses a HeaderBar for action buttons
instead of the action-area.
For technical reasons, this property is declared as an integer
property, but you should only set it to true or false.
Readable | Writable | Construct Only
Window
accept-focus
Whether the window should receive the input focus.
Readable | Writable
application
The Application associated with the window.
The application will be kept alive for at least as long as it
has any windows associated with it (see ApplicationExtManual::hold()
for a way to keep it alive without windows).
Normally, the connection between the application and the window
will remain until the window is destroyed, but you can explicitly
remove it by setting the :application property to None.
Readable | Writable
attached-to
The widget to which this window is attached.
See GtkWindowExt::set_attached_to().
Examples of places where specifying this relation is useful are
for instance a Menu created by a ComboBox, a completion
popup window created by Entry or a typeahead search entry
created by TreeView.
Readable | Writable | Construct
decorated
Whether the window should be decorated by the window manager.
Readable | Writable
default-height
Readable | Writable
default-width
Readable | Writable
deletable
Whether the window frame should have a close button.
Readable | Writable
destroy-with-parent
Readable | Writable
focus-on-map
Whether the window should receive the input focus when mapped.
Readable | Writable
focus-visible
Whether ‘focus rectangles’ are currently visible in this window.
This property is maintained by GTK+ based on user input and should not be set by applications.
Readable | Writable
gravity
The window gravity of the window. See GtkWindowExt::move_() and gdk::Gravity for
more details about window gravity.
Readable | Writable
has-resize-grip
Whether the window has a corner resize grip.
Note that the resize grip is only shown if the window is
actually resizable and not maximized. Use
resize-grip-visible to find out if the resize
grip is currently shown.
Readable | Writable
has-toplevel-focus
Readable
hide-titlebar-when-maximized
Whether the titlebar should be hidden during maximization.
Readable | Writable
icon
Readable | Writable
icon-name
The :icon-name property specifies the name of the themed icon to
use as the window icon. See IconTheme for more details.
Readable | Writable
is-active
Readable
is-maximized
Readable
mnemonics-visible
Whether mnemonics are currently visible in this window.
This property is maintained by GTK+ based on user input, and should not be set by applications.
Readable | Writable
modal
Readable | Writable
resizable
Readable | Writable
resize-grip-visible
Whether a corner resize grip is currently shown.
Readable
role
Readable | Writable
screen
Readable | Writable
skip-pager-hint
Readable | Writable
skip-taskbar-hint
Readable | Writable
startup-id
The :startup-id is a write-only property for setting window’s
startup notification identifier. See GtkWindowExt::set_startup_id()
for more details.
Writable
title
Readable | Writable
transient-for
The transient parent of the window. See GtkWindowExt::set_transient_for() for
more details about transient windows.
Readable | Writable | Construct
type
Readable | Writable | Construct Only
type-hint
Readable | Writable
urgency-hint
Readable | Writable
window-position
Readable | Writable
Widget
app-paintable
Readable | Writable
can-default
Readable | Writable
can-focus
Readable | Writable
composite-child
Readable
double-buffered
Whether the widget is double buffered.
Readable | Writable
events
Readable | Writable
expand
Whether to expand in both directions. Setting this sets both hexpand and vexpand
Readable | Writable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Before 3.20, several widgets (GtkButton, GtkFileChooserButton, GtkComboBox) implemented this property individually.
Readable | Writable
halign
How to distribute horizontal space if widget gets extra space, see Align
Readable | Writable
has-default
Readable | Writable
has-focus
Readable | Writable
has-tooltip
Enables or disables the emission of query-tooltip on widget.
A value of true indicates that widget can have a tooltip, in this case
the widget will be queried using query-tooltip to determine
whether it will provide a tooltip or not.
Note that setting this property to true for the first time will change
the event masks of the GdkWindows of this widget to include leave-notify
and motion-notify events. This cannot and will not be undone when the
property is set to false again.
Readable | Writable
height-request
Readable | Writable
hexpand
Whether to expand horizontally. See WidgetExt::set_hexpand().
Readable | Writable
hexpand-set
Whether to use the hexpand property. See WidgetExt::is_hexpand_set().
Readable | Writable
is-focus
Readable | Writable
margin
Sets all four sides’ margin at once. If read, returns max margin on any side.
Readable | Writable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-end
Margin on end of widget, horizontally. This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-left
Margin on left side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-right
Margin on right side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-start
Margin on start of widget, horizontally. This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
name
Readable | Writable
no-show-all
Readable | Writable
opacity
The requested opacity of the widget. See WidgetExt::set_opacity() for
more details about window opacity.
Before 3.8 this was only available in GtkWindow
Readable | Writable
parent
Readable | Writable
receives-default
Readable | Writable
scale-factor
The scale factor of the widget. See WidgetExt::scale_factor() for
more details about widget scaling.
Readable
sensitive
Readable | Writable
style
The style of the widget, which contains information about how it will look (colors, etc).
Readable | Writable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up
with the [Pango text markup language][PangoMarkupFormat].
Also see Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not None: has-tooltip
will automatically be set to true and there will be taken care of
query-tooltip in the default signal handler.
Note that if both tooltip-text and tooltip-markup
are set, the last one wins.
Readable | Writable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not None: has-tooltip
will automatically be set to true and there will be taken care of
query-tooltip in the default signal handler.
Note that if both tooltip-text and tooltip-markup
are set, the last one wins.
Readable | Writable
valign
How to distribute vertical space if widget gets extra space, see Align
Readable | Writable
vexpand
Whether to expand vertically. See WidgetExt::set_vexpand().
Readable | Writable
vexpand-set
Whether to use the vexpand property. See WidgetExt::is_vexpand_set().
Readable | Writable
visible
Readable | Writable
width-request
Readable | Writable
window
The widget’s window if it is realized, None otherwise.
Readable
AppChooser
content-type
The content type of the AppChooser object.
See [GContentType][gio-GContentType] for more information about content types.
Readable | Writable | Construct Only
Implements
AppChooserDialogExt, DialogExt, GtkWindowExt, BinExt, ContainerExt, WidgetExt, [trait@glib::ObjectExt], BuildableExt, AppChooserExt, DialogExtManual, [GtkWindowExtManual][trait@crate::prelude::GtkWindowExtManual], ContainerExtManual, WidgetExtManual, BuildableExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl AppChooserDialog
impl AppChooserDialog
pub const NONE: Option<&'static AppChooserDialog> = None
Sourcepub fn new(
parent: Option<&impl IsA<Window>>,
flags: DialogFlags,
file: &impl IsA<File>,
) -> AppChooserDialog
pub fn new( parent: Option<&impl IsA<Window>>, flags: DialogFlags, file: &impl IsA<File>, ) -> AppChooserDialog
Creates a new AppChooserDialog for the provided gio::File,
to allow the user to select an application for it.
parent
flags
flags for this dialog
file
Returns
a newly created AppChooserDialog
Sourcepub fn for_content_type(
parent: Option<&impl IsA<Window>>,
flags: DialogFlags,
content_type: &str,
) -> AppChooserDialog
pub fn for_content_type( parent: Option<&impl IsA<Window>>, flags: DialogFlags, content_type: &str, ) -> AppChooserDialog
Creates a new AppChooserDialog for the provided content type,
to allow the user to select an application for it.
parent
flags
flags for this dialog
content_type
a content type string
Returns
a newly created AppChooserDialog
Sourcepub fn builder() -> AppChooserDialogBuilder
pub fn builder() -> AppChooserDialogBuilder
Creates a new builder-pattern struct instance to construct AppChooserDialog objects.
This method returns an instance of AppChooserDialogBuilder which can be used to create AppChooserDialog objects.