Struct gtk::AppChooserWidgetClass
source · [−]#[repr(C)]pub struct AppChooserWidgetClass(_);Trait Implementations
sourceimpl Deref for AppChooserWidgetClass
impl Deref for AppChooserWidgetClass
type Target = <Box as ObjectType>::RustClassType
type Target = <Box as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for AppChooserWidgetClass
impl DerefMut for AppChooserWidgetClass
sourceimpl IsClassFor for AppChooserWidgetClass
impl IsClassFor for AppChooserWidgetClass
type Instance = AppChooserWidget
type Instance = AppChooserWidget
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for AppChooserWidgetClass
impl Sync for AppChooserWidgetClass