Struct gtk::ApplicationClass
source · [−]#[repr(C)]pub struct ApplicationClass(_);Trait Implementations
sourceimpl Deref for ApplicationClass
impl Deref for ApplicationClass
type Target = <Application as ObjectType>::RustClassType
type Target = <Application as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ApplicationClass
impl DerefMut for ApplicationClass
sourceimpl IsClassFor for ApplicationClass
impl IsClassFor for ApplicationClass
type Instance = Application
type Instance = Application
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ApplicationClass
impl Sync for ApplicationClass