Struct gtk::ApplicationInhibitFlags
source · [−]pub struct ApplicationInhibitFlags { /* private fields */ }Implementations
sourceimpl ApplicationInhibitFlags
impl ApplicationInhibitFlags
pub const LOGOUT: ApplicationInhibitFlags = _
pub const SWITCH: ApplicationInhibitFlags = _
pub const SUSPEND: ApplicationInhibitFlags = _
pub const IDLE: ApplicationInhibitFlags = _
sourcepub const fn empty() -> ApplicationInhibitFlags
pub const fn empty() -> ApplicationInhibitFlags
Returns an empty set of flags
sourcepub const fn all() -> ApplicationInhibitFlags
pub const fn all() -> ApplicationInhibitFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<ApplicationInhibitFlags>
pub fn from_bits(bits: u32) -> Option<ApplicationInhibitFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> ApplicationInhibitFlags
pub const fn from_bits_truncate(bits: u32) -> ApplicationInhibitFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> ApplicationInhibitFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> ApplicationInhibitFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: ApplicationInhibitFlags) -> bool
pub const fn intersects(&self, other: ApplicationInhibitFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: ApplicationInhibitFlags) -> bool
pub const fn contains(&self, other: ApplicationInhibitFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: ApplicationInhibitFlags)
pub fn insert(&mut self, other: ApplicationInhibitFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: ApplicationInhibitFlags)
pub fn remove(&mut self, other: ApplicationInhibitFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: ApplicationInhibitFlags)
pub fn toggle(&mut self, other: ApplicationInhibitFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: ApplicationInhibitFlags, value: bool)
pub fn set(&mut self, other: ApplicationInhibitFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.