Struct gtk::ApplicationWindowClass
source · [−]#[repr(C)]pub struct ApplicationWindowClass(_);Trait Implementations
sourceimpl Deref for ApplicationWindowClass
impl Deref for ApplicationWindowClass
type Target = <Window as ObjectType>::RustClassType
type Target = <Window as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ApplicationWindowClass
impl DerefMut for ApplicationWindowClass
sourceimpl IsClassFor for ApplicationWindowClass
impl IsClassFor for ApplicationWindowClass
type Instance = ApplicationWindow
type Instance = ApplicationWindow
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ApplicationWindowClass
impl Sync for ApplicationWindowClass