Struct gtk::ButtonBoxClass
source · [−]#[repr(C)]pub struct ButtonBoxClass(_);Trait Implementations
sourceimpl Deref for ButtonBoxClass
impl Deref for ButtonBoxClass
type Target = <Box as ObjectType>::RustClassType
type Target = <Box as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ButtonBoxClass
impl DerefMut for ButtonBoxClass
sourceimpl IsClassFor for ButtonBoxClass
impl IsClassFor for ButtonBoxClass
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ButtonBoxClass
impl Sync for ButtonBoxClass