Struct gtk::CalendarClass
source · [−]#[repr(C)]pub struct CalendarClass(_);Trait Implementations
sourceimpl Deref for CalendarClass
impl Deref for CalendarClass
type Target = <Widget as ObjectType>::RustClassType
type Target = <Widget as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for CalendarClass
impl DerefMut for CalendarClass
sourceimpl IsClassFor for CalendarClass
impl IsClassFor for CalendarClass
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for CalendarClass
impl Sync for CalendarClass