Struct gtk::CalendarDisplayOptions
source · [−]pub struct CalendarDisplayOptions { /* private fields */ }Implementations
sourceimpl CalendarDisplayOptions
impl CalendarDisplayOptions
pub const SHOW_HEADING: CalendarDisplayOptions = _
pub const SHOW_DAY_NAMES: CalendarDisplayOptions = _
pub const NO_MONTH_CHANGE: CalendarDisplayOptions = _
pub const SHOW_WEEK_NUMBERS: CalendarDisplayOptions = _
pub const SHOW_DETAILS: CalendarDisplayOptions = _
sourcepub const fn empty() -> CalendarDisplayOptions
pub const fn empty() -> CalendarDisplayOptions
Returns an empty set of flags
sourcepub const fn all() -> CalendarDisplayOptions
pub const fn all() -> CalendarDisplayOptions
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<CalendarDisplayOptions>
pub fn from_bits(bits: u32) -> Option<CalendarDisplayOptions>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> CalendarDisplayOptions
pub const fn from_bits_truncate(bits: u32) -> CalendarDisplayOptions
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> CalendarDisplayOptions
pub const unsafe fn from_bits_unchecked(bits: u32) -> CalendarDisplayOptions
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: CalendarDisplayOptions) -> bool
pub const fn intersects(&self, other: CalendarDisplayOptions) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: CalendarDisplayOptions) -> bool
pub const fn contains(&self, other: CalendarDisplayOptions) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: CalendarDisplayOptions)
pub fn insert(&mut self, other: CalendarDisplayOptions)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: CalendarDisplayOptions)
pub fn remove(&mut self, other: CalendarDisplayOptions)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: CalendarDisplayOptions)
pub fn toggle(&mut self, other: CalendarDisplayOptions)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: CalendarDisplayOptions, value: bool)
pub fn set(&mut self, other: CalendarDisplayOptions, value: bool)
Inserts or removes the specified flags depending on the passed value.