pub struct CellArea { /* private fields */ }Expand description
iter); } } } } return have_focus; } ]|
Note that the layouting widget is responsible for matching the GtkDirectionType values to the way it lays out its cells.
Cell Properties
The CellArea introduces cell properties for GtkCellRenderers
in very much the same way that Container introduces
[child properties][child-properties]
for GtkWidgets. This provides some general interfaces for defining
the relationship cell areas have with their cells. For instance in a
CellAreaBox a cell might “expand” and receive extra space when
the area is allocated more than its full natural request, or a cell
might be configured to “align” with adjacent rows which were requested
and rendered with the same CellAreaContext.
Use gtk_cell_area_class_install_cell_property() to install cell
properties for a cell area class and gtk_cell_area_class_find_cell_property()
or gtk_cell_area_class_list_cell_properties() to get information about
existing cell properties.
To set the value of a cell property, use CellAreaExt::cell_set_property(),
gtk_cell_area_cell_set() or gtk_cell_area_cell_set_valist(). To obtain
the value of a cell property, use CellAreaExt::cell_get_property(),
gtk_cell_area_cell_get() or gtk_cell_area_cell_get_valist().
This is an Abstract Base Class, you cannot instantiate it.
Properties
edit-widget
The widget currently editing the edited cell
This property is read-only and only changes as
a result of a call CellAreaExt::activate_cell().
Readable
edited-cell
The cell in the area that is currently edited
This property is read-only and only changes as
a result of a call CellAreaExt::activate_cell().
Readable
focus-cell
The cell in the area that currently has focus
Readable | Writable
Signals
add-editable
Indicates that editing has started on renderer and that editable
should be added to the owning cell-layouting widget at cell_area.
apply-attributes
This signal is emitted whenever applying attributes to area from model
focus-changed
Indicates that focus changed on this area. This signal
is emitted either as a result of focus handling or event
handling.
It’s possible that the signal is emitted even if the currently focused renderer did not change, this is because focus may change to the same renderer in the same cell area for a different row of data.
remove-editable
Indicates that editing finished on renderer and that editable
should be removed from the owning cell-layouting widget.
Implements
CellAreaExt, [trait@glib::ObjectExt], BuildableExt, CellLayoutExt, BuildableExtManual
GLib type: GObject with reference counted clone semantics.
Implementations