Struct gtk::CellAreaBoxClass
source · [−]#[repr(C)]pub struct CellAreaBoxClass(_);Trait Implementations
sourceimpl Deref for CellAreaBoxClass
impl Deref for CellAreaBoxClass
type Target = <CellArea as ObjectType>::RustClassType
type Target = <CellArea as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for CellAreaBoxClass
impl DerefMut for CellAreaBoxClass
sourceimpl IsClassFor for CellAreaBoxClass
impl IsClassFor for CellAreaBoxClass
type Instance = CellAreaBox
type Instance = CellAreaBox
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for CellAreaBoxClass
impl Sync for CellAreaBoxClass