Struct gtk::CellRendererAccelClass
source · [−]#[repr(C)]pub struct CellRendererAccelClass(_);Trait Implementations
sourceimpl Deref for CellRendererAccelClass
impl Deref for CellRendererAccelClass
type Target = <CellRendererText as ObjectType>::RustClassType
type Target = <CellRendererText as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for CellRendererAccelClass
impl DerefMut for CellRendererAccelClass
sourceimpl IsClassFor for CellRendererAccelClass
impl IsClassFor for CellRendererAccelClass
type Instance = CellRendererAccel
type Instance = CellRendererAccel
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for CellRendererAccelClass
impl Sync for CellRendererAccelClass