pub struct CellRendererPixbuf { /* private fields */ }Expand description
A CellRendererPixbuf can be used to render an image in a cell. It allows
to render either a given gdk_pixbuf::Pixbuf (set via the
pixbuf property) or a named icon (set via the
icon-name property).
To support the tree view, CellRendererPixbuf also supports rendering two
alternative pixbufs, when the is-expander property is true.
If the is-expanded property is true and the
pixbuf-expander-open property is set to a pixbuf, it
renders that pixbuf, if the is-expanded property is false
and the pixbuf-expander-closed property is set to a
pixbuf, it renders that one.
Properties
follow-state
Specifies whether the rendered pixbuf should be colorized
according to the CellRendererState.
Readable | Writable
gicon
The GIcon representing the icon to display. If the icon theme is changed, the image will be updated automatically.
Readable | Writable
icon-name
The name of the themed icon to display. This property only has an effect if not overridden by “stock_id” or “pixbuf” properties.
Readable | Writable
pixbuf
Readable | Writable
pixbuf-expander-closed
Readable | Writable
pixbuf-expander-open
Readable | Writable
stock-detail
Readable | Writable
stock-id
Readable | Writable
stock-size
The IconSize value that specifies the size of the rendered icon.
Readable | Writable
surface
Readable | Writable
CellRenderer
cell-background
Writable
cell-background-gdk
Cell background as a GdkColor
Readable | Writable
cell-background-rgba
Cell background as a gdk::RGBA
Readable | Writable
cell-background-set
Readable | Writable
editing
Readable
height
Readable | Writable
is-expanded
Readable | Writable
is-expander
Readable | Writable
mode
Readable | Writable
sensitive
Readable | Writable
visible
Readable | Writable
width
Readable | Writable
xalign
Readable | Writable
xpad
Readable | Writable
yalign
Readable | Writable
ypad
Readable | Writable
Implements
CellRendererPixbufExt, CellRendererExt, [trait@glib::ObjectExt], CellRendererPixbufExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl CellRendererPixbuf
impl CellRendererPixbuf
pub const NONE: Option<&'static CellRendererPixbuf> = None
Sourcepub fn new() -> CellRendererPixbuf
pub fn new() -> CellRendererPixbuf
Creates a new CellRendererPixbuf. Adjust rendering
parameters using object properties. Object properties can be set
globally (with [ObjectExt::set()][crate::glib::prelude::ObjectExt::set()]). Also, with TreeViewColumn, you
can bind a property to a value in a TreeModel. For example, you
can bind the “pixbuf” property on the cell renderer to a pixbuf value
in the model, thus rendering a different image in each row of the
TreeView.
Returns
the new cell renderer
Sourcepub fn builder() -> CellRendererPixbufBuilder
pub fn builder() -> CellRendererPixbufBuilder
Creates a new builder-pattern struct instance to construct CellRendererPixbuf objects.
This method returns an instance of CellRendererPixbufBuilder which can be used to create CellRendererPixbuf objects.