pub struct CellRendererProgress { /* private fields */ }Expand description
CellRendererProgress renders a numeric value as a progress par in a cell.
Additionally, it can display a text on top of the progress bar.
The CellRendererProgress cell renderer was added in GTK+ 2.6.
Properties
inverted
Readable | Writable
pulse
Setting this to a non-negative value causes the cell renderer to enter “activity mode”, where a block bounces back and forth to indicate that some progress is made, without specifying exactly how much.
Each increment of the property causes the block to move by a little bit.
To indicate that the activity has not started yet, set the property
to zero. To indicate completion, set the property to G_MAXINT.
Readable | Writable
text
The “text” property determines the label which will be drawn
over the progress bar. Setting this property to None causes the default
label to be displayed. Setting this property to an empty string causes
no label to be displayed.
Readable | Writable
text-xalign
The “text-xalign” property controls the horizontal alignment of the text in the progress bar. Valid values range from 0 (left) to 1 (right). Reserved for RTL layouts.
Readable | Writable
text-yalign
The “text-yalign” property controls the vertical alignment of the text in the progress bar. Valid values range from 0 (top) to 1 (bottom).
Readable | Writable
value
The “value” property determines the percentage to which the progress bar will be “filled in”.
Readable | Writable
CellRenderer
cell-background
Writable
cell-background-gdk
Cell background as a GdkColor
Readable | Writable
cell-background-rgba
Cell background as a gdk::RGBA
Readable | Writable
cell-background-set
Readable | Writable
editing
Readable
height
Readable | Writable
is-expanded
Readable | Writable
is-expander
Readable | Writable
mode
Readable | Writable
sensitive
Readable | Writable
visible
Readable | Writable
width
Readable | Writable
xalign
Readable | Writable
xpad
Readable | Writable
yalign
Readable | Writable
ypad
Readable | Writable
Implements
CellRendererProgressExt, CellRendererExt, [trait@glib::ObjectExt], OrientableExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl CellRendererProgress
impl CellRendererProgress
pub const NONE: Option<&'static CellRendererProgress> = None
Sourcepub fn new() -> CellRendererProgress
pub fn new() -> CellRendererProgress
Sourcepub fn builder() -> CellRendererProgressBuilder
pub fn builder() -> CellRendererProgressBuilder
Creates a new builder-pattern struct instance to construct CellRendererProgress objects.
This method returns an instance of CellRendererProgressBuilder which can be used to create CellRendererProgress objects.