Struct gtk::CellRendererProgressClass
source · [−]#[repr(C)]pub struct CellRendererProgressClass(_);Trait Implementations
sourceimpl Deref for CellRendererProgressClass
impl Deref for CellRendererProgressClass
type Target = <CellRenderer as ObjectType>::RustClassType
type Target = <CellRenderer as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for CellRendererProgressClass
impl DerefMut for CellRendererProgressClass
sourceimpl IsClassFor for CellRendererProgressClass
impl IsClassFor for CellRendererProgressClass
type Instance = CellRendererProgress
type Instance = CellRendererProgress
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for CellRendererProgressClass
impl Sync for CellRendererProgressClass