pub struct CellRendererSpin { /* private fields */ }Expand description
CellRendererSpin renders text in a cell like CellRendererText from
which it is derived. But while CellRendererText offers a simple entry to
edit the text, CellRendererSpin offers a SpinButton widget. Of course,
that means that the text has to be parseable as a floating point number.
The range of the spinbutton is taken from the adjustment property of the
cell renderer, which can be set explicitly or mapped to a column in the
tree model, like all properties of cell renders. CellRendererSpin
also has properties for the climb-rate and the number
of digits to display. Other SpinButton properties
can be set in a handler for the editing-started signal.
The CellRendererSpin cell renderer was added in GTK+ 2.10.
Properties
adjustment
The adjustment that holds the value of the spinbutton.
This must be non-None for the cell renderer to be editable.
Readable | Writeable
climb-rate
The acceleration rate when you hold down a button.
Readable | Writeable
digits
The number of decimal places to display.
Readable | Writeable
CellRendererText
align-set
Readable | Writeable
alignment
Specifies how to align the lines of text with respect to each other.
Note that this property describes how to align the lines of text in
case there are several of them. The “xalign” property of CellRenderer,
on the other hand, sets the horizontal alignment of the whole text.
Readable | Writeable
attributes
Readable | Writeable
background
Writeable
background-gdk
Background color as a GdkColor
Readable | Writeable
background-rgba
Background color as a gdk::RGBA
Readable | Writeable
background-set
Readable | Writeable
editable
Readable | Writeable
editable-set
Readable | Writeable
ellipsize
Specifies the preferred place to ellipsize the string, if the cell renderer
does not have enough room to display the entire string. Setting it to
pango::EllipsizeMode::None turns off ellipsizing. See the wrap-width property
for another way of making the text fit into a given width.
Readable | Writeable
ellipsize-set
Readable | Writeable
family
Readable | Writeable
family-set
Readable | Writeable
font
Readable | Writeable
font-desc
Readable | Writeable
foreground
Writeable
foreground-gdk
Foreground color as a GdkColor
Readable | Writeable
foreground-rgba
Foreground color as a gdk::RGBA
Readable | Writeable
foreground-set
Readable | Writeable
language
Readable | Writeable
language-set
Readable | Writeable
markup
Writeable
max-width-chars
The desired maximum width of the cell, in characters. If this property is set to -1, the width will be calculated automatically.
For cell renderers that ellipsize or wrap text; this property
controls the maximum reported width of the cell. The
cell should not receive any greater allocation unless it is
set to expand in its CellLayout and all of the cell’s siblings
have received their natural width.
Readable | Writeable
placeholder-text
The text that will be displayed in the CellRenderer if
editable is true and the cell is empty.
Since 3.6
Readable | Writeable
rise
Readable | Writeable
rise-set
Readable | Writeable
scale
Readable | Writeable
scale-set
Readable | Writeable
single-paragraph-mode
Readable | Writeable
size
Readable | Writeable
size-points
Readable | Writeable
size-set
Readable | Writeable
stretch
Readable | Writeable
stretch-set
Readable | Writeable
strikethrough
Readable | Writeable
strikethrough-set
Readable | Writeable
style
Readable | Writeable
style-set
Readable | Writeable
text
Readable | Writeable
underline
Readable | Writeable
underline-set
Readable | Writeable
variant
Readable | Writeable
variant-set
Readable | Writeable
weight
Readable | Writeable
weight-set
Readable | Writeable
width-chars
The desired width of the cell, in characters. If this property is set to -1, the width will be calculated automatically, otherwise the cell will request either 3 characters or the property value, whichever is greater.
Readable | Writeable
wrap-mode
Specifies how to break the string into multiple lines, if the cell renderer does not have enough room to display the entire string. This property has no effect unless the wrap-width property is set.
Readable | Writeable
wrap-width
Specifies the minimum width at which the text is wrapped. The wrap-mode property can be used to influence at what character positions the line breaks can be placed. Setting wrap-width to -1 turns wrapping off.
Readable | Writeable
CellRenderer
cell-background
Writeable
cell-background-gdk
Cell background as a GdkColor
Readable | Writeable
cell-background-rgba
Cell background as a gdk::RGBA
Readable | Writeable
cell-background-set
Readable | Writeable
editing
Readable
height
Readable | Writeable
is-expanded
Readable | Writeable
is-expander
Readable | Writeable
mode
Readable | Writeable
sensitive
Readable | Writeable
visible
Readable | Writeable
width
Readable | Writeable
xalign
Readable | Writeable
xpad
Readable | Writeable
yalign
Readable | Writeable
ypad
Readable | Writeable
Implements
CellRendererSpinExt, CellRendererTextExt, CellRendererExt, glib::ObjectExt
Implementations
Sourceimpl CellRendererSpin
impl CellRendererSpin
pub const NONE: Option<&'static CellRendererSpin> = None
Sourcepub fn new() -> CellRendererSpin
pub fn new() -> CellRendererSpin
Sourcepub fn builder() -> CellRendererSpinBuilder
pub fn builder() -> CellRendererSpinBuilder
Creates a new builder-pattern struct instance to construct CellRendererSpin objects.
This method returns an instance of CellRendererSpinBuilder which can be used to create CellRendererSpin objects.