Struct gtk::CellRendererSpinClass
source · [−]#[repr(C)]pub struct CellRendererSpinClass(_);Trait Implementations
sourceimpl Deref for CellRendererSpinClass
impl Deref for CellRendererSpinClass
type Target = <CellRendererText as ObjectType>::RustClassType
type Target = <CellRendererText as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for CellRendererSpinClass
impl DerefMut for CellRendererSpinClass
sourceimpl IsClassFor for CellRendererSpinClass
impl IsClassFor for CellRendererSpinClass
type Instance = CellRendererSpin
type Instance = CellRendererSpin
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for CellRendererSpinClass
impl Sync for CellRendererSpinClass