Struct gtk::CellRendererSpinnerClass
source · [−]#[repr(C)]pub struct CellRendererSpinnerClass(_);Trait Implementations
sourceimpl Deref for CellRendererSpinnerClass
impl Deref for CellRendererSpinnerClass
type Target = <CellRenderer as ObjectType>::RustClassType
type Target = <CellRenderer as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for CellRendererSpinnerClass
impl DerefMut for CellRendererSpinnerClass
sourceimpl IsClassFor for CellRendererSpinnerClass
impl IsClassFor for CellRendererSpinnerClass
type Instance = CellRendererSpinner
type Instance = CellRendererSpinner
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for CellRendererSpinnerClass
impl Sync for CellRendererSpinnerClass