Struct gtk::CellRendererState
source · [−]pub struct CellRendererState { /* private fields */ }Implementations
sourceimpl CellRendererState
impl CellRendererState
pub const SELECTED: CellRendererState = _
pub const PRELIT: CellRendererState = _
pub const INSENSITIVE: CellRendererState = _
pub const SORTED: CellRendererState = _
pub const FOCUSED: CellRendererState = _
pub const EXPANDABLE: CellRendererState = _
pub const EXPANDED: CellRendererState = _
sourcepub const fn empty() -> CellRendererState
pub const fn empty() -> CellRendererState
Returns an empty set of flags
sourcepub const fn all() -> CellRendererState
pub const fn all() -> CellRendererState
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<CellRendererState>
pub fn from_bits(bits: u32) -> Option<CellRendererState>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> CellRendererState
pub const fn from_bits_truncate(bits: u32) -> CellRendererState
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> CellRendererState
pub const unsafe fn from_bits_unchecked(bits: u32) -> CellRendererState
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: CellRendererState) -> bool
pub const fn intersects(&self, other: CellRendererState) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: CellRendererState) -> bool
pub const fn contains(&self, other: CellRendererState) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: CellRendererState)
pub fn insert(&mut self, other: CellRendererState)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: CellRendererState)
pub fn remove(&mut self, other: CellRendererState)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: CellRendererState)
pub fn toggle(&mut self, other: CellRendererState)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: CellRendererState, value: bool)
pub fn set(&mut self, other: CellRendererState, value: bool)
Inserts or removes the specified flags depending on the passed value.