Struct gtk::ColorButtonClass
source · [−]#[repr(C)]pub struct ColorButtonClass(_);Trait Implementations
sourceimpl Deref for ColorButtonClass
impl Deref for ColorButtonClass
type Target = <Button as ObjectType>::RustClassType
type Target = <Button as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ColorButtonClass
impl DerefMut for ColorButtonClass
sourceimpl IsClassFor for ColorButtonClass
impl IsClassFor for ColorButtonClass
type Instance = ColorButton
type Instance = ColorButton
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ColorButtonClass
impl Sync for ColorButtonClass