Struct gtk::ColorChooserDialogClass
source · [−]#[repr(C)]pub struct ColorChooserDialogClass(_);Trait Implementations
sourceimpl Deref for ColorChooserDialogClass
impl Deref for ColorChooserDialogClass
type Target = <Dialog as ObjectType>::RustClassType
type Target = <Dialog as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ColorChooserDialogClass
impl DerefMut for ColorChooserDialogClass
sourceimpl IsClassFor for ColorChooserDialogClass
impl IsClassFor for ColorChooserDialogClass
type Instance = ColorChooserDialog
type Instance = ColorChooserDialog
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ColorChooserDialogClass
impl Sync for ColorChooserDialogClass