Struct gtk::ComboBoxTextClass
source · [−]#[repr(C)]pub struct ComboBoxTextClass(_);Trait Implementations
sourceimpl Deref for ComboBoxTextClass
impl Deref for ComboBoxTextClass
type Target = <ComboBox as ObjectType>::RustClassType
type Target = <ComboBox as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ComboBoxTextClass
impl DerefMut for ComboBoxTextClass
sourceimpl IsClassFor for ComboBoxTextClass
impl IsClassFor for ComboBoxTextClass
type Instance = ComboBoxText
type Instance = ComboBoxText
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ComboBoxTextClass
impl Sync for ComboBoxTextClass