Struct gtk::ContainerClass
source · [−]#[repr(C)]pub struct ContainerClass(_);Trait Implementations
sourceimpl Deref for ContainerClass
impl Deref for ContainerClass
type Target = <Widget as ObjectType>::RustClassType
type Target = <Widget as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ContainerClass
impl DerefMut for ContainerClass
sourceimpl IsClassFor for ContainerClass
impl IsClassFor for ContainerClass
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ContainerClass
impl Sync for ContainerClass