pub struct CssProvider { /* private fields */ }Expand description
GtkCssProvider is an object implementing the StyleProvider interface.
It is able to parse [CSS-like][css-overview] input in order to style widgets.
An application can make GTK+ parse a specific CSS style sheet by calling
CssProviderExt::load_from_file() or CssProviderExt::load_from_resource()
and adding the provider with StyleContextExt::add_provider() or
StyleContext::add_provider_for_screen().
In addition, certain files will be read when GTK+ is initialized. First, the
file $XDG_CONFIG_HOME/gtk-3.0/gtk.css is loaded if it exists. Then, GTK+
loads the first existing file among
XDG_DATA_HOME/themes/THEME/gtk-VERSION/gtk.css,
$HOME/.themes/THEME/gtk-VERSION/gtk.css,
$XDG_DATA_DIRS/themes/THEME/gtk-VERSION/gtk.css and
DATADIR/share/themes/THEME/gtk-VERSION/gtk.css, where THEME is the name of
the current theme (see the gtk-theme-name setting), DATADIR
is the prefix configured when GTK+ was compiled (unless overridden by the
GTK_DATA_PREFIX environment variable), and VERSION is the GTK+ version number.
If no file is found for the current version, GTK+ tries older versions all the
way back to 3.0.
In the same way, GTK+ tries to load a gtk-keys.css file for the current
key theme, as defined by gtk-key-theme-name.
Signals
parsing-error
Signals that a parsing error occurred. the path, line and position
describe the actual location of the error as accurately as possible.
Parsing errors are never fatal, so the parsing will resume after the error. Errors may however cause parts of the given data or even all of it to not be parsed at all. So it is a useful idea to check that the parsing succeeds by connecting to this signal.
Note that this signal may be emitted at any time as the css provider may opt to defer parsing parts or all of the input to a later time than when a loading function was called.
Implements
CssProviderExt, [trait@glib::ObjectExt], StyleProviderExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl CssProvider
impl CssProvider
pub const NONE: Option<&'static CssProvider> = None
Sourcepub fn new() -> CssProvider
pub fn new() -> CssProvider
Sourcepub fn default() -> Option<CssProvider>
👎Deprecated: Since 3.24
pub fn default() -> Option<CssProvider>
Since 3.24
Sourcepub fn named(name: &str, variant: Option<&str>) -> Option<CssProvider>
pub fn named(name: &str, variant: Option<&str>) -> Option<CssProvider>
Loads a theme from the usual theme paths
name
A theme name
variant
variant to load, for example, “dark”, or
None for the default
Returns
a CssProvider with the theme loaded.
This memory is owned by GTK+, and you must not free it.