CssSection

Struct CssSection 

pub struct CssSection { /* private fields */ }
Defines a part of a CSS document. Because sections are nested into one another, you can use parent() to get the containing region.

Implementations

Source

impl CssSection

pub fn as_ptr(&self) -> *mut GtkCssSection

Return the inner pointer to the underlying C value.

pub unsafe fn from_glib_ptr_borrow<'a>( ptr: *const *const GtkCssSection, ) -> &'a Self

Borrows the underlying C value.

Source

impl CssSection

pub fn end_line(&self) -> u32

Returns the line in the CSS document where this section end. The line number is 0-indexed, so the first line of the document will return 0. This value may change in future invocations of this function if self is not yet parsed completely. This will for example happen in the GtkCssProvider::parsing-error signal. The end position and line may be identical to the start position and line for sections which failed to parse anything successfully.

Returns

the line number

pub fn end_position(&self) -> u32

Returns the offset in bytes from the start of the current line returned via end_line(). This value may change in future invocations of this function if self is not yet parsed completely. This will for example happen in the GtkCssProvider::parsing-error signal. The end position and line may be identical to the start position and line for sections which failed to parse anything successfully.

Returns

the offset in bytes from the start of the line.

pub fn file(&self) -> Option<File>

Gets the file that self was parsed from. If no such file exists, for example because the CSS was loaded via CssProviderExt::load_from_data(), then None is returned.

Returns

the gio::File that self was parsed from or None if self was parsed from other data

pub fn parent(&self) -> Option<CssSection>

Gets the parent section for the given self. The parent section is the section that contains this self. A special case are sections of type CssSectionType::Document. Their parent will either be None if they are the original CSS document that was loaded by CssProviderExt::load_from_file() or a section of type CssSectionType::Import if it was loaded with an import rule from a different file.

Returns

the parent section or None if none

pub fn section_type(&self) -> CssSectionType

Gets the type of information that self describes.

Returns

the type of self

pub fn start_line(&self) -> u32

Returns the line in the CSS document where this section starts. The line number is 0-indexed, so the first line of the document will return 0.

Returns

the line number

pub fn start_position(&self) -> u32

Returns the offset in bytes from the start of the current line returned via start_line().

Returns

the offset in bytes from the start of the line.