Struct gtk::DialogClass
source · [−]#[repr(C)]pub struct DialogClass(_);Trait Implementations
sourceimpl Deref for DialogClass
impl Deref for DialogClass
type Target = <Window as ObjectType>::RustClassType
type Target = <Window as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for DialogClass
impl DerefMut for DialogClass
sourceimpl IsClassFor for DialogClass
impl IsClassFor for DialogClass
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for DialogClass
impl Sync for DialogClass