Struct gtk::DialogFlags
source · [−]pub struct DialogFlags { /* private fields */ }Implementations
sourceimpl DialogFlags
impl DialogFlags
pub const MODAL: DialogFlags = _
pub const DESTROY_WITH_PARENT: DialogFlags = _
pub const USE_HEADER_BAR: DialogFlags = _
sourcepub const fn empty() -> DialogFlags
pub const fn empty() -> DialogFlags
Returns an empty set of flags
sourcepub const fn all() -> DialogFlags
pub const fn all() -> DialogFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<DialogFlags>
pub fn from_bits(bits: u32) -> Option<DialogFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> DialogFlags
pub const fn from_bits_truncate(bits: u32) -> DialogFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> DialogFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> DialogFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: DialogFlags) -> bool
pub const fn intersects(&self, other: DialogFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: DialogFlags) -> bool
pub const fn contains(&self, other: DialogFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: DialogFlags)
pub fn insert(&mut self, other: DialogFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: DialogFlags)
pub fn remove(&mut self, other: DialogFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: DialogFlags)
pub fn toggle(&mut self, other: DialogFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: DialogFlags, value: bool)
pub fn set(&mut self, other: DialogFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.