Struct gtk::DrawingAreaClass
source · [−]#[repr(C)]pub struct DrawingAreaClass(_);Trait Implementations
sourceimpl Deref for DrawingAreaClass
impl Deref for DrawingAreaClass
type Target = <Widget as ObjectType>::RustClassType
type Target = <Widget as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for DrawingAreaClass
impl DerefMut for DrawingAreaClass
sourceimpl IsClassFor for DrawingAreaClass
impl IsClassFor for DrawingAreaClass
type Instance = DrawingArea
type Instance = DrawingArea
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for DrawingAreaClass
impl Sync for DrawingAreaClass