pub struct EventController { /* private fields */ }Expand description
EventController is a base, low-level implementation for event
controllers. Those react to a series of GdkEvents, and possibly trigger
actions as a consequence of those.
This is an Abstract Base Class, you cannot instantiate it.
Properties
propagation-phase
The propagation phase at which this controller will handle events.
Readable | Writeable
widget
The widget receiving the GdkEvents that the controller will handle.
Readable | Writeable | Construct Only
Implements
Implementations
Sourceimpl EventController
impl EventController
pub const NONE: Option<&'static EventController> = None