pub struct EventControllerKey { /* private fields */ }Available on crate feature
v3_24 only.Expand description
EventControllerKey is an event controller meant for situations
where you need access to key events.
This object was added in 3.24.
Signals
focus-in
focus-out
im-update
key-pressed
This signal is emitted whenever a key is pressed.
key-released
This signal is emitted whenever a key is released.
modifiers
Implements
EventControllerExt, [trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl EventControllerKey
impl EventControllerKey
pub fn new(widget: &impl IsA<Widget>) -> EventControllerKey
pub fn forward(&self, widget: &impl IsA<Widget>) -> bool
pub fn group(&self) -> u32
Sourcepub fn im_context(&self) -> Option<IMContext>
pub fn im_context(&self) -> Option<IMContext>
pub fn set_im_context(&self, im_context: &impl IsA<IMContext>)
pub fn connect_focus_in<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_focus_out<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_im_update<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Sourcepub fn connect_key_pressed<F: Fn(&Self, u32, u32, ModifierType) -> bool + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_key_pressed<F: Fn(&Self, u32, u32, ModifierType) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcepub fn connect_key_released<F: Fn(&Self, u32, u32, ModifierType) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_key_released<F: Fn(&Self, u32, u32, ModifierType) + 'static>( &self, f: F, ) -> SignalHandlerId
This signal is emitted whenever a key is released.
keyval
the released key.
keycode
the raw code of the released key.
state
the bitmask, representing the state of modifier keys and pointer buttons. See gdk::ModifierType.
pub fn connect_modifiers<F: Fn(&Self, ModifierType) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId