pub struct EventControllerScroll { /* private fields */ }v3_24 only.Expand description
EventControllerScroll is an event controller meant to handle
scroll events from mice and touchpads. It is capable of handling
both discrete and continuous scroll events, abstracting them both
on the scroll signal (deltas in the
discrete case are multiples of 1).
In the case of continuous scroll events, EventControllerScroll
encloses all scroll events between two
scroll-begin and scroll-end
signals.
The behavior of the event controller can be modified by the
flags given at creation time, or modified at a later point through
set_flags() (e.g. because the scrolling
conditions of the widget changed).
The controller can be set up to emit motion for either/both vertical
and horizontal scroll events through EventControllerScrollFlags::VERTICAL,
EventControllerScrollFlags::HORIZONTAL and GTK_EVENT_CONTROLLER_SCROLL_BOTH.
If any axis is disabled, the respective scroll
delta will be 0. Vertical scroll events will be translated to horizontal
motion for the devices incapable of horizontal scrolling.
The event controller can also be forced to emit discrete events on all devices
through EventControllerScrollFlags::DISCRETE. This can be used to implement
discrete actions triggered through scroll events (e.g. switching across
combobox options).
The EventControllerScrollFlags::KINETIC flag toggles the emission of the
decelerate signal, emitted at the end of scrolling
with two X/Y velocity arguments that are consistent with the motion that
was received.
This object was added in 3.24.
Properties
flags
The flags affecting event controller behavior
Readable | Writeable
EventController
propagation-phase
The propagation phase at which this controller will handle events.
Readable | Writeable
widget
The widget receiving the GdkEvents that the controller will handle.
Readable | Writeable | Construct Only
Signals
decelerate
Emitted after scroll is finished if the EventControllerScrollFlags::KINETIC
flag is set. vel_x and vel_y express the initial velocity that was
imprinted by the scroll events. vel_x and vel_y are expressed in
pixels/ms.
scroll
Signals that the widget should scroll by the
amount specified by dx and dy.
scroll-begin
Signals that a new scrolling operation has begun. It will only be emitted on devices capable of it.
scroll-end
Signals that a new scrolling operation has finished. It will only be emitted on devices capable of it.
Implements
Implementations
Sourceimpl EventControllerScroll
impl EventControllerScroll
Sourcepub fn new(
widget: &impl IsA<Widget>,
flags: EventControllerScrollFlags,
) -> EventControllerScroll
pub fn new( widget: &impl IsA<Widget>, flags: EventControllerScrollFlags, ) -> EventControllerScroll
Creates a new event controller that will handle scroll events
for the given widget.
widget
a Widget
flags
behavior flags
Returns
a new EventControllerScroll
Sourcepub fn flags(&self) -> EventControllerScrollFlags
pub fn flags(&self) -> EventControllerScrollFlags
Sourcepub fn set_flags(&self, flags: EventControllerScrollFlags)
pub fn set_flags(&self, flags: EventControllerScrollFlags)
Sourcepub fn connect_decelerate<F: Fn(&Self, f64, f64) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_decelerate<F: Fn(&Self, f64, f64) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted after scroll is finished if the EventControllerScrollFlags::KINETIC
flag is set. vel_x and vel_y express the initial velocity that was
imprinted by the scroll events. vel_x and vel_y are expressed in
pixels/ms.
vel_x
X velocity
vel_y
Y velocity
Sourcepub fn connect_scroll<F: Fn(&Self, f64, f64) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_scroll<F: Fn(&Self, f64, f64) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcepub fn connect_scroll_begin<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_scroll_begin<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Signals that a new scrolling operation has begun. It will only be emitted on devices capable of it.
Sourcepub fn connect_scroll_end<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_scroll_end<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Signals that a new scrolling operation has finished. It will only be emitted on devices capable of it.
pub fn connect_flags_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId