Struct gtk::FileChooserButtonClass
source · [−]#[repr(C)]pub struct FileChooserButtonClass(_);Trait Implementations
sourceimpl Deref for FileChooserButtonClass
impl Deref for FileChooserButtonClass
type Target = <Box as ObjectType>::RustClassType
type Target = <Box as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for FileChooserButtonClass
impl DerefMut for FileChooserButtonClass
sourceimpl IsClassFor for FileChooserButtonClass
impl IsClassFor for FileChooserButtonClass
type Instance = FileChooserButton
type Instance = FileChooserButton
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for FileChooserButtonClass
impl Sync for FileChooserButtonClass