Struct gtk::FileChooserWidgetClass
source · [−]#[repr(C)]pub struct FileChooserWidgetClass(_);Trait Implementations
sourceimpl Deref for FileChooserWidgetClass
impl Deref for FileChooserWidgetClass
type Target = <Box as ObjectType>::RustClassType
type Target = <Box as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for FileChooserWidgetClass
impl DerefMut for FileChooserWidgetClass
sourceimpl IsClassFor for FileChooserWidgetClass
impl IsClassFor for FileChooserWidgetClass
type Instance = FileChooserWidget
type Instance = FileChooserWidget
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for FileChooserWidgetClass
impl Sync for FileChooserWidgetClass