pub struct FileFilter { /* private fields */ }Expand description
]|
Implements
[trait@glib::ObjectExt], BuildableExt, BuildableExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl FileFilter
impl FileFilter
Sourcepub fn new() -> FileFilter
pub fn new() -> FileFilter
GtkFileFilter filter = gtk_file_filter_new (); gtk_file_filter_add_pattern (filter, “”); ]|
Returns
a new FileFilter
Sourcepub fn from_gvariant(variant: &Variant) -> FileFilter
pub fn from_gvariant(variant: &Variant) -> FileFilter
Deserialize a file filter from an a{sv} variant in
the format produced by to_gvariant().
variant
an a{sv} glib::Variant
Returns
a new FileFilter object
Sourcepub fn add_custom<P: Fn(&FileFilterInfo) -> bool + 'static>(
&self,
needed: FileFilterFlags,
func: P,
)
pub fn add_custom<P: Fn(&FileFilterInfo) -> bool + 'static>( &self, needed: FileFilterFlags, func: P, )
Adds rule to a filter that allows files based on a custom callback
function. The bitfield needed which is passed in provides information
about what sorts of information that the filter function needs;
this allows GTK+ to avoid retrieving expensive information when
it isn’t needed by the filter.
needed
bitfield of flags indicating the information that the custom filter function needs.
func
callback function; if the function returns true, then
the file will be displayed.
notify
function to call to free data when it is no longer needed.
Sourcepub fn add_mime_type(&self, mime_type: &str)
pub fn add_mime_type(&self, mime_type: &str)
Sourcepub fn add_pattern(&self, pattern: &str)
pub fn add_pattern(&self, pattern: &str)
Sourcepub fn add_pixbuf_formats(&self)
pub fn add_pixbuf_formats(&self)
Adds a rule allowing image files in the formats supported by GdkPixbuf.
Sourcepub fn filter(&self, filter_info: &FileFilterInfo) -> bool
pub fn filter(&self, filter_info: &FileFilterInfo) -> bool
Tests whether a file should be displayed according to self.
The FileFilterInfo filter_info should include
the fields returned from needed().
This function will not typically be used by applications; it
is intended principally for use in the implementation of
FileChooser.
filter_info
a FileFilterInfo containing information
about a file.
Returns
true if the file should be displayed
Sourcepub fn name(&self) -> Option<GString>
pub fn name(&self) -> Option<GString>
Gets the human-readable name for the filter. See set_name().
Returns
The human-readable name of the filter,
or None. This value is owned by GTK+ and must not
be modified or freed.
Sourcepub fn needed(&self) -> FileFilterFlags
pub fn needed(&self) -> FileFilterFlags
Gets the fields that need to be filled in for the FileFilterInfo
passed to filter()
This function will not typically be used by applications; it
is intended principally for use in the implementation of
FileChooser.
Returns
bitfield of flags indicating needed fields when
calling filter()
Sourcepub fn to_gvariant(&self) -> Option<Variant>
pub fn to_gvariant(&self) -> Option<Variant>