Struct gtk::FileFilterFlags
source · [−]pub struct FileFilterFlags { /* private fields */ }Implementations
sourceimpl FileFilterFlags
impl FileFilterFlags
pub const FILENAME: FileFilterFlags = _
pub const URI: FileFilterFlags = _
pub const DISPLAY_NAME: FileFilterFlags = _
pub const MIME_TYPE: FileFilterFlags = _
sourcepub const fn empty() -> FileFilterFlags
pub const fn empty() -> FileFilterFlags
Returns an empty set of flags
sourcepub const fn all() -> FileFilterFlags
pub const fn all() -> FileFilterFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<FileFilterFlags>
pub fn from_bits(bits: u32) -> Option<FileFilterFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> FileFilterFlags
pub const fn from_bits_truncate(bits: u32) -> FileFilterFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> FileFilterFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> FileFilterFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: FileFilterFlags) -> bool
pub const fn intersects(&self, other: FileFilterFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: FileFilterFlags) -> bool
pub const fn contains(&self, other: FileFilterFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: FileFilterFlags)
pub fn insert(&mut self, other: FileFilterFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: FileFilterFlags)
pub fn remove(&mut self, other: FileFilterFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: FileFilterFlags)
pub fn toggle(&mut self, other: FileFilterFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: FileFilterFlags, value: bool)
pub fn set(&mut self, other: FileFilterFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.