Struct gtk::FlowBoxChildClass
source · [−]#[repr(C)]pub struct FlowBoxChildClass(_);Trait Implementations
sourceimpl Deref for FlowBoxChildClass
impl Deref for FlowBoxChildClass
type Target = <Bin as ObjectType>::RustClassType
type Target = <Bin as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for FlowBoxChildClass
impl DerefMut for FlowBoxChildClass
sourceimpl IsClassFor for FlowBoxChildClass
impl IsClassFor for FlowBoxChildClass
type Instance = FlowBoxChild
type Instance = FlowBoxChild
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for FlowBoxChildClass
impl Sync for FlowBoxChildClass