Struct gtk::FontButtonClass
source · [−]#[repr(C)]pub struct FontButtonClass(_);Trait Implementations
sourceimpl Deref for FontButtonClass
impl Deref for FontButtonClass
type Target = <Button as ObjectType>::RustClassType
type Target = <Button as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for FontButtonClass
impl DerefMut for FontButtonClass
sourceimpl IsClassFor for FontButtonClass
impl IsClassFor for FontButtonClass
type Instance = FontButton
type Instance = FontButton
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for FontButtonClass
impl Sync for FontButtonClass