Struct gtk::FontChooserDialogClass
source · [−]#[repr(C)]pub struct FontChooserDialogClass(_);Trait Implementations
sourceimpl Deref for FontChooserDialogClass
impl Deref for FontChooserDialogClass
type Target = <Dialog as ObjectType>::RustClassType
type Target = <Dialog as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for FontChooserDialogClass
impl DerefMut for FontChooserDialogClass
sourceimpl IsClassFor for FontChooserDialogClass
impl IsClassFor for FontChooserDialogClass
type Instance = FontChooserDialog
type Instance = FontChooserDialog
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for FontChooserDialogClass
impl Sync for FontChooserDialogClass