Struct gtk::GLAreaClass
source · [−]#[repr(C)]pub struct GLAreaClass(_);Trait Implementations
sourceimpl Deref for GLAreaClass
impl Deref for GLAreaClass
type Target = <Widget as ObjectType>::RustClassType
type Target = <Widget as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for GLAreaClass
impl DerefMut for GLAreaClass
sourceimpl IsClassFor for GLAreaClass
impl IsClassFor for GLAreaClass
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for GLAreaClass
impl Sync for GLAreaClass