Struct gtk::GestureClass
source · [−]#[repr(C)]pub struct GestureClass(_);Trait Implementations
sourceimpl Deref for GestureClass
impl Deref for GestureClass
type Target = <EventController as ObjectType>::RustClassType
type Target = <EventController as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for GestureClass
impl DerefMut for GestureClass
sourceimpl IsClassFor for GestureClass
impl IsClassFor for GestureClass
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for GestureClass
impl Sync for GestureClass