Struct gtk::GestureLongPressClass
source · [−]#[repr(C)]pub struct GestureLongPressClass(_);Trait Implementations
sourceimpl Deref for GestureLongPressClass
impl Deref for GestureLongPressClass
type Target = <GestureSingle as ObjectType>::RustClassType
type Target = <GestureSingle as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for GestureLongPressClass
impl DerefMut for GestureLongPressClass
sourceimpl IsClassFor for GestureLongPressClass
impl IsClassFor for GestureLongPressClass
type Instance = GestureLongPress
type Instance = GestureLongPress
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for GestureLongPressClass
impl Sync for GestureLongPressClass