pub struct GestureMultiPress { /* private fields */ }Expand description
1
touch/button press through set_area(), so any
click happening outside that area is considered to be a first click of
its own.
Signals
pressed
This signal is emitted whenever a button or touch press happens.
released
This signal is emitted when a button or touch is released. n_press
will report the number of press that is paired to this event, note
that stopped may have been emitted between the
press and its release, n_press will only start over at the next press.
stopped
This signal is emitted whenever any time/distance threshold has been exceeded.
Gesture
begin
This signal is emitted when the gesture is recognized. This means the
number of touch sequences matches n-points, and the check
handler(s) returned true.
Note: These conditions may also happen when an extra touch (eg. a third touch
on a 2-touches gesture) is lifted, in that situation sequence won’t pertain
to the current set of active touches, so don’t rely on this being true.
cancel
This signal is emitted whenever a sequence is cancelled. This usually
happens on active touches when EventControllerExt::reset() is called
on gesture (manually, due to grabs…), or the individual sequence
was claimed by parent widgets’ controllers (see GestureExt::set_sequence_state()).
gesture must forget everything about sequence as a reaction to this signal.
end
This signal is emitted when gesture either stopped recognizing the event
sequences as something to be handled (the check handler returned
false), or the number of touch sequences became higher or lower than
n-points.
Note: sequence might not pertain to the group of sequences that were
previously triggering recognition on gesture (ie. a just pressed touch
sequence that exceeds n-points). This situation may be detected
by checking through GestureExt::handles_sequence().
sequence-state-changed
This signal is emitted whenever a sequence state changes. See
GestureExt::set_sequence_state() to know more about the expectable
sequence lifetimes.
update
This signal is emitted whenever an event is handled while the gesture is
recognized. sequence is guaranteed to pertain to the set of active touches.
Implements
GestureSingleExt, GestureExt, EventControllerExt, [trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl GestureMultiPress
impl GestureMultiPress
Sourcepub fn new(widget: &impl IsA<Widget>) -> GestureMultiPress
pub fn new(widget: &impl IsA<Widget>) -> GestureMultiPress
Returns a newly created Gesture that recognizes single and multiple
presses.
widget
a Widget
Returns
a newly created GestureMultiPress
Sourcepub fn builder() -> GestureMultiPressBuilder
pub fn builder() -> GestureMultiPressBuilder
Creates a new builder-pattern struct instance to construct GestureMultiPress objects.
This method returns an instance of GestureMultiPressBuilder which can be used to create GestureMultiPress objects.
Sourcepub fn area(&self) -> Option<Rectangle>
pub fn area(&self) -> Option<Rectangle>
If an area was set through set_area(),
this function will return true and fill in rect with the
press area. See set_area() for more
details on what the press area represents.
Returns
true if rect was filled with the press area
rect
return location for the press area
Sourcepub fn set_area(&self, rect: Option<&Rectangle>)
pub fn set_area(&self, rect: Option<&Rectangle>)
If rect is non-None, the press area will be checked to be
confined within the rectangle, otherwise the button count
will be reset so the press is seen as being the first one.
If rect is None, the area will be reset to an unrestricted
state.
Note: The rectangle is only used to determine whether any non-first click falls within the expected area. This is not akin to an input shape.
rect
rectangle to receive coordinates on
Sourcepub fn connect_pressed<F: Fn(&Self, i32, f64, f64) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_pressed<F: Fn(&Self, i32, f64, f64) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcepub fn connect_released<F: Fn(&Self, i32, f64, f64) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_released<F: Fn(&Self, i32, f64, f64) + 'static>( &self, f: F, ) -> SignalHandlerId
This signal is emitted when a button or touch is released. n_press
will report the number of press that is paired to this event, note
that stopped may have been emitted between the
press and its release, n_press will only start over at the next press.
n_press
number of press that is paired with this release
x
The X coordinate, in widget allocation coordinates
y
The Y coordinate, in widget allocation coordinates
Sourcepub fn connect_stopped<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_stopped<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
This signal is emitted whenever any time/distance threshold has been exceeded.