Struct gtk::GestureMultiPressClass
source · [−]#[repr(C)]pub struct GestureMultiPressClass(_);Trait Implementations
sourceimpl Deref for GestureMultiPressClass
impl Deref for GestureMultiPressClass
type Target = <GestureSingle as ObjectType>::RustClassType
type Target = <GestureSingle as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for GestureMultiPressClass
impl DerefMut for GestureMultiPressClass
sourceimpl IsClassFor for GestureMultiPressClass
impl IsClassFor for GestureMultiPressClass
type Instance = GestureMultiPress
type Instance = GestureMultiPress
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for GestureMultiPressClass
impl Sync for GestureMultiPressClass