pub struct GestureStylus { /* private fields */ }v3_24 only.Expand description
GestureStylus is a Gesture implementation specific to stylus
input. The provided signals just provide the basic information
Signals
down
motion
proximity
up
Gesture
begin
This signal is emitted when the gesture is recognized. This means the
number of touch sequences matches n-points, and the check
handler(s) returned true.
Note: These conditions may also happen when an extra touch (eg. a third touch
on a 2-touches gesture) is lifted, in that situation sequence won’t pertain
to the current set of active touches, so don’t rely on this being true.
cancel
This signal is emitted whenever a sequence is cancelled. This usually
happens on active touches when EventControllerExt::reset() is called
on gesture (manually, due to grabs…), or the individual sequence
was claimed by parent widgets’ controllers (see GestureExt::set_sequence_state()).
gesture must forget everything about sequence as a reaction to this signal.
end
This signal is emitted when gesture either stopped recognizing the event
sequences as something to be handled (the check handler returned
false), or the number of touch sequences became higher or lower than
n-points.
Note: sequence might not pertain to the group of sequences that were
previously triggering recognition on gesture (ie. a just pressed touch
sequence that exceeds n-points). This situation may be detected
by checking through GestureExt::handles_sequence().
sequence-state-changed
This signal is emitted whenever a sequence state changes. See
GestureExt::set_sequence_state() to know more about the expectable
sequence lifetimes.
update
This signal is emitted whenever an event is handled while the gesture is
recognized. sequence is guaranteed to pertain to the set of active touches.
Implements
GestureSingleExt, GestureExt, EventControllerExt, [trait@glib::ObjectExt], GestureStylusExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl GestureStylus
impl GestureStylus
Sourcepub fn new(widget: &impl IsA<Widget>) -> GestureStylus
pub fn new(widget: &impl IsA<Widget>) -> GestureStylus
Sourcepub fn device_tool(&self) -> Option<DeviceTool>
pub fn device_tool(&self) -> Option<DeviceTool>
pub fn connect_down<F: Fn(&Self, f64, f64) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_motion<F: Fn(&Self, f64, f64) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_proximity<F: Fn(&Self, f64, f64) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_up<F: Fn(&Self, f64, f64) + 'static>( &self, f: F, ) -> SignalHandlerId