pub struct GestureSwipe { /* private fields */ }Expand description
GestureSwipe is a Gesture implementation able to recognize
swipes, after a press/move/…/move/release sequence happens, the
swipe signal will be emitted, providing the velocity
and directionality of the sequence at the time it was lifted.
If the velocity is desired in intermediate points,
velocity() can be called on eg. a
update handler.
All velocities are reported in pixels/sec units.
Signals
swipe
This signal is emitted when the recognized gesture is finished, velocity and direction are a product of previously recorded events.
Gesture
begin
This signal is emitted when the gesture is recognized. This means the
number of touch sequences matches n-points, and the check
handler(s) returned true.
Note: These conditions may also happen when an extra touch (eg. a third touch
on a 2-touches gesture) is lifted, in that situation sequence won’t pertain
to the current set of active touches, so don’t rely on this being true.
cancel
This signal is emitted whenever a sequence is cancelled. This usually
happens on active touches when EventControllerExt::reset() is called
on gesture (manually, due to grabs…), or the individual sequence
was claimed by parent widgets’ controllers (see GestureExt::set_sequence_state()).
gesture must forget everything about sequence as a reaction to this signal.
end
This signal is emitted when gesture either stopped recognizing the event
sequences as something to be handled (the check handler returned
false), or the number of touch sequences became higher or lower than
n-points.
Note: sequence might not pertain to the group of sequences that were
previously triggering recognition on gesture (ie. a just pressed touch
sequence that exceeds n-points). This situation may be detected
by checking through GestureExt::handles_sequence().
sequence-state-changed
This signal is emitted whenever a sequence state changes. See
GestureExt::set_sequence_state() to know more about the expectable
sequence lifetimes.
update
This signal is emitted whenever an event is handled while the gesture is
recognized. sequence is guaranteed to pertain to the set of active touches.
Implements
GestureSingleExt, GestureExt, EventControllerExt, glib::ObjectExt
Implementations
Sourceimpl GestureSwipe
impl GestureSwipe
Sourcepub fn new(widget: &impl IsA<Widget>) -> GestureSwipe
pub fn new(widget: &impl IsA<Widget>) -> GestureSwipe
Returns a newly created Gesture that recognizes swipes.
widget
a Widget
Returns
a newly created GestureSwipe
Sourcepub fn builder() -> GestureSwipeBuilder
pub fn builder() -> GestureSwipeBuilder
Creates a new builder-pattern struct instance to construct GestureSwipe objects.
This method returns an instance of GestureSwipeBuilder which can be used to create GestureSwipe objects.
Sourcepub fn velocity(&self) -> Option<(f64, f64)>
pub fn velocity(&self) -> Option<(f64, f64)>
If the gesture is recognized, this function returns true and fill in
velocity_x and velocity_y with the recorded velocity, as per the
last event(s) processed.
Returns
whether velocity could be calculated
velocity_x
return value for the velocity in the X axis, in pixels/sec
velocity_y
return value for the velocity in the Y axis, in pixels/sec
Sourcepub fn connect_swipe<F: Fn(&Self, f64, f64) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_swipe<F: Fn(&Self, f64, f64) + 'static>( &self, f: F, ) -> SignalHandlerId