Struct gtk::GestureSwipeClass
source · [−]#[repr(C)]pub struct GestureSwipeClass(_);Trait Implementations
sourceimpl Deref for GestureSwipeClass
impl Deref for GestureSwipeClass
type Target = <GestureSingle as ObjectType>::RustClassType
type Target = <GestureSingle as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for GestureSwipeClass
impl DerefMut for GestureSwipeClass
sourceimpl IsClassFor for GestureSwipeClass
impl IsClassFor for GestureSwipeClass
type Instance = GestureSwipe
type Instance = GestureSwipe
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for GestureSwipeClass
impl Sync for GestureSwipeClass