Struct gtk::GestureZoomClass
source · [−]#[repr(C)]pub struct GestureZoomClass(_);Trait Implementations
sourceimpl Deref for GestureZoomClass
impl Deref for GestureZoomClass
type Target = <Gesture as ObjectType>::RustClassType
type Target = <Gesture as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for GestureZoomClass
impl DerefMut for GestureZoomClass
sourceimpl IsClassFor for GestureZoomClass
impl IsClassFor for GestureZoomClass
type Instance = GestureZoom
type Instance = GestureZoom
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for GestureZoomClass
impl Sync for GestureZoomClass