Struct gtk::HeaderBarClass
source · [−]#[repr(C)]pub struct HeaderBarClass(_);Trait Implementations
sourceimpl Deref for HeaderBarClass
impl Deref for HeaderBarClass
type Target = <Container as ObjectType>::RustClassType
type Target = <Container as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for HeaderBarClass
impl DerefMut for HeaderBarClass
sourceimpl IsClassFor for HeaderBarClass
impl IsClassFor for HeaderBarClass
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for HeaderBarClass
impl Sync for HeaderBarClass