pub struct IMContext { /* private fields */ }Expand description
GtkIMContext * im_module_create(const gchar *context_id);
]|
This function should return a pointer to a newly created instance of the
IMContext subclass identified by context_id. The context ID is the same
as specified in the GtkIMContextInfo array returned by im_module_list().
After a new loadable input method module has been installed on the system,
the configuration file gtk.immodules needs to be
regenerated by [gtk-query-immodules-3.0][gtk-query-immodules-3.0],
in order for the new input method to become available to GTK+ applications.
This is an Abstract Base Class, you cannot instantiate it.
Properties
input-hints
Readable | Writable
input-purpose
Readable | Writable
Signals
commit
The ::commit signal is emitted when a complete input sequence has been entered by the user. This can be a single character immediately after a key press or the final result of preediting.
delete-surrounding
The ::delete-surrounding signal is emitted when the input method needs to delete all or part of the context surrounding the cursor.
preedit-changed
The ::preedit-changed signal is emitted whenever the preedit sequence
currently being entered has changed. It is also emitted at the end of
a preedit sequence, in which case
IMContextExt::preedit_string() returns the empty string.
preedit-end
The ::preedit-end signal is emitted when a preediting sequence has been completed or canceled.
preedit-start
The ::preedit-start signal is emitted when a new preediting sequence starts.
retrieve-surrounding
The ::retrieve-surrounding signal is emitted when the input method
requires the context surrounding the cursor. The callback should set
the input method surrounding context by calling the
IMContextExt::set_surrounding() method.
Implements
IMContextExt, [trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations