Struct gtk::IMContextClass
source · [−]#[repr(C)]pub struct IMContextClass(_);Trait Implementations
sourceimpl Deref for IMContextClass
impl Deref for IMContextClass
type Target = <Object as ObjectType>::RustClassType
type Target = <Object as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for IMContextClass
impl DerefMut for IMContextClass
sourceimpl IsClassFor for IMContextClass
impl IsClassFor for IMContextClass
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for IMContextClass
impl Sync for IMContextClass