pub struct IMContextSimple { /* private fields */ }Expand description
GtkIMContextSimple is a simple input method context supporting table-based input methods. It has a built-in table of compose sequences that is derived from the X11 Compose files.
GtkIMContextSimple reads additional compose sequences from the first of the following files that is found: ~/.config/gtk-3.0/Compose, ~/.XCompose, /usr/share/X11/locale/$locale/Compose (for locales that have a nontrivial Compose file). The syntax of these files is described in the Compose(5) manual page.
Unicode characters
GtkIMContextSimple also supports numeric entry of Unicode characters by typing Ctrl-Shift-u, followed by a hexadecimal Unicode codepoint. For example, Ctrl-Shift-u 1 2 3 Enter yields U+0123 LATIN SMALL LETTER G WITH CEDILLA, i.e. ģ.
Implements
IMContextExt, [trait@glib::ObjectExt], IMContextSimpleExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl IMContextSimple
impl IMContextSimple
pub const NONE: Option<&'static IMContextSimple> = None
Sourcepub fn new() -> IMContextSimple
pub fn new() -> IMContextSimple
Sourcepub fn builder() -> IMContextSimpleBuilder
pub fn builder() -> IMContextSimpleBuilder
Creates a new builder-pattern struct instance to construct IMContextSimple objects.
This method returns an instance of IMContextSimpleBuilder which can be used to create IMContextSimple objects.