pub struct IconInfo { /* private fields */ }Expand description
Contains information found when looking up an icon in an icon theme.
Implements
[trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl IconInfo
impl IconInfo
Sourcepub fn base_scale(&self) -> i32
pub fn base_scale(&self) -> i32
Gets the base scale for the icon. The base scale is a scale for the icon that was specified by the icon theme creator. For instance an icon drawn for a high-dpi screen with window scale 2 for a base size of 32 will be 64 pixels tall and have a base scale of 2.
Returns
the base scale
Sourcepub fn base_size(&self) -> i32
pub fn base_size(&self) -> i32
Gets the base size for the icon. The base size is a size for the icon that was specified by the icon theme creator. This may be different than the actual size of image; an example of this is small emblem icons that can be attached to a larger icon. These icons will be given the same base size as the larger icons to which they are attached.
Note that for scaled icons the base size does not include the base scale.
Returns
the base size, or 0, if no base size is known for the icon.
Sourcepub fn filename(&self) -> Option<PathBuf>
pub fn filename(&self) -> Option<PathBuf>
Gets the filename for the icon. If the IconLookupFlags::USE_BUILTIN
flag was passed to IconThemeExt::lookup_icon(), there may be no
filename if a builtin icon is returned; in this case, you should
use gtk_icon_info_get_builtin_pixbuf().
Returns
the filename for the icon, or None
if gtk_icon_info_get_builtin_pixbuf() should be used instead.
The return value is owned by GTK+ and should not be modified
or freed.
Sourcepub fn is_symbolic(&self) -> bool
pub fn is_symbolic(&self) -> bool
Sourcepub fn load_icon(&self) -> Result<Pixbuf, Error>
pub fn load_icon(&self) -> Result<Pixbuf, Error>
Renders an icon previously looked up in an icon theme using
IconThemeExt::lookup_icon(); the size will be based on the size
passed to IconThemeExt::lookup_icon(). Note that the resulting
pixbuf may not be exactly this size; an icon theme may have icons
that differ slightly from their nominal sizes, and in addition GTK+
will avoid scaling icons that it considers sufficiently close to the
requested size or for which the source image would have to be scaled
up too far. (This maintains sharpness.). This behaviour can be changed
by passing the IconLookupFlags::FORCE_SIZE flag when obtaining
the IconInfo. If this flag has been specified, the pixbuf
returned by this function will be scaled to the exact size.
Returns
the rendered icon; this may be a newly
created icon or a new reference to an internal icon, so you must
not modify the icon. Use g_object_unref() to release your reference
to the icon.
Sourcepub fn load_icon_async<P: FnOnce(Result<Pixbuf, Error>) + 'static>(
&self,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn load_icon_async<P: FnOnce(Result<Pixbuf, Error>) + 'static>( &self, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
Asynchronously load, render and scale an icon previously looked up
from the icon theme using IconThemeExt::lookup_icon().
For more details, see load_icon() which is the synchronous
version of this call.
cancellable
optional gio::Cancellable object, None to ignore
callback
a GAsyncReadyCallback to call when the
request is satisfied
pub fn load_icon_future( &self, ) -> Pin<Box_<dyn Future<Output = Result<Pixbuf, Error>> + 'static>>
Sourcepub fn load_surface(
&self,
for_window: Option<&Window>,
) -> Result<Surface, Error>
pub fn load_surface( &self, for_window: Option<&Window>, ) -> Result<Surface, Error>
Renders an icon previously looked up in an icon theme using
IconThemeExt::lookup_icon(); the size will be based on the size
passed to IconThemeExt::lookup_icon(). Note that the resulting
surface may not be exactly this size; an icon theme may have icons
that differ slightly from their nominal sizes, and in addition GTK+
will avoid scaling icons that it considers sufficiently close to the
requested size or for which the source image would have to be scaled
up too far. (This maintains sharpness.). This behaviour can be changed
by passing the IconLookupFlags::FORCE_SIZE flag when obtaining
the IconInfo. If this flag has been specified, the pixbuf
returned by this function will be scaled to the exact size.
for_window
gdk::Window to optimize drawing for, or None
Returns
the rendered icon; this may be a newly
created icon or a new reference to an internal icon, so you must
not modify the icon. Use cairo_surface_destroy() to release your
reference to the icon.
Sourcepub fn load_symbolic(
&self,
fg: &RGBA,
success_color: Option<&RGBA>,
warning_color: Option<&RGBA>,
error_color: Option<&RGBA>,
) -> Result<(Pixbuf, bool), Error>
pub fn load_symbolic( &self, fg: &RGBA, success_color: Option<&RGBA>, warning_color: Option<&RGBA>, error_color: Option<&RGBA>, ) -> Result<(Pixbuf, bool), Error>
Loads an icon, modifying it to match the system colours for the foreground,
success, warning and error colors provided. If the icon is not a symbolic
one, the function will return the result from load_icon().
This allows loading symbolic icons that will match the system theme.
Unless you are implementing a widget, you will want to use
g_themed_icon_new_with_default_fallbacks() to load the icon.
As implementation details, the icon loaded needs to be of SVG type, contain the “symbolic” term as the last component of the icon name, and use the “fg”, “success”, “warning” and “error” CSS styles in the SVG file itself.
See the Symbolic Icons Specification for more information about symbolic icons.
fg
a gdk::RGBA representing the foreground color of the icon
success_color
a gdk::RGBA representing the warning color
of the icon or None to use the default color
warning_color
a gdk::RGBA representing the warning color
of the icon or None to use the default color
error_color
a gdk::RGBA representing the error color
of the icon or None to use the default color (allow-none)
Returns
a gdk_pixbuf::Pixbuf representing the loaded icon
was_symbolic
a gboolean, returns whether the
loaded icon was a symbolic one and whether the fg color was
applied to it.
Sourcepub fn load_symbolic_async<P: FnOnce(Result<(Pixbuf, bool), Error>) + 'static>(
&self,
fg: &RGBA,
success_color: Option<&RGBA>,
warning_color: Option<&RGBA>,
error_color: Option<&RGBA>,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn load_symbolic_async<P: FnOnce(Result<(Pixbuf, bool), Error>) + 'static>( &self, fg: &RGBA, success_color: Option<&RGBA>, warning_color: Option<&RGBA>, error_color: Option<&RGBA>, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
Asynchronously load, render and scale a symbolic icon previously looked up
from the icon theme using IconThemeExt::lookup_icon().
For more details, see load_symbolic() which is the synchronous
version of this call.
fg
a gdk::RGBA representing the foreground color of the icon
success_color
a gdk::RGBA representing the warning color
of the icon or None to use the default color
warning_color
a gdk::RGBA representing the warning color
of the icon or None to use the default color
error_color
a gdk::RGBA representing the error color
of the icon or None to use the default color (allow-none)
cancellable
optional gio::Cancellable object,
None to ignore
callback
a GAsyncReadyCallback to call when the
request is satisfied
pub fn load_symbolic_future( &self, fg: &RGBA, success_color: Option<&RGBA>, warning_color: Option<&RGBA>, error_color: Option<&RGBA>, ) -> Pin<Box_<dyn Future<Output = Result<(Pixbuf, bool), Error>> + 'static>>
Sourcepub fn load_symbolic_for_context(
&self,
context: &impl IsA<StyleContext>,
) -> Result<(Pixbuf, bool), Error>
pub fn load_symbolic_for_context( &self, context: &impl IsA<StyleContext>, ) -> Result<(Pixbuf, bool), Error>
Loads an icon, modifying it to match the system colors for the foreground,
success, warning and error colors provided. If the icon is not a symbolic
one, the function will return the result from load_icon().
This function uses the regular foreground color and the symbolic colors
with the names “success_color”, “warning_color” and “error_color” from
the context.
This allows loading symbolic icons that will match the system theme.
See load_symbolic() for more details.
context
Returns
a gdk_pixbuf::Pixbuf representing the loaded icon
was_symbolic
a gboolean, returns whether the
loaded icon was a symbolic one and whether the fg color was
applied to it.
Sourcepub fn load_symbolic_for_context_async<P: FnOnce(Result<(Pixbuf, bool), Error>) + 'static>(
&self,
context: &impl IsA<StyleContext>,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn load_symbolic_for_context_async<P: FnOnce(Result<(Pixbuf, bool), Error>) + 'static>( &self, context: &impl IsA<StyleContext>, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
Asynchronously load, render and scale a symbolic icon previously
looked up from the icon theme using IconThemeExt::lookup_icon().
For more details, see load_symbolic_for_context()
which is the synchronous version of this call.
context
cancellable
optional gio::Cancellable object,
None to ignore
callback
a GAsyncReadyCallback to call when the
request is satisfied
pub fn load_symbolic_for_context_future( &self, context: &(impl IsA<StyleContext> + Clone + 'static), ) -> Pin<Box_<dyn Future<Output = Result<(Pixbuf, bool), Error>> + 'static>>