Struct gtk::IconLookupFlags
source · [−]pub struct IconLookupFlags { /* private fields */ }Implementations
sourceimpl IconLookupFlags
impl IconLookupFlags
pub const NO_SVG: IconLookupFlags = _
pub const FORCE_SVG: IconLookupFlags = _
pub const USE_BUILTIN: IconLookupFlags = _
pub const GENERIC_FALLBACK: IconLookupFlags = _
pub const FORCE_SIZE: IconLookupFlags = _
pub const FORCE_REGULAR: IconLookupFlags = _
pub const FORCE_SYMBOLIC: IconLookupFlags = _
pub const DIR_LTR: IconLookupFlags = _
pub const DIR_RTL: IconLookupFlags = _
sourcepub const fn empty() -> IconLookupFlags
pub const fn empty() -> IconLookupFlags
Returns an empty set of flags
sourcepub const fn all() -> IconLookupFlags
pub const fn all() -> IconLookupFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<IconLookupFlags>
pub fn from_bits(bits: u32) -> Option<IconLookupFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> IconLookupFlags
pub const fn from_bits_truncate(bits: u32) -> IconLookupFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> IconLookupFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> IconLookupFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: IconLookupFlags) -> bool
pub const fn intersects(&self, other: IconLookupFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: IconLookupFlags) -> bool
pub const fn contains(&self, other: IconLookupFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: IconLookupFlags)
pub fn insert(&mut self, other: IconLookupFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: IconLookupFlags)
pub fn remove(&mut self, other: IconLookupFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: IconLookupFlags)
pub fn toggle(&mut self, other: IconLookupFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: IconLookupFlags, value: bool)
pub fn set(&mut self, other: IconLookupFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.