IconTheme

Struct IconTheme 

pub struct IconTheme { /* private fields */ }
message); g_error_free (error); } else { // Use the pixbuf g_object_unref (pixbuf); } ]|

Signals

changed

Emitted when the current icon theme is switched or GTK+ detects that a change has occurred in the contents of the current icon theme.

Implements

IconThemeExt, [trait@glib::ObjectExt]

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl IconTheme

pub const NONE: Option<&'static IconTheme> = None

pub fn new() -> IconTheme

Creates a new icon theme object. Icon theme objects are used to lookup up an icon by name in a particular icon theme. Usually, you’ll want to use default() or for_screen() rather than creating a new icon theme object for scratch.

Returns

the newly created IconTheme object.

pub fn default() -> Option<IconTheme>

Gets the icon theme for the default screen. See for_screen().

Returns

A unique IconTheme associated with the default screen. This icon theme is associated with the screen and can be used as long as the screen is open. Do not ref or unref it.

pub fn for_screen(screen: &Screen) -> Option<IconTheme>

Gets the icon theme object associated with screen; if this function has not previously been called for the given screen, a new icon theme object will be created and associated with the screen. Icon theme objects are fairly expensive to create, so using this function is usually a better choice than calling than new() and setting the screen yourself; by using this function a single icon theme object will be shared between users.

screen

a gdk::Screen

Returns

A unique IconTheme associated with the given screen. This icon theme is associated with the screen and can be used as long as the screen is open. Do not ref or unref it.