Struct gtk::IconViewClass
source · [−]#[repr(C)]pub struct IconViewClass(_);Trait Implementations
sourceimpl Deref for IconViewClass
impl Deref for IconViewClass
type Target = <Container as ObjectType>::RustClassType
type Target = <Container as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for IconViewClass
impl DerefMut for IconViewClass
sourceimpl IsClassFor for IconViewClass
impl IsClassFor for IconViewClass
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for IconViewClass
impl Sync for IconViewClass