Struct gtk::InputHints
source · [−]pub struct InputHints { /* private fields */ }Implementations
sourceimpl InputHints
impl InputHints
pub const NONE: InputHints = _
pub const SPELLCHECK: InputHints = _
pub const NO_SPELLCHECK: InputHints = _
pub const WORD_COMPLETION: InputHints = _
pub const LOWERCASE: InputHints = _
pub const UPPERCASE_CHARS: InputHints = _
pub const UPPERCASE_WORDS: InputHints = _
pub const UPPERCASE_SENTENCES: InputHints = _
pub const INHIBIT_OSK: InputHints = _
pub const VERTICAL_WRITING: InputHints = _
sourcepub const fn empty() -> InputHints
pub const fn empty() -> InputHints
Returns an empty set of flags
sourcepub const fn all() -> InputHints
pub const fn all() -> InputHints
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<InputHints>
pub fn from_bits(bits: u32) -> Option<InputHints>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> InputHints
pub const fn from_bits_truncate(bits: u32) -> InputHints
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> InputHints
pub const unsafe fn from_bits_unchecked(bits: u32) -> InputHints
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: InputHints) -> bool
pub const fn intersects(&self, other: InputHints) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: InputHints) -> bool
pub const fn contains(&self, other: InputHints) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: InputHints)
pub fn insert(&mut self, other: InputHints)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: InputHints)
pub fn remove(&mut self, other: InputHints)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: InputHints)
pub fn toggle(&mut self, other: InputHints)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: InputHints, value: bool)
pub fn set(&mut self, other: InputHints, value: bool)
Inserts or removes the specified flags depending on the passed value.