Struct gtk::JunctionSides
source · [−]pub struct JunctionSides { /* private fields */ }Implementations
sourceimpl JunctionSides
impl JunctionSides
pub const NONE: JunctionSides = _
pub const CORNER_TOPLEFT: JunctionSides = _
pub const CORNER_TOPRIGHT: JunctionSides = _
pub const CORNER_BOTTOMLEFT: JunctionSides = _
pub const CORNER_BOTTOMRIGHT: JunctionSides = _
pub const TOP: JunctionSides = _
pub const BOTTOM: JunctionSides = _
pub const LEFT: JunctionSides = _
pub const RIGHT: JunctionSides = _
sourcepub const fn empty() -> JunctionSides
pub const fn empty() -> JunctionSides
Returns an empty set of flags
sourcepub const fn all() -> JunctionSides
pub const fn all() -> JunctionSides
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<JunctionSides>
pub fn from_bits(bits: u32) -> Option<JunctionSides>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> JunctionSides
pub const fn from_bits_truncate(bits: u32) -> JunctionSides
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> JunctionSides
pub const unsafe fn from_bits_unchecked(bits: u32) -> JunctionSides
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: JunctionSides) -> bool
pub const fn intersects(&self, other: JunctionSides) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: JunctionSides) -> bool
pub const fn contains(&self, other: JunctionSides) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: JunctionSides)
pub fn insert(&mut self, other: JunctionSides)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: JunctionSides)
pub fn remove(&mut self, other: JunctionSides)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: JunctionSides)
pub fn toggle(&mut self, other: JunctionSides)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: JunctionSides, value: bool)
pub fn set(&mut self, other: JunctionSides, value: bool)
Inserts or removes the specified flags depending on the passed value.