Struct gtk::LabelClass
source · [−]#[repr(C)]pub struct LabelClass(_);Trait Implementations
sourceimpl Deref for LabelClass
impl Deref for LabelClass
type Target = <Misc as ObjectType>::RustClassType
type Target = <Misc as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for LabelClass
impl DerefMut for LabelClass
sourceimpl IsClassFor for LabelClass
impl IsClassFor for LabelClass
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for LabelClass
impl Sync for LabelClass