Struct gtk::MenuButtonClass
source · [−]#[repr(C)]pub struct MenuButtonClass(_);Trait Implementations
sourceimpl Deref for MenuButtonClass
impl Deref for MenuButtonClass
type Target = <ToggleButton as ObjectType>::RustClassType
type Target = <ToggleButton as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for MenuButtonClass
impl DerefMut for MenuButtonClass
sourceimpl IsClassFor for MenuButtonClass
impl IsClassFor for MenuButtonClass
type Instance = MenuButton
type Instance = MenuButton
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for MenuButtonClass
impl Sync for MenuButtonClass