Struct gtk::MenuItemClass
source · [−]#[repr(C)]pub struct MenuItemClass(_);Trait Implementations
sourceimpl Deref for MenuItemClass
impl Deref for MenuItemClass
type Target = <Bin as ObjectType>::RustClassType
type Target = <Bin as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for MenuItemClass
impl DerefMut for MenuItemClass
sourceimpl IsClassFor for MenuItemClass
impl IsClassFor for MenuItemClass
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for MenuItemClass
impl Sync for MenuItemClass