Struct gtk::MenuShellClass
source · [−]#[repr(C)]pub struct MenuShellClass(_);Trait Implementations
sourceimpl Deref for MenuShellClass
impl Deref for MenuShellClass
type Target = <Container as ObjectType>::RustClassType
type Target = <Container as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for MenuShellClass
impl DerefMut for MenuShellClass
sourceimpl IsClassFor for MenuShellClass
impl IsClassFor for MenuShellClass
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for MenuShellClass
impl Sync for MenuShellClass