Struct gtk::MenuToolButtonClass
source · [−]#[repr(C)]pub struct MenuToolButtonClass(_);Trait Implementations
sourceimpl Deref for MenuToolButtonClass
impl Deref for MenuToolButtonClass
type Target = <ToolButton as ObjectType>::RustClassType
type Target = <ToolButton as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for MenuToolButtonClass
impl DerefMut for MenuToolButtonClass
sourceimpl IsClassFor for MenuToolButtonClass
impl IsClassFor for MenuToolButtonClass
type Instance = MenuToolButton
type Instance = MenuToolButton
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for MenuToolButtonClass
impl Sync for MenuToolButtonClass