Struct gtk::MessageDialogClass
source · [−]#[repr(C)]pub struct MessageDialogClass(_);Trait Implementations
sourceimpl Deref for MessageDialogClass
impl Deref for MessageDialogClass
type Target = <Dialog as ObjectType>::RustClassType
type Target = <Dialog as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for MessageDialogClass
impl DerefMut for MessageDialogClass
sourceimpl IsClassFor for MessageDialogClass
impl IsClassFor for MessageDialogClass
type Instance = MessageDialog
type Instance = MessageDialog
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for MessageDialogClass
impl Sync for MessageDialogClass