Struct gtk::ModelButtonClass
source · [−]#[repr(C)]pub struct ModelButtonClass(_);Trait Implementations
sourceimpl Deref for ModelButtonClass
impl Deref for ModelButtonClass
type Target = <Button as ObjectType>::RustClassType
type Target = <Button as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ModelButtonClass
impl DerefMut for ModelButtonClass
sourceimpl IsClassFor for ModelButtonClass
impl IsClassFor for ModelButtonClass
type Instance = ModelButton
type Instance = ModelButton
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ModelButtonClass
impl Sync for ModelButtonClass