Struct gtk::MountOperationClass
source · [−]#[repr(C)]pub struct MountOperationClass(_);Trait Implementations
sourceimpl Deref for MountOperationClass
impl Deref for MountOperationClass
type Target = <MountOperation as ObjectType>::RustClassType
type Target = <MountOperation as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for MountOperationClass
impl DerefMut for MountOperationClass
sourceimpl IsClassFor for MountOperationClass
impl IsClassFor for MountOperationClass
type Instance = MountOperation
type Instance = MountOperation
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for MountOperationClass
impl Sync for MountOperationClass