pub struct OffscreenWindow { /* private fields */ }Expand description
GtkOffscreenWindow is strictly intended to be used for obtaining
snapshots of widgets that are not part of a normal widget hierarchy.
Since OffscreenWindow is a toplevel widget you cannot obtain
snapshots of a full window with it since you cannot pack a toplevel
widget in another toplevel.
The idea is to take a widget and manually set the state of it,
add it to a GtkOffscreenWindow and then retrieve the snapshot
as a cairo::Surface or gdk_pixbuf::Pixbuf.
GtkOffscreenWindow derives from Window only as an implementation
detail. Applications should not use any API specific to Window
to operate on this object. It should be treated as a Bin that
has no parent widget.
When contained offscreen widgets are redrawn, GtkOffscreenWindow
will emit a damage-event signal.
Implements
OffscreenWindowExt, GtkWindowExt, BinExt, ContainerExt, WidgetExt, glib::ObjectExt, BuildableExt, [GtkWindowExtManual][trait@crate::prelude::GtkWindowExtManual], ContainerExtManual, WidgetExtManual, BuildableExtManual
Implementations
Sourceimpl OffscreenWindow
impl OffscreenWindow
pub const NONE: Option<&'static OffscreenWindow> = None
Sourcepub fn new() -> OffscreenWindow
pub fn new() -> OffscreenWindow
Sourcepub fn builder() -> OffscreenWindowBuilder
pub fn builder() -> OffscreenWindowBuilder
Creates a new builder-pattern struct instance to construct OffscreenWindow objects.
This method returns an instance of OffscreenWindowBuilder which can be used to create OffscreenWindow objects.