pub struct PadController { /* private fields */ }Expand description
PadController is an event controller for the pads found in drawing
tablets (The collection of buttons and tactile sensors often found around
the stylus-sensitive area).
These buttons and sensors have no implicit meaning, and by default they
perform no action, this event controller is provided to map those to
GAction objects, thus letting the application give those a more semantic
meaning.
Buttons and sensors are not constrained to triggering a single action, some
GDK_SOURCE_TABLET_PAD devices feature multiple “modes”, all these input
elements have one current mode, which may determine the final action
being triggered. Pad devices often divide buttons and sensors into groups,
all elements in a group share the same current mode, but different groups
may have different modes. See gdk_device_pad_get_n_groups() and
gdk_device_pad_get_group_n_modes().
Each of the actions that a given button/strip/ring performs for a given
mode is defined by PadActionEntry, it contains an action name that
will be looked up in the given gio::ActionGroup and activated whenever the
specified input element and mode are triggered.
A simple example of PadController usage, assigning button 1 in all
modes and pad devices to an “invert-selection” action:
GtkPadActionEntry *pad_actions[] = {
{ GTK_PAD_ACTION_BUTTON, 1, -1, "Invert selection", "pad-actions.invert-selection" },
…
};
…
action_group = g_simple_action_group_new ();
action = g_simple_action_new ("pad-actions.invert-selection", NULL);
g_signal_connect (action, "activate", on_invert_selection_activated, NULL);
g_action_map_add_action (G_ACTION_MAP (action_group), action);
…
pad_controller = gtk_pad_controller_new (window, action_group, NULL);The actions belonging to rings/strips will be activated with a parameter
of type G_VARIANT_TYPE_DOUBLE bearing the value of the given axis, it
is required that those are made stateful and accepting this glib::VariantType.
Properties
action-group
Readable | Writable | Construct Only
pad
Readable | Writable | Construct Only
EventController
propagation-phase
The propagation phase at which this controller will handle events.
Readable | Writable
widget
The widget receiving the GdkEvents that the controller will handle.
Readable | Writable | Construct Only
Implements
EventControllerExt, [trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl PadController
impl PadController
Sourcepub fn new(
window: &impl IsA<Window>,
group: &impl IsA<ActionGroup>,
pad: Option<&Device>,
) -> PadController
pub fn new( window: &impl IsA<Window>, group: &impl IsA<ActionGroup>, pad: Option<&Device>, ) -> PadController
Creates a new PadController that will associate events from pad to
actions. A None pad may be provided so the controller manages all pad devices
generically, it is discouraged to mix PadController objects with None
and non-None pad argument on the same window, as execution order is not
guaranteed.
The PadController is created with no mapped actions. In order to map pad
events to actions, use set_action_entries() or
set_action().
window
a Window
group
gio::ActionGroup to trigger actions from
pad
A GDK_SOURCE_TABLET_PAD device, or None to handle all pads
Returns
A newly created PadController
Sourcepub fn builder() -> PadControllerBuilder
pub fn builder() -> PadControllerBuilder
Creates a new builder-pattern struct instance to construct PadController objects.
This method returns an instance of PadControllerBuilder which can be used to create PadController objects.
Sourcepub fn set_action(
&self,
type_: PadActionType,
index: i32,
mode: i32,
label: &str,
action_name: &str,
)
pub fn set_action( &self, type_: PadActionType, index: i32, mode: i32, label: &str, action_name: &str, )
Adds an individual action to self. This action will only be activated
if the given button/ring/strip number in index is interacted while
the current mode is mode. -1 may be used for simple cases, so the action
is triggered on all modes.
The given label should be considered user-visible, so internationalization
rules apply. Some windowing systems may be able to use those for user
feedback.
type_
the type of pad feature that will trigger this action
index
the 0-indexed button/ring/strip number that will trigger this action
mode
the mode that will trigger this action, or -1 for all modes.
label
Human readable description of this action, this string should be deemed user-visible.
action_name
action name that will be activated in the gio::ActionGroup
pub fn action_group(&self) -> Option<ActionGroup>
pub fn pad(&self) -> Option<Device>
Sourceimpl PadController
impl PadController
Sourcepub fn set_action_entries(&self, entries: &[PadActionEntry])
pub fn set_action_entries(&self, entries: &[PadActionEntry])
This is a convenience function to add a group of action entries on
self. See PadActionEntry and set_action().
entries
the action entries to set on self