pub struct PageSetup { /* private fields */ }Expand description
static GtkPrintSettings *settings = NULL; static GtkPageSetup *page_setup = NULL;
static void do_page_setup (void) { GtkPageSetup *new_page_setup;
if (settings == NULL) settings = gtk_print_settings_new ();
new_page_setup = gtk_print_run_page_setup_dialog (GTK_WINDOW (main_window), page_setup, settings);
if (page_setup) g_object_unref (page_setup);
page_setup = new_page_setup; } ]|
Printing support was added in GTK+ 2.10.
Implements
[trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl PageSetup
impl PageSetup
Sourcepub fn from_gvariant(variant: &Variant) -> PageSetup
pub fn from_gvariant(variant: &Variant) -> PageSetup
Desrialize a page setup from an a{sv} variant in
the format produced by to_gvariant().
variant
an a{sv} glib::Variant
Returns
a new PageSetup object
Sourcepub fn from_key_file(
key_file: &KeyFile,
group_name: Option<&str>,
) -> Result<PageSetup, Error>
pub fn from_key_file( key_file: &KeyFile, group_name: Option<&str>, ) -> Result<PageSetup, Error>
Reads the page setup from the group group_name in the key file
key_file. Returns a new PageSetup object with the restored
page setup, or None if an error occurred.
key_file
the glib::KeyFile to retrieve the page_setup from
group_name
the name of the group in the key_file to read, or None
to use the default name “Page Setup”
Returns
the restored PageSetup
pub fn copy(&self) -> Option<PageSetup>
Sourcepub fn bottom_margin(&self, unit: Unit) -> f64
pub fn bottom_margin(&self, unit: Unit) -> f64
Sourcepub fn left_margin(&self, unit: Unit) -> f64
pub fn left_margin(&self, unit: Unit) -> f64
Sourcepub fn orientation(&self) -> PageOrientation
pub fn orientation(&self) -> PageOrientation
Sourcepub fn page_height(&self, unit: Unit) -> f64
pub fn page_height(&self, unit: Unit) -> f64
Returns the page height in units of unit.
Note that this function takes orientation and
margins into consideration.
See paper_height().
unit
the unit for the return value
Returns
the page height.
Sourcepub fn page_width(&self, unit: Unit) -> f64
pub fn page_width(&self, unit: Unit) -> f64
Returns the page width in units of unit.
Note that this function takes orientation and
margins into consideration.
See paper_width().
unit
the unit for the return value
Returns
the page width.
Sourcepub fn paper_height(&self, unit: Unit) -> f64
pub fn paper_height(&self, unit: Unit) -> f64
Returns the paper height in units of unit.
Note that this function takes orientation, but
not margins into consideration.
See page_height().
unit
the unit for the return value
Returns
the paper height.
Sourcepub fn paper_size(&self) -> PaperSize
pub fn paper_size(&self) -> PaperSize
Sourcepub fn paper_width(&self, unit: Unit) -> f64
pub fn paper_width(&self, unit: Unit) -> f64
Returns the paper width in units of unit.
Note that this function takes orientation, but
not margins into consideration.
See page_width().
unit
the unit for the return value
Returns
the paper width.
Sourcepub fn right_margin(&self, unit: Unit) -> f64
pub fn right_margin(&self, unit: Unit) -> f64
Sourcepub fn top_margin(&self, unit: Unit) -> f64
pub fn top_margin(&self, unit: Unit) -> f64
Sourcepub fn load_key_file(
&self,
key_file: &KeyFile,
group_name: Option<&str>,
) -> Result<(), Error>
pub fn load_key_file( &self, key_file: &KeyFile, group_name: Option<&str>, ) -> Result<(), Error>
Sourcepub fn set_bottom_margin(&self, margin: f64, unit: Unit)
pub fn set_bottom_margin(&self, margin: f64, unit: Unit)
Sourcepub fn set_left_margin(&self, margin: f64, unit: Unit)
pub fn set_left_margin(&self, margin: f64, unit: Unit)
Sourcepub fn set_orientation(&self, orientation: PageOrientation)
pub fn set_orientation(&self, orientation: PageOrientation)
Sourcepub fn set_paper_size(&self, size: &PaperSize)
pub fn set_paper_size(&self, size: &PaperSize)
Sets the paper size of the PageSetup without
changing the margins. See
set_paper_size_and_default_margins().
size
Sourcepub fn set_paper_size_and_default_margins(&self, size: &PaperSize)
pub fn set_paper_size_and_default_margins(&self, size: &PaperSize)
Sourcepub fn set_right_margin(&self, margin: f64, unit: Unit)
pub fn set_right_margin(&self, margin: f64, unit: Unit)
Sourcepub fn set_top_margin(&self, margin: f64, unit: Unit)
pub fn set_top_margin(&self, margin: f64, unit: Unit)
Sourcepub fn to_gvariant(&self) -> Option<Variant>
pub fn to_gvariant(&self) -> Option<Variant>
Sourcepub fn to_key_file(&self, key_file: &KeyFile, group_name: Option<&str>)
pub fn to_key_file(&self, key_file: &KeyFile, group_name: Option<&str>)
This function adds the page setup from self to key_file.
key_file
the glib::KeyFile to save the page setup to
group_name
the group to add the settings to in key_file,
or None to use the default name “Page Setup”