pub struct PlacesOpenFlags(/* private fields */);Expand description
These flags serve two purposes. First, the application can call PlacesSidebar::set_open_flags()
using these flags as a bitmask. This tells the sidebar that the application is able to open
folders selected from the sidebar in various ways, for example, in new tabs or in new windows in
addition to the normal mode.
Second, when one of these values gets passed back to the application in the
open-location signal, it means that the application should
open the selected location in the normal way, in a new tab, or in a new
window. The sidebar takes care of determining the desired way to open the location,
based on the modifier keys that the user is pressing at the time the selection is made.
If the application never calls PlacesSidebar::set_open_flags(), then the sidebar will only
use NORMAL in the open-location signal. This is the
default mode of operation.
Implementations
Sourceimpl PlacesOpenFlags
impl PlacesOpenFlags
Sourcepub const NORMAL: Self
pub const NORMAL: Self
This is the default mode that PlacesSidebar uses if no other flags
are specified. It indicates that the calling application should open the selected location
in the normal way, for example, in the folder view beside the sidebar.
Sourcepub const NEW_TAB: Self
pub const NEW_TAB: Self
When passed to PlacesSidebar::set_open_flags(), this indicates
that the application can open folders selected from the sidebar in new tabs. This value
will be passed to the open-location signal when the user selects
that a location be opened in a new tab instead of in the standard fashion.
Sourcepub const NEW_WINDOW: Self
pub const NEW_WINDOW: Self
Similar to NEW_TAB, but indicates that the application
can open folders in new windows.
Sourceimpl PlacesOpenFlags
impl PlacesOpenFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl PlacesOpenFlags
impl PlacesOpenFlags
Sourcepub const fn iter(&self) -> Iter<PlacesOpenFlags> ⓘ
pub const fn iter(&self) -> Iter<PlacesOpenFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<PlacesOpenFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<PlacesOpenFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.