Struct gtk::PlacesSidebarClass
source · [−]#[repr(C)]pub struct PlacesSidebarClass(_);Trait Implementations
sourceimpl Deref for PlacesSidebarClass
impl Deref for PlacesSidebarClass
type Target = <ScrolledWindow as ObjectType>::RustClassType
type Target = <ScrolledWindow as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for PlacesSidebarClass
impl DerefMut for PlacesSidebarClass
sourceimpl IsClassFor for PlacesSidebarClass
impl IsClassFor for PlacesSidebarClass
type Instance = PlacesSidebar
type Instance = PlacesSidebar
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for PlacesSidebarClass
impl Sync for PlacesSidebarClass