Struct gtk::PopoverMenuClass
source · [−]#[repr(C)]pub struct PopoverMenuClass(_);Trait Implementations
sourceimpl Deref for PopoverMenuClass
impl Deref for PopoverMenuClass
type Target = <Popover as ObjectType>::RustClassType
type Target = <Popover as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for PopoverMenuClass
impl DerefMut for PopoverMenuClass
sourceimpl IsClassFor for PopoverMenuClass
impl IsClassFor for PopoverMenuClass
type Instance = PopoverMenu
type Instance = PopoverMenu
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for PopoverMenuClass
impl Sync for PopoverMenuClass