Struct gtk::RadioButtonClass
source · [−]#[repr(C)]pub struct RadioButtonClass(_);Trait Implementations
sourceimpl Deref for RadioButtonClass
impl Deref for RadioButtonClass
type Target = <CheckButton as ObjectType>::RustClassType
type Target = <CheckButton as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for RadioButtonClass
impl DerefMut for RadioButtonClass
sourceimpl IsClassFor for RadioButtonClass
impl IsClassFor for RadioButtonClass
type Instance = RadioButton
type Instance = RadioButton
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for RadioButtonClass
impl Sync for RadioButtonClass