Struct gtk::RadioMenuItemClass
source · [−]#[repr(C)]pub struct RadioMenuItemClass(_);Trait Implementations
sourceimpl Deref for RadioMenuItemClass
impl Deref for RadioMenuItemClass
type Target = <CheckMenuItem as ObjectType>::RustClassType
type Target = <CheckMenuItem as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for RadioMenuItemClass
impl DerefMut for RadioMenuItemClass
sourceimpl IsClassFor for RadioMenuItemClass
impl IsClassFor for RadioMenuItemClass
type Instance = RadioMenuItem
type Instance = RadioMenuItem
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for RadioMenuItemClass
impl Sync for RadioMenuItemClass