pub struct RadioToolButton { /* private fields */ }Expand description
A RadioToolButton is a ToolItem that contains a radio button,
that is, a button that is part of a group of toggle buttons where only
one button can be active at a time.
Use new() to create a new GtkRadioToolButton. Use
from_widget() to create a new GtkRadioToolButton
that is part of the same group as an existing GtkRadioToolButton.
CSS nodes
GtkRadioToolButton has a single CSS node with name toolbutton.
Properties
group
Sets a new group for a radio tool button.
Writable
ToolButton
icon-name
The name of the themed icon displayed on the item.
This property only has an effect if not overridden by
label-widget, icon-widget or
stock-id properties.
Readable | Writable
icon-widget
Readable | Writable
label
Readable | Writable
label-widget
Readable | Writable
stock-id
Readable | Writable
use-underline
Readable | Writable
ToolItem
is-important
Readable | Writable
visible-horizontal
Readable | Writable
visible-vertical
Readable | Writable
Widget
app-paintable
Readable | Writable
can-default
Readable | Writable
can-focus
Readable | Writable
composite-child
Readable
double-buffered
Whether the widget is double buffered.
Readable | Writable
events
Readable | Writable
expand
Whether to expand in both directions. Setting this sets both hexpand and vexpand
Readable | Writable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Before 3.20, several widgets (GtkButton, GtkFileChooserButton, GtkComboBox) implemented this property individually.
Readable | Writable
halign
How to distribute horizontal space if widget gets extra space, see Align
Readable | Writable
has-default
Readable | Writable
has-focus
Readable | Writable
has-tooltip
Enables or disables the emission of query-tooltip on widget.
A value of true indicates that widget can have a tooltip, in this case
the widget will be queried using query-tooltip to determine
whether it will provide a tooltip or not.
Note that setting this property to true for the first time will change
the event masks of the GdkWindows of this widget to include leave-notify
and motion-notify events. This cannot and will not be undone when the
property is set to false again.
Readable | Writable
height-request
Readable | Writable
hexpand
Whether to expand horizontally. See WidgetExt::set_hexpand().
Readable | Writable
hexpand-set
Whether to use the hexpand property. See WidgetExt::is_hexpand_set().
Readable | Writable
is-focus
Readable | Writable
margin
Sets all four sides’ margin at once. If read, returns max margin on any side.
Readable | Writable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-end
Margin on end of widget, horizontally. This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-left
Margin on left side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-right
Margin on right side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-start
Margin on start of widget, horizontally. This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
WidgetExt::set_size_request() for example.
Readable | Writable
name
Readable | Writable
no-show-all
Readable | Writable
opacity
The requested opacity of the widget. See WidgetExt::set_opacity() for
more details about window opacity.
Before 3.8 this was only available in GtkWindow
Readable | Writable
parent
Readable | Writable
receives-default
Readable | Writable
scale-factor
The scale factor of the widget. See WidgetExt::scale_factor() for
more details about widget scaling.
Readable
sensitive
Readable | Writable
style
The style of the widget, which contains information about how it will look (colors, etc).
Readable | Writable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up
with the [Pango text markup language][PangoMarkupFormat].
Also see Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not None: has-tooltip
will automatically be set to true and there will be taken care of
query-tooltip in the default signal handler.
Note that if both tooltip-text and tooltip-markup
are set, the last one wins.
Readable | Writable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not None: has-tooltip
will automatically be set to true and there will be taken care of
query-tooltip in the default signal handler.
Note that if both tooltip-text and tooltip-markup
are set, the last one wins.
Readable | Writable
valign
How to distribute vertical space if widget gets extra space, see Align
Readable | Writable
vexpand
Whether to expand vertically. See WidgetExt::set_vexpand().
Readable | Writable
vexpand-set
Whether to use the vexpand property. See WidgetExt::is_vexpand_set().
Readable | Writable
visible
Readable | Writable
width-request
Readable | Writable
window
The widget’s window if it is realized, None otherwise.
Readable
Activatable
related-action
call gtk_activatable_do_set_related_action() when it changes.
Readable | Writable
use-action-appearance
widget when it changes.
Readable | Writable
Implements
RadioToolButtonExt, ToggleToolButtonExt, ToolButtonExt, ToolItemExt, BinExt, ContainerExt, WidgetExt, [trait@glib::ObjectExt], BuildableExt, ActionableExt, ContainerExtManual, WidgetExtManual, BuildableExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl RadioToolButton
impl RadioToolButton
pub const NONE: Option<&'static RadioToolButton> = None
Sourcepub fn from_widget(group: &impl IsA<RadioToolButton>) -> RadioToolButton
pub fn from_widget(group: &impl IsA<RadioToolButton>) -> RadioToolButton
Creates a new RadioToolButton adding it to the same group as gruup
group
An existing RadioToolButton, or None
Returns
The new RadioToolButton
Sourcepub fn builder() -> RadioToolButtonBuilder
pub fn builder() -> RadioToolButtonBuilder
Creates a new builder-pattern struct instance to construct RadioToolButton objects.
This method returns an instance of RadioToolButtonBuilder which can be used to create RadioToolButton objects.
Sourceimpl RadioToolButton
impl RadioToolButton
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new RadioToolButton, adding it to group.
group
An
existing radio button group, or None if you are creating a new group
Returns
The new RadioToolButton
pub fn from_stock(stock_id: &str) -> Self
pub fn join_group(&self, group: Option<&RadioToolButton>)