Struct gtk::RadioToolButtonClass
source · [−]#[repr(C)]pub struct RadioToolButtonClass(_);Trait Implementations
sourceimpl Deref for RadioToolButtonClass
impl Deref for RadioToolButtonClass
type Target = <ToggleToolButton as ObjectType>::RustClassType
type Target = <ToggleToolButton as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for RadioToolButtonClass
impl DerefMut for RadioToolButtonClass
sourceimpl IsClassFor for RadioToolButtonClass
impl IsClassFor for RadioToolButtonClass
type Instance = RadioToolButton
type Instance = RadioToolButton
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for RadioToolButtonClass
impl Sync for RadioToolButtonClass