pub struct RecentChooser { /* private fields */ }Expand description
RecentChooser is an interface that can be implemented by widgets
displaying the list of recently used files. In GTK+, the main objects
that implement this interface are RecentChooserWidget,
RecentChooserDialog and RecentChooserMenu.
Recently used files are supported since GTK+ 2.10.
Properties
filter
The RecentFilter object to be used when displaying
the recently used resources.
Readable | Writable
limit
The maximum number of recently used resources to be displayed, or -1 to display all items.
Readable | Writable
local-only
Whether this RecentChooser should display only local (file:)
resources.
Readable | Writable
recent-manager
The RecentManager instance used by the RecentChooser to
display the list of recently used resources.
Writable | Construct Only
select-multiple
Allow the user to select multiple resources.
Readable | Writable
show-icons
Whether this RecentChooser should display an icon near the item.
Readable | Writable
show-not-found
Whether this RecentChooser should display the recently used resources
even if not present anymore. Setting this to false will perform a
potentially expensive check on every local resource (every remote
resource will always be displayed).
Readable | Writable
show-private
Readable | Writable
show-tips
Whether this RecentChooser should display a tooltip containing the
full path of the recently used resources.
Readable | Writable
sort-type
Sorting order to be used when displaying the recently used resources.
Readable | Writable
Signals
item-activated
This signal is emitted when the user “activates” a recent item
in the recent chooser. This can happen by double-clicking on an item
in the recently used resources list, or by pressing
Enter.
selection-changed
This signal is emitted when there is a change in the set of selected recently used resources. This can happen when a user modifies the selection with the mouse or the keyboard, or when explicitly calling functions to change the selection.
Implements
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl RecentChooser
impl RecentChooser
pub const NONE: Option<&'static RecentChooser> = None