Struct gtk::RecentChooserWidgetClass
source · [−]#[repr(C)]pub struct RecentChooserWidgetClass(_);Trait Implementations
sourceimpl Deref for RecentChooserWidgetClass
impl Deref for RecentChooserWidgetClass
type Target = <Box as ObjectType>::RustClassType
type Target = <Box as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for RecentChooserWidgetClass
impl DerefMut for RecentChooserWidgetClass
sourceimpl IsClassFor for RecentChooserWidgetClass
impl IsClassFor for RecentChooserWidgetClass
type Instance = RecentChooserWidget
type Instance = RecentChooserWidget
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for RecentChooserWidgetClass
impl Sync for RecentChooserWidgetClass