pub struct RecentFilter { /* private fields */ }Expand description
]|
Implements
[trait@glib::ObjectExt], BuildableExt, BuildableExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl RecentFilter
impl RecentFilter
Sourcepub fn new() -> RecentFilter
pub fn new() -> RecentFilter
GtkRecentFilter filter = gtk_recent_filter_new (); gtk_recent_filter_add_pattern (filter, “”); ]|
Returns
a new RecentFilter
Sourcepub fn add_age(&self, days: i32)
pub fn add_age(&self, days: i32)
Adds a rule that allows resources based on their age - that is, the number of days elapsed since they were last modified.
days
number of days
Sourcepub fn add_application(&self, application: &str)
pub fn add_application(&self, application: &str)
Adds a rule that allows resources based on the name of the application that has registered them.
application
an application name
Sourcepub fn add_group(&self, group: &str)
pub fn add_group(&self, group: &str)
Adds a rule that allows resources based on the name of the group to which they belong
group
a group name
Sourcepub fn add_mime_type(&self, mime_type: &str)
pub fn add_mime_type(&self, mime_type: &str)
Sourcepub fn add_pattern(&self, pattern: &str)
pub fn add_pattern(&self, pattern: &str)
Adds a rule that allows resources based on a pattern matching their display name.
pattern
a file pattern
Sourcepub fn add_pixbuf_formats(&self)
pub fn add_pixbuf_formats(&self)
Adds a rule allowing image files in the formats supported by GdkPixbuf.
Sourcepub fn name(&self) -> Option<GString>
pub fn name(&self) -> Option<GString>
Gets the human-readable name for the filter.
See set_name().
Returns
the name of the filter, or None. The returned string
is owned by the filter object and should not be freed.
Sourcepub fn needed(&self) -> RecentFilterFlags
pub fn needed(&self) -> RecentFilterFlags
Gets the fields that need to be filled in for the GtkRecentFilterInfo
passed to gtk_recent_filter_filter()
This function will not typically be used by applications; it
is intended principally for use in the implementation of
RecentChooser.
Returns
bitfield of flags indicating needed fields when
calling gtk_recent_filter_filter()