Struct gtk::RecentFilterFlags
source · [−]pub struct RecentFilterFlags { /* private fields */ }Implementations
sourceimpl RecentFilterFlags
impl RecentFilterFlags
pub const URI: RecentFilterFlags = _
pub const DISPLAY_NAME: RecentFilterFlags = _
pub const MIME_TYPE: RecentFilterFlags = _
pub const APPLICATION: RecentFilterFlags = _
pub const GROUP: RecentFilterFlags = _
pub const AGE: RecentFilterFlags = _
sourcepub const fn empty() -> RecentFilterFlags
pub const fn empty() -> RecentFilterFlags
Returns an empty set of flags
sourcepub const fn all() -> RecentFilterFlags
pub const fn all() -> RecentFilterFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<RecentFilterFlags>
pub fn from_bits(bits: u32) -> Option<RecentFilterFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> RecentFilterFlags
pub const fn from_bits_truncate(bits: u32) -> RecentFilterFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> RecentFilterFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> RecentFilterFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: RecentFilterFlags) -> bool
pub const fn intersects(&self, other: RecentFilterFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: RecentFilterFlags) -> bool
pub const fn contains(&self, other: RecentFilterFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: RecentFilterFlags)
pub fn insert(&mut self, other: RecentFilterFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: RecentFilterFlags)
pub fn remove(&mut self, other: RecentFilterFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: RecentFilterFlags)
pub fn toggle(&mut self, other: RecentFilterFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: RecentFilterFlags, value: bool)
pub fn set(&mut self, other: RecentFilterFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.