RecentInfo

Struct RecentInfo 

pub struct RecentInfo { /* private fields */ }
RecentInfo-struct contains private data only, and should be accessed using the provided API.

RecentInfo constains all the meta-data associated with an entry in the recently used files list.

GLib type: Shared boxed type with reference counted clone semantics.

Implementations

Source

impl RecentInfo

pub fn as_ptr(&self) -> *mut GtkRecentInfo

Return the inner pointer to the underlying C value.

pub unsafe fn from_glib_ptr_borrow(ptr: &*mut GtkRecentInfo) -> &Self

Borrows the underlying C value.

Source

impl RecentInfo

pub fn create_app_info( &self, app_name: Option<&str>, ) -> Result<Option<AppInfo>, Error>

Creates a gio::AppInfo for the specified RecentInfo

app_name

the name of the application that should be mapped to a gio::AppInfo; if None is used then the default application for the MIME type is used

Returns

the newly created gio::AppInfo, or None. In case of error, error will be set either with a GTK_RECENT_MANAGER_ERROR or a G_IO_ERROR

pub fn exists(&self) -> bool

Checks whether the resource pointed by self still exists. At the moment this check is done only on resources pointing to local files.

Returns

true if the resource exists

pub fn added(&self) -> time_t

Gets the timestamp (seconds from system’s Epoch) when the resource was added to the recently used resources list.

Returns

the number of seconds elapsed from system’s Epoch when the resource was added to the list, or -1 on failure.

pub fn age(&self) -> i32

Gets the number of days elapsed since the last update of the resource pointed by self.

Returns

a positive integer containing the number of days elapsed since the time this resource was last modified

pub fn application_info(&self, app_name: &str) -> Option<(GString, u32, time_t)>

Gets the data regarding the application that has registered the resource pointed by self.

If the command line contains any escape characters defined inside the storage specification, they will be expanded.

app_name

the name of the application that has registered this item

Returns

true if an application with app_name has registered this resource inside the recently used list, or false otherwise. The app_exec string is owned by the RecentInfo and should not be modified or freed

app_exec

return location for the string containing the command line

count

return location for the number of times this item was registered

time_

return location for the timestamp this item was last registered for this application

pub fn applications(&self) -> Vec<GString>

Retrieves the list of applications that have registered this resource.

Returns

a newly allocated None-terminated array of strings. Use g_strfreev() to free it.

pub fn description(&self) -> Option<GString>

Gets the (short) description of the resource.

Returns

the description of the resource. The returned string is owned by the recent manager, and should not be freed.

pub fn display_name(&self) -> Option<GString>

Gets the name of the resource. If none has been defined, the basename of the resource is obtained.

Returns

the display name of the resource. The returned string is owned by the recent manager, and should not be freed.

pub fn gicon(&self) -> Option<Icon>

Retrieves the icon associated to the resource MIME type.

Returns

a gio::Icon containing the icon, or None. Use g_object_unref() when finished using the icon

pub fn groups(&self) -> Vec<GString>

Returns all groups registered for the recently used item self. The array of returned group names will be None terminated, so length might optionally be None.

Returns

a newly allocated None terminated array of strings. Use g_strfreev() to free it.

pub fn icon(&self, size: i32) -> Option<Pixbuf>

Retrieves the icon of size size associated to the resource MIME type.

size

the size of the icon in pixels

Returns

a gdk_pixbuf::Pixbuf containing the icon, or None. Use g_object_unref() when finished using the icon.

pub fn mime_type(&self) -> Option<GString>

Gets the MIME type of the resource.

Returns

the MIME type of the resource. The returned string is owned by the recent manager, and should not be freed.

pub fn modified(&self) -> time_t

Gets the timestamp (seconds from system’s Epoch) when the meta-data for the resource was last modified.

Returns

the number of seconds elapsed from system’s Epoch when the resource was last modified, or -1 on failure.

pub fn is_private_hint(&self) -> bool

Gets the value of the “private” flag. Resources in the recently used list that have this flag set to true should only be displayed by the applications that have registered them.

Returns

true if the private flag was found, false otherwise

pub fn short_name(&self) -> Option<GString>

Computes a valid UTF-8 string that can be used as the name of the item in a menu or list. For example, calling this function on an item that refers to “file:///foo/bar.txt” will yield “bar.txt”.

Returns

A newly-allocated string in UTF-8 encoding free it with g_free()

pub fn uri(&self) -> Option<GString>

Gets the URI of the resource.

Returns

the URI of the resource. The returned string is owned by the recent manager, and should not be freed.

pub fn uri_display(&self) -> Option<GString>

Gets a displayable version of the resource’s URI. If the resource is local, it returns a local path; if the resource is not local, it returns the UTF-8 encoded content of uri().

Returns

a newly allocated UTF-8 string containing the resource’s URI or None. Use g_free() when done using it.

pub fn visited(&self) -> time_t

Gets the timestamp (seconds from system’s Epoch) when the meta-data for the resource was last visited.

Returns

the number of seconds elapsed from system’s Epoch when the resource was last visited, or -1 on failure.

pub fn has_application(&self, app_name: &str) -> bool

Checks whether an application registered this resource using app_name.

app_name

a string containing an application name

Returns

true if an application with name app_name was found, false otherwise

pub fn has_group(&self, group_name: &str) -> bool

Checks whether group_name appears inside the groups registered for the recently used item self.

group_name

name of a group

Returns

true if the group was found

pub fn is_local(&self) -> bool

Checks whether the resource is local or not by looking at the scheme of its URI.

Returns

true if the resource is local

pub fn last_application(&self) -> Option<GString>

Gets the name of the last application that have registered the recently used resource represented by self.

Returns

an application name. Use g_free() to free it.

pub fn match_(&self, info_b: &RecentInfo) -> bool

Checks whether two RecentInfo-struct point to the same resource.

info_b

a RecentInfo

Returns

true if both RecentInfo-struct point to the same resource, false otherwise