Struct gtk::RegionFlags
source · [−]pub struct RegionFlags { /* private fields */ }Implementations
sourceimpl RegionFlags
impl RegionFlags
pub const EVEN: RegionFlags = _
pub const ODD: RegionFlags = _
pub const FIRST: RegionFlags = _
pub const LAST: RegionFlags = _
pub const ONLY: RegionFlags = _
pub const SORTED: RegionFlags = _
sourcepub const fn empty() -> RegionFlags
pub const fn empty() -> RegionFlags
Returns an empty set of flags
sourcepub const fn all() -> RegionFlags
pub const fn all() -> RegionFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<RegionFlags>
pub fn from_bits(bits: u32) -> Option<RegionFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> RegionFlags
pub const fn from_bits_truncate(bits: u32) -> RegionFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> RegionFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> RegionFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: RegionFlags) -> bool
pub const fn intersects(&self, other: RegionFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: RegionFlags) -> bool
pub const fn contains(&self, other: RegionFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: RegionFlags)
pub fn insert(&mut self, other: RegionFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: RegionFlags)
pub fn remove(&mut self, other: RegionFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: RegionFlags)
pub fn toggle(&mut self, other: RegionFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: RegionFlags, value: bool)
pub fn set(&mut self, other: RegionFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.