Struct gtk::ScaleButtonClass
source · [−]#[repr(C)]pub struct ScaleButtonClass(_);Trait Implementations
sourceimpl Deref for ScaleButtonClass
impl Deref for ScaleButtonClass
type Target = <Button as ObjectType>::RustClassType
type Target = <Button as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ScaleButtonClass
impl DerefMut for ScaleButtonClass
sourceimpl IsClassFor for ScaleButtonClass
impl IsClassFor for ScaleButtonClass
type Instance = ScaleButton
type Instance = ScaleButton
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ScaleButtonClass
impl Sync for ScaleButtonClass