Scrollable

Struct Scrollable 

pub struct Scrollable { /* private fields */ }
Scrollable is an interface that is implemented by widgets with native scrolling ability.

To implement this interface you should override the hadjustment and vadjustment properties.

Creating a scrollable widget

All scrollable widgets should do the following.

  • When a parent widget sets the scrollable child widget’s adjustments, the widget should populate the adjustments’ lower, upper, step-increment, page-increment and page-size properties and connect to the value-changed signal.

  • Because its preferred size is the size for a fully expanded widget, the scrollable widget must be able to cope with underallocations. This means that it must accept any value passed to its GtkWidgetClass.size_allocate() function.

  • When the parent allocates space to the scrollable child widget, the widget should update the adjustments’ properties with new values.

  • When any of the adjustments emits the value-changed signal, the scrollable widget should scroll its contents.

Properties

hadjustment

Horizontal Adjustment of the scrollable widget. This adjustment is shared between the scrollable widget and its parent.

Readable | Writeable | Construct

hscroll-policy

Determines whether horizontal scrolling should start once the scrollable widget is allocated less than its minimum width or less than its natural width.

Readable | Writeable

vadjustment

Verical Adjustment of the scrollable widget. This adjustment is shared between the scrollable widget and its parent.

Readable | Writeable | Construct

vscroll-policy

Determines whether vertical scrolling should start once the scrollable widget is allocated less than its minimum height or less than its natural height.

Readable | Writeable

Implements

ScrollableExt

Implementations

Source

impl Scrollable

pub const NONE: Option<&'static Scrollable> = None