pub struct Scrollbar { /* private fields */ }Expand description
scrollbar[.fine-tune] ╰── contents ├── [button.up] ├── [button.down] ├── trough │ ╰── slider ├── [button.up] ╰── [button.down] ]|
GtkScrollbar has a main CSS node with name scrollbar and a subnode for its contents, with subnodes named trough and slider.
The main node gets the style class .fine-tune added when the scrollbar is in ‘fine-tuning’ mode.
If steppers are enabled, they are represented by up to four additional subnodes with name button. These get the style classes .up and .down to indicate in which direction they are moving.
Other style classes that may be added to scrollbars inside ScrolledWindow
include the positional classes (.left, .right, .top, .bottom) and style
classes related to overlay scrolling (.overlay-indicator, .dragging, .hovering).
Implements
RangeExt, WidgetExt, [trait@glib::ObjectExt], BuildableExt, OrientableExt, WidgetExtManual, BuildableExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl Scrollbar
impl Scrollbar
pub const NONE: Option<&'static Scrollbar> = None
Sourcepub fn new(
orientation: Orientation,
adjustment: Option<&impl IsA<Adjustment>>,
) -> Scrollbar
pub fn new( orientation: Orientation, adjustment: Option<&impl IsA<Adjustment>>, ) -> Scrollbar
Sourcepub fn builder() -> ScrollbarBuilder
pub fn builder() -> ScrollbarBuilder
Creates a new builder-pattern struct instance to construct Scrollbar objects.
This method returns an instance of ScrollbarBuilder which can be used to create Scrollbar objects.