Struct gtk::SeparatorToolItemClass
source · [−]#[repr(C)]pub struct SeparatorToolItemClass(_);Trait Implementations
sourceimpl Deref for SeparatorToolItemClass
impl Deref for SeparatorToolItemClass
type Target = <ToolItem as ObjectType>::RustClassType
type Target = <ToolItem as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for SeparatorToolItemClass
impl DerefMut for SeparatorToolItemClass
sourceimpl IsClassFor for SeparatorToolItemClass
impl IsClassFor for SeparatorToolItemClass
type Instance = SeparatorToolItem
type Instance = SeparatorToolItem
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for SeparatorToolItemClass
impl Sync for SeparatorToolItemClass