Struct gtk::ShortcutsWindowClass
source · [−]#[repr(C)]pub struct ShortcutsWindowClass(_);Trait Implementations
sourceimpl Deref for ShortcutsWindowClass
impl Deref for ShortcutsWindowClass
type Target = <Window as ObjectType>::RustClassType
type Target = <Window as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ShortcutsWindowClass
impl DerefMut for ShortcutsWindowClass
sourceimpl IsClassFor for ShortcutsWindowClass
impl IsClassFor for ShortcutsWindowClass
type Instance = ShortcutsWindow
type Instance = ShortcutsWindow
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ShortcutsWindowClass
impl Sync for ShortcutsWindowClass