Struct gtk::StackSidebarClass
source · [−]#[repr(C)]pub struct StackSidebarClass(_);Trait Implementations
sourceimpl Deref for StackSidebarClass
impl Deref for StackSidebarClass
type Target = <Bin as ObjectType>::RustClassType
type Target = <Bin as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for StackSidebarClass
impl DerefMut for StackSidebarClass
sourceimpl IsClassFor for StackSidebarClass
impl IsClassFor for StackSidebarClass
type Instance = StackSidebar
type Instance = StackSidebar
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for StackSidebarClass
impl Sync for StackSidebarClass