StackSwitcher

Struct StackSwitcher 

pub struct StackSwitcher { /* private fields */ }
The GtkStackSwitcher widget acts as a controller for a Stack; it shows a row of buttons to switch between the various pages of the associated stack widget.

All the content for the buttons comes from the child properties of the Stack; the button visibility in a StackSwitcher widget is controlled by the visibility of the child in the Stack.

It is possible to associate multiple StackSwitcher widgets with the same Stack widget.

The GtkStackSwitcher widget was added in 3.10.

CSS nodes

GtkStackSwitcher has a single CSS node named stackswitcher and style class .stack-switcher.

When circumstances require it, GtkStackSwitcher adds the .needs-attention style class to the widgets representing the stack pages.

Properties

icon-size

Use the “icon-size” property to change the size of the image displayed when a StackSwitcher is displaying icons.

Readable | Writeable

stack

Readable | Writeable | Construct

Box

baseline-position

Readable | Writeable

homogeneous

Readable | Writeable

spacing

Readable | Writeable

Container

border-width

Readable | Writeable

child

Writeable

resize-mode

Readable | Writeable

Widget

app-paintable

Readable | Writeable

can-default

Readable | Writeable

can-focus

Readable | Writeable

composite-child

Readable

double-buffered

Whether the widget is double buffered.

Readable | Writeable

events

Readable | Writeable

expand

Whether to expand in both directions. Setting this sets both hexpand and vexpand

Readable | Writeable

focus-on-click

Whether the widget should grab focus when it is clicked with the mouse.

This property is only relevant for widgets that can take focus.

Before 3.20, several widgets (GtkButton, GtkFileChooserButton, GtkComboBox) implemented this property individually.

Readable | Writeable

halign

How to distribute horizontal space if widget gets extra space, see Align

Readable | Writeable

has-default

Readable | Writeable

has-focus

Readable | Writeable

has-tooltip

Enables or disables the emission of query-tooltip on widget. A value of true indicates that widget can have a tooltip, in this case the widget will be queried using query-tooltip to determine whether it will provide a tooltip or not.

Note that setting this property to true for the first time will change the event masks of the GdkWindows of this widget to include leave-notify and motion-notify events. This cannot and will not be undone when the property is set to false again.

Readable | Writeable

height-request

Readable | Writeable

hexpand

Whether to expand horizontally. See WidgetExt::set_hexpand().

Readable | Writeable

hexpand-set

Whether to use the hexpand property. See WidgetExt::is_hexpand_set().

Readable | Writeable

is-focus

Readable | Writeable

margin

Sets all four sides’ margin at once. If read, returns max margin on any side.

Readable | Writeable

margin-bottom

Margin on bottom side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writeable

margin-end

Margin on end of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writeable

margin-left

Margin on left side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writeable

margin-right

Margin on right side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writeable

margin-start

Margin on start of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writeable

margin-top

Margin on top side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writeable

name

Readable | Writeable

no-show-all

Readable | Writeable

opacity

The requested opacity of the widget. See WidgetExt::set_opacity() for more details about window opacity.

Before 3.8 this was only available in GtkWindow

Readable | Writeable

parent

Readable | Writeable

receives-default

Readable | Writeable

scale-factor

The scale factor of the widget. See WidgetExt::scale_factor() for more details about widget scaling.

Readable

sensitive

Readable | Writeable

style

The style of the widget, which contains information about how it will look (colors, etc).

Readable | Writeable

tooltip-markup

Sets the text of tooltip to be the given string, which is marked up with the [Pango text markup language][PangoMarkupFormat]. Also see Tooltip::set_markup().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

Readable | Writeable

tooltip-text

Sets the text of tooltip to be the given string.

Also see Tooltip::set_text().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

Readable | Writeable

valign

How to distribute vertical space if widget gets extra space, see Align

Readable | Writeable

vexpand

Whether to expand vertically. See WidgetExt::set_vexpand().

Readable | Writeable

vexpand-set

Whether to use the vexpand property. See WidgetExt::is_vexpand_set().

Readable | Writeable

visible

Readable | Writeable

width-request

Readable | Writeable

window

The widget’s window if it is realized, None otherwise.

Readable

Orientable

orientation

The orientation of the orientable.

Readable | Writeable

Implements

StackSwitcherExt, BoxExt, ContainerExt, WidgetExt, glib::ObjectExt, BuildableExt, OrientableExt, StackSwitcherExtManual, ContainerExtManual, WidgetExtManual, BuildableExtManual

Implementations

Source

impl StackSwitcher

pub const NONE: Option<&'static StackSwitcher> = None

pub fn new() -> StackSwitcher

Create a new StackSwitcher.

Returns

a new StackSwitcher.

Source

impl StackSwitcher

pub fn builder() -> StackSwitcherBuilder

Creates a new builder-style object to construct a StackSwitcher.

This method returns an instance of StackSwitcherBuilder which can be used to create a StackSwitcher.