Struct gtk::StateFlags
source · [−]pub struct StateFlags { /* private fields */ }Implementations
sourceimpl StateFlags
impl StateFlags
pub const NORMAL: StateFlags = _
pub const ACTIVE: StateFlags = _
pub const PRELIGHT: StateFlags = _
pub const SELECTED: StateFlags = _
pub const INSENSITIVE: StateFlags = _
pub const INCONSISTENT: StateFlags = _
pub const FOCUSED: StateFlags = _
pub const BACKDROP: StateFlags = _
pub const DIR_LTR: StateFlags = _
pub const DIR_RTL: StateFlags = _
pub const LINK: StateFlags = _
pub const VISITED: StateFlags = _
pub const CHECKED: StateFlags = _
pub const DROP_ACTIVE: StateFlags = _
sourcepub const fn empty() -> StateFlags
pub const fn empty() -> StateFlags
Returns an empty set of flags
sourcepub const fn all() -> StateFlags
pub const fn all() -> StateFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<StateFlags>
pub fn from_bits(bits: u32) -> Option<StateFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> StateFlags
pub const fn from_bits_truncate(bits: u32) -> StateFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> StateFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> StateFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: StateFlags) -> bool
pub const fn intersects(&self, other: StateFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: StateFlags) -> bool
pub const fn contains(&self, other: StateFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: StateFlags)
pub fn insert(&mut self, other: StateFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: StateFlags)
pub fn remove(&mut self, other: StateFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: StateFlags)
pub fn toggle(&mut self, other: StateFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: StateFlags, value: bool)
pub fn set(&mut self, other: StateFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.