Struct gtk::StatusbarClass
source · [−]#[repr(C)]pub struct StatusbarClass(_);Trait Implementations
sourceimpl Deref for StatusbarClass
impl Deref for StatusbarClass
type Target = <Box as ObjectType>::RustClassType
type Target = <Box as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for StatusbarClass
impl DerefMut for StatusbarClass
sourceimpl IsClassFor for StatusbarClass
impl IsClassFor for StatusbarClass
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for StatusbarClass
impl Sync for StatusbarClass