StyleContext

Struct StyleContext 

pub struct StyleContext { /* private fields */ }
StyleContext is an object that stores styling information affecting a widget defined by WidgetPath.

In order to construct the final style information, StyleContext queries information from all attached GtkStyleProviders. Style providers can be either attached explicitly to the context through StyleContextExt::add_provider(), or to the screen through add_provider_for_screen(). The resulting style is a combination of all providers’ information in priority order.

For GTK+ widgets, any StyleContext returned by WidgetExt::style_context() will already have a WidgetPath, a gdk::Screen and RTL/LTR information set. The style context will also be updated automatically if any of these settings change on the widget.

If you are using the theming layer standalone, you will need to set a widget path and a screen yourself to the created style context through StyleContextExt::set_path() and possibly StyleContextExt::set_screen(). See the “Foreign drawing“ example in gtk3-demo.

Style Classes # {gtkstylecontext-classes}

Widgets can add style classes to their context, which can be used to associate different styles by class. The documentation for individual widgets lists which style classes it uses itself, and which style classes may be added by applications to affect their appearance.

GTK+ defines macros for a number of style classes.

Style Regions

Widgets can also add regions with flags to their context. This feature is deprecated and will be removed in a future GTK+ update. Please use style classes instead.

GTK+ defines macros for a number of style regions.

Custom styling in UI libraries and applications

If you are developing a library with custom GtkWidgets that render differently than standard components, you may need to add a StyleProvider yourself with the GTK_STYLE_PROVIDER_PRIORITY_FALLBACK priority, either a CssProvider or a custom object implementing the StyleProvider interface. This way themes may still attempt to style your UI elements in a different way if needed so.

If you are using custom styling on an applications, you probably want then to make your style information prevail to the theme’s, so you must use a StyleProvider with the GTK_STYLE_PROVIDER_PRIORITY_APPLICATION priority, keep in mind that the user settings in XDG_CONFIG_HOME/gtk-3.0/gtk.css will still take precedence over your changes, as it uses the GTK_STYLE_PROVIDER_PRIORITY_USER priority.

Properties

direction

Readable | Writable

paint-clock

Readable | Writable

parent

Sets or gets the style context’s parent. See StyleContextExt::set_parent() for details.

Readable | Writable

screen

Readable | Writable

Signals

changed

The ::changed signal is emitted when there is a change in the StyleContext.

For a StyleContext returned by WidgetExt::style_context(), the style-updated signal/vfunc might be more convenient to use.

This signal is useful when using the theming layer standalone.

Implements

StyleContextExt, [trait@glib::ObjectExt], StyleContextExtManual

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl StyleContext

pub const NONE: Option<&'static StyleContext> = None

pub fn new() -> StyleContext

Creates a standalone StyleContext, this style context won’t be attached to any widget, so you may want to call StyleContextExt::set_path() yourself.

This function is only useful when using the theming layer separated from GTK+, if you are using StyleContext to theme GtkWidgets, use WidgetExt::style_context() in order to get a style context ready to theme the widget.

Returns

A newly created StyleContext.

pub fn builder() -> StyleContextBuilder

Creates a new builder-pattern struct instance to construct StyleContext objects.

This method returns an instance of StyleContextBuilder which can be used to create StyleContext objects.

pub fn add_provider_for_screen( screen: &Screen, provider: &impl IsA<StyleProvider>, priority: u32, )

Adds a global style provider to screen, which will be used in style construction for all GtkStyleContexts under screen.

GTK+ uses this to make styling information from Settings available.

Note: If both priorities are the same, A StyleProvider added through StyleContextExt::add_provider() takes precedence over another added through this function.

screen

a gdk::Screen

provider

a StyleProvider

priority

the priority of the style provider. The lower it is, the earlier it will be used in the style construction. Typically this will be in the range between GTK_STYLE_PROVIDER_PRIORITY_FALLBACK and GTK_STYLE_PROVIDER_PRIORITY_USER

pub fn remove_provider_for_screen( screen: &Screen, provider: &impl IsA<StyleProvider>, )

Removes provider from the global style providers list in screen.

screen

a gdk::Screen

provider

a StyleProvider

pub fn reset_widgets(screen: &Screen)

This function recomputes the styles for all widgets under a particular gdk::Screen. This is useful when some global parameter has changed that affects the appearance of all widgets, because when a widget gets a new style, it will both redraw and recompute any cached information about its appearance. As an example, it is used when the color scheme changes in the related Settings object.

screen

a gdk::Screen