Struct gtk::StyleContextPrintFlags
source · [−]pub struct StyleContextPrintFlags { /* private fields */ }Implementations
sourceimpl StyleContextPrintFlags
impl StyleContextPrintFlags
pub const NONE: StyleContextPrintFlags = _
pub const RECURSE: StyleContextPrintFlags = _
pub const SHOW_STYLE: StyleContextPrintFlags = _
sourcepub const fn empty() -> StyleContextPrintFlags
pub const fn empty() -> StyleContextPrintFlags
Returns an empty set of flags
sourcepub const fn all() -> StyleContextPrintFlags
pub const fn all() -> StyleContextPrintFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<StyleContextPrintFlags>
pub fn from_bits(bits: u32) -> Option<StyleContextPrintFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> StyleContextPrintFlags
pub const fn from_bits_truncate(bits: u32) -> StyleContextPrintFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> StyleContextPrintFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> StyleContextPrintFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: StyleContextPrintFlags) -> bool
pub const fn intersects(&self, other: StyleContextPrintFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: StyleContextPrintFlags) -> bool
pub const fn contains(&self, other: StyleContextPrintFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: StyleContextPrintFlags)
pub fn insert(&mut self, other: StyleContextPrintFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: StyleContextPrintFlags)
pub fn remove(&mut self, other: StyleContextPrintFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: StyleContextPrintFlags)
pub fn toggle(&mut self, other: StyleContextPrintFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: StyleContextPrintFlags, value: bool)
pub fn set(&mut self, other: StyleContextPrintFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.