pub struct StyleProperties { /* private fields */ }Expand description
GtkStyleProperties provides the storage for style information
that is used by StyleContext and other StyleProvider
implementations.
Before style properties can be stored in GtkStyleProperties, they
must be registered with gtk_style_properties_register_property().
Unless you are writing a StyleProvider implementation, you
are unlikely to use this API directly, as gtk_style_context_get()
and its variants are the preferred way to access styling information
from widget implementations and theming engine implementations
should use the APIs provided by GtkThemingEngine instead.
StyleProperties has been deprecated in GTK 3.16. The CSS
machinery does not use it anymore and all users of this object
have been deprecated.
Implements
[trait@glib::ObjectExt], StyleProviderExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl StyleProperties
impl StyleProperties
pub const NONE: Option<&'static StyleProperties> = None