Struct gtk::SwitchClass
source · [−]#[repr(C)]pub struct SwitchClass(_);Trait Implementations
sourceimpl Deref for SwitchClass
impl Deref for SwitchClass
type Target = <Widget as ObjectType>::RustClassType
type Target = <Widget as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for SwitchClass
impl DerefMut for SwitchClass
sourceimpl IsClassFor for SwitchClass
impl IsClassFor for SwitchClass
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for SwitchClass
impl Sync for SwitchClass