Struct gtk::TargetFlags
source · [−]pub struct TargetFlags { /* private fields */ }Implementations
sourceimpl TargetFlags
impl TargetFlags
pub const SAME_APP: TargetFlags = _
pub const SAME_WIDGET: TargetFlags = _
pub const OTHER_APP: TargetFlags = _
pub const OTHER_WIDGET: TargetFlags = _
sourcepub const fn empty() -> TargetFlags
pub const fn empty() -> TargetFlags
Returns an empty set of flags
sourcepub const fn all() -> TargetFlags
pub const fn all() -> TargetFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<TargetFlags>
pub fn from_bits(bits: u32) -> Option<TargetFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> TargetFlags
pub const fn from_bits_truncate(bits: u32) -> TargetFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> TargetFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> TargetFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: TargetFlags) -> bool
pub const fn intersects(&self, other: TargetFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: TargetFlags) -> bool
pub const fn contains(&self, other: TargetFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: TargetFlags)
pub fn insert(&mut self, other: TargetFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: TargetFlags)
pub fn remove(&mut self, other: TargetFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: TargetFlags)
pub fn toggle(&mut self, other: TargetFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: TargetFlags, value: bool)
pub fn set(&mut self, other: TargetFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.