TextBuffer

Struct TextBuffer 

pub struct TextBuffer { /* private fields */ }
You may wish to begin by reading the text widget conceptual overview which gives an overview of all the objects and data types related to the text widget and how they work together.

Properties

copy-target-list

The list of targets this buffer supports for clipboard copying and as DND source.

Readable

cursor-position

The position of the insert mark (as offset from the beginning of the buffer). It is useful for getting notified when the cursor moves.

Readable

has-selection

Whether the buffer has some text currently selected.

Readable

paste-target-list

The list of targets this buffer supports for clipboard pasting and as DND destination.

Readable

tag-table

Readable | Writable | Construct Only

text

The text content of the buffer. Without child widgets and images, see TextBufferExt::text() for more information.

Readable | Writable

Signals

apply-tag

The ::apply-tag signal is emitted to apply a tag to a range of text in a TextBuffer. Applying actually occurs in the default handler.

Note that if your handler runs before the default handler it must not invalidate the start and end iters (or has to revalidate them).

See also: TextBufferExt::apply_tag(), gtk_text_buffer_insert_with_tags(), TextBufferExt::insert_range().

begin-user-action

The ::begin-user-action signal is emitted at the beginning of a single user-visible operation on a TextBuffer.

See also: TextBufferExt::begin_user_action(), TextBufferExt::insert_interactive(), TextBufferExt::insert_range_interactive(), TextBufferExt::delete_interactive(), TextBufferExt::backspace(), TextBufferExt::delete_selection().

changed

The ::changed signal is emitted when the content of a TextBuffer has changed.

delete-range

The ::delete-range signal is emitted to delete a range from a TextBuffer.

Note that if your handler runs before the default handler it must not invalidate the start and end iters (or has to revalidate them). The default signal handler revalidates the start and end iters to both point to the location where text was deleted. Handlers which run after the default handler (see g_signal_connect_after()) do not have access to the deleted text.

See also: TextBufferExt::delete().

end-user-action

The ::end-user-action signal is emitted at the end of a single user-visible operation on the TextBuffer.

See also: TextBufferExt::end_user_action(), TextBufferExt::insert_interactive(), TextBufferExt::insert_range_interactive(), TextBufferExt::delete_interactive(), TextBufferExt::backspace(), TextBufferExt::delete_selection(), TextBufferExt::backspace().

insert-child-anchor

The ::insert-child-anchor signal is emitted to insert a TextChildAnchor in a TextBuffer. Insertion actually occurs in the default handler.

Note that if your handler runs before the default handler it must not invalidate the location iter (or has to revalidate it). The default signal handler revalidates it to be placed after the inserted anchor.

See also: TextBufferExt::insert_child_anchor().

insert-pixbuf

The ::insert-pixbuf signal is emitted to insert a gdk_pixbuf::Pixbuf in a TextBuffer. Insertion actually occurs in the default handler.

Note that if your handler runs before the default handler it must not invalidate the location iter (or has to revalidate it). The default signal handler revalidates it to be placed after the inserted pixbuf.

See also: TextBufferExt::insert_pixbuf().

insert-text

The ::insert-text signal is emitted to insert text in a TextBuffer. Insertion actually occurs in the default handler.

Note that if your handler runs before the default handler it must not invalidate the location iter (or has to revalidate it). The default signal handler revalidates it to point to the end of the inserted text.

See also: TextBufferExt::insert(), TextBufferExt::insert_range().

mark-deleted

The ::mark-deleted signal is emitted as notification after a TextMark is deleted.

See also: TextBufferExt::delete_mark().

mark-set

The ::mark-set signal is emitted as notification after a TextMark is set.

See also: TextBufferExt::create_mark(), TextBufferExt::move_mark().

modified-changed

The ::modified-changed signal is emitted when the modified bit of a TextBuffer flips.

See also: TextBufferExt::set_modified().

paste-done

The paste-done signal is emitted after paste operation has been completed. This is useful to properly scroll the view to the end of the pasted text. See TextBufferExt::paste_clipboard() for more details.

remove-tag

The ::remove-tag signal is emitted to remove all occurrences of tag from a range of text in a TextBuffer. Removal actually occurs in the default handler.

Note that if your handler runs before the default handler it must not invalidate the start and end iters (or has to revalidate them).

See also: TextBufferExt::remove_tag().

Implements

TextBufferExt, [trait@glib::ObjectExt], TextBufferExtManual

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl TextBuffer

pub const NONE: Option<&'static TextBuffer> = None

pub fn new(table: Option<&impl IsA<TextTagTable>>) -> TextBuffer

Creates a new text buffer.

table

a tag table, or None to create a new one

Returns

a new text buffer

pub fn builder() -> TextBufferBuilder

Creates a new builder-pattern struct instance to construct TextBuffer objects.

This method returns an instance of TextBufferBuilder which can be used to create TextBuffer objects.