Struct gtk::TextSearchFlags
source · [−]pub struct TextSearchFlags { /* private fields */ }Implementations
sourceimpl TextSearchFlags
impl TextSearchFlags
pub const VISIBLE_ONLY: TextSearchFlags = _
pub const TEXT_ONLY: TextSearchFlags = _
pub const CASE_INSENSITIVE: TextSearchFlags = _
sourcepub const fn empty() -> TextSearchFlags
pub const fn empty() -> TextSearchFlags
Returns an empty set of flags
sourcepub const fn all() -> TextSearchFlags
pub const fn all() -> TextSearchFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<TextSearchFlags>
pub fn from_bits(bits: u32) -> Option<TextSearchFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> TextSearchFlags
pub const fn from_bits_truncate(bits: u32) -> TextSearchFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> TextSearchFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> TextSearchFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: TextSearchFlags) -> bool
pub const fn intersects(&self, other: TextSearchFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: TextSearchFlags) -> bool
pub const fn contains(&self, other: TextSearchFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: TextSearchFlags)
pub fn insert(&mut self, other: TextSearchFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: TextSearchFlags)
pub fn remove(&mut self, other: TextSearchFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: TextSearchFlags)
pub fn toggle(&mut self, other: TextSearchFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: TextSearchFlags, value: bool)
pub fn set(&mut self, other: TextSearchFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.