Struct gtk::ToggleButtonClass
source · [−]#[repr(C)]pub struct ToggleButtonClass(_);Trait Implementations
sourceimpl Deref for ToggleButtonClass
impl Deref for ToggleButtonClass
type Target = <Button as ObjectType>::RustClassType
type Target = <Button as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ToggleButtonClass
impl DerefMut for ToggleButtonClass
sourceimpl IsClassFor for ToggleButtonClass
impl IsClassFor for ToggleButtonClass
type Instance = ToggleButton
type Instance = ToggleButton
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ToggleButtonClass
impl Sync for ToggleButtonClass