Struct gtk::ToolButtonClass
source · [−]#[repr(C)]pub struct ToolButtonClass(_);Trait Implementations
sourceimpl Deref for ToolButtonClass
impl Deref for ToolButtonClass
type Target = <ToolItem as ObjectType>::RustClassType
type Target = <ToolItem as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ToolButtonClass
impl DerefMut for ToolButtonClass
sourceimpl IsClassFor for ToolButtonClass
impl IsClassFor for ToolButtonClass
type Instance = ToolButton
type Instance = ToolButton
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ToolButtonClass
impl Sync for ToolButtonClass