Struct gtk::ToolItemClass
source · [−]#[repr(C)]pub struct ToolItemClass(_);Trait Implementations
sourceimpl Deref for ToolItemClass
impl Deref for ToolItemClass
type Target = <Bin as ObjectType>::RustClassType
type Target = <Bin as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ToolItemClass
impl DerefMut for ToolItemClass
sourceimpl IsClassFor for ToolItemClass
impl IsClassFor for ToolItemClass
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ToolItemClass
impl Sync for ToolItemClass