Struct gtk::ToolPaletteClass
source · [−]#[repr(C)]pub struct ToolPaletteClass(_);Trait Implementations
sourceimpl Deref for ToolPaletteClass
impl Deref for ToolPaletteClass
type Target = <Container as ObjectType>::RustClassType
type Target = <Container as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ToolPaletteClass
impl DerefMut for ToolPaletteClass
sourceimpl IsClassFor for ToolPaletteClass
impl IsClassFor for ToolPaletteClass
type Instance = ToolPalette
type Instance = ToolPalette
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ToolPaletteClass
impl Sync for ToolPaletteClass