Struct gtk::ToolPaletteDragTargets
source · [−]pub struct ToolPaletteDragTargets { /* private fields */ }Implementations
sourceimpl ToolPaletteDragTargets
impl ToolPaletteDragTargets
pub const ITEMS: ToolPaletteDragTargets = _
pub const GROUPS: ToolPaletteDragTargets = _
sourcepub const fn empty() -> ToolPaletteDragTargets
pub const fn empty() -> ToolPaletteDragTargets
Returns an empty set of flags
sourcepub const fn all() -> ToolPaletteDragTargets
pub const fn all() -> ToolPaletteDragTargets
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<ToolPaletteDragTargets>
pub fn from_bits(bits: u32) -> Option<ToolPaletteDragTargets>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> ToolPaletteDragTargets
pub const fn from_bits_truncate(bits: u32) -> ToolPaletteDragTargets
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> ToolPaletteDragTargets
pub const unsafe fn from_bits_unchecked(bits: u32) -> ToolPaletteDragTargets
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: ToolPaletteDragTargets) -> bool
pub const fn intersects(&self, other: ToolPaletteDragTargets) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: ToolPaletteDragTargets) -> bool
pub const fn contains(&self, other: ToolPaletteDragTargets) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: ToolPaletteDragTargets)
pub fn insert(&mut self, other: ToolPaletteDragTargets)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: ToolPaletteDragTargets)
pub fn remove(&mut self, other: ToolPaletteDragTargets)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: ToolPaletteDragTargets)
pub fn toggle(&mut self, other: ToolPaletteDragTargets)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: ToolPaletteDragTargets, value: bool)
pub fn set(&mut self, other: ToolPaletteDragTargets, value: bool)
Inserts or removes the specified flags depending on the passed value.