Struct gtk::TreeModelFlags
source · [−]pub struct TreeModelFlags { /* private fields */ }Implementations
sourceimpl TreeModelFlags
impl TreeModelFlags
pub const ITERS_PERSIST: TreeModelFlags = _
pub const LIST_ONLY: TreeModelFlags = _
sourcepub const fn empty() -> TreeModelFlags
pub const fn empty() -> TreeModelFlags
Returns an empty set of flags
sourcepub const fn all() -> TreeModelFlags
pub const fn all() -> TreeModelFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<TreeModelFlags>
pub fn from_bits(bits: u32) -> Option<TreeModelFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> TreeModelFlags
pub const fn from_bits_truncate(bits: u32) -> TreeModelFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> TreeModelFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> TreeModelFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: TreeModelFlags) -> bool
pub const fn intersects(&self, other: TreeModelFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: TreeModelFlags) -> bool
pub const fn contains(&self, other: TreeModelFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: TreeModelFlags)
pub fn insert(&mut self, other: TreeModelFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: TreeModelFlags)
pub fn remove(&mut self, other: TreeModelFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: TreeModelFlags)
pub fn toggle(&mut self, other: TreeModelFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: TreeModelFlags, value: bool)
pub fn set(&mut self, other: TreeModelFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.