TreeRowReference

Struct TreeRowReference 

pub struct TreeRowReference { /* private fields */ }
A GtkTreeRowReference tracks model changes so that it always refers to the same row (a TreePath refers to a position, not a fixed row). Create a new GtkTreeRowReference with new().

Implementations

Source

impl TreeRowReference

pub fn as_ptr(&self) -> *mut GtkTreeRowReference

Return the inner pointer to the underlying C value.

pub unsafe fn from_glib_ptr_borrow<'a>( ptr: *const *const GtkTreeRowReference, ) -> &'a Self

Borrows the underlying C value.

pub unsafe fn from_glib_ptr_borrow_mut<'a>( ptr: *mut *mut GtkTreeRowReference, ) -> &'a mut Self

Borrows the underlying C value mutably.

Source

impl TreeRowReference

pub fn new( model: &impl IsA<TreeModel>, path: &TreePath, ) -> Option<TreeRowReference>

Creates a row reference based on path.

This reference will keep pointing to the node pointed to by path, so long as it exists. Any changes that occur on model are propagated, and the path is updated appropriately. If path isn’t a valid path in model, then None is returned.

model

a TreeModel

path

a valid TreePath-struct to monitor

Returns

a newly allocated TreeRowReference, or None

pub fn new_proxy( proxy: &impl IsA<Object>, model: &impl IsA<TreeModel>, path: &TreePath, ) -> Option<TreeRowReference>

You do not need to use this function.

Creates a row reference based on path.

This reference will keep pointing to the node pointed to by path, so long as it exists. If path isn’t a valid path in model, then None is returned. However, unlike references created with new(), it does not listen to the model for changes. The creator of the row reference must do this explicitly using inserted(), deleted(), gtk_tree_row_reference_reordered().

These functions must be called exactly once per proxy when the corresponding signal on the model is emitted. This single call updates all row references for that proxy. Since built-in GTK+ objects like TreeView already use this mechanism internally, using them as the proxy object will produce unpredictable results. Further more, passing the same object as model and proxy doesn’t work for reasons of internal implementation.

This type of row reference is primarily meant by structures that need to carefully monitor exactly when a row reference updates itself, and is not generally needed by most applications.

proxy

a proxy glib::Object

model

a TreeModel

path

a valid TreePath-struct to monitor

Returns

a newly allocated TreeRowReference, or None

pub fn model(&self) -> TreeModel

Returns the model that the row reference is monitoring.

Returns

the model

pub fn path(&self) -> Option<TreePath>

Returns a path that the row reference currently points to, or None if the path pointed to is no longer valid.

Returns

a current path, or None

pub fn valid(&self) -> bool

Returns true if the self is non-None and refers to a current valid path.

Returns

true if self points to a valid path

pub fn deleted(proxy: &impl IsA<Object>, path: &TreePath)

Lets a set of row reference created by new_proxy() know that the model emitted the row-deleted signal.

proxy

a glib::Object

path

the path position that was deleted

pub fn inserted(proxy: &impl IsA<Object>, path: &TreePath)

Lets a set of row reference created by new_proxy() know that the model emitted the row-inserted signal.

proxy

a glib::Object

path

the row position that was inserted

Source

impl TreeRowReference

pub unsafe fn reordered<T: IsA<Object>>( proxy: &T, path: &TreePath, iter: Option<&TreeIter>, new_order: &[u32], )

This is unsafe because new_order bounds can’t be checked. Lets a set of row reference created by new_proxy() know that the model emitted the rows-reordered signal.

proxy

a glib::Object

path

the parent path of the reordered signal

iter

the iter pointing to the parent of the reordered

new_order

the new order of rows