Struct gtk::TreeViewClass
source · [−]#[repr(C)]pub struct TreeViewClass(_);Trait Implementations
sourceimpl Deref for TreeViewClass
impl Deref for TreeViewClass
type Target = <Container as ObjectType>::RustClassType
type Target = <Container as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for TreeViewClass
impl DerefMut for TreeViewClass
sourceimpl IsClassFor for TreeViewClass
impl IsClassFor for TreeViewClass
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for TreeViewClass
impl Sync for TreeViewClass