TreeViewColumn

Struct TreeViewColumn 

pub struct TreeViewColumn { /* private fields */ }
The GtkTreeViewColumn object represents a visible column in a TreeView widget. It allows to set properties of the column header, and functions as a holding pen for the cell renderers which determine how the data in the column is displayed.

Please refer to the tree widget conceptual overview for an overview of all the objects and data types related to the tree widget and how they work together.

Properties

alignment

Readable | Writable

cell-area

The CellArea used to layout cell renderers for this column.

If no area is specified when creating the tree view column with TreeViewColumn::with_area() a horizontally oriented CellAreaBox will be used.

Readable | Writable | Construct Only

clickable

Readable | Writable

expand

Readable | Writable

fixed-width

Readable | Writable

max-width

Readable | Writable

min-width

Readable | Writable

reorderable

Readable | Writable

resizable

Readable | Writable

sizing

Readable | Writable

sort-column-id

Logical sort column ID this column sorts on when selected for sorting. Setting the sort column ID makes the column header clickable. Set to -1 to make the column unsortable.

Readable | Writable

sort-indicator

Readable | Writable

sort-order

Readable | Writable

spacing

Readable | Writable

title

Readable | Writable

visible

Readable | Writable

widget

Readable | Writable

width

Readable

x-offset

Readable

Signals

clicked

Implements

TreeViewColumnExt, [trait@glib::ObjectExt], BuildableExt, CellLayoutExt, BuildableExtManual

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl TreeViewColumn

pub const NONE: Option<&'static TreeViewColumn> = None

pub fn new() -> TreeViewColumn

Creates a new TreeViewColumn.

Returns

A newly created TreeViewColumn.

pub fn with_area(area: &impl IsA<CellArea>) -> TreeViewColumn

Creates a new TreeViewColumn using area to render its cells.

area

the CellArea that the newly created column should use to layout cells.

Returns

A newly created TreeViewColumn.

pub fn builder() -> TreeViewColumnBuilder

Creates a new builder-pattern struct instance to construct TreeViewColumn objects.

This method returns an instance of TreeViewColumnBuilder which can be used to create TreeViewColumn objects.

Source

impl TreeViewColumn

pub fn with_attributes( title: &str, cell_renderer: &impl IsA<CellRenderer>, attributes: &[(&str, i32)], ) -> Self

enum { TEXT_COLUMN, COLOR_COLUMN, N_COLUMNS }; // … { GtkTreeViewColumn *column; GtkCellRenderer *renderer = gtk_cell_renderer_text_new ();

column = gtk_tree_view_column_new_with_attributes (“Title”, renderer, “text”, TEXT_COLUMN, “foreground”, COLOR_COLUMN, NULL); } ]|

title

The title to set the header to

cell

The CellRenderer

Returns

A newly created TreeViewColumn.

pub fn set_attributes( &self, cell_renderer: &impl IsA<CellRenderer>, attributes: &[(&str, i32)], )