Struct gtk::TreeViewColumnClass
source · [−]#[repr(C)]pub struct TreeViewColumnClass(_);Trait Implementations
sourceimpl Deref for TreeViewColumnClass
impl Deref for TreeViewColumnClass
type Target = <Object as ObjectType>::RustClassType
type Target = <Object as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for TreeViewColumnClass
impl DerefMut for TreeViewColumnClass
sourceimpl IsClassFor for TreeViewColumnClass
impl IsClassFor for TreeViewColumnClass
type Instance = TreeViewColumn
type Instance = TreeViewColumn
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for TreeViewColumnClass
impl Sync for TreeViewColumnClass