ButtonImpl

Trait ButtonImpl 

pub trait ButtonImpl: ButtonImplExt + BinImpl {
    // Provided methods
    fn activate(&self) { ... }
    fn clicked(&self) { ... }
}

Provided Methods

fn activate(&self)

Signal that causes the button to animate press then release. Applications should never connect to this signal, but use the clicked signal.

fn clicked(&self)

Emits a clicked signal to the given Button.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors