DialogImpl

Trait DialogImpl 

pub trait DialogImpl: DialogImplExt + WindowImpl {
    // Provided methods
    fn response(&self, response: ResponseType) { ... }
    fn close(&self) { ... }
}

Provided Methods

fn response(&self, response: ResponseType)

Emits the response signal with the given response ID. Used to indicate that the user has responded to the dialog in some way; typically either you or DialogExt::run() will be monitoring the ::response signal and take appropriate action.

response_id

response ID

fn close(&self)

Signal emitted when the user uses a keybinding to close the dialog.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors