EntryImpl

Trait EntryImpl 

pub trait EntryImpl: EntryImplExt + WidgetImpl {
    // Provided methods
    fn populate_popup(&self, popup: &Widget) { ... }
    fn activate(&self) { ... }
}

Provided Methods

fn populate_popup(&self, popup: &Widget)

Class handler for the populate-popup signal. If non-None, this will be called to add additional entries to the context menu when it is displayed.

fn activate(&self)

Class handler for the activate signal. The default implementation calls GtkWindowExt::activate_default() on the entry’s top-level window.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors