pub trait ScrolledWindowImpl: ScrolledWindowImplExt + BinImpl {
// Provided methods
fn move_focus_out(&self, direction_type: DirectionType) { ... }
fn scroll_child(&self, scroll: ScrollType, horizontal: bool) -> bool { ... }
}Provided Methods
Sourcefn move_focus_out(&self, direction_type: DirectionType)
fn move_focus_out(&self, direction_type: DirectionType)
Keybinding signal which gets emitted when focus is moved away from the scrolled window by a keybinding.
Sourcefn scroll_child(&self, scroll: ScrollType, horizontal: bool) -> bool
fn scroll_child(&self, scroll: ScrollType, horizontal: bool) -> bool
Keybinding signal which gets emitted when a keybinding that scrolls is pressed.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".