EntryBuilder

Struct EntryBuilder 

pub struct EntryBuilder { /* private fields */ }
A builder-pattern type to construct Entry objects.

Implementations

Source

impl EntryBuilder

pub fn activates_default(self, activates_default: bool) -> Self

pub fn attributes(self, attributes: &AttrList) -> Self

A list of Pango attributes to apply to the text of the entry.

This is mainly useful to change the size or weight of the text.

The PangoAttribute’s start_index and end_index must refer to the EntryBuffer text, i.e. without the preedit string.

pub fn buffer(self, buffer: &impl IsA<EntryBuffer>) -> Self

pub fn caps_lock_warning(self, caps_lock_warning: bool) -> Self

Whether password entries will show a warning when Caps Lock is on.

Note that the warning is shown using a secondary icon, and thus does not work if you are using the secondary icon position for some other purpose.

pub fn completion(self, completion: &impl IsA<EntryCompletion>) -> Self

The auxiliary completion object to use with the entry.

pub fn editable(self, editable: bool) -> Self

pub fn enable_emoji_completion(self, enable_emoji_completion: bool) -> Self

pub fn has_frame(self, has_frame: bool) -> Self

pub fn im_module(self, im_module: impl Into<GString>) -> Self

Which IM (input method) module should be used for this entry. See IMContext.

Setting this to a non-None value overrides the system-wide IM module setting. See the GtkSettings gtk-im-module property.

pub fn input_hints(self, input_hints: InputHints) -> Self

Additional hints (beyond input-purpose) that allow input methods to fine-tune their behaviour.

pub fn input_purpose(self, input_purpose: InputPurpose) -> Self

The purpose of this text field.

This property can be used by on-screen keyboards and other input methods to adjust their behaviour.

Note that setting the purpose to InputPurpose::Password or InputPurpose::Pin is independent from setting visibility.

pub fn invisible_char(self, invisible_char: u32) -> Self

The invisible character is used when masking entry contents (in "password mode")“). When it is not explicitly set with the invisible-char property, GTK+ determines the character to use from a list of possible candidates, depending on availability in the current font.

This style property allows the theme to prepend a character to the list of candidates.

pub fn invisible_char_set(self, invisible_char_set: bool) -> Self

Whether the invisible char has been set for the Entry.

pub fn max_length(self, max_length: i32) -> Self

pub fn max_width_chars(self, max_width_chars: i32) -> Self

The desired maximum width of the entry, in characters. If this property is set to -1, the width will be calculated automatically.

pub fn overwrite_mode(self, overwrite_mode: bool) -> Self

If text is overwritten when typing in the Entry.

pub fn placeholder_text(self, placeholder_text: impl Into<GString>) -> Self

The text that will be displayed in the Entry when it is empty and unfocused.

pub fn populate_all(self, populate_all: bool) -> Self

If :populate-all is true, the populate-popup signal is also emitted for touch popups.

pub fn primary_icon_activatable(self, primary_icon_activatable: bool) -> Self

Whether the primary icon is activatable.

GTK+ emits the icon-press and icon-release signals only on sensitive, activatable icons.

Sensitive, but non-activatable icons can be used for purely informational purposes.

pub fn primary_icon_gicon(self, primary_icon_gicon: &impl IsA<Icon>) -> Self

The gio::Icon to use for the primary icon for the entry.

pub fn primary_icon_name(self, primary_icon_name: impl Into<GString>) -> Self

The icon name to use for the primary icon for the entry.

pub fn primary_icon_pixbuf(self, primary_icon_pixbuf: &Pixbuf) -> Self

A pixbuf to use as the primary icon for the entry.

pub fn primary_icon_sensitive(self, primary_icon_sensitive: bool) -> Self

Whether the primary icon is sensitive.

An insensitive icon appears grayed out. GTK+ does not emit the icon-press and icon-release signals and does not allow DND from insensitive icons.

An icon should be set insensitive if the action that would trigger when clicked is currently not available.

pub fn primary_icon_tooltip_markup( self, primary_icon_tooltip_markup: impl Into<GString>, ) -> Self

The contents of the tooltip on the primary icon, which is marked up with the [Pango text markup language][PangoMarkupFormat].

Also see EntryExt::set_icon_tooltip_markup().

pub fn primary_icon_tooltip_text( self, primary_icon_tooltip_text: impl Into<GString>, ) -> Self

The contents of the tooltip on the primary icon.

Also see EntryExt::set_icon_tooltip_text().

pub fn progress_fraction(self, progress_fraction: f64) -> Self

The current fraction of the task that’s been completed.

pub fn progress_pulse_step(self, progress_pulse_step: f64) -> Self

The fraction of total entry width to move the progress bouncing block for each call to EntryExt::progress_pulse().

pub fn secondary_icon_activatable( self, secondary_icon_activatable: bool, ) -> Self

Whether the secondary icon is activatable.

GTK+ emits the icon-press and icon-release signals only on sensitive, activatable icons.

Sensitive, but non-activatable icons can be used for purely informational purposes.

pub fn secondary_icon_gicon(self, secondary_icon_gicon: &impl IsA<Icon>) -> Self

The gio::Icon to use for the secondary icon for the entry.

pub fn secondary_icon_name( self, secondary_icon_name: impl Into<GString>, ) -> Self

The icon name to use for the secondary icon for the entry.

pub fn secondary_icon_pixbuf(self, secondary_icon_pixbuf: &Pixbuf) -> Self

An pixbuf to use as the secondary icon for the entry.

pub fn secondary_icon_sensitive(self, secondary_icon_sensitive: bool) -> Self

Whether the secondary icon is sensitive.

An insensitive icon appears grayed out. GTK+ does not emit the icon-press and icon-release signals and does not allow DND from insensitive icons.

An icon should be set insensitive if the action that would trigger when clicked is currently not available.

pub fn secondary_icon_tooltip_markup( self, secondary_icon_tooltip_markup: impl Into<GString>, ) -> Self

The contents of the tooltip on the secondary icon, which is marked up with the [Pango text markup language][PangoMarkupFormat].

Also see EntryExt::set_icon_tooltip_markup().

pub fn secondary_icon_tooltip_text( self, secondary_icon_tooltip_text: impl Into<GString>, ) -> Self

The contents of the tooltip on the secondary icon.

Also see EntryExt::set_icon_tooltip_text().

pub fn show_emoji_icon(self, show_emoji_icon: bool) -> Self

pub fn tabs(self, tabs: &TabArray) -> Self

pub fn text(self, text: impl Into<GString>) -> Self

pub fn truncate_multiline(self, truncate_multiline: bool) -> Self

When true, pasted multi-line text is truncated to the first line.

pub fn visibility(self, visibility: bool) -> Self

pub fn width_chars(self, width_chars: i32) -> Self

pub fn xalign(self, xalign: f32) -> Self

The horizontal alignment, from 0 (left) to 1 (right). Reversed for RTL layouts.

pub fn app_paintable(self, app_paintable: bool) -> Self

pub fn can_default(self, can_default: bool) -> Self

pub fn can_focus(self, can_focus: bool) -> Self

pub fn events(self, events: EventMask) -> Self

pub fn expand(self, expand: bool) -> Self

Whether to expand in both directions. Setting this sets both hexpand and vexpand

pub fn focus_on_click(self, focus_on_click: bool) -> Self

Whether the widget should grab focus when it is clicked with the mouse.

This property is only relevant for widgets that can take focus.

Before 3.20, several widgets (GtkButton, GtkFileChooserButton, GtkComboBox) implemented this property individually.

pub fn halign(self, halign: Align) -> Self

How to distribute horizontal space if widget gets extra space, see Align

pub fn has_default(self, has_default: bool) -> Self

pub fn has_focus(self, has_focus: bool) -> Self

pub fn has_tooltip(self, has_tooltip: bool) -> Self

Enables or disables the emission of query-tooltip on widget. A value of true indicates that widget can have a tooltip, in this case the widget will be queried using query-tooltip to determine whether it will provide a tooltip or not.

Note that setting this property to true for the first time will change the event masks of the GdkWindows of this widget to include leave-notify and motion-notify events. This cannot and will not be undone when the property is set to false again.

pub fn height_request(self, height_request: i32) -> Self

pub fn hexpand(self, hexpand: bool) -> Self

Whether to expand horizontally. See WidgetExt::set_hexpand().

pub fn hexpand_set(self, hexpand_set: bool) -> Self

Whether to use the hexpand property. See WidgetExt::is_hexpand_set().

pub fn is_focus(self, is_focus: bool) -> Self

pub fn margin(self, margin: i32) -> Self

Sets all four sides’ margin at once. If read, returns max margin on any side.

pub fn margin_bottom(self, margin_bottom: i32) -> Self

Margin on bottom side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_end(self, margin_end: i32) -> Self

Margin on end of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_start(self, margin_start: i32) -> Self

Margin on start of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_top(self, margin_top: i32) -> Self

Margin on top side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn name(self, name: impl Into<GString>) -> Self

pub fn no_show_all(self, no_show_all: bool) -> Self

pub fn opacity(self, opacity: f64) -> Self

The requested opacity of the widget. See WidgetExt::set_opacity() for more details about window opacity.

Before 3.8 this was only available in GtkWindow

pub fn parent(self, parent: &impl IsA<Container>) -> Self

pub fn receives_default(self, receives_default: bool) -> Self

pub fn sensitive(self, sensitive: bool) -> Self

pub fn tooltip_markup(self, tooltip_markup: impl Into<GString>) -> Self

Sets the text of tooltip to be the given string, which is marked up with the [Pango text markup language][PangoMarkupFormat]. Also see Tooltip::set_markup().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn tooltip_text(self, tooltip_text: impl Into<GString>) -> Self

Sets the text of tooltip to be the given string.

Also see Tooltip::set_text().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn valign(self, valign: Align) -> Self

How to distribute vertical space if widget gets extra space, see Align

pub fn vexpand(self, vexpand: bool) -> Self

Whether to expand vertically. See WidgetExt::set_vexpand().

pub fn vexpand_set(self, vexpand_set: bool) -> Self

Whether to use the vexpand property. See WidgetExt::is_vexpand_set().

pub fn visible(self, visible: bool) -> Self

pub fn width_request(self, width_request: i32) -> Self

pub fn editing_canceled(self, editing_canceled: bool) -> Self

Indicates whether editing on the cell has been canceled.

pub fn build(self) -> Entry

Build the Entry.