pub struct FileChooserNativeBuilder { /* private fields */ }Expand description
A builder-pattern type to construct FileChooserNative objects.
Implementations
Sourceimpl FileChooserNativeBuilder
impl FileChooserNativeBuilder
Sourcepub fn accept_label(self, accept_label: impl Into<GString>) -> Self
pub fn accept_label(self, accept_label: impl Into<GString>) -> Self
The text used for the label on the accept button in the dialog, or
None to use the default text.
Sourcepub fn cancel_label(self, cancel_label: impl Into<GString>) -> Self
pub fn cancel_label(self, cancel_label: impl Into<GString>) -> Self
The text used for the label on the cancel button in the dialog, or
None to use the default text.
Sourcepub fn modal(self, modal: bool) -> Self
pub fn modal(self, modal: bool) -> Self
Whether the window should be modal with respect to its transient parent.
Sourcepub fn transient_for(self, transient_for: &impl IsA<Window>) -> Self
pub fn transient_for(self, transient_for: &impl IsA<Window>) -> Self
The transient parent of the dialog, or None for none.
pub fn action(self, action: FileChooserAction) -> Self
Sourcepub fn create_folders(self, create_folders: bool) -> Self
pub fn create_folders(self, create_folders: bool) -> Self
Whether a file chooser not in FileChooserAction::Open mode
will offer the user to create new folders.
Sourcepub fn do_overwrite_confirmation(self, do_overwrite_confirmation: bool) -> Self
pub fn do_overwrite_confirmation(self, do_overwrite_confirmation: bool) -> Self
Whether a file chooser in FileChooserAction::Save mode
will present an overwrite confirmation dialog if the user
selects a file name that already exists.
pub fn extra_widget(self, extra_widget: &impl IsA<Widget>) -> Self
pub fn filter(self, filter: &FileFilter) -> Self
pub fn local_only(self, local_only: bool) -> Self
pub fn preview_widget(self, preview_widget: &impl IsA<Widget>) -> Self
pub fn preview_widget_active(self, preview_widget_active: bool) -> Self
pub fn select_multiple(self, select_multiple: bool) -> Self
pub fn use_preview_label(self, use_preview_label: bool) -> Self
Sourcepub fn build(self) -> FileChooserNative
pub fn build(self) -> FileChooserNative
Build the FileChooserNative.