pub struct GestureRotateBuilder { /* private fields */ }Expand description
A builder-pattern type to construct GestureRotate objects.
Implementations
Sourceimpl GestureRotateBuilder
impl GestureRotateBuilder
Sourcepub fn n_points(self, n_points: u32) -> Self
pub fn n_points(self, n_points: u32) -> Self
The number of touch points that trigger recognition on this gesture,
Sourcepub fn window(self, window: &Window) -> Self
pub fn window(self, window: &Window) -> Self
If non-None, the gesture will only listen for events that happen on
this gdk::Window, or a child of it.
Sourcepub fn propagation_phase(self, propagation_phase: PropagationPhase) -> Self
pub fn propagation_phase(self, propagation_phase: PropagationPhase) -> Self
The propagation phase at which this controller will handle events.
Sourcepub fn widget(self, widget: &impl IsA<Widget>) -> Self
pub fn widget(self, widget: &impl IsA<Widget>) -> Self
The widget receiving the GdkEvents that the controller will handle.
Sourcepub fn build(self) -> GestureRotate
pub fn build(self) -> GestureRotate
Build the GestureRotate.