IconViewBuilder

Struct IconViewBuilder 

pub struct IconViewBuilder { /* private fields */ }
A builder-pattern type to construct IconView objects.

Implementations

Source

impl IconViewBuilder

pub fn activate_on_single_click(self, activate_on_single_click: bool) -> Self

The activate-on-single-click property specifies whether the “item-activated” signal will be emitted after a single click.

pub fn cell_area(self, cell_area: &impl IsA<CellArea>) -> Self

The CellArea used to layout cell renderers for this view.

If no area is specified when creating the icon view with IconView::with_area() a CellAreaBox will be used.

pub fn column_spacing(self, column_spacing: i32) -> Self

The column-spacing property specifies the space which is inserted between the columns of the icon view.

pub fn columns(self, columns: i32) -> Self

The columns property contains the number of the columns in which the items should be displayed. If it is -1, the number of columns will be chosen automatically to fill the available area.

pub fn item_orientation(self, item_orientation: Orientation) -> Self

The item-orientation property specifies how the cells (i.e. the icon and the text) of the item are positioned relative to each other.

pub fn item_padding(self, item_padding: i32) -> Self

The item-padding property specifies the padding around each of the icon view’s item.

pub fn item_width(self, item_width: i32) -> Self

The item-width property specifies the width to use for each item. If it is set to -1, the icon view will automatically determine a suitable item size.

pub fn margin(self, margin: i32) -> Self

The margin property specifies the space which is inserted at the edges of the icon view.

pub fn markup_column(self, markup_column: i32) -> Self

The ::markup-column property contains the number of the model column containing markup information to be displayed. The markup column must be of type G_TYPE_STRING. If this property and the :text-column property are both set to column numbers, it overrides the text column. If both are set to -1, no texts are displayed.

pub fn model(self, model: &impl IsA<TreeModel>) -> Self

pub fn pixbuf_column(self, pixbuf_column: i32) -> Self

The ::pixbuf-column property contains the number of the model column containing the pixbufs which are displayed. The pixbuf column must be of type GDK_TYPE_PIXBUF. Setting this property to -1 turns off the display of pixbufs.

pub fn reorderable(self, reorderable: bool) -> Self

The reorderable property specifies if the items can be reordered by DND.

pub fn row_spacing(self, row_spacing: i32) -> Self

The row-spacing property specifies the space which is inserted between the rows of the icon view.

pub fn selection_mode(self, selection_mode: SelectionMode) -> Self

The ::selection-mode property specifies the selection mode of icon view. If the mode is SelectionMode::Multiple, rubberband selection is enabled, for the other modes, only keyboard selection is possible.

pub fn spacing(self, spacing: i32) -> Self

The spacing property specifies the space which is inserted between the cells (i.e. the icon and the text) of an item.

pub fn text_column(self, text_column: i32) -> Self

The ::text-column property contains the number of the model column containing the texts which are displayed. The text column must be of type G_TYPE_STRING. If this property and the :markup-column property are both set to -1, no texts are displayed.

pub fn tooltip_column(self, tooltip_column: i32) -> Self

pub fn border_width(self, border_width: u32) -> Self

pub fn child(self, child: &impl IsA<Widget>) -> Self

pub fn resize_mode(self, resize_mode: ResizeMode) -> Self

pub fn app_paintable(self, app_paintable: bool) -> Self

pub fn can_default(self, can_default: bool) -> Self

pub fn can_focus(self, can_focus: bool) -> Self

pub fn events(self, events: EventMask) -> Self

pub fn expand(self, expand: bool) -> Self

Whether to expand in both directions. Setting this sets both hexpand and vexpand

pub fn focus_on_click(self, focus_on_click: bool) -> Self

Whether the widget should grab focus when it is clicked with the mouse.

This property is only relevant for widgets that can take focus.

Before 3.20, several widgets (GtkButton, GtkFileChooserButton, GtkComboBox) implemented this property individually.

pub fn halign(self, halign: Align) -> Self

How to distribute horizontal space if widget gets extra space, see Align

pub fn has_default(self, has_default: bool) -> Self

pub fn has_focus(self, has_focus: bool) -> Self

pub fn has_tooltip(self, has_tooltip: bool) -> Self

Enables or disables the emission of query-tooltip on widget. A value of true indicates that widget can have a tooltip, in this case the widget will be queried using query-tooltip to determine whether it will provide a tooltip or not.

Note that setting this property to true for the first time will change the event masks of the GdkWindows of this widget to include leave-notify and motion-notify events. This cannot and will not be undone when the property is set to false again.

pub fn height_request(self, height_request: i32) -> Self

pub fn hexpand(self, hexpand: bool) -> Self

Whether to expand horizontally. See WidgetExt::set_hexpand().

pub fn hexpand_set(self, hexpand_set: bool) -> Self

Whether to use the hexpand property. See WidgetExt::is_hexpand_set().

pub fn is_focus(self, is_focus: bool) -> Self

pub fn margin_bottom(self, margin_bottom: i32) -> Self

Margin on bottom side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_end(self, margin_end: i32) -> Self

Margin on end of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_start(self, margin_start: i32) -> Self

Margin on start of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn margin_top(self, margin_top: i32) -> Self

Margin on top side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

pub fn name(self, name: impl Into<GString>) -> Self

pub fn no_show_all(self, no_show_all: bool) -> Self

pub fn opacity(self, opacity: f64) -> Self

The requested opacity of the widget. See WidgetExt::set_opacity() for more details about window opacity.

Before 3.8 this was only available in GtkWindow

pub fn parent(self, parent: &impl IsA<Container>) -> Self

pub fn receives_default(self, receives_default: bool) -> Self

pub fn sensitive(self, sensitive: bool) -> Self

pub fn tooltip_markup(self, tooltip_markup: impl Into<GString>) -> Self

Sets the text of tooltip to be the given string, which is marked up with the [Pango text markup language][PangoMarkupFormat]. Also see Tooltip::set_markup().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn tooltip_text(self, tooltip_text: impl Into<GString>) -> Self

Sets the text of tooltip to be the given string.

Also see Tooltip::set_text().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

pub fn valign(self, valign: Align) -> Self

How to distribute vertical space if widget gets extra space, see Align

pub fn vexpand(self, vexpand: bool) -> Self

Whether to expand vertically. See WidgetExt::set_vexpand().

pub fn vexpand_set(self, vexpand_set: bool) -> Self

Whether to use the vexpand property. See WidgetExt::is_vexpand_set().

pub fn visible(self, visible: bool) -> Self

pub fn width_request(self, width_request: i32) -> Self

pub fn hadjustment(self, hadjustment: &impl IsA<Adjustment>) -> Self

Horizontal Adjustment of the scrollable widget. This adjustment is shared between the scrollable widget and its parent.

pub fn hscroll_policy(self, hscroll_policy: ScrollablePolicy) -> Self

Determines whether horizontal scrolling should start once the scrollable widget is allocated less than its minimum width or less than its natural width.

pub fn vadjustment(self, vadjustment: &impl IsA<Adjustment>) -> Self

Verical Adjustment of the scrollable widget. This adjustment is shared between the scrollable widget and its parent.

pub fn vscroll_policy(self, vscroll_policy: ScrollablePolicy) -> Self

Determines whether vertical scrolling should start once the scrollable widget is allocated less than its minimum height or less than its natural height.

pub fn build(self) -> IconView

Build the IconView.