pub struct TreeViewColumnBuilder { /* private fields */ }Expand description
A builder-pattern type to construct TreeViewColumn objects.
Implementations
Sourceimpl TreeViewColumnBuilder
impl TreeViewColumnBuilder
pub fn alignment(self, alignment: f32) -> Self
Sourcepub fn cell_area(self, cell_area: &impl IsA<CellArea>) -> Self
pub fn cell_area(self, cell_area: &impl IsA<CellArea>) -> Self
The CellArea used to layout cell renderers for this column.
If no area is specified when creating the tree view column with TreeViewColumn::with_area()
a horizontally oriented CellAreaBox will be used.
pub fn clickable(self, clickable: bool) -> Self
pub fn expand(self, expand: bool) -> Self
pub fn fixed_width(self, fixed_width: i32) -> Self
pub fn max_width(self, max_width: i32) -> Self
pub fn min_width(self, min_width: i32) -> Self
pub fn reorderable(self, reorderable: bool) -> Self
pub fn resizable(self, resizable: bool) -> Self
pub fn sizing(self, sizing: TreeViewColumnSizing) -> Self
Sourcepub fn sort_column_id(self, sort_column_id: i32) -> Self
pub fn sort_column_id(self, sort_column_id: i32) -> Self
Logical sort column ID this column sorts on when selected for sorting. Setting the sort column ID makes the column header clickable. Set to -1 to make the column unsortable.
pub fn sort_indicator(self, sort_indicator: bool) -> Self
pub fn sort_order(self, sort_order: SortType) -> Self
pub fn spacing(self, spacing: i32) -> Self
pub fn title(self, title: impl Into<GString>) -> Self
pub fn visible(self, visible: bool) -> Self
pub fn widget(self, widget: &impl IsA<Widget>) -> Self
Sourcepub fn build(self) -> TreeViewColumn
pub fn build(self) -> TreeViewColumn
Build the TreeViewColumn.