#[non_exhaustive]pub enum Align {
Fill,
Start,
End,
Center,
Baseline,
}Expand description
Controls how a widget deals with extra space in a single (x or y) dimension.
Alignment only matters if the widget receives a “too large” allocation,
for example if you packed the widget with the expand
flag inside a Box, then the widget might get extra space. If
you have for example a 16x16 icon inside a 32x32 space, the icon
could be scaled and stretched, it could be centered, or it could be
positioned to one side of the space.
Note that in horizontal context Start and End
are interpreted relative to text direction.
GTK_ALIGN_BASELINE support for it is optional for containers and widgets, and
it is only supported for vertical alignment. When its not supported by
a child or a container it is treated as Fill.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Fill
stretch to fill all space if possible, center if no meaningful way to stretch
Start
snap to left or top side, leaving space on right or bottom
End
snap to right or bottom side, leaving space on left or top
Center
center natural width of widget inside the allocation
Baseline
align the widget according to the baseline. Since 3.10.