accel_groups_activate

Function accel_groups_activate 

pub fn accel_groups_activate(
    object: &impl IsA<Object>,
    accel_key: u32,
    accel_mods: ModifierType,
) -> bool
Finds the first accelerator in any AccelGroup attached to object that matches accel_key and accel_mods, and activates that accelerator.

object

the glib::Object, usually a Window, on which to activate the accelerator

accel_key

accelerator keyval from a key event

accel_mods

keyboard state mask from a key event

Returns

true if an accelerator was activated and handled this keypress