pub fn accelerator_parse(accelerator: &str) -> (u32, ModifierType)Expand description
Parses a string representing an accelerator. The format looks like
<Control>`a` or <Alt>`F1` or z (the last one is
for key release).
The parser is fairly liberal and allows lower or upper case, and also
abbreviations such as <Ctl> and <Ctrl>. Key names are parsed using
gdk_keyval_from_name(). For character keys the name is not the symbol,
but the lowercase name, e.g. one would use <Ctrl>`minus` instead of -.
If the parse fails, accelerator_key and accelerator_mods will
be set to 0 (zero).
accelerator
string representing an accelerator
Returns
accelerator_key
return location for accelerator
keyval, or None
accelerator_mods
return location for accelerator
modifier mask, None