Function current_event_state
Source pub fn current_event_state() -> Option<ModifierType>
If there is a current event and it has a state field, place
that state field in state and return true, otherwise return
false.
Returns
true if there was a current event and it
had a state field
state
a location to store the state of the current event