pub fn current_event_time() -> u32
If there is a current event and it has a timestamp, return that timestamp, otherwise return GDK_CURRENT_TIME.
GDK_CURRENT_TIME
the timestamp from the current event, or GDK_CURRENT_TIME.