pub fn render_frame(
context: &impl IsA<StyleContext>,
cr: &Context,
x: f64,
y: f64,
width: f64,
height: f64,
)Expand description
Renders a frame around the rectangle defined by x, y, width, height.
Examples of frame rendering, showing the effect of border-image,
border-color, border-width, border-radius and junctions:

context
cr
x
X origin of the rectangle
y
Y origin of the rectangle
width
rectangle width
height
rectangle height