Function selection_add_target
Source pub fn selection_add_target(
widget: &impl IsA<Widget>,
selection: &Atom,
target: &Atom,
info: u32,
)
Appends a specified target to the list of supported targets for a
given widget and selection.
a Widget
selection
the selection
target
target to add.
info
A unsigned integer which will be passed back to the application.