pub fn selection_owner_set_for_display(
display: &Display,
widget: Option<&impl IsA<Widget>>,
selection: &Atom,
time_: u32,
) -> boolExpand description
Claim ownership of a given selection for a particular widget, or,
if widget is None, release ownership of the selection.
display
the gdk::Display where the selection is set
widget
new selection owner (a Widget), or None.
selection
an interned atom representing the selection to claim.
time_
timestamp with which to claim the selection
Returns
TRUE if the operation succeeded