Function targets_include_uri
Source pub fn targets_include_uri(targets: &[Atom]) -> bool
Determines if any of the targets in targets can be used to
provide an uri list.
targets
an array of GdkAtoms
Returns
true if targets include a suitable target for uri lists,
otherwise false.