pub fn test_find_sibling(
base_widget: &impl IsA<Widget>,
widget_type: Type,
) -> Option<Widget>Expand description
This function will search siblings of base_widget and siblings of its
ancestors for all widgets matching widget_type.
Of the matching widgets, the one that is geometrically closest to
base_widget will be returned.
The general purpose of this function is to find the most likely “action”
widget, relative to another labeling widget. Such as finding a
button or text entry widget, given its corresponding label widget.
base_widget
Valid widget, part of a widget hierarchy
widget_type
Type of a aearched for sibling widget
Returns
a widget of type widget_type if any is found.