pub fn test_widget_send_key(
widget: &impl IsA<Widget>,
keyval: u32,
modifiers: ModifierType,
) -> boolExpand description
window.
Certain caveats should be considered when using this function, in
particular because the mouse pointer is warped to the key press
location, see gdk_test_simulate_key() for details.
widget
Widget to generate a key press and release on.
keyval
A Gdk keyboard value.
modifiers
Keyboard modifiers the event is setup with.
Returns
whether all actions neccessary for the key event simulation were carried out successfully.