AboutDialogExt

Trait AboutDialogExt 

pub trait AboutDialogExt: IsA<AboutDialog> + 'static {
Show 47 methods // Provided methods fn add_credit_section(&self, section_name: &str, people: &[&str]) { ... } fn artists(&self) -> Vec<GString> { ... } fn authors(&self) -> Vec<GString> { ... } fn comments(&self) -> Option<GString> { ... } fn copyright(&self) -> Option<GString> { ... } fn documenters(&self) -> Vec<GString> { ... } fn license(&self) -> Option<GString> { ... } fn license_type(&self) -> License { ... } fn logo(&self) -> Option<Pixbuf> { ... } fn logo_icon_name(&self) -> Option<GString> { ... } fn program_name(&self) -> Option<GString> { ... } fn translator_credits(&self) -> Option<GString> { ... } fn version(&self) -> Option<GString> { ... } fn website(&self) -> Option<GString> { ... } fn website_label(&self) -> Option<GString> { ... } fn wraps_license(&self) -> bool { ... } fn set_artists(&self, artists: &[&str]) { ... } fn set_authors(&self, authors: &[&str]) { ... } fn set_comments(&self, comments: Option<&str>) { ... } fn set_copyright(&self, copyright: Option<&str>) { ... } fn set_documenters(&self, documenters: &[&str]) { ... } fn set_license(&self, license: Option<&str>) { ... } fn set_license_type(&self, license_type: License) { ... } fn set_logo(&self, logo: Option<&Pixbuf>) { ... } fn set_logo_icon_name(&self, icon_name: Option<&str>) { ... } fn set_program_name(&self, name: &str) { ... } fn set_translator_credits(&self, translator_credits: Option<&str>) { ... } fn set_version(&self, version: Option<&str>) { ... } fn set_website(&self, website: Option<&str>) { ... } fn set_website_label(&self, website_label: Option<&str>) { ... } fn set_wrap_license(&self, wrap_license: bool) { ... } fn connect_activate_link<F: Fn(&Self, &str) -> Propagation + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_artists_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_authors_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_comments_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_copyright_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_documenters_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_license_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_license_type_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_logo_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_logo_icon_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_program_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_translator_credits_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_version_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_website_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_website_label_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_wrap_license_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all AboutDialog methods.

Implementors

AboutDialog

Provided Methods

fn add_credit_section(&self, section_name: &str, people: &[&str])

Creates a new section in the Credits page.

section_name

The name of the section

people

The people who belong to that section

fn artists(&self) -> Vec<GString>

Returns the string which are displayed in the artists tab of the secondary credits dialog.

Returns

A None-terminated string array containing the artists. The array is owned by the about dialog and must not be modified.

fn authors(&self) -> Vec<GString>

Returns the string which are displayed in the authors tab of the secondary credits dialog.

Returns

A None-terminated string array containing the authors. The array is owned by the about dialog and must not be modified.

fn comments(&self) -> Option<GString>

Returns the comments string.

Returns

The comments. The string is owned by the about dialog and must not be modified.

fn copyright(&self) -> Option<GString>

Returns the copyright string.

Returns

The copyright string. The string is owned by the about dialog and must not be modified.

fn documenters(&self) -> Vec<GString>

Returns the string which are displayed in the documenters tab of the secondary credits dialog.

Returns

A None-terminated string array containing the documenters. The array is owned by the about dialog and must not be modified.

fn license(&self) -> Option<GString>

Returns the license information.

Returns

The license information. The string is owned by the about dialog and must not be modified.

fn license_type(&self) -> License

Retrieves the license set using set_license_type()

Returns

a License value

Returns the pixbuf displayed as logo in the about dialog.

Returns

the pixbuf displayed as logo. The pixbuf is owned by the about dialog. If you want to keep a reference to it, you have to call g_object_ref() on it.

fn logo_icon_name(&self) -> Option<GString>

Returns the icon name displayed as logo in the about dialog.

Returns

the icon name displayed as logo. The string is owned by the dialog. If you want to keep a reference to it, you have to call g_strdup() on it.

fn program_name(&self) -> Option<GString>

Returns the program name displayed in the about dialog.

Returns

The program name. The string is owned by the about dialog and must not be modified.

fn translator_credits(&self) -> Option<GString>

Returns the translator credits string which is displayed in the translators tab of the secondary credits dialog.

Returns

The translator credits string. The string is owned by the about dialog and must not be modified.

fn version(&self) -> Option<GString>

Returns the version string.

Returns

The version string. The string is owned by the about dialog and must not be modified.

fn website(&self) -> Option<GString>

Returns the website URL.

Returns

The website URL. The string is owned by the about dialog and must not be modified.

fn website_label(&self) -> Option<GString>

Returns the label used for the website link.

Returns

The label used for the website link. The string is owned by the about dialog and must not be modified.

fn wraps_license(&self) -> bool

Returns whether the license text in self is automatically wrapped.

Returns

true if the license text is wrapped

fn set_artists(&self, artists: &[&str])

Sets the strings which are displayed in the artists tab of the secondary credits dialog.

artists

a None-terminated array of strings

fn set_authors(&self, authors: &[&str])

Sets the strings which are displayed in the authors tab of the secondary credits dialog.

authors

a None-terminated array of strings

fn set_comments(&self, comments: Option<&str>)

Sets the comments string to display in the about dialog. This should be a short string of one or two lines.

comments

a comments string

Sets the copyright string to display in the about dialog. This should be a short string of one or two lines.

the copyright string

fn set_documenters(&self, documenters: &[&str])

Sets the strings which are displayed in the documenters tab of the secondary credits dialog.

documenters

a None-terminated array of strings

fn set_license(&self, license: Option<&str>)

Sets the license information to be displayed in the secondary license dialog. If license is None, the license button is hidden.

license

the license information or None

fn set_license_type(&self, license_type: License)

Sets the license of the application showing the self dialog from a list of known licenses.

This function overrides the license set using set_license().

license_type

the type of license

Sets the pixbuf to be displayed as logo in the about dialog. If it is None, the default window icon set with Window::set_default_icon() will be used.

a gdk_pixbuf::Pixbuf, or None

fn set_logo_icon_name(&self, icon_name: Option<&str>)

Sets the pixbuf to be displayed as logo in the about dialog. If it is None, the default window icon set with Window::set_default_icon() will be used.

icon_name

an icon name, or None

fn set_program_name(&self, name: &str)

Sets the name to display in the about dialog. If this is not set, it defaults to g_get_application_name().

name

the program name

fn set_translator_credits(&self, translator_credits: Option<&str>)

GtkWidget *about = gtk_about_dialog_new (); gtk_about_dialog_set_translator_credits (GTK_ABOUT_DIALOG (about), _(“translator-credits”)); ]| It is a good idea to use the customary msgid “translator-credits” for this purpose, since translators will already know the purpose of that msgid, and since AboutDialog will detect if “translator-credits” is untranslated and hide the tab.

translator_credits

the translator credits

fn set_version(&self, version: Option<&str>)

Sets the version string to display in the about dialog.

version

the version string

fn set_website(&self, website: Option<&str>)

Sets the URL to use for the website link.

website

a URL string starting with “http://”

fn set_website_label(&self, website_label: Option<&str>)

Sets the label to be used for the website link.

website_label

the label used for the website link

fn set_wrap_license(&self, wrap_license: bool)

Sets whether the license text in self is automatically wrapped.

wrap_license

whether to wrap the license

The signal which gets emitted to activate a URI. Applications may connect to it to override the default behaviour, which is to call show_uri_on_window().

uri

the URI that is activated

Returns

true if the link has been activated

fn connect_artists_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_authors_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_comments_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_documenters_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_license_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_license_type_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_logo_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_logo_icon_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_program_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_translator_credits_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_version_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_website_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_website_label_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_wrap_license_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors