pub trait AppChooserDialogExt:
IsA<AppChooserDialog>
+ Sealed
+ 'static {
// Provided methods
fn heading(&self) -> Option<GString> { ... }
fn widget(&self) -> Widget { ... }
fn set_heading(&self, heading: &str) { ... }
fn gfile(&self) -> Option<File> { ... }
fn connect_heading_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn set_heading(&self, heading: &str)
fn set_heading(&self, heading: &str)
Sets the text to display at the top of the dialog. If the heading is not set, the dialog displays a default text.
heading
a string containing Pango markup
Sourcefn gfile(&self) -> Option<File>
fn gfile(&self) -> Option<File>
The GFile used by the AppChooserDialog.
The dialog’s AppChooserWidget content type will be guessed from the
file, if present.
fn connect_heading_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".