AppChooserWidgetExt

Trait AppChooserWidgetExt 

pub trait AppChooserWidgetExt: IsA<AppChooserWidget> + 'static {
Show 21 methods // Provided methods fn default_text(&self) -> Option<GString> { ... } fn shows_all(&self) -> bool { ... } fn shows_default(&self) -> bool { ... } fn shows_fallback(&self) -> bool { ... } fn shows_other(&self) -> bool { ... } fn shows_recommended(&self) -> bool { ... } fn set_default_text(&self, text: &str) { ... } fn set_show_all(&self, setting: bool) { ... } fn set_show_default(&self, setting: bool) { ... } fn set_show_fallback(&self, setting: bool) { ... } fn set_show_other(&self, setting: bool) { ... } fn set_show_recommended(&self, setting: bool) { ... } fn connect_application_activated<F: Fn(&Self, &AppInfo) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_application_selected<F: Fn(&Self, &AppInfo) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_populate_popup<F: Fn(&Self, &Menu, &AppInfo) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_default_text_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_show_all_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_show_default_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_show_fallback_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_show_other_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_show_recommended_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all AppChooserWidget methods.

Implementors

AppChooserWidget

Provided Methods

fn default_text(&self) -> Option<GString>

Returns the text that is shown if there are not applications that can handle the content type.

Returns

the value of default-text

fn shows_all(&self) -> bool

Returns the current value of the show-all property.

Returns

the value of show-all

fn shows_default(&self) -> bool

Returns the current value of the show-default property.

Returns

the value of show-default

fn shows_fallback(&self) -> bool

Returns the current value of the show-fallback property.

Returns

the value of show-fallback

fn shows_other(&self) -> bool

Returns the current value of the show-other property.

Returns

the value of show-other

Returns the current value of the show-recommended property.

Returns

the value of show-recommended

fn set_default_text(&self, text: &str)

Sets the text that is shown if there are not applications that can handle the content type.

text

the new value for default-text

fn set_show_all(&self, setting: bool)

Sets whether the app chooser should show all applications in a flat list.

setting

the new value for show-all

fn set_show_default(&self, setting: bool)

Sets whether the app chooser should show the default handler for the content type in a separate section.

setting

the new value for show-default

fn set_show_fallback(&self, setting: bool)

Sets whether the app chooser should show related applications for the content type in a separate section.

setting

the new value for show-fallback

fn set_show_other(&self, setting: bool)

Sets whether the app chooser should show applications which are unrelated to the content type.

setting

the new value for show-other

Sets whether the app chooser should show recommended applications for the content type in a separate section.

setting

the new value for show-recommended

fn connect_application_activated<F: Fn(&Self, &AppInfo) + 'static>( &self, f: F, ) -> SignalHandlerId

Emitted when an application item is activated from the widget’s list.

This usually happens when the user double clicks an item, or an item is selected and the user presses one of the keys Space, Shift+Space, Return or Enter.

application

the activated gio::AppInfo

fn connect_application_selected<F: Fn(&Self, &AppInfo) + 'static>( &self, f: F, ) -> SignalHandlerId

Emitted when an application item is selected from the widget’s list.

application

the selected gio::AppInfo

fn connect_populate_popup<F: Fn(&Self, &Menu, &AppInfo) + 'static>( &self, f: F, ) -> SignalHandlerId

Emitted when a context menu is about to popup over an application item. Clients can insert menu items into the provided Menu object in the callback of this signal; the context menu will be shown over the item if at least one item has been added to the menu.

the Menu to populate

application

the current gio::AppInfo

fn connect_default_text_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_show_all_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_show_default_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_show_fallback_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_show_other_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors