pub trait AppChooserWidgetExt: IsA<AppChooserWidget> + 'static {
Show 21 methods
// Provided methods
fn default_text(&self) -> Option<GString> { ... }
fn shows_all(&self) -> bool { ... }
fn shows_default(&self) -> bool { ... }
fn shows_fallback(&self) -> bool { ... }
fn shows_other(&self) -> bool { ... }
fn shows_recommended(&self) -> bool { ... }
fn set_default_text(&self, text: &str) { ... }
fn set_show_all(&self, setting: bool) { ... }
fn set_show_default(&self, setting: bool) { ... }
fn set_show_fallback(&self, setting: bool) { ... }
fn set_show_other(&self, setting: bool) { ... }
fn set_show_recommended(&self, setting: bool) { ... }
fn connect_application_activated<F: Fn(&Self, &AppInfo) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_application_selected<F: Fn(&Self, &AppInfo) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_populate_popup<F: Fn(&Self, &Menu, &AppInfo) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_default_text_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_show_all_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_show_default_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_show_fallback_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_show_other_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_show_recommended_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn default_text(&self) -> Option<GString>
fn default_text(&self) -> Option<GString>
Returns the text that is shown if there are not applications that can handle the content type.
Returns
the value of default-text
Sourcefn shows_default(&self) -> bool
fn shows_default(&self) -> bool
Sourcefn shows_fallback(&self) -> bool
fn shows_fallback(&self) -> bool
Sourcefn shows_other(&self) -> bool
fn shows_other(&self) -> bool
Sourcefn shows_recommended(&self) -> bool
fn shows_recommended(&self) -> bool
Sourcefn set_default_text(&self, text: &str)
fn set_default_text(&self, text: &str)
Sets the text that is shown if there are not applications that can handle the content type.
text
the new value for default-text
Sourcefn set_show_all(&self, setting: bool)
fn set_show_all(&self, setting: bool)
Sourcefn set_show_default(&self, setting: bool)
fn set_show_default(&self, setting: bool)
Sets whether the app chooser should show the default handler for the content type in a separate section.
setting
the new value for show-default
Sourcefn set_show_fallback(&self, setting: bool)
fn set_show_fallback(&self, setting: bool)
Sets whether the app chooser should show related applications for the content type in a separate section.
setting
the new value for show-fallback
Sourcefn set_show_other(&self, setting: bool)
fn set_show_other(&self, setting: bool)
Sets whether the app chooser should show applications which are unrelated to the content type.
setting
the new value for show-other
Sourcefn set_show_recommended(&self, setting: bool)
fn set_show_recommended(&self, setting: bool)
Sets whether the app chooser should show recommended applications for the content type in a separate section.
setting
the new value for show-recommended
Sourcefn connect_application_activated<F: Fn(&Self, &AppInfo) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_application_activated<F: Fn(&Self, &AppInfo) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when an application item is activated from the widget’s list.
This usually happens when the user double clicks an item, or an item is selected and the user presses one of the keys Space, Shift+Space, Return or Enter.
application
the activated gio::AppInfo
Sourcefn connect_application_selected<F: Fn(&Self, &AppInfo) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_application_selected<F: Fn(&Self, &AppInfo) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when an application item is selected from the widget’s list.
application
the selected gio::AppInfo
Sourcefn connect_populate_popup<F: Fn(&Self, &Menu, &AppInfo) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_populate_popup<F: Fn(&Self, &Menu, &AppInfo) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when a context menu is about to popup over an application item.
Clients can insert menu items into the provided Menu object in the
callback of this signal; the context menu will be shown over the item
if at least one item has been added to the menu.
menu
the Menu to populate
application
the current gio::AppInfo
fn connect_default_text_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_show_all_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_show_default_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_show_fallback_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_show_other_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_show_recommended_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".