pub trait ApplicationWindowExt:
IsA<ApplicationWindow>
+ Sealed
+ 'static {
// Provided methods
fn help_overlay(&self) -> Option<ShortcutsWindow> { ... }
fn id(&self) -> u32 { ... }
fn shows_menubar(&self) -> bool { ... }
fn set_help_overlay(&self, help_overlay: Option<&impl IsA<ShortcutsWindow>>) { ... }
fn set_show_menubar(&self, show_menubar: bool) { ... }
fn connect_show_menubar_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn help_overlay(&self) -> Option<ShortcutsWindow>
fn help_overlay(&self) -> Option<ShortcutsWindow>
Gets the ShortcutsWindow that has been set up with
a prior call to set_help_overlay().
Returns
the help overlay associated with self, or None
Sourcefn id(&self) -> u32
fn id(&self) -> u32
Returns the unique ID of the window. If the window has not yet been added to
a Application, returns 0.
Returns
the unique ID for self, or 0 if the window
has not yet been added to a Application
Sourcefn set_help_overlay(&self, help_overlay: Option<&impl IsA<ShortcutsWindow>>)
fn set_help_overlay(&self, help_overlay: Option<&impl IsA<ShortcutsWindow>>)
Associates a shortcuts window with the application window, and sets up an action with the name win.show-help-overlay to present it.
self takes resposibility for destroying help_overlay.
help_overlay
Sets whether the window will display a menubar for the app menu and menubar as needed.
show_menubar
whether to show a menubar when needed
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".