Trait BinExt Copy item path Source pub trait BinExt:
IsA <Bin >
+ Sealed
+ 'static {
// Provided method
fn child (&self) -> Option <Widget > { ... }
}Expand description Trait containing all Bin methods.
 Implementors
ActionBar , Bin , Button , ComboBox , EventBox , Expander , FlowBoxChild , Frame , ListBoxRow , MenuItem , Overlay , Popover , Revealer , ScrolledWindow , SearchBar , StackSidebar , ToolItem , Viewport , Window
Gets the child of the Bin , or None if the bin contains
no child widget. The returned widget does not have a reference
added, so you do not need to unref it.
 Returns
the child of self, or None if it does
not have a child.
This trait is not dyn compatible .
In older versions of Rust, dyn compatibility was called "object safety".