pub trait CalendarExt: IsA<Calendar> + 'static {
Show 47 methods
// Provided methods
fn clear_marks(&self) { ... }
fn date(&self) -> (u32, u32, u32) { ... }
fn day_is_marked(&self, day: u32) -> bool { ... }
fn detail_height_rows(&self) -> i32 { ... }
fn detail_width_chars(&self) -> i32 { ... }
fn display_options(&self) -> CalendarDisplayOptions { ... }
fn mark_day(&self, day: u32) { ... }
fn select_day(&self, day: u32) { ... }
fn select_month(&self, month: u32, year: u32) { ... }
fn set_detail_func<P: Fn(&Calendar, u32, u32, u32) -> Option<String> + 'static>(
&self,
func: P,
) { ... }
fn set_detail_height_rows(&self, rows: i32) { ... }
fn set_detail_width_chars(&self, chars: i32) { ... }
fn set_display_options(&self, flags: CalendarDisplayOptions) { ... }
fn unmark_day(&self, day: u32) { ... }
fn day(&self) -> i32 { ... }
fn set_day(&self, day: i32) { ... }
fn month(&self) -> i32 { ... }
fn set_month(&self, month: i32) { ... }
fn is_no_month_change(&self) -> bool { ... }
fn set_no_month_change(&self, no_month_change: bool) { ... }
fn shows_day_names(&self) -> bool { ... }
fn set_show_day_names(&self, show_day_names: bool) { ... }
fn shows_details(&self) -> bool { ... }
fn set_show_details(&self, show_details: bool) { ... }
fn shows_heading(&self) -> bool { ... }
fn set_show_heading(&self, show_heading: bool) { ... }
fn shows_week_numbers(&self) -> bool { ... }
fn set_show_week_numbers(&self, show_week_numbers: bool) { ... }
fn year(&self) -> i32 { ... }
fn set_year(&self, year: i32) { ... }
fn connect_day_selected<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_day_selected_double_click<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_month_changed<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_next_month<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_next_year<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn connect_prev_month<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_prev_year<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn connect_day_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_detail_height_rows_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_detail_width_chars_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_month_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_no_month_change_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_show_day_names_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_show_details_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_show_heading_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_show_week_numbers_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_year_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Provided Methods
Sourcefn clear_marks(&self)
fn clear_marks(&self)
Remove all visual markers.
Sourcefn day_is_marked(&self, day: u32) -> bool
fn day_is_marked(&self, day: u32) -> bool
Sourcefn detail_height_rows(&self) -> i32
fn detail_height_rows(&self) -> i32
Queries the height of detail cells, in rows.
See detail-width-chars.
Returns
The height of detail cells, in rows.
Sourcefn detail_width_chars(&self) -> i32
fn detail_width_chars(&self) -> i32
Queries the width of detail cells, in characters.
See detail-width-chars.
Returns
The width of detail cells, in characters.
Sourcefn display_options(&self) -> CalendarDisplayOptions
fn display_options(&self) -> CalendarDisplayOptions
Sourcefn select_day(&self, day: u32)
fn select_day(&self, day: u32)
Selects a day from the current month.
day
the day number between 1 and 31, or 0 to unselect the currently selected day.
Sourcefn select_month(&self, month: u32, year: u32)
fn select_month(&self, month: u32, year: u32)
Sourcefn set_detail_func<P: Fn(&Calendar, u32, u32, u32) -> Option<String> + 'static>(
&self,
func: P,
)
fn set_detail_func<P: Fn(&Calendar, u32, u32, u32) -> Option<String> + 'static>( &self, func: P, )
Installs a function which provides Pango markup with detail information
for each day. Examples for such details are holidays or appointments. That
information is shown below each day when show-details is set.
A tooltip containing with full detail information is provided, if the entire
text should not fit into the details area, or if show-details
is not set.
The size of the details area can be restricted by setting the
detail-width-chars and detail-height-rows
properties.
func
a function providing details for each day.
Sourcefn set_detail_height_rows(&self, rows: i32)
fn set_detail_height_rows(&self, rows: i32)
Sourcefn set_detail_width_chars(&self, chars: i32)
fn set_detail_width_chars(&self, chars: i32)
Sourcefn set_display_options(&self, flags: CalendarDisplayOptions)
fn set_display_options(&self, flags: CalendarDisplayOptions)
Sets display options (whether to display the heading and the month headings).
flags
the display options to set
Sourcefn unmark_day(&self, day: u32)
fn unmark_day(&self, day: u32)
Sourcefn day(&self) -> i32
fn day(&self) -> i32
The selected day (as a number between 1 and 31, or 0 to unselect the currently selected day). This property gets initially set to the current day.
Sourcefn set_day(&self, day: i32)
fn set_day(&self, day: i32)
The selected day (as a number between 1 and 31, or 0 to unselect the currently selected day). This property gets initially set to the current day.
Sourcefn month(&self) -> i32
fn month(&self) -> i32
The selected month (as a number between 0 and 11). This property gets initially set to the current month.
Sourcefn set_month(&self, month: i32)
fn set_month(&self, month: i32)
The selected month (as a number between 0 and 11). This property gets initially set to the current month.
Sourcefn is_no_month_change(&self) -> bool
fn is_no_month_change(&self) -> bool
Determines whether the selected month can be changed.
Sourcefn set_no_month_change(&self, no_month_change: bool)
fn set_no_month_change(&self, no_month_change: bool)
Determines whether the selected month can be changed.
Sourcefn shows_day_names(&self) -> bool
fn shows_day_names(&self) -> bool
Determines whether day names are displayed.
Sourcefn set_show_day_names(&self, show_day_names: bool)
fn set_show_day_names(&self, show_day_names: bool)
Determines whether day names are displayed.
Sourcefn shows_details(&self) -> bool
fn shows_details(&self) -> bool
Determines whether details are shown directly in the widget, or if they are available only as tooltip. When this property is set days with details are marked.
Sourcefn set_show_details(&self, show_details: bool)
fn set_show_details(&self, show_details: bool)
Determines whether details are shown directly in the widget, or if they are available only as tooltip. When this property is set days with details are marked.
Sourcefn shows_heading(&self) -> bool
fn shows_heading(&self) -> bool
Determines whether a heading is displayed.
Sourcefn set_show_heading(&self, show_heading: bool)
fn set_show_heading(&self, show_heading: bool)
Determines whether a heading is displayed.
Sourcefn shows_week_numbers(&self) -> bool
fn shows_week_numbers(&self) -> bool
Determines whether week numbers are displayed.
Sourcefn set_show_week_numbers(&self, show_week_numbers: bool)
fn set_show_week_numbers(&self, show_week_numbers: bool)
Determines whether week numbers are displayed.
Sourcefn set_year(&self, year: i32)
fn set_year(&self, year: i32)
The selected year. This property gets initially set to the current year.
Sourcefn connect_day_selected<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_day_selected<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Emitted when the user selects a day.
Sourcefn connect_day_selected_double_click<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_day_selected_double_click<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when the user double-clicks a day.
Sourcefn connect_month_changed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_month_changed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Emitted when the user clicks a button to change the selected month on a calendar.
Sourcefn connect_next_month<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_next_month<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Emitted when the user switched to the next month.
Sourcefn connect_next_year<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_next_year<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Emitted when user switched to the next year.
Sourcefn connect_prev_month<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_prev_month<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Emitted when the user switched to the previous month.
Sourcefn connect_prev_year<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_prev_year<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Emitted when user switched to the previous year.
fn connect_day_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_detail_height_rows_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_detail_width_chars_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_month_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_no_month_change_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_show_day_names_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_show_details_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_show_heading_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_show_week_numbers_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_year_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".