CalendarExt

Trait CalendarExt 

pub trait CalendarExt:
    IsA<Calendar>
    + Sealed
    + 'static {
Show 47 methods // Provided methods fn clear_marks(&self) { ... } fn date(&self) -> (u32, u32, u32) { ... } fn day_is_marked(&self, day: u32) -> bool { ... } fn detail_height_rows(&self) -> i32 { ... } fn detail_width_chars(&self) -> i32 { ... } fn display_options(&self) -> CalendarDisplayOptions { ... } fn mark_day(&self, day: u32) { ... } fn select_day(&self, day: u32) { ... } fn select_month(&self, month: u32, year: u32) { ... } fn set_detail_func<P: Fn(&Calendar, u32, u32, u32) -> Option<String> + 'static>( &self, func: P, ) { ... } fn set_detail_height_rows(&self, rows: i32) { ... } fn set_detail_width_chars(&self, chars: i32) { ... } fn set_display_options(&self, flags: CalendarDisplayOptions) { ... } fn unmark_day(&self, day: u32) { ... } fn day(&self) -> i32 { ... } fn set_day(&self, day: i32) { ... } fn month(&self) -> i32 { ... } fn set_month(&self, month: i32) { ... } fn is_no_month_change(&self) -> bool { ... } fn set_no_month_change(&self, no_month_change: bool) { ... } fn shows_day_names(&self) -> bool { ... } fn set_show_day_names(&self, show_day_names: bool) { ... } fn shows_details(&self) -> bool { ... } fn set_show_details(&self, show_details: bool) { ... } fn shows_heading(&self) -> bool { ... } fn set_show_heading(&self, show_heading: bool) { ... } fn shows_week_numbers(&self) -> bool { ... } fn set_show_week_numbers(&self, show_week_numbers: bool) { ... } fn year(&self) -> i32 { ... } fn set_year(&self, year: i32) { ... } fn connect_day_selected<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_day_selected_double_click<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_month_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_next_month<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_next_year<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... } fn connect_prev_month<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_prev_year<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... } fn connect_day_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_detail_height_rows_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_detail_width_chars_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_month_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_no_month_change_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_show_day_names_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_show_details_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_show_heading_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_show_week_numbers_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_year_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all Calendar methods.

Implementors

Calendar

Provided Methods

fn clear_marks(&self)

Remove all visual markers.

fn date(&self) -> (u32, u32, u32)

Obtains the selected date from a Calendar.

Returns
year

location to store the year as a decimal number (e.g. 2011), or None

month

location to store the month number (between 0 and 11), or None

day

location to store the day number (between 1 and 31), or None

fn day_is_marked(&self, day: u32) -> bool

Returns if the day of the self is already marked.

day

the day number between 1 and 31.

Returns

whether the day is marked.

fn detail_height_rows(&self) -> i32

Queries the height of detail cells, in rows. See detail-width-chars.

Returns

The height of detail cells, in rows.

fn detail_width_chars(&self) -> i32

Queries the width of detail cells, in characters. See detail-width-chars.

Returns

The width of detail cells, in characters.

fn display_options(&self) -> CalendarDisplayOptions

Returns the current display options of self.

Returns

the display options.

fn mark_day(&self, day: u32)

Places a visual marker on a particular day.

day

the day number to mark between 1 and 31.

fn select_day(&self, day: u32)

Selects a day from the current month.

day

the day number between 1 and 31, or 0 to unselect the currently selected day.

fn select_month(&self, month: u32, year: u32)

Shifts the calendar to a different month.

month

a month number between 0 and 11.

year

the year the month is in.

fn set_detail_func<P: Fn(&Calendar, u32, u32, u32) -> Option<String> + 'static>( &self, func: P, )

Installs a function which provides Pango markup with detail information for each day. Examples for such details are holidays or appointments. That information is shown below each day when show-details is set. A tooltip containing with full detail information is provided, if the entire text should not fit into the details area, or if show-details is not set.

The size of the details area can be restricted by setting the detail-width-chars and detail-height-rows properties.

func

a function providing details for each day.

fn set_detail_height_rows(&self, rows: i32)

Updates the height of detail cells. See detail-height-rows.

rows

detail height in rows.

fn set_detail_width_chars(&self, chars: i32)

Updates the width of detail cells. See detail-width-chars.

chars

detail width in characters.

fn set_display_options(&self, flags: CalendarDisplayOptions)

Sets display options (whether to display the heading and the month headings).

flags

the display options to set

fn unmark_day(&self, day: u32)

Removes the visual marker from a particular day.

day

the day number to unmark between 1 and 31.

fn day(&self) -> i32

The selected day (as a number between 1 and 31, or 0 to unselect the currently selected day). This property gets initially set to the current day.

fn set_day(&self, day: i32)

The selected day (as a number between 1 and 31, or 0 to unselect the currently selected day). This property gets initially set to the current day.

fn month(&self) -> i32

The selected month (as a number between 0 and 11). This property gets initially set to the current month.

fn set_month(&self, month: i32)

The selected month (as a number between 0 and 11). This property gets initially set to the current month.

fn is_no_month_change(&self) -> bool

Determines whether the selected month can be changed.

fn set_no_month_change(&self, no_month_change: bool)

Determines whether the selected month can be changed.

fn shows_day_names(&self) -> bool

Determines whether day names are displayed.

fn set_show_day_names(&self, show_day_names: bool)

Determines whether day names are displayed.

fn shows_details(&self) -> bool

Determines whether details are shown directly in the widget, or if they are available only as tooltip. When this property is set days with details are marked.

fn set_show_details(&self, show_details: bool)

Determines whether details are shown directly in the widget, or if they are available only as tooltip. When this property is set days with details are marked.

fn shows_heading(&self) -> bool

Determines whether a heading is displayed.

fn set_show_heading(&self, show_heading: bool)

Determines whether a heading is displayed.

fn shows_week_numbers(&self) -> bool

Determines whether week numbers are displayed.

fn set_show_week_numbers(&self, show_week_numbers: bool)

Determines whether week numbers are displayed.

fn year(&self) -> i32

The selected year. This property gets initially set to the current year.

fn set_year(&self, year: i32)

The selected year. This property gets initially set to the current year.

fn connect_day_selected<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Emitted when the user selects a day.

fn connect_day_selected_double_click<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Emitted when the user double-clicks a day.

fn connect_month_changed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Emitted when the user clicks a button to change the selected month on a calendar.

fn connect_next_month<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Emitted when the user switched to the next month.

fn connect_next_year<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Emitted when user switched to the next year.

fn connect_prev_month<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Emitted when the user switched to the previous month.

fn connect_prev_year<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Emitted when user switched to the previous year.

fn connect_day_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_detail_height_rows_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_detail_width_chars_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_month_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_no_month_change_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_show_day_names_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_show_details_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_show_heading_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_show_week_numbers_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_year_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors