pub trait CellRendererAccelExt: IsA<CellRendererAccel> + 'static {
Show 14 methods
// Provided methods
fn accel_key(&self) -> u32 { ... }
fn set_accel_key(&self, accel_key: u32) { ... }
fn accel_mode(&self) -> CellRendererAccelMode { ... }
fn set_accel_mode(&self, accel_mode: CellRendererAccelMode) { ... }
fn accel_mods(&self) -> ModifierType { ... }
fn set_accel_mods(&self, accel_mods: ModifierType) { ... }
fn keycode(&self) -> u32 { ... }
fn set_keycode(&self, keycode: u32) { ... }
fn connect_accel_cleared<F: Fn(&Self, TreePath) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_accel_edited<F: Fn(&Self, TreePath, u32, ModifierType, u32) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_accel_key_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_accel_mode_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_accel_mods_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_keycode_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn set_accel_key(&self, accel_key: u32)
fn set_accel_key(&self, accel_key: u32)
The keyval of the accelerator.
Sourcefn accel_mode(&self) -> CellRendererAccelMode
fn accel_mode(&self) -> CellRendererAccelMode
Determines if the edited accelerators are GTK+ accelerators. If they are, consumed modifiers are suppressed, only accelerators accepted by GTK+ are allowed, and the accelerators are rendered in the same way as they are in menus.
Sourcefn set_accel_mode(&self, accel_mode: CellRendererAccelMode)
fn set_accel_mode(&self, accel_mode: CellRendererAccelMode)
Determines if the edited accelerators are GTK+ accelerators. If they are, consumed modifiers are suppressed, only accelerators accepted by GTK+ are allowed, and the accelerators are rendered in the same way as they are in menus.
Sourcefn accel_mods(&self) -> ModifierType
fn accel_mods(&self) -> ModifierType
The modifier mask of the accelerator.
Sourcefn set_accel_mods(&self, accel_mods: ModifierType)
fn set_accel_mods(&self, accel_mods: ModifierType)
The modifier mask of the accelerator.
Sourcefn keycode(&self) -> u32
fn keycode(&self) -> u32
The hardware keycode of the accelerator. Note that the hardware keycode is only relevant if the key does not have a keyval. Normally, the keyboard configuration should assign keyvals to all keys.
Sourcefn set_keycode(&self, keycode: u32)
fn set_keycode(&self, keycode: u32)
The hardware keycode of the accelerator. Note that the hardware keycode is only relevant if the key does not have a keyval. Normally, the keyboard configuration should assign keyvals to all keys.
Sourcefn connect_accel_cleared<F: Fn(&Self, TreePath) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_accel_cleared<F: Fn(&Self, TreePath) + 'static>( &self, f: F, ) -> SignalHandlerId
Gets emitted when the user has removed the accelerator.
path_string
the path identifying the row of the edited cell
Sourcefn connect_accel_edited<F: Fn(&Self, TreePath, u32, ModifierType, u32) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_accel_edited<F: Fn(&Self, TreePath, u32, ModifierType, u32) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_accel_key_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_accel_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_accel_mods_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_keycode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".