CellRendererAccelExt

Trait CellRendererAccelExt 

pub trait CellRendererAccelExt:
    IsA<CellRendererAccel>
    + Sealed
    + 'static {
Show 14 methods // Provided methods fn accel_key(&self) -> u32 { ... } fn set_accel_key(&self, accel_key: u32) { ... } fn accel_mode(&self) -> CellRendererAccelMode { ... } fn set_accel_mode(&self, accel_mode: CellRendererAccelMode) { ... } fn accel_mods(&self) -> ModifierType { ... } fn set_accel_mods(&self, accel_mods: ModifierType) { ... } fn keycode(&self) -> u32 { ... } fn set_keycode(&self, keycode: u32) { ... } fn connect_accel_cleared<F: Fn(&Self, TreePath) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accel_edited<F: Fn(&Self, TreePath, u32, ModifierType, u32) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accel_key_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accel_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accel_mods_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_keycode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all CellRendererAccel methods.

Implementors

CellRendererAccel

Provided Methods

fn accel_key(&self) -> u32

The keyval of the accelerator.

fn set_accel_key(&self, accel_key: u32)

The keyval of the accelerator.

fn accel_mode(&self) -> CellRendererAccelMode

Determines if the edited accelerators are GTK+ accelerators. If they are, consumed modifiers are suppressed, only accelerators accepted by GTK+ are allowed, and the accelerators are rendered in the same way as they are in menus.

fn set_accel_mode(&self, accel_mode: CellRendererAccelMode)

Determines if the edited accelerators are GTK+ accelerators. If they are, consumed modifiers are suppressed, only accelerators accepted by GTK+ are allowed, and the accelerators are rendered in the same way as they are in menus.

fn accel_mods(&self) -> ModifierType

The modifier mask of the accelerator.

fn set_accel_mods(&self, accel_mods: ModifierType)

The modifier mask of the accelerator.

fn keycode(&self) -> u32

The hardware keycode of the accelerator. Note that the hardware keycode is only relevant if the key does not have a keyval. Normally, the keyboard configuration should assign keyvals to all keys.

fn set_keycode(&self, keycode: u32)

The hardware keycode of the accelerator. Note that the hardware keycode is only relevant if the key does not have a keyval. Normally, the keyboard configuration should assign keyvals to all keys.

fn connect_accel_cleared<F: Fn(&Self, TreePath) + 'static>( &self, f: F, ) -> SignalHandlerId

Gets emitted when the user has removed the accelerator.

path_string

the path identifying the row of the edited cell

fn connect_accel_edited<F: Fn(&Self, TreePath, u32, ModifierType, u32) + 'static>( &self, f: F, ) -> SignalHandlerId

Gets emitted when the user has selected a new accelerator.

path_string

the path identifying the row of the edited cell

accel_key

the new accelerator keyval

accel_mods

the new acclerator modifier mask

hardware_keycode

the keycode of the new accelerator

fn connect_accel_key_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_accel_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_accel_mods_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_keycode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors