pub trait CellRendererPixbufExt:
IsA<CellRendererPixbuf>
+ Sealed
+ 'static {
Show 22 methods
// Provided methods
fn gicon(&self) -> Option<Icon> { ... }
fn set_gicon<P: IsA<Icon>>(&self, gicon: Option<&P>) { ... }
fn icon_name(&self) -> Option<GString> { ... }
fn set_icon_name(&self, icon_name: Option<&str>) { ... }
fn pixbuf(&self) -> Option<Pixbuf> { ... }
fn set_pixbuf(&self, pixbuf: Option<&Pixbuf>) { ... }
fn pixbuf_expander_closed(&self) -> Option<Pixbuf> { ... }
fn set_pixbuf_expander_closed(
&self,
pixbuf_expander_closed: Option<&Pixbuf>,
) { ... }
fn pixbuf_expander_open(&self) -> Option<Pixbuf> { ... }
fn set_pixbuf_expander_open(&self, pixbuf_expander_open: Option<&Pixbuf>) { ... }
fn stock_detail(&self) -> Option<GString> { ... }
fn set_stock_detail(&self, stock_detail: Option<&str>) { ... }
fn surface(&self) -> Option<Surface> { ... }
fn set_surface(&self, surface: Option<&Surface>) { ... }
fn connect_gicon_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_icon_name_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_pixbuf_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_pixbuf_expander_closed_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_pixbuf_expander_open_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_stock_detail_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_stock_size_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_surface_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn gicon(&self) -> Option<Icon>
fn gicon(&self) -> Option<Icon>
The GIcon representing the icon to display. If the icon theme is changed, the image will be updated automatically.
Sourcefn set_gicon<P: IsA<Icon>>(&self, gicon: Option<&P>)
fn set_gicon<P: IsA<Icon>>(&self, gicon: Option<&P>)
The GIcon representing the icon to display. If the icon theme is changed, the image will be updated automatically.
Sourcefn icon_name(&self) -> Option<GString>
fn icon_name(&self) -> Option<GString>
The name of the themed icon to display. This property only has an effect if not overridden by “stock_id” or “pixbuf” properties.
Sourcefn set_icon_name(&self, icon_name: Option<&str>)
fn set_icon_name(&self, icon_name: Option<&str>)
The name of the themed icon to display. This property only has an effect if not overridden by “stock_id” or “pixbuf” properties.
fn pixbuf(&self) -> Option<Pixbuf>
fn set_pixbuf(&self, pixbuf: Option<&Pixbuf>)
fn pixbuf_expander_closed(&self) -> Option<Pixbuf>
fn set_pixbuf_expander_closed(&self, pixbuf_expander_closed: Option<&Pixbuf>)
fn pixbuf_expander_open(&self) -> Option<Pixbuf>
fn set_pixbuf_expander_open(&self, pixbuf_expander_open: Option<&Pixbuf>)
fn stock_detail(&self) -> Option<GString>
fn set_stock_detail(&self, stock_detail: Option<&str>)
fn surface(&self) -> Option<Surface>
fn set_surface(&self, surface: Option<&Surface>)
fn connect_gicon_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_icon_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_pixbuf_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_pixbuf_expander_closed_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_pixbuf_expander_open_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_stock_detail_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_stock_size_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_surface_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".