pub trait CellRendererPixbufExtManual:
IsA<CellRendererPixbuf>
+ IsA<Object>
+ 'static {
// Provided methods
fn stock_size(&self) -> IconSize { ... }
fn set_stock_size(&self, stock_size: IconSize) { ... }
}Provided Methods
Sourcefn stock_size(&self) -> IconSize
fn stock_size(&self) -> IconSize
The IconSize value that specifies the size of the rendered icon.
Sourcefn set_stock_size(&self, stock_size: IconSize)
fn set_stock_size(&self, stock_size: IconSize)
The IconSize value that specifies the size of the rendered icon.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".