CellRendererProgressExt

Trait CellRendererProgressExt 

pub trait CellRendererProgressExt:
    IsA<CellRendererProgress>
    + Sealed
    + 'static {
Show 18 methods // Provided methods fn is_inverted(&self) -> bool { ... } fn set_inverted(&self, inverted: bool) { ... } fn pulse(&self) -> i32 { ... } fn set_pulse(&self, pulse: i32) { ... } fn text(&self) -> Option<GString> { ... } fn set_text(&self, text: Option<&str>) { ... } fn text_xalign(&self) -> f32 { ... } fn set_text_xalign(&self, text_xalign: f32) { ... } fn text_yalign(&self) -> f32 { ... } fn set_text_yalign(&self, text_yalign: f32) { ... } fn value(&self) -> i32 { ... } fn set_value(&self, value: i32) { ... } fn connect_inverted_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_pulse_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_text_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_text_xalign_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_text_yalign_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_value_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all CellRendererProgress methods.

Implementors

CellRendererProgress

Provided Methods

fn is_inverted(&self) -> bool

fn set_inverted(&self, inverted: bool)

fn pulse(&self) -> i32

Setting this to a non-negative value causes the cell renderer to enter “activity mode”, where a block bounces back and forth to indicate that some progress is made, without specifying exactly how much.

Each increment of the property causes the block to move by a little bit.

To indicate that the activity has not started yet, set the property to zero. To indicate completion, set the property to G_MAXINT.

fn set_pulse(&self, pulse: i32)

Setting this to a non-negative value causes the cell renderer to enter “activity mode”, where a block bounces back and forth to indicate that some progress is made, without specifying exactly how much.

Each increment of the property causes the block to move by a little bit.

To indicate that the activity has not started yet, set the property to zero. To indicate completion, set the property to G_MAXINT.

fn text(&self) -> Option<GString>

The “text” property determines the label which will be drawn over the progress bar. Setting this property to None causes the default label to be displayed. Setting this property to an empty string causes no label to be displayed.

fn set_text(&self, text: Option<&str>)

The “text” property determines the label which will be drawn over the progress bar. Setting this property to None causes the default label to be displayed. Setting this property to an empty string causes no label to be displayed.

fn text_xalign(&self) -> f32

The “text-xalign” property controls the horizontal alignment of the text in the progress bar. Valid values range from 0 (left) to 1 (right). Reserved for RTL layouts.

fn set_text_xalign(&self, text_xalign: f32)

The “text-xalign” property controls the horizontal alignment of the text in the progress bar. Valid values range from 0 (left) to 1 (right). Reserved for RTL layouts.

fn text_yalign(&self) -> f32

The “text-yalign” property controls the vertical alignment of the text in the progress bar. Valid values range from 0 (top) to 1 (bottom).

fn set_text_yalign(&self, text_yalign: f32)

The “text-yalign” property controls the vertical alignment of the text in the progress bar. Valid values range from 0 (top) to 1 (bottom).

fn value(&self) -> i32

The “value” property determines the percentage to which the progress bar will be “filled in”.

fn set_value(&self, value: i32)

The “value” property determines the percentage to which the progress bar will be “filled in”.

fn connect_inverted_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_pulse_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_text_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_text_xalign_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_text_yalign_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_value_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors