CellRendererSpinExt

Trait CellRendererSpinExt 

pub trait CellRendererSpinExt:
    IsA<CellRendererSpin>
    + Sealed
    + 'static {
    // Provided methods
    fn adjustment(&self) -> Option<Adjustment> { ... }
    fn set_adjustment<P: IsA<Adjustment>>(&self, adjustment: Option<&P>) { ... }
    fn climb_rate(&self) -> f64 { ... }
    fn set_climb_rate(&self, climb_rate: f64) { ... }
    fn digits(&self) -> u32 { ... }
    fn set_digits(&self, digits: u32) { ... }
    fn connect_adjustment_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
    fn connect_climb_rate_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
    fn connect_digits_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
}
Trait containing all CellRendererSpin methods.

Implementors

CellRendererSpin

Provided Methods

fn adjustment(&self) -> Option<Adjustment>

The adjustment that holds the value of the spinbutton. This must be non-None for the cell renderer to be editable.

fn set_adjustment<P: IsA<Adjustment>>(&self, adjustment: Option<&P>)

The adjustment that holds the value of the spinbutton. This must be non-None for the cell renderer to be editable.

fn climb_rate(&self) -> f64

The acceleration rate when you hold down a button.

fn set_climb_rate(&self, climb_rate: f64)

The acceleration rate when you hold down a button.

fn digits(&self) -> u32

The number of decimal places to display.

fn set_digits(&self, digits: u32)

The number of decimal places to display.

fn connect_adjustment_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_climb_rate_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_digits_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors