CellRendererSpinnerExt

Trait CellRendererSpinnerExt 

pub trait CellRendererSpinnerExt: IsA<CellRendererSpinner> + 'static {
    // Provided methods
    fn is_active(&self) -> bool { ... }
    fn set_active(&self, active: bool) { ... }
    fn pulse(&self) -> u32 { ... }
    fn set_pulse(&self, pulse: u32) { ... }
    fn size(&self) -> IconSize { ... }
    fn set_size(&self, size: IconSize) { ... }
    fn connect_active_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
    fn connect_pulse_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
    fn connect_size_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
}
Trait containing all CellRendererSpinner methods.

Implementors

CellRendererSpinner

Provided Methods

fn is_active(&self) -> bool

fn set_active(&self, active: bool)

fn pulse(&self) -> u32

Pulse of the spinner. Increment this value to draw the next frame of the spinner animation. Usually, you would update this value in a timeout.

By default, the Spinner widget draws one full cycle of the animation, consisting of 12 frames, in 750 milliseconds.

fn set_pulse(&self, pulse: u32)

Pulse of the spinner. Increment this value to draw the next frame of the spinner animation. Usually, you would update this value in a timeout.

By default, the Spinner widget draws one full cycle of the animation, consisting of 12 frames, in 750 milliseconds.

fn size(&self) -> IconSize

The IconSize value that specifies the size of the rendered spinner.

fn set_size(&self, size: IconSize)

The IconSize value that specifies the size of the rendered spinner.

fn connect_active_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_pulse_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_size_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors