pub trait CellRendererToggleExt: IsA<CellRendererToggle> + 'static {
Show 16 methods
// Provided methods
fn is_activatable(&self) -> bool { ... }
fn is_active(&self) -> bool { ... }
fn is_radio(&self) -> bool { ... }
fn set_activatable(&self, setting: bool) { ... }
fn set_active(&self, setting: bool) { ... }
fn set_radio(&self, radio: bool) { ... }
fn is_inconsistent(&self) -> bool { ... }
fn set_inconsistent(&self, inconsistent: bool) { ... }
fn indicator_size(&self) -> i32 { ... }
fn set_indicator_size(&self, indicator_size: i32) { ... }
fn connect_toggled<F: Fn(&Self, TreePath) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_activatable_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_active_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_inconsistent_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_indicator_size_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_radio_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn is_activatable(&self) -> bool
fn is_activatable(&self) -> bool
Returns whether the cell renderer is activatable. See
set_activatable().
Returns
true if the cell renderer is activatable.
Sourcefn is_active(&self) -> bool
fn is_active(&self) -> bool
Returns whether the cell renderer is active. See
set_active().
Returns
true if the cell renderer is active.
Sourcefn set_activatable(&self, setting: bool)
fn set_activatable(&self, setting: bool)
Sourcefn set_active(&self, setting: bool)
fn set_active(&self, setting: bool)
Sourcefn set_radio(&self, radio: bool)
fn set_radio(&self, radio: bool)
If radio is true, the cell renderer renders a radio toggle
(i.e. a toggle in a group of mutually-exclusive toggles).
If false, it renders a check toggle (a standalone boolean option).
This can be set globally for the cell renderer, or changed just
before rendering each cell in the model (for TreeView, you set
up a per-row setting using TreeViewColumn to associate model
columns with cell renderer properties).
radio
true to make the toggle look like a radio button
fn is_inconsistent(&self) -> bool
fn set_inconsistent(&self, inconsistent: bool)
fn indicator_size(&self) -> i32
fn set_indicator_size(&self, indicator_size: i32)
Sourcefn connect_toggled<F: Fn(&Self, TreePath) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_toggled<F: Fn(&Self, TreePath) + 'static>( &self, f: F, ) -> SignalHandlerId
The ::toggled signal is emitted when the cell is toggled.
It is the responsibility of the application to update the model
with the correct value to store at path. Often this is simply the
opposite of the value currently stored at path.
path
string representation of TreePath describing the
event location
fn connect_activatable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_active_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_inconsistent_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_indicator_size_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_radio_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".