pub trait CellViewExt:
IsA<CellView>
+ Sealed
+ 'static {
Show 21 methods
// Provided methods
fn displayed_row(&self) -> Option<TreePath> { ... }
fn draws_sensitive(&self) -> bool { ... }
fn fits_model(&self) -> bool { ... }
fn model(&self) -> Option<TreeModel> { ... }
fn set_background_rgba(&self, rgba: &RGBA) { ... }
fn set_displayed_row(&self, path: &mut TreePath) { ... }
fn set_draw_sensitive(&self, draw_sensitive: bool) { ... }
fn set_fit_model(&self, fit_model: bool) { ... }
fn set_model(&self, model: Option<&impl IsA<TreeModel>>) { ... }
fn set_background(&self, background: Option<&str>) { ... }
fn background_rgba(&self) -> Option<RGBA> { ... }
fn is_background_set(&self) -> bool { ... }
fn set_background_set(&self, background_set: bool) { ... }
fn cell_area(&self) -> Option<CellArea> { ... }
fn cell_area_context(&self) -> Option<CellAreaContext> { ... }
fn connect_background_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_background_rgba_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_background_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_draw_sensitive_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_fit_model_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_model_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Provided Methods
Sourcefn displayed_row(&self) -> Option<TreePath>
fn displayed_row(&self) -> Option<TreePath>
Sourcefn draws_sensitive(&self) -> bool
fn draws_sensitive(&self) -> bool
Gets whether self is configured to draw all of its
cells in a sensitive state.
Returns
whether self draws all of its
cells in a sensitive state
Sourcefn fits_model(&self) -> bool
fn fits_model(&self) -> bool
Sourcefn set_background_rgba(&self, rgba: &RGBA)
fn set_background_rgba(&self, rgba: &RGBA)
Sourcefn set_displayed_row(&self, path: &mut TreePath)
fn set_displayed_row(&self, path: &mut TreePath)
Sets the row of the model that is currently displayed
by the CellView. If the path is unset, then the
contents of the cellview “stick” at their last value;
this is not normally a desired result, but may be
a needed intermediate state if say, the model for
the CellView becomes temporarily empty.
path
Sourcefn set_draw_sensitive(&self, draw_sensitive: bool)
fn set_draw_sensitive(&self, draw_sensitive: bool)
Sourcefn set_fit_model(&self, fit_model: bool)
fn set_fit_model(&self, fit_model: bool)
fn set_background(&self, background: Option<&str>)
Sourcefn background_rgba(&self) -> Option<RGBA>
fn background_rgba(&self) -> Option<RGBA>
The background color as a gdk::RGBA
fn is_background_set(&self) -> bool
fn set_background_set(&self, background_set: bool)
Sourcefn cell_area(&self) -> Option<CellArea>
fn cell_area(&self) -> Option<CellArea>
The CellArea rendering cells
If no area is specified when creating the cell view with CellView::with_context()
a horizontally oriented CellAreaBox will be used.
since 3.0
Sourcefn cell_area_context(&self) -> Option<CellAreaContext>
fn cell_area_context(&self) -> Option<CellAreaContext>
The CellAreaContext used to compute the geometry of the cell view.
A group of cell views can be assigned the same context in order to ensure the sizes and cell alignments match across all the views with the same context.
ComboBox menus uses this to assign the same context to all cell views
in the menu items for a single menu (each submenu creates its own
context since the size of each submenu does not depend on parent
or sibling menus).
since 3.0
fn connect_background_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_background_rgba_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_background_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_draw_sensitive_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_fit_model_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_model_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".