pub trait CheckMenuItemExt:
IsA<CheckMenuItem>
+ Sealed
+ 'static {
// Provided methods
fn is_active(&self) -> bool { ... }
fn draws_as_radio(&self) -> bool { ... }
fn is_inconsistent(&self) -> bool { ... }
fn set_active(&self, is_active: bool) { ... }
fn set_draw_as_radio(&self, draw_as_radio: bool) { ... }
fn set_inconsistent(&self, setting: bool) { ... }
fn toggled(&self) { ... }
fn connect_toggled<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn connect_active_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_draw_as_radio_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_inconsistent_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn draws_as_radio(&self) -> bool
fn draws_as_radio(&self) -> bool
Sourcefn is_inconsistent(&self) -> bool
fn is_inconsistent(&self) -> bool
Sourcefn set_active(&self, is_active: bool)
fn set_active(&self, is_active: bool)
Sets the active state of the menu item’s check box.
is_active
boolean value indicating whether the check box is active.
Sourcefn set_draw_as_radio(&self, draw_as_radio: bool)
fn set_draw_as_radio(&self, draw_as_radio: bool)
Sets whether self is drawn like a RadioMenuItem
draw_as_radio
whether self is drawn like a RadioMenuItem
Sourcefn set_inconsistent(&self, setting: bool)
fn set_inconsistent(&self, setting: bool)
If the user has selected a range of elements (such as some text or
spreadsheet cells) that are affected by a boolean setting, and the
current values in that range are inconsistent, you may want to
display the check in an “in between” state. This function turns on
“in between” display. Normally you would turn off the inconsistent
state again if the user explicitly selects a setting. This has to be
done manually, set_inconsistent() only affects
visual appearance, it doesn’t affect the semantics of the widget.
setting
true to display an “inconsistent” third state check
Sourcefn connect_toggled<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_toggled<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
This signal is emitted when the state of the check box is changed.
A signal handler can use is_active()
to discover the new state.
fn connect_active_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_draw_as_radio_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_inconsistent_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".