ColorButtonExt

Trait ColorButtonExt 

pub trait ColorButtonExt:
    IsA<ColorButton>
    + Sealed
    + 'static {
    // Provided methods
    fn title(&self) -> Option<GString> { ... }
    fn set_title(&self, title: &str) { ... }
    fn alpha(&self) -> u32 { ... }
    fn set_alpha(&self, alpha: u32) { ... }
    fn shows_editor(&self) -> bool { ... }
    fn set_show_editor(&self, show_editor: bool) { ... }
    fn connect_color_set<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
    fn connect_alpha_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
    fn connect_show_editor_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
    fn connect_title_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
}
Trait containing all ColorButton methods.

Implementors

ColorButton

Provided Methods

fn title(&self) -> Option<GString>

Gets the title of the color selection dialog.

Returns

An internal string, do not free the return value

fn set_title(&self, title: &str)

Sets the title for the color selection dialog.

title

String containing new window title

fn alpha(&self) -> u32

The selected opacity value (0 fully transparent, 65535 fully opaque).

fn set_alpha(&self, alpha: u32)

The selected opacity value (0 fully transparent, 65535 fully opaque).

fn shows_editor(&self) -> bool

Set this property to true to skip the palette in the dialog and go directly to the color editor.

This property should be used in cases where the palette in the editor would be redundant, such as when the color button is already part of a palette.

fn set_show_editor(&self, show_editor: bool)

Set this property to true to skip the palette in the dialog and go directly to the color editor.

This property should be used in cases where the palette in the editor would be redundant, such as when the color button is already part of a palette.

fn connect_color_set<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The ::color-set signal is emitted when the user selects a color. When handling this signal, use gtk_color_button_get_rgba() to find out which color was just selected.

Note that this signal is only emitted when the user changes the color. If you need to react to programmatic color changes as well, use the notify::color signal.

fn connect_alpha_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_show_editor_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_title_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors