pub trait ColorChooserExt: IsA<ColorChooser> + 'static {
// Provided methods
fn rgba(&self) -> RGBA { ... }
fn uses_alpha(&self) -> bool { ... }
fn set_rgba(&self, color: &RGBA) { ... }
fn set_use_alpha(&self, use_alpha: bool) { ... }
fn connect_color_activated<F: Fn(&Self, &RGBA) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_rgba_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_use_alpha_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Trait containing all ColorChooser methods.
Implementors
ColorButton, ColorChooserDialog, ColorChooserWidget, ColorChooser
Provided Methods
Sourcefn uses_alpha(&self) -> bool
fn uses_alpha(&self) -> bool
Sourcefn set_use_alpha(&self, use_alpha: bool)
fn set_use_alpha(&self, use_alpha: bool)
Sourcefn connect_color_activated<F: Fn(&Self, &RGBA) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_color_activated<F: Fn(&Self, &RGBA) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when a color is activated from the color chooser. This usually happens when the user clicks a color swatch, or a color is selected and the user presses one of the keys Space, Shift+Space, Return or Enter.
color
the color
fn connect_rgba_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_use_alpha_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".