ComboBoxExtManual

Trait ComboBoxExtManual 

pub trait ComboBoxExtManual:
    IsA<ComboBox>
    + Sealed
    + 'static {
    // Provided methods
    fn set_active(&self, index_: Option<u32>) { ... }
    fn active(&self) -> Option<u32> { ... }
}

Provided Methods

fn set_active(&self, index_: Option<u32>)

Sets the active item of self to be the item at index.

index_

An index in the model passed during construction, or -1 to have no active item

fn active(&self) -> Option<u32>

Returns the index of the currently active item, or -1 if there’s no active item. If the model is a non-flat treemodel, and the active item is not an immediate child of the root of the tree, this function returns gtk_tree_path_get_indices (path)[0], where path is the TreePath of the active item.

Returns

An integer which is the index of the currently active item, or -1 if there’s no active item.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors