pub trait ComboBoxTextExt: IsA<ComboBoxText> + 'static {
// Provided methods
fn append(&self, id: Option<&str>, text: &str) { ... }
fn append_text(&self, text: &str) { ... }
fn active_text(&self) -> Option<GString> { ... }
fn insert(&self, position: i32, id: Option<&str>, text: &str) { ... }
fn insert_text(&self, position: i32, text: &str) { ... }
fn prepend(&self, id: Option<&str>, text: &str) { ... }
fn prepend_text(&self, text: &str) { ... }
fn remove(&self, position: i32) { ... }
fn remove_all(&self) { ... }
}Expand description
Provided Methods
Sourcefn append_text(&self, text: &str)
fn append_text(&self, text: &str)
Appends text to the list of strings stored in self.
This is the same as calling insert_text() with a
position of -1.
text
A string
Sourcefn active_text(&self) -> Option<GString>
fn active_text(&self) -> Option<GString>
Sourcefn insert_text(&self, position: i32, text: &str)
fn insert_text(&self, position: i32, text: &str)
Sourcefn prepend_text(&self, text: &str)
fn prepend_text(&self, text: &str)
Prepends text to the list of strings stored in self.
This is the same as calling insert_text() with a
position of 0.
text
A string
Sourcefn remove_all(&self)
fn remove_all(&self)
Removes all the text entries from the combo box.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".