pub trait EntryExtManual:
IsA<Entry>
+ Sealed
+ 'static {
// Provided method
fn invisible_char(&self) -> Option<char> { ... }
}Provided Methods
Sourcefn invisible_char(&self) -> Option<char>
fn invisible_char(&self) -> Option<char>
Retrieves the character displayed in place of the real characters
for entries with visibility set to false. See EntryExt::set_invisible_char().
Returns
the current invisible char, or 0, if the entry does not show invisible text at all.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".