FileChooserButtonExt

Trait FileChooserButtonExt 

pub trait FileChooserButtonExt:
    IsA<FileChooserButton>
    + Sealed
    + 'static {
    // Provided methods
    fn title(&self) -> Option<GString> { ... }
    fn width_chars(&self) -> i32 { ... }
    fn set_title(&self, title: &str) { ... }
    fn set_width_chars(&self, n_chars: i32) { ... }
    fn connect_file_set<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
    fn connect_title_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
    fn connect_width_chars_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
}
Trait containing all FileChooserButton methods.

Implementors

FileChooserButton

Provided Methods

fn title(&self) -> Option<GString>

Retrieves the title of the browse dialog used by self. The returned value should not be modified or freed.

Returns

a pointer to the browse dialog’s title.

fn width_chars(&self) -> i32

Retrieves the width in characters of the self widget’s entry and/or label.

Returns

an integer width (in characters) that the button will use to size itself.

fn set_title(&self, title: &str)

Modifies the title of the browse dialog used by self.

title

the new browse dialog title.

fn set_width_chars(&self, n_chars: i32)

Sets the width (in characters) that self will use to n_chars.

n_chars

the new width, in characters.

fn connect_file_set<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The ::file-set signal is emitted when the user selects a file.

Note that this signal is only emitted when the user changes the file.

fn connect_title_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_width_chars_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors