pub trait FileChooserExtManual:
IsA<FileChooser>
+ Sealed
+ 'static {
// Provided method
fn add_choice(&self, id: &str, label: &str, options: &[(&str, &str)]) { ... }
}Provided Methods
Sourcefn add_choice(&self, id: &str, label: &str, options: &[(&str, &str)])
Available on crate feature v3_22 only.
fn add_choice(&self, id: &str, label: &str, options: &[(&str, &str)])
v3_22 only.Adds a ‘choice’ to the file chooser. This is typically implemented
as a combobox or, for boolean choices, as a checkbutton. You can select
a value using FileChooserExt::set_choice() before the dialog is shown,
and you can obtain the user-selected value in the ::response signal handler
using FileChooserExt::choice().
Compare FileChooserExt::set_extra_widget().
id
id for the added choice
label
user-visible label for the added choice
options
ids for the options of the choice, or None for a boolean choice
option_labels
user-visible labels for the options, must be the same length as options
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".