FileChooserWidgetExt

Trait FileChooserWidgetExt 

pub trait FileChooserWidgetExt:
    IsA<FileChooserWidget>
    + Sealed
    + 'static {
Show 29 methods // Provided methods fn is_search_mode(&self) -> bool { ... } fn set_search_mode(&self, search_mode: bool) { ... } fn subtitle(&self) -> Option<GString> { ... } fn connect_desktop_folder<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn emit_desktop_folder(&self) { ... } fn connect_down_folder<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn emit_down_folder(&self) { ... } fn connect_home_folder<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn emit_home_folder(&self) { ... } fn connect_location_popup<F: Fn(&Self, &str) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn emit_location_popup(&self, path: &str) { ... } fn connect_location_popup_on_paste<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn emit_location_popup_on_paste(&self) { ... } fn connect_location_toggle_popup<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn emit_location_toggle_popup(&self) { ... } fn connect_places_shortcut<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn emit_places_shortcut(&self) { ... } fn connect_quick_bookmark<F: Fn(&Self, i32) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn emit_quick_bookmark(&self, bookmark_index: i32) { ... } fn connect_recent_shortcut<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn emit_recent_shortcut(&self) { ... } fn connect_search_shortcut<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn emit_search_shortcut(&self) { ... } fn connect_show_hidden<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn emit_show_hidden(&self) { ... } fn connect_up_folder<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... } fn emit_up_folder(&self) { ... } fn connect_search_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_subtitle_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all FileChooserWidget methods.

Implementors

FileChooserWidget

Provided Methods

fn is_search_mode(&self) -> bool

fn set_search_mode(&self, search_mode: bool)

fn subtitle(&self) -> Option<GString>

fn connect_desktop_folder<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

The ::desktop-folder signal is a [keybinding signal][GtkBindingSignal] which gets emitted when the user asks for it.

This is used to make the file chooser show the user’s Desktop folder in the file list.

The default binding for this signal is Alt + D.

fn emit_desktop_folder(&self)

fn connect_down_folder<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The ::down-folder signal is a [keybinding signal][GtkBindingSignal] which gets emitted when the user asks for it.

This is used to make the file chooser go to a child of the current folder in the file hierarchy. The subfolder that will be used is displayed in the path bar widget of the file chooser. For example, if the path bar is showing “/foo/bar/baz”, with bar currently displayed, then this will cause the file chooser to switch to the “baz” subfolder.

The default binding for this signal is Alt + Down.

fn emit_down_folder(&self)

fn connect_home_folder<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The ::home-folder signal is a [keybinding signal][GtkBindingSignal] which gets emitted when the user asks for it.

This is used to make the file chooser show the user’s home folder in the file list.

The default binding for this signal is Alt + Home.

fn emit_home_folder(&self)

fn connect_location_popup<F: Fn(&Self, &str) + 'static>( &self, f: F, ) -> SignalHandlerId

The ::location-popup signal is a [keybinding signal][GtkBindingSignal] which gets emitted when the user asks for it.

This is used to make the file chooser show a “Location” prompt which the user can use to manually type the name of the file he wishes to select.

The default bindings for this signal are Control + L with a path string of “” (the empty string). It is also bound to / with a path string of “/” (a slash): this lets you type / and immediately type a path name. On Unix systems, this is bound to ~ (tilde) with a path string of “~” itself for access to home directories.

path

a string that gets put in the text entry for the file name

fn emit_location_popup(&self, path: &str)

fn connect_location_popup_on_paste<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

The ::location-popup-on-paste signal is a [keybinding signal][GtkBindingSignal] which gets emitted when the user asks for it.

This is used to make the file chooser show a “Location” prompt when the user pastes into a FileChooserWidget.

The default binding for this signal is Control + V.

fn emit_location_popup_on_paste(&self)

fn connect_location_toggle_popup<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

The ::location-toggle-popup signal is a [keybinding signal][GtkBindingSignal] which gets emitted when the user asks for it.

This is used to toggle the visibility of a “Location” prompt which the user can use to manually type the name of the file he wishes to select.

The default binding for this signal is Control + L.

fn emit_location_toggle_popup(&self)

fn connect_places_shortcut<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

The ::places-shortcut signal is a [keybinding signal][GtkBindingSignal] which gets emitted when the user asks for it.

This is used to move the focus to the places sidebar.

The default binding for this signal is Alt + P.

fn emit_places_shortcut(&self)

fn connect_quick_bookmark<F: Fn(&Self, i32) + 'static>( &self, f: F, ) -> SignalHandlerId

The ::quick-bookmark signal is a [keybinding signal][GtkBindingSignal] which gets emitted when the user asks for it.

This is used to make the file chooser switch to the bookmark specified in the bookmark_index parameter. For example, if you have three bookmarks, you can pass 0, 1, 2 to this signal to switch to each of them, respectively.

The default binding for this signal is Alt + 1, Alt + 2, etc. until Alt + 0. Note that in the default binding, that Alt + 1 is actually defined to switch to the bookmark at index 0, and so on successively; Alt + 0 is defined to switch to the bookmark at index 10.

bookmark_index

the number of the bookmark to switch to

fn emit_quick_bookmark(&self, bookmark_index: i32)

fn connect_recent_shortcut<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

The ::recent-shortcut signal is a [keybinding signal][GtkBindingSignal] which gets emitted when the user asks for it.

This is used to make the file chooser show the Recent location.

The default binding for this signal is Alt + R.

fn emit_recent_shortcut(&self)

fn connect_search_shortcut<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

The ::search-shortcut signal is a [keybinding signal][GtkBindingSignal] which gets emitted when the user asks for it.

This is used to make the file chooser show the search entry.

The default binding for this signal is Alt + S.

fn emit_search_shortcut(&self)

fn connect_show_hidden<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The ::show-hidden signal is a [keybinding signal][GtkBindingSignal] which gets emitted when the user asks for it.

This is used to make the file chooser display hidden files.

The default binding for this signal is Control + H.

fn emit_show_hidden(&self)

fn connect_up_folder<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The ::up-folder signal is a [keybinding signal][GtkBindingSignal] which gets emitted when the user asks for it.

This is used to make the file chooser go to the parent of the current folder in the file hierarchy.

The default binding for this signal is Alt + Up.

fn emit_up_folder(&self)

fn connect_search_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_subtitle_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors