Trait FixedExt
Source pub trait FixedExt: IsA<Fixed> + 'static {
// Provided methods
fn move_(&self, widget: &impl IsA<Widget>, x: i32, y: i32) { ... }
fn put(&self, widget: &impl IsA<Widget>, x: i32, y: i32) { ... }
}
Trait containing all Fixed methods.
Implementors
Fixed
Moves a child of a Fixed container to the given position.
the child widget.
the horizontal position to move the widget to.
the vertical position to move the widget to.
Adds a widget to a Fixed container at the given position.
the widget to add.
the horizontal position to place the widget at.
the vertical position to place the widget at.
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".