pub trait FontButtonExt: IsA<FontButton> + 'static {
Show 16 methods
// Provided methods
fn shows_size(&self) -> bool { ... }
fn shows_style(&self) -> bool { ... }
fn title(&self) -> Option<GString> { ... }
fn uses_font(&self) -> bool { ... }
fn uses_size(&self) -> bool { ... }
fn set_show_size(&self, show_size: bool) { ... }
fn set_show_style(&self, show_style: bool) { ... }
fn set_title(&self, title: &str) { ... }
fn set_use_font(&self, use_font: bool) { ... }
fn set_use_size(&self, use_size: bool) { ... }
fn connect_font_set<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn connect_show_size_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_show_style_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_title_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_use_font_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_use_size_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn shows_size(&self) -> bool
fn shows_size(&self) -> bool
Returns whether the font size will be shown in the label.
Returns
whether the font size will be shown in the label.
Sourcefn shows_style(&self) -> bool
fn shows_style(&self) -> bool
Returns whether the name of the font style will be shown in the label.
Returns
whether the font style will be shown in the label.
Sourcefn title(&self) -> Option<GString>
fn title(&self) -> Option<GString>
Retrieves the title of the font chooser dialog.
Returns
an internal copy of the title string which must not be freed.
Sourcefn uses_font(&self) -> bool
fn uses_font(&self) -> bool
Returns whether the selected font is used in the label.
Returns
whether the selected font is used in the label.
Sourcefn uses_size(&self) -> bool
fn uses_size(&self) -> bool
Returns whether the selected size is used in the label.
Returns
whether the selected size is used in the label.
Sourcefn set_show_size(&self, show_size: bool)
fn set_show_size(&self, show_size: bool)
Sourcefn set_show_style(&self, show_style: bool)
fn set_show_style(&self, show_style: bool)
Sourcefn set_title(&self, title: &str)
fn set_title(&self, title: &str)
Sets the title for the font chooser dialog.
title
a string containing the font chooser dialog title
Sourcefn set_use_font(&self, use_font: bool)
fn set_use_font(&self, use_font: bool)
Sourcefn set_use_size(&self, use_size: bool)
fn set_use_size(&self, use_size: bool)
Sourcefn connect_font_set<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_font_set<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
The ::font-set signal is emitted when the user selects a font.
When handling this signal, use FontChooserExt::font()
to find out which font was just selected.
Note that this signal is only emitted when the user changes the font. If you need to react to programmatic font changes as well, use the notify::font signal.
fn connect_show_size_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_show_style_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_title_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_use_font_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_use_size_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".