pub trait GtkMountOperationExt: IsA<MountOperation> + 'static {
// Provided methods
fn parent(&self) -> Option<Window> { ... }
fn screen(&self) -> Option<Screen> { ... }
fn is_showing(&self) -> bool { ... }
fn set_parent(&self, parent: Option<&impl IsA<Window>>) { ... }
fn set_screen(&self, screen: &Screen) { ... }
fn connect_is_showing_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_parent_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_screen_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn parent(&self) -> Option<Window>
fn parent(&self) -> Option<Window>
Gets the transient parent used by the MountOperation
Returns
the transient parent for windows shown by self
Sourcefn screen(&self) -> Option<Screen>
fn screen(&self) -> Option<Screen>
Gets the screen on which windows of the MountOperation
will be shown.
Returns
the screen on which windows of self are shown
Sourcefn is_showing(&self) -> bool
fn is_showing(&self) -> bool
Returns whether the MountOperation is currently displaying
a window.
Returns
true if self is currently displaying a window
Sourcefn set_parent(&self, parent: Option<&impl IsA<Window>>)
fn set_parent(&self, parent: Option<&impl IsA<Window>>)
Sets the transient parent for windows shown by the
MountOperation.
parent
transient parent of the window, or None
Sourcefn set_screen(&self, screen: &Screen)
fn set_screen(&self, screen: &Screen)
fn connect_is_showing_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_parent_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_screen_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".