GtkSettingsExt

Trait GtkSettingsExt 

pub trait GtkSettingsExt:
    IsA<Settings>
    + Sealed
    + 'static {
Show 154 methods // Provided methods fn reset_property(&self, name: &str) { ... } fn is_gtk_alternative_button_order(&self) -> bool { ... } fn set_gtk_alternative_button_order( &self, gtk_alternative_button_order: bool, ) { ... } fn is_gtk_alternative_sort_arrows(&self) -> bool { ... } fn set_gtk_alternative_sort_arrows(&self, gtk_alternative_sort_arrows: bool) { ... } fn is_gtk_application_prefer_dark_theme(&self) -> bool { ... } fn set_gtk_application_prefer_dark_theme( &self, gtk_application_prefer_dark_theme: bool, ) { ... } fn gtk_cursor_aspect_ratio(&self) -> f32 { ... } fn set_gtk_cursor_aspect_ratio(&self, gtk_cursor_aspect_ratio: f32) { ... } fn is_gtk_cursor_blink(&self) -> bool { ... } fn set_gtk_cursor_blink(&self, gtk_cursor_blink: bool) { ... } fn gtk_cursor_blink_time(&self) -> i32 { ... } fn set_gtk_cursor_blink_time(&self, gtk_cursor_blink_time: i32) { ... } fn gtk_cursor_blink_timeout(&self) -> i32 { ... } fn set_gtk_cursor_blink_timeout(&self, gtk_cursor_blink_timeout: i32) { ... } fn gtk_cursor_theme_name(&self) -> Option<GString> { ... } fn set_gtk_cursor_theme_name(&self, gtk_cursor_theme_name: Option<&str>) { ... } fn gtk_cursor_theme_size(&self) -> i32 { ... } fn set_gtk_cursor_theme_size(&self, gtk_cursor_theme_size: i32) { ... } fn gtk_decoration_layout(&self) -> Option<GString> { ... } fn set_gtk_decoration_layout(&self, gtk_decoration_layout: Option<&str>) { ... } fn is_gtk_dialogs_use_header(&self) -> bool { ... } fn set_gtk_dialogs_use_header(&self, gtk_dialogs_use_header: bool) { ... } fn gtk_dnd_drag_threshold(&self) -> i32 { ... } fn set_gtk_dnd_drag_threshold(&self, gtk_dnd_drag_threshold: i32) { ... } fn gtk_double_click_distance(&self) -> i32 { ... } fn set_gtk_double_click_distance(&self, gtk_double_click_distance: i32) { ... } fn gtk_double_click_time(&self) -> i32 { ... } fn set_gtk_double_click_time(&self, gtk_double_click_time: i32) { ... } fn is_gtk_enable_accels(&self) -> bool { ... } fn set_gtk_enable_accels(&self, gtk_enable_accels: bool) { ... } fn is_gtk_enable_animations(&self) -> bool { ... } fn set_gtk_enable_animations(&self, gtk_enable_animations: bool) { ... } fn is_gtk_enable_event_sounds(&self) -> bool { ... } fn set_gtk_enable_event_sounds(&self, gtk_enable_event_sounds: bool) { ... } fn is_gtk_enable_input_feedback_sounds(&self) -> bool { ... } fn set_gtk_enable_input_feedback_sounds( &self, gtk_enable_input_feedback_sounds: bool, ) { ... } fn is_gtk_enable_primary_paste(&self) -> bool { ... } fn set_gtk_enable_primary_paste(&self, gtk_enable_primary_paste: bool) { ... } fn gtk_entry_password_hint_timeout(&self) -> u32 { ... } fn set_gtk_entry_password_hint_timeout( &self, gtk_entry_password_hint_timeout: u32, ) { ... } fn is_gtk_entry_select_on_focus(&self) -> bool { ... } fn set_gtk_entry_select_on_focus(&self, gtk_entry_select_on_focus: bool) { ... } fn is_gtk_error_bell(&self) -> bool { ... } fn set_gtk_error_bell(&self, gtk_error_bell: bool) { ... } fn gtk_font_name(&self) -> Option<GString> { ... } fn set_gtk_font_name(&self, gtk_font_name: Option<&str>) { ... } fn gtk_fontconfig_timestamp(&self) -> u32 { ... } fn set_gtk_fontconfig_timestamp(&self, gtk_fontconfig_timestamp: u32) { ... } fn gtk_icon_theme_name(&self) -> Option<GString> { ... } fn set_gtk_icon_theme_name(&self, gtk_icon_theme_name: Option<&str>) { ... } fn gtk_im_module(&self) -> Option<GString> { ... } fn set_gtk_im_module(&self, gtk_im_module: Option<&str>) { ... } fn gtk_key_theme_name(&self) -> Option<GString> { ... } fn set_gtk_key_theme_name(&self, gtk_key_theme_name: Option<&str>) { ... } fn is_gtk_keynav_use_caret(&self) -> bool { ... } fn set_gtk_keynav_use_caret(&self, gtk_keynav_use_caret: bool) { ... } fn is_gtk_label_select_on_focus(&self) -> bool { ... } fn set_gtk_label_select_on_focus(&self, gtk_label_select_on_focus: bool) { ... } fn gtk_long_press_time(&self) -> u32 { ... } fn set_gtk_long_press_time(&self, gtk_long_press_time: u32) { ... } fn gtk_modules(&self) -> Option<GString> { ... } fn set_gtk_modules(&self, gtk_modules: Option<&str>) { ... } fn is_gtk_overlay_scrolling(&self) -> bool { ... } fn set_gtk_overlay_scrolling(&self, gtk_overlay_scrolling: bool) { ... } fn is_gtk_primary_button_warps_slider(&self) -> bool { ... } fn set_gtk_primary_button_warps_slider( &self, gtk_primary_button_warps_slider: bool, ) { ... } fn gtk_print_backends(&self) -> Option<GString> { ... } fn set_gtk_print_backends(&self, gtk_print_backends: Option<&str>) { ... } fn gtk_print_preview_command(&self) -> Option<GString> { ... } fn set_gtk_print_preview_command( &self, gtk_print_preview_command: Option<&str>, ) { ... } fn is_gtk_recent_files_enabled(&self) -> bool { ... } fn set_gtk_recent_files_enabled(&self, gtk_recent_files_enabled: bool) { ... } fn gtk_recent_files_max_age(&self) -> i32 { ... } fn set_gtk_recent_files_max_age(&self, gtk_recent_files_max_age: i32) { ... } fn is_gtk_shell_shows_app_menu(&self) -> bool { ... } fn set_gtk_shell_shows_app_menu(&self, gtk_shell_shows_app_menu: bool) { ... } fn is_gtk_shell_shows_desktop(&self) -> bool { ... } fn set_gtk_shell_shows_desktop(&self, gtk_shell_shows_desktop: bool) { ... } fn is_gtk_shell_shows_menubar(&self) -> bool { ... } fn set_gtk_shell_shows_menubar(&self, gtk_shell_shows_menubar: bool) { ... } fn gtk_sound_theme_name(&self) -> Option<GString> { ... } fn set_gtk_sound_theme_name(&self, gtk_sound_theme_name: Option<&str>) { ... } fn is_gtk_split_cursor(&self) -> bool { ... } fn set_gtk_split_cursor(&self, gtk_split_cursor: bool) { ... } fn gtk_theme_name(&self) -> Option<GString> { ... } fn set_gtk_theme_name(&self, gtk_theme_name: Option<&str>) { ... } fn gtk_titlebar_double_click(&self) -> Option<GString> { ... } fn set_gtk_titlebar_double_click( &self, gtk_titlebar_double_click: Option<&str>, ) { ... } fn gtk_titlebar_middle_click(&self) -> Option<GString> { ... } fn set_gtk_titlebar_middle_click( &self, gtk_titlebar_middle_click: Option<&str>, ) { ... } fn gtk_titlebar_right_click(&self) -> Option<GString> { ... } fn set_gtk_titlebar_right_click( &self, gtk_titlebar_right_click: Option<&str>, ) { ... } fn gtk_xft_antialias(&self) -> i32 { ... } fn set_gtk_xft_antialias(&self, gtk_xft_antialias: i32) { ... } fn gtk_xft_dpi(&self) -> i32 { ... } fn set_gtk_xft_dpi(&self, gtk_xft_dpi: i32) { ... } fn gtk_xft_hinting(&self) -> i32 { ... } fn set_gtk_xft_hinting(&self, gtk_xft_hinting: i32) { ... } fn gtk_xft_hintstyle(&self) -> Option<GString> { ... } fn set_gtk_xft_hintstyle(&self, gtk_xft_hintstyle: Option<&str>) { ... } fn gtk_xft_rgba(&self) -> Option<GString> { ... } fn set_gtk_xft_rgba(&self, gtk_xft_rgba: Option<&str>) { ... } fn connect_gtk_alternative_button_order_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_alternative_sort_arrows_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_application_prefer_dark_theme_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_cursor_aspect_ratio_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_cursor_blink_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_cursor_blink_time_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_cursor_blink_timeout_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_cursor_theme_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_cursor_theme_size_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_decoration_layout_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_dialogs_use_header_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_dnd_drag_threshold_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_double_click_distance_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_double_click_time_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_enable_accels_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_enable_animations_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_enable_event_sounds_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_enable_input_feedback_sounds_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_enable_primary_paste_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_entry_password_hint_timeout_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_entry_select_on_focus_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_error_bell_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_font_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_fontconfig_timestamp_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_icon_theme_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_im_module_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_key_theme_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_keynav_use_caret_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_label_select_on_focus_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_long_press_time_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_modules_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_overlay_scrolling_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_primary_button_warps_slider_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_print_backends_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_print_preview_command_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_recent_files_enabled_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_recent_files_max_age_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_shell_shows_app_menu_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_shell_shows_desktop_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_shell_shows_menubar_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_sound_theme_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_split_cursor_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_theme_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_titlebar_double_click_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_titlebar_middle_click_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_titlebar_right_click_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_xft_antialias_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_xft_dpi_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_xft_hinting_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_xft_hintstyle_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_gtk_xft_rgba_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all Settings methods.

Implementors

Settings

Provided Methods

fn reset_property(&self, name: &str)

Undoes the effect of calling [ObjectExt::set()][crate::glib::prelude::ObjectExt::set()] to install an application-specific value for a setting. After this call, the setting will again follow the session-wide value for this setting.

name

the name of the setting to reset

fn is_gtk_alternative_button_order(&self) -> bool

fn set_gtk_alternative_button_order(&self, gtk_alternative_button_order: bool)

fn is_gtk_alternative_sort_arrows(&self) -> bool

Controls the direction of the sort indicators in sorted list and tree views. By default an arrow pointing down means the column is sorted in ascending order. When set to true, this order will be inverted.

fn set_gtk_alternative_sort_arrows(&self, gtk_alternative_sort_arrows: bool)

Controls the direction of the sort indicators in sorted list and tree views. By default an arrow pointing down means the column is sorted in ascending order. When set to true, this order will be inverted.

fn is_gtk_application_prefer_dark_theme(&self) -> bool

Whether the application prefers to use a dark theme. If a GTK+ theme includes a dark variant, it will be used instead of the configured theme.

Some applications benefit from minimizing the amount of light pollution that interferes with the content. Good candidates for dark themes are photo and video editors that make the actual content get all the attention and minimize the distraction of the chrome.

Dark themes should not be used for documents, where large spaces are white/light and the dark chrome creates too much contrast (web browser, text editor…).

fn set_gtk_application_prefer_dark_theme( &self, gtk_application_prefer_dark_theme: bool, )

Whether the application prefers to use a dark theme. If a GTK+ theme includes a dark variant, it will be used instead of the configured theme.

Some applications benefit from minimizing the amount of light pollution that interferes with the content. Good candidates for dark themes are photo and video editors that make the actual content get all the attention and minimize the distraction of the chrome.

Dark themes should not be used for documents, where large spaces are white/light and the dark chrome creates too much contrast (web browser, text editor…).

fn gtk_cursor_aspect_ratio(&self) -> f32

Available on crate feature v3_24 only.
fn set_gtk_cursor_aspect_ratio(&self, gtk_cursor_aspect_ratio: f32)

Available on crate feature v3_24 only.

Whether the cursor should blink.

Also see the gtk-cursor-blink-timeout setting, which allows more flexible control over cursor blinking.

Whether the cursor should blink.

Also see the gtk-cursor-blink-timeout setting, which allows more flexible control over cursor blinking.

Time after which the cursor stops blinking, in seconds. The timer is reset after each user interaction.

Setting this to zero has the same effect as setting gtk-cursor-blink to false.

Time after which the cursor stops blinking, in seconds. The timer is reset after each user interaction.

Setting this to zero has the same effect as setting gtk-cursor-blink to false.

fn gtk_cursor_theme_name(&self) -> Option<GString>

fn set_gtk_cursor_theme_name(&self, gtk_cursor_theme_name: Option<&str>)

fn gtk_cursor_theme_size(&self) -> i32

fn set_gtk_cursor_theme_size(&self, gtk_cursor_theme_size: i32)

fn gtk_decoration_layout(&self) -> Option<GString>

This setting determines which buttons should be put in the titlebar of client-side decorated windows, and whether they should be placed at the left of right.

The format of the string is button names, separated by commas. A colon separates the buttons that should appear on the left from those on the right. Recognized button names are minimize, maximize, close, icon (the window icon) and menu (a menu button for the fallback app menu).

For example, “menu:minimize,maximize,close” specifies a menu on the left, and minimize, maximize and close buttons on the right.

Note that buttons will only be shown when they are meaningful. E.g. a menu button only appears when the desktop shell does not show the app menu, and a close button only appears on a window that can be closed.

Also note that the setting can be overridden with the decoration-layout property.

fn set_gtk_decoration_layout(&self, gtk_decoration_layout: Option<&str>)

This setting determines which buttons should be put in the titlebar of client-side decorated windows, and whether they should be placed at the left of right.

The format of the string is button names, separated by commas. A colon separates the buttons that should appear on the left from those on the right. Recognized button names are minimize, maximize, close, icon (the window icon) and menu (a menu button for the fallback app menu).

For example, “menu:minimize,maximize,close” specifies a menu on the left, and minimize, maximize and close buttons on the right.

Note that buttons will only be shown when they are meaningful. E.g. a menu button only appears when the desktop shell does not show the app menu, and a close button only appears on a window that can be closed.

Also note that the setting can be overridden with the decoration-layout property.

fn is_gtk_dialogs_use_header(&self) -> bool

Whether builtin GTK+ dialogs such as the file chooser, the color chooser or the font chooser will use a header bar at the top to show action widgets, or an action area at the bottom.

This setting does not affect custom dialogs using GtkDialog directly, or message dialogs.

fn set_gtk_dialogs_use_header(&self, gtk_dialogs_use_header: bool)

Whether builtin GTK+ dialogs such as the file chooser, the color chooser or the font chooser will use a header bar at the top to show action widgets, or an action area at the bottom.

This setting does not affect custom dialogs using GtkDialog directly, or message dialogs.

fn gtk_dnd_drag_threshold(&self) -> i32

fn set_gtk_dnd_drag_threshold(&self, gtk_dnd_drag_threshold: i32)

fn gtk_double_click_distance(&self) -> i32

fn set_gtk_double_click_distance(&self, gtk_double_click_distance: i32)

fn gtk_double_click_time(&self) -> i32

fn set_gtk_double_click_time(&self, gtk_double_click_time: i32)

fn is_gtk_enable_accels(&self) -> bool

Whether menu items should have visible accelerators which can be activated.

fn set_gtk_enable_accels(&self, gtk_enable_accels: bool)

Whether menu items should have visible accelerators which can be activated.

fn is_gtk_enable_animations(&self) -> bool

fn set_gtk_enable_animations(&self, gtk_enable_animations: bool)

fn is_gtk_enable_event_sounds(&self) -> bool

Whether to play any event sounds at all.

See the Sound Theme Specifications for more information on event sounds and sound themes.

GTK+ itself does not support event sounds, you have to use a loadable module like the one that comes with libcanberra.

fn set_gtk_enable_event_sounds(&self, gtk_enable_event_sounds: bool)

Whether to play any event sounds at all.

See the Sound Theme Specifications for more information on event sounds and sound themes.

GTK+ itself does not support event sounds, you have to use a loadable module like the one that comes with libcanberra.

fn is_gtk_enable_input_feedback_sounds(&self) -> bool

Whether to play event sounds as feedback to user input.

See the Sound Theme Specifications for more information on event sounds and sound themes.

GTK+ itself does not support event sounds, you have to use a loadable module like the one that comes with libcanberra.

fn set_gtk_enable_input_feedback_sounds( &self, gtk_enable_input_feedback_sounds: bool, )

Whether to play event sounds as feedback to user input.

See the Sound Theme Specifications for more information on event sounds and sound themes.

GTK+ itself does not support event sounds, you have to use a loadable module like the one that comes with libcanberra.

fn is_gtk_enable_primary_paste(&self) -> bool

Whether a middle click on a mouse should paste the ‘PRIMARY’ clipboard content at the cursor location.

fn set_gtk_enable_primary_paste(&self, gtk_enable_primary_paste: bool)

Whether a middle click on a mouse should paste the ‘PRIMARY’ clipboard content at the cursor location.

fn gtk_entry_password_hint_timeout(&self) -> u32

How long to show the last input character in hidden entries. This value is in milliseconds. 0 disables showing the last char. 600 is a good value for enabling it.

fn set_gtk_entry_password_hint_timeout( &self, gtk_entry_password_hint_timeout: u32, )

How long to show the last input character in hidden entries. This value is in milliseconds. 0 disables showing the last char. 600 is a good value for enabling it.

fn is_gtk_entry_select_on_focus(&self) -> bool

fn set_gtk_entry_select_on_focus(&self, gtk_entry_select_on_focus: bool)

fn is_gtk_error_bell(&self) -> bool

When true, keyboard navigation and other input-related errors will cause a beep. Since the error bell is implemented using Window::beep(), the windowing system may offer ways to configure the error bell in many ways, such as flashing the window or similar visual effects.

fn set_gtk_error_bell(&self, gtk_error_bell: bool)

When true, keyboard navigation and other input-related errors will cause a beep. Since the error bell is implemented using Window::beep(), the windowing system may offer ways to configure the error bell in many ways, such as flashing the window or similar visual effects.

fn gtk_font_name(&self) -> Option<GString>

The default font to use. GTK+ uses the family name and size from this string.

fn set_gtk_font_name(&self, gtk_font_name: Option<&str>)

The default font to use. GTK+ uses the family name and size from this string.

fn gtk_fontconfig_timestamp(&self) -> u32

fn set_gtk_fontconfig_timestamp(&self, gtk_fontconfig_timestamp: u32)

fn gtk_icon_theme_name(&self) -> Option<GString>

fn set_gtk_icon_theme_name(&self, gtk_icon_theme_name: Option<&str>)

fn gtk_im_module(&self) -> Option<GString>

Which IM (input method) module should be used by default. This is the input method that will be used if the user has not explicitly chosen another input method from the IM context menu. This also can be a colon-separated list of input methods, which GTK+ will try in turn until it finds one available on the system.

See IMContext.

fn set_gtk_im_module(&self, gtk_im_module: Option<&str>)

Which IM (input method) module should be used by default. This is the input method that will be used if the user has not explicitly chosen another input method from the IM context menu. This also can be a colon-separated list of input methods, which GTK+ will try in turn until it finds one available on the system.

See IMContext.

fn gtk_key_theme_name(&self) -> Option<GString>

fn set_gtk_key_theme_name(&self, gtk_key_theme_name: Option<&str>)

fn is_gtk_keynav_use_caret(&self) -> bool

Whether GTK+ should make sure that text can be navigated with a caret, even if it is not editable. This is useful when using a screen reader.

fn set_gtk_keynav_use_caret(&self, gtk_keynav_use_caret: bool)

Whether GTK+ should make sure that text can be navigated with a caret, even if it is not editable. This is useful when using a screen reader.

fn is_gtk_label_select_on_focus(&self) -> bool

fn set_gtk_label_select_on_focus(&self, gtk_label_select_on_focus: bool)

fn gtk_long_press_time(&self) -> u32

The time for a button or touch press to be considered a “long press”.

fn set_gtk_long_press_time(&self, gtk_long_press_time: u32)

The time for a button or touch press to be considered a “long press”.

fn gtk_modules(&self) -> Option<GString>

fn set_gtk_modules(&self, gtk_modules: Option<&str>)

fn is_gtk_overlay_scrolling(&self) -> bool

Available on crate feature v3_24_9 only.

Whether scrolled windows may use overlayed scrolling indicators. If this is set to false, scrolled windows will have permanent scrollbars.

fn set_gtk_overlay_scrolling(&self, gtk_overlay_scrolling: bool)

Available on crate feature v3_24_9 only.

Whether scrolled windows may use overlayed scrolling indicators. If this is set to false, scrolled windows will have permanent scrollbars.

fn is_gtk_primary_button_warps_slider(&self) -> bool

If the value of this setting is true, clicking the primary button in a Range trough will move the slider, and hence set the range’s value, to the point that you clicked. If it is false, a primary click will cause the slider/value to move by the range’s page-size towards the point clicked.

Whichever action you choose for the primary button, the other action will be available by holding Shift and primary-clicking, or (since GTK+ 3.22.25) clicking the middle mouse button.

fn set_gtk_primary_button_warps_slider( &self, gtk_primary_button_warps_slider: bool, )

If the value of this setting is true, clicking the primary button in a Range trough will move the slider, and hence set the range’s value, to the point that you clicked. If it is false, a primary click will cause the slider/value to move by the range’s page-size towards the point clicked.

Whichever action you choose for the primary button, the other action will be available by holding Shift and primary-clicking, or (since GTK+ 3.22.25) clicking the middle mouse button.

fn gtk_print_backends(&self) -> Option<GString>

A comma-separated list of print backends to use in the print dialog. Available print backends depend on the GTK+ installation, and may include “file”, “cups”, “lpr” or “papi”.

fn set_gtk_print_backends(&self, gtk_print_backends: Option<&str>)

A comma-separated list of print backends to use in the print dialog. Available print backends depend on the GTK+ installation, and may include “file”, “cups”, “lpr” or “papi”.

fn gtk_print_preview_command(&self) -> Option<GString>

A command to run for displaying the print preview. The command should contain a f placeholder, which will get replaced by the path to the pdf file. The command may also contain a s placeholder, which will get replaced by the path to a file containing the print settings in the format produced by PrintSettings::to_file().

The preview application is responsible for removing the pdf file and the print settings file when it is done.

fn set_gtk_print_preview_command(&self, gtk_print_preview_command: Option<&str>)

A command to run for displaying the print preview. The command should contain a f placeholder, which will get replaced by the path to the pdf file. The command may also contain a s placeholder, which will get replaced by the path to a file containing the print settings in the format produced by PrintSettings::to_file().

The preview application is responsible for removing the pdf file and the print settings file when it is done.

fn is_gtk_recent_files_enabled(&self) -> bool

Whether GTK+ should keep track of items inside the recently used resources list. If set to false, the list will always be empty.

fn set_gtk_recent_files_enabled(&self, gtk_recent_files_enabled: bool)

Whether GTK+ should keep track of items inside the recently used resources list. If set to false, the list will always be empty.

fn gtk_recent_files_max_age(&self) -> i32

The maximum age, in days, of the items inside the recently used resources list. Items older than this setting will be excised from the list. If set to 0, the list will always be empty; if set to -1, no item will be removed.

fn set_gtk_recent_files_max_age(&self, gtk_recent_files_max_age: i32)

The maximum age, in days, of the items inside the recently used resources list. Items older than this setting will be excised from the list. If set to 0, the list will always be empty; if set to -1, no item will be removed.

fn is_gtk_shell_shows_app_menu(&self) -> bool

fn set_gtk_shell_shows_app_menu(&self, gtk_shell_shows_app_menu: bool)

fn is_gtk_shell_shows_desktop(&self) -> bool

fn set_gtk_shell_shows_desktop(&self, gtk_shell_shows_desktop: bool)

fn is_gtk_shell_shows_menubar(&self) -> bool

fn set_gtk_shell_shows_menubar(&self, gtk_shell_shows_menubar: bool)

fn gtk_sound_theme_name(&self) -> Option<GString>

The XDG sound theme to use for event sounds.

See the Sound Theme Specifications for more information on event sounds and sound themes.

GTK+ itself does not support event sounds, you have to use a loadable module like the one that comes with libcanberra.

fn set_gtk_sound_theme_name(&self, gtk_sound_theme_name: Option<&str>)

The XDG sound theme to use for event sounds.

See the Sound Theme Specifications for more information on event sounds and sound themes.

GTK+ itself does not support event sounds, you have to use a loadable module like the one that comes with libcanberra.

fn is_gtk_split_cursor(&self) -> bool

fn set_gtk_split_cursor(&self, gtk_split_cursor: bool)

fn gtk_theme_name(&self) -> Option<GString>

fn set_gtk_theme_name(&self, gtk_theme_name: Option<&str>)

fn gtk_titlebar_double_click(&self) -> Option<GString>

This setting determines the action to take when a double-click occurs on the titlebar of client-side decorated windows.

Recognized actions are minimize, toggle-maximize, menu, lower or none.

fn set_gtk_titlebar_double_click(&self, gtk_titlebar_double_click: Option<&str>)

This setting determines the action to take when a double-click occurs on the titlebar of client-side decorated windows.

Recognized actions are minimize, toggle-maximize, menu, lower or none.

fn gtk_titlebar_middle_click(&self) -> Option<GString>

This setting determines the action to take when a middle-click occurs on the titlebar of client-side decorated windows.

Recognized actions are minimize, toggle-maximize, menu, lower or none.

fn set_gtk_titlebar_middle_click(&self, gtk_titlebar_middle_click: Option<&str>)

This setting determines the action to take when a middle-click occurs on the titlebar of client-side decorated windows.

Recognized actions are minimize, toggle-maximize, menu, lower or none.

fn gtk_titlebar_right_click(&self) -> Option<GString>

This setting determines the action to take when a right-click occurs on the titlebar of client-side decorated windows.

Recognized actions are minimize, toggle-maximize, menu, lower or none.

fn set_gtk_titlebar_right_click(&self, gtk_titlebar_right_click: Option<&str>)

This setting determines the action to take when a right-click occurs on the titlebar of client-side decorated windows.

Recognized actions are minimize, toggle-maximize, menu, lower or none.

fn gtk_xft_antialias(&self) -> i32

fn set_gtk_xft_antialias(&self, gtk_xft_antialias: i32)

fn gtk_xft_dpi(&self) -> i32

fn set_gtk_xft_dpi(&self, gtk_xft_dpi: i32)

fn gtk_xft_hinting(&self) -> i32

fn set_gtk_xft_hinting(&self, gtk_xft_hinting: i32)

fn gtk_xft_hintstyle(&self) -> Option<GString>

fn set_gtk_xft_hintstyle(&self, gtk_xft_hintstyle: Option<&str>)

fn gtk_xft_rgba(&self) -> Option<GString>

fn set_gtk_xft_rgba(&self, gtk_xft_rgba: Option<&str>)

fn connect_gtk_alternative_button_order_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_alternative_sort_arrows_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_application_prefer_dark_theme_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_cursor_aspect_ratio_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Available on crate feature v3_24 only.
fn connect_gtk_cursor_theme_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_cursor_theme_size_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_decoration_layout_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_dialogs_use_header_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_dnd_drag_threshold_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_double_click_distance_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_double_click_time_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_enable_accels_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_enable_animations_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_enable_event_sounds_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_enable_input_feedback_sounds_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_enable_primary_paste_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_entry_password_hint_timeout_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_entry_select_on_focus_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_error_bell_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_font_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_fontconfig_timestamp_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_icon_theme_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_im_module_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_key_theme_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_keynav_use_caret_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_label_select_on_focus_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_long_press_time_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_modules_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_overlay_scrolling_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Available on crate feature v3_24_9 only.
fn connect_gtk_primary_button_warps_slider_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_print_backends_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_print_preview_command_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_recent_files_enabled_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_recent_files_max_age_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_shell_shows_app_menu_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_shell_shows_desktop_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_shell_shows_menubar_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_sound_theme_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_split_cursor_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_theme_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_titlebar_double_click_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_titlebar_middle_click_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_titlebar_right_click_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_xft_antialias_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_xft_dpi_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_xft_hinting_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_xft_hintstyle_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_gtk_xft_rgba_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors