IMMulticontextExt

Trait IMMulticontextExt 

pub trait IMMulticontextExt:
    IsA<IMMulticontext>
    + Sealed
    + 'static {
    // Provided methods
    fn context_id(&self) -> Option<GString> { ... }
    fn set_context_id(&self, context_id: &str) { ... }
}
Trait containing all IMMulticontext methods.

Implementors

IMMulticontext

Provided Methods

fn context_id(&self) -> Option<GString>

Gets the id of the currently active slave of the self.

Returns

the id of the currently active slave

fn set_context_id(&self, context_id: &str)

Sets the context id for self.

This causes the currently active slave of self to be replaced by the slave corresponding to the new context id.

context_id

the id to use

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors