LayoutExt

Trait LayoutExt 

pub trait LayoutExt:
    IsA<Layout>
    + Sealed
    + 'static {
Show 15 methods // Provided methods fn bin_window(&self) -> Option<Window> { ... } fn size(&self) -> (u32, u32) { ... } fn move_(&self, child_widget: &impl IsA<Widget>, x: i32, y: i32) { ... } fn put(&self, child_widget: &impl IsA<Widget>, x: i32, y: i32) { ... } fn set_size(&self, width: u32, height: u32) { ... } fn height(&self) -> u32 { ... } fn set_height(&self, height: u32) { ... } fn width(&self) -> u32 { ... } fn set_width(&self, width: u32) { ... } fn child_x<T: IsA<Widget>>(&self, item: &T) -> i32 { ... } fn set_child_x<T: IsA<Widget>>(&self, item: &T, x: i32) { ... } fn child_y<T: IsA<Widget>>(&self, item: &T) -> i32 { ... } fn set_child_y<T: IsA<Widget>>(&self, item: &T, y: i32) { ... } fn connect_height_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_width_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all Layout methods.

Implementors

Layout

Provided Methods

fn bin_window(&self) -> Option<Window>

Retrieve the bin window of the layout used for drawing operations.

Returns

a gdk::Window

fn size(&self) -> (u32, u32)

Gets the size that has been set on the layout, and that determines the total extents of the layout’s scrollbar area. See gtk_layout_set_size ().

Returns
width

location to store the width set on self, or None

height

location to store the height set on self, or None

fn move_(&self, child_widget: &impl IsA<Widget>, x: i32, y: i32)

fn put(&self, child_widget: &impl IsA<Widget>, x: i32, y: i32)

Adds child_widget to self, at position (x,y). self becomes the new parent container of child_widget.

child_widget

child widget

x

X position of child widget

y

Y position of child widget

fn set_size(&self, width: u32, height: u32)

Sets the size of the scrollable area of the layout.

width

width of entire scrollable area

height

height of entire scrollable area

fn height(&self) -> u32

fn set_height(&self, height: u32)

fn width(&self) -> u32

fn set_width(&self, width: u32)

fn child_x<T: IsA<Widget>>(&self, item: &T) -> i32

fn set_child_x<T: IsA<Widget>>(&self, item: &T, x: i32)

fn child_y<T: IsA<Widget>>(&self, item: &T) -> i32

fn set_child_y<T: IsA<Widget>>(&self, item: &T, y: i32)

fn connect_height_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_width_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<O: IsA<Layout>> LayoutExt for O