LevelBarExt

Trait LevelBarExt 

pub trait LevelBarExt: IsA<LevelBar> + 'static {
Show 19 methods // Provided methods fn add_offset_value(&self, name: &str, value: f64) { ... } fn is_inverted(&self) -> bool { ... } fn max_value(&self) -> f64 { ... } fn min_value(&self) -> f64 { ... } fn mode(&self) -> LevelBarMode { ... } fn offset_value(&self, name: Option<&str>) -> Option<f64> { ... } fn value(&self) -> f64 { ... } fn remove_offset_value(&self, name: Option<&str>) { ... } fn set_inverted(&self, inverted: bool) { ... } fn set_max_value(&self, value: f64) { ... } fn set_min_value(&self, value: f64) { ... } fn set_mode(&self, mode: LevelBarMode) { ... } fn set_value(&self, value: f64) { ... } fn connect_offset_changed<F: Fn(&Self, &str) + 'static>( &self, detail: Option<&str>, f: F, ) -> SignalHandlerId { ... } fn connect_inverted_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_max_value_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_min_value_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_value_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all LevelBar methods.

Implementors

LevelBar

Provided Methods

fn add_offset_value(&self, name: &str, value: f64)

Adds a new offset marker on self at the position specified by value. When the bar value is in the interval topped by value (or between value and max-value in case the offset is the last one on the bar) a style class named level-``name will be applied when rendering the level bar fill. If another offset marker named name exists, its value will be replaced by value.

name

the name of the new offset

value

the value for the new offset

fn is_inverted(&self) -> bool

Return the value of the inverted property.

Returns

true if the level bar is inverted

fn max_value(&self) -> f64

Returns the value of the max-value property.

Returns

a positive value

fn min_value(&self) -> f64

Returns the value of the min-value property.

Returns

a positive value

fn mode(&self) -> LevelBarMode

Returns the value of the mode property.

Returns

a LevelBarMode

fn offset_value(&self, name: Option<&str>) -> Option<f64>

Fetches the value specified for the offset marker name in self, returning true in case an offset named name was found.

name

the name of an offset in the bar

Returns

true if the specified offset is found

value

location where to store the value

fn value(&self) -> f64

Returns the value of the value property.

Returns

a value in the interval between min-value and max-value

fn remove_offset_value(&self, name: Option<&str>)

Removes an offset marker previously added with add_offset_value().

name

the name of an offset in the bar

fn set_inverted(&self, inverted: bool)

Sets the value of the inverted property.

inverted

true to invert the level bar

fn set_max_value(&self, value: f64)

Sets the value of the max-value property.

You probably want to update preexisting level offsets after calling this function.

value

a positive value

fn set_min_value(&self, value: f64)

Sets the value of the min-value property.

You probably want to update preexisting level offsets after calling this function.

value

a positive value

fn set_mode(&self, mode: LevelBarMode)

Sets the value of the mode property.

mode

a LevelBarMode

fn set_value(&self, value: f64)

Sets the value of the value property.

value

a value in the interval between min-value and max-value

fn connect_offset_changed<F: Fn(&Self, &str) + 'static>( &self, detail: Option<&str>, f: F, ) -> SignalHandlerId

Emitted when an offset specified on the bar changes value as an effect to add_offset_value() being called.

The signal supports detailed connections; you can connect to the detailed signal “changed::x” in order to only receive callbacks when the value of offset “x” changes.

name

the name of the offset that changed value

fn connect_inverted_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_max_value_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_min_value_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_mode_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_value_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors