pub trait LevelBarExt:
IsA<LevelBar>
+ Sealed
+ 'static {
Show 19 methods
// Provided methods
fn add_offset_value(&self, name: &str, value: f64) { ... }
fn is_inverted(&self) -> bool { ... }
fn max_value(&self) -> f64 { ... }
fn min_value(&self) -> f64 { ... }
fn mode(&self) -> LevelBarMode { ... }
fn offset_value(&self, name: Option<&str>) -> Option<f64> { ... }
fn value(&self) -> f64 { ... }
fn remove_offset_value(&self, name: Option<&str>) { ... }
fn set_inverted(&self, inverted: bool) { ... }
fn set_max_value(&self, value: f64) { ... }
fn set_min_value(&self, value: f64) { ... }
fn set_mode(&self, mode: LevelBarMode) { ... }
fn set_value(&self, value: f64) { ... }
fn connect_offset_changed<F: Fn(&Self, &str) + 'static>(
&self,
detail: Option<&str>,
f: F,
) -> SignalHandlerId { ... }
fn connect_inverted_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_max_value_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_min_value_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_mode_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_value_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Provided Methods
Sourcefn add_offset_value(&self, name: &str, value: f64)
fn add_offset_value(&self, name: &str, value: f64)
Adds a new offset marker on self at the position specified by value.
When the bar value is in the interval topped by value (or between value
and max-value in case the offset is the last one on the bar)
a style class named level-``name will be applied
when rendering the level bar fill.
If another offset marker named name exists, its value will be
replaced by value.
name
the name of the new offset
value
the value for the new offset
Sourcefn is_inverted(&self) -> bool
fn is_inverted(&self) -> bool
Sourcefn mode(&self) -> LevelBarMode
fn mode(&self) -> LevelBarMode
Sourcefn remove_offset_value(&self, name: Option<&str>)
fn remove_offset_value(&self, name: Option<&str>)
Removes an offset marker previously added with
add_offset_value().
name
the name of an offset in the bar
Sourcefn set_inverted(&self, inverted: bool)
fn set_inverted(&self, inverted: bool)
Sourcefn set_max_value(&self, value: f64)
fn set_max_value(&self, value: f64)
Sourcefn set_min_value(&self, value: f64)
fn set_min_value(&self, value: f64)
Sourcefn set_mode(&self, mode: LevelBarMode)
fn set_mode(&self, mode: LevelBarMode)
Sourcefn connect_offset_changed<F: Fn(&Self, &str) + 'static>(
&self,
detail: Option<&str>,
f: F,
) -> SignalHandlerId
fn connect_offset_changed<F: Fn(&Self, &str) + 'static>( &self, detail: Option<&str>, f: F, ) -> SignalHandlerId
Emitted when an offset specified on the bar changes value as an
effect to add_offset_value() being called.
The signal supports detailed connections; you can connect to the detailed signal “changed::x” in order to only receive callbacks when the value of offset “x” changes.
name
the name of the offset that changed value
fn connect_inverted_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_max_value_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_min_value_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_mode_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_value_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".