pub trait MenuBarExt:
IsA<MenuBar>
+ Sealed
+ 'static {
// Provided methods
fn child_pack_direction(&self) -> PackDirection { ... }
fn pack_direction(&self) -> PackDirection { ... }
fn set_child_pack_direction(&self, child_pack_dir: PackDirection) { ... }
fn set_pack_direction(&self, pack_dir: PackDirection) { ... }
fn connect_child_pack_direction_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_pack_direction_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Provided Methods
Sourcefn child_pack_direction(&self) -> PackDirection
fn child_pack_direction(&self) -> PackDirection
Retrieves the current child pack direction of the menubar.
See set_child_pack_direction().
Returns
the child pack direction
Sourcefn pack_direction(&self) -> PackDirection
fn pack_direction(&self) -> PackDirection
Retrieves the current pack direction of the menubar.
See set_pack_direction().
Returns
the pack direction
Sourcefn set_child_pack_direction(&self, child_pack_dir: PackDirection)
fn set_child_pack_direction(&self, child_pack_dir: PackDirection)
Sets how widgets should be packed inside the children of a menubar.
child_pack_dir
a new PackDirection
Sourcefn set_pack_direction(&self, pack_dir: PackDirection)
fn set_pack_direction(&self, pack_dir: PackDirection)
fn connect_child_pack_direction_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_pack_direction_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".