MessageDialogExt

Trait MessageDialogExt 

pub trait MessageDialogExt:
    IsA<MessageDialog>
    + Sealed
    + 'static {
Show 18 methods // Provided methods fn message_area(&self) -> Widget { ... } fn set_markup(&self, str: &str) { ... } fn message_type(&self) -> MessageType { ... } fn set_message_type(&self, message_type: MessageType) { ... } fn secondary_text(&self) -> Option<GString> { ... } fn set_secondary_text(&self, secondary_text: Option<&str>) { ... } fn is_secondary_use_markup(&self) -> bool { ... } fn set_secondary_use_markup(&self, secondary_use_markup: bool) { ... } fn text(&self) -> Option<GString> { ... } fn set_text(&self, text: Option<&str>) { ... } fn uses_markup(&self) -> bool { ... } fn set_use_markup(&self, use_markup: bool) { ... } fn connect_message_area_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_message_type_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_secondary_text_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_secondary_use_markup_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_text_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_use_markup_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all MessageDialog methods.

Implementors

MessageDialog

Provided Methods

fn message_area(&self) -> Widget

Returns the message area of the dialog. This is the box where the dialog’s primary and secondary labels are packed. You can add your own extra content to that box and it will appear below those labels. See DialogExt::content_area() for the corresponding function in the parent Dialog.

Returns

A Box corresponding to the “message area” in the self.

fn set_markup(&self, str: &str)

Sets the text of the message dialog to be str, which is marked up with the [Pango text markup language][PangoMarkupFormat].

str

markup string (see [Pango markup format][PangoMarkupFormat])

fn message_type(&self) -> MessageType

The type of the message.

fn set_message_type(&self, message_type: MessageType)

The type of the message.

fn secondary_text(&self) -> Option<GString>

The secondary text of the message dialog.

fn set_secondary_text(&self, secondary_text: Option<&str>)

The secondary text of the message dialog.

fn is_secondary_use_markup(&self) -> bool

true if the secondary text of the dialog includes Pango markup. See pango_parse_markup().

fn set_secondary_use_markup(&self, secondary_use_markup: bool)

true if the secondary text of the dialog includes Pango markup. See pango_parse_markup().

fn text(&self) -> Option<GString>

The primary text of the message dialog. If the dialog has a secondary text, this will appear as the title.

fn set_text(&self, text: Option<&str>)

The primary text of the message dialog. If the dialog has a secondary text, this will appear as the title.

fn uses_markup(&self) -> bool

true if the primary text of the dialog includes Pango markup. See pango_parse_markup().

fn set_use_markup(&self, use_markup: bool)

true if the primary text of the dialog includes Pango markup. See pango_parse_markup().

fn connect_message_area_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_message_type_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_secondary_text_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_secondary_use_markup_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_text_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_use_markup_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors