PanedExt

Trait PanedExt 

pub trait PanedExt: IsA<Paned> + 'static {
Show 36 methods // Provided methods fn add1(&self, child: &impl IsA<Widget>) { ... } fn add2(&self, child: &impl IsA<Widget>) { ... } fn child1(&self) -> Option<Widget> { ... } fn child2(&self) -> Option<Widget> { ... } fn handle_window(&self) -> Option<Window> { ... } fn position(&self) -> i32 { ... } fn is_wide_handle(&self) -> bool { ... } fn pack1(&self, child: &impl IsA<Widget>, resize: bool, shrink: bool) { ... } fn pack2(&self, child: &impl IsA<Widget>, resize: bool, shrink: bool) { ... } fn set_position(&self, position: i32) { ... } fn set_wide_handle(&self, wide: bool) { ... } fn max_position(&self) -> i32 { ... } fn min_position(&self) -> i32 { ... } fn is_position_set(&self) -> bool { ... } fn set_position_set(&self, position_set: bool) { ... } fn child_resizes<T: IsA<Widget>>(&self, item: &T) -> bool { ... } fn set_child_resize<T: IsA<Widget>>(&self, item: &T, resize: bool) { ... } fn child_shrinks<T: IsA<Widget>>(&self, item: &T) -> bool { ... } fn set_child_shrink<T: IsA<Widget>>(&self, item: &T, shrink: bool) { ... } fn connect_accept_position<F: Fn(&Self) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn emit_accept_position(&self) -> bool { ... } fn connect_cancel_position<F: Fn(&Self) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn emit_cancel_position(&self) -> bool { ... } fn connect_cycle_child_focus<F: Fn(&Self, bool) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn emit_cycle_child_focus(&self, reversed: bool) -> bool { ... } fn connect_cycle_handle_focus<F: Fn(&Self, bool) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn emit_cycle_handle_focus(&self, reversed: bool) -> bool { ... } fn connect_move_handle<F: Fn(&Self, ScrollType) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn emit_move_handle(&self, scroll_type: ScrollType) -> bool { ... } fn connect_toggle_handle_focus<F: Fn(&Self) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn emit_toggle_handle_focus(&self) -> bool { ... } fn connect_max_position_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_min_position_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_position_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_position_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_wide_handle_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all Paned methods.

Implementors

Paned

Provided Methods

fn add1(&self, child: &impl IsA<Widget>)

Adds a child to the top or left pane with default parameters. This is equivalent to gtk_paned_pack1 (paned, child, FALSE, TRUE).

child

the child to add

fn add2(&self, child: &impl IsA<Widget>)

Adds a child to the bottom or right pane with default parameters. This is equivalent to gtk_paned_pack2 (paned, child, TRUE, TRUE).

child

the child to add

fn child1(&self) -> Option<Widget>

Obtains the first child of the paned widget.

Returns

first child, or None if it is not set.

fn child2(&self) -> Option<Widget>

Obtains the second child of the paned widget.

Returns

second child, or None if it is not set.

fn handle_window(&self) -> Option<Window>

Returns the gdk::Window of the handle. This function is useful when handling button or motion events because it enables the callback to distinguish between the window of the paned, a child and the handle.

Returns

the paned’s handle window.

fn position(&self) -> i32

Obtains the position of the divider between the two panes.

Returns

position of the divider

fn is_wide_handle(&self) -> bool

Gets the wide-handle property.

Returns

true if the paned should have a wide handle

fn pack1(&self, child: &impl IsA<Widget>, resize: bool, shrink: bool)

Adds a child to the top or left pane.

child

the child to add

resize

should this child expand when the paned widget is resized.

shrink

can this child be made smaller than its requisition.

fn pack2(&self, child: &impl IsA<Widget>, resize: bool, shrink: bool)

Adds a child to the bottom or right pane.

child

the child to add

resize

should this child expand when the paned widget is resized.

shrink

can this child be made smaller than its requisition.

fn set_position(&self, position: i32)

Sets the position of the divider between the two panes.

position

pixel position of divider, a negative value means that the position is unset.

fn set_wide_handle(&self, wide: bool)

Sets the wide-handle property.

wide

the new value for the wide-handle property

fn max_position(&self) -> i32

The largest possible value for the position property. This property is derived from the size and shrinkability of the widget’s children.

fn min_position(&self) -> i32

The smallest possible value for the position property. This property is derived from the size and shrinkability of the widget’s children.

fn is_position_set(&self) -> bool

fn set_position_set(&self, position_set: bool)

fn child_resizes<T: IsA<Widget>>(&self, item: &T) -> bool

fn set_child_resize<T: IsA<Widget>>(&self, item: &T, resize: bool)

fn child_shrinks<T: IsA<Widget>>(&self, item: &T) -> bool

fn set_child_shrink<T: IsA<Widget>>(&self, item: &T, shrink: bool)

fn connect_accept_position<F: Fn(&Self) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId

The ::accept-position signal is a [keybinding signal][GtkBindingSignal] which gets emitted to accept the current position of the handle when moving it using key bindings.

The default binding for this signal is Return or Space.

fn emit_accept_position(&self) -> bool

fn connect_cancel_position<F: Fn(&Self) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId

The ::cancel-position signal is a [keybinding signal][GtkBindingSignal] which gets emitted to cancel moving the position of the handle using key bindings. The position of the handle will be reset to the value prior to moving it.

The default binding for this signal is Escape.

fn emit_cancel_position(&self) -> bool

fn connect_cycle_child_focus<F: Fn(&Self, bool) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId

The ::cycle-child-focus signal is a [keybinding signal][GtkBindingSignal] which gets emitted to cycle the focus between the children of the paned.

The default binding is f6.

reversed

whether cycling backward or forward

fn emit_cycle_child_focus(&self, reversed: bool) -> bool

fn connect_cycle_handle_focus<F: Fn(&Self, bool) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId

The ::cycle-handle-focus signal is a [keybinding signal][GtkBindingSignal] which gets emitted to cycle whether the paned should grab focus to allow the user to change position of the handle by using key bindings.

The default binding for this signal is f8.

reversed

whether cycling backward or forward

fn emit_cycle_handle_focus(&self, reversed: bool) -> bool

fn connect_move_handle<F: Fn(&Self, ScrollType) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId

The ::move-handle signal is a [keybinding signal][GtkBindingSignal] which gets emitted to move the handle when the user is using key bindings to move it.

scroll_type

a ScrollType

fn emit_move_handle(&self, scroll_type: ScrollType) -> bool

fn connect_toggle_handle_focus<F: Fn(&Self) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId

The ::toggle-handle-focus is a [keybinding signal][GtkBindingSignal] which gets emitted to accept the current position of the handle and then move focus to the next widget in the focus chain.

The default binding is Tab.

fn emit_toggle_handle_focus(&self) -> bool

fn connect_max_position_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_min_position_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_position_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_position_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_wide_handle_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<O: IsA<Paned>> PanedExt for O