pub trait PlugExt:
IsA<Plug>
+ Sealed
+ 'static {
// Provided methods
fn construct(&self, socket_id: Window) { ... }
fn construct_for_display(&self, display: &Display, socket_id: Window) { ... }
fn is_embedded(&self) -> bool { ... }
fn id(&self) -> Window { ... }
fn socket_window(&self) -> Option<Window> { ... }
fn connect_embedded<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn connect_embedded_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_socket_window_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Available on
gdk_backend=x11 only.Provided Methods
Sourcefn construct_for_display(&self, display: &Display, socket_id: Window)
fn construct_for_display(&self, display: &Display, socket_id: Window)
Sourcefn is_embedded(&self) -> bool
fn is_embedded(&self) -> bool
Sourcefn id(&self) -> Window
fn id(&self) -> Window
Gets the window ID of a Plug widget, which can then
be used to embed this window inside another window, for
instance with GtkSocketExt::add_id().
Returns
the window ID for the plug
Sourcefn socket_window(&self) -> Option<Window>
fn socket_window(&self) -> Option<Window>
Sourcefn connect_embedded<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_embedded<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Gets emitted when the plug becomes embedded in a socket.
fn connect_embedded_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_socket_window_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".