pub trait RadioMenuItemExt: IsA<RadioMenuItem> + 'static {
// Provided methods
fn group(&self) -> Vec<RadioMenuItem> { ... }
fn join_group(&self, group_source: Option<&impl IsA<RadioMenuItem>>) { ... }
fn connect_group_changed<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn group(&self) -> Vec<RadioMenuItem>
fn group(&self) -> Vec<RadioMenuItem>
Returns the group to which the radio menu item belongs, as a GList of
RadioMenuItem. The list belongs to GTK+ and should not be freed.
Returns
the group
of self
Sourcefn join_group(&self, group_source: Option<&impl IsA<RadioMenuItem>>)
fn join_group(&self, group_source: Option<&impl IsA<RadioMenuItem>>)
Joins a RadioMenuItem object to the group of another RadioMenuItem
object.
This function should be used by language bindings to avoid the memory
manangement of the opaque GSList of group()
and gtk_radio_menu_item_set_group().
A common way to set up a group of RadioMenuItem instances is:
GtkRadioMenuItem *last_item = NULL;
while ( ...more items to add... )
{
GtkRadioMenuItem *radio_item;
radio_item = gtk_radio_menu_item_new (...);
gtk_radio_menu_item_join_group (radio_item, last_item);
last_item = radio_item;
}group_source
a RadioMenuItem whose group we are
joining, or None to remove the self from its current
group
fn connect_group_changed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".