RevealerExt

Trait RevealerExt 

pub trait RevealerExt: IsA<Revealer> + 'static {
    // Provided methods
    fn is_child_revealed(&self) -> bool { ... }
    fn reveals_child(&self) -> bool { ... }
    fn transition_duration(&self) -> u32 { ... }
    fn transition_type(&self) -> RevealerTransitionType { ... }
    fn set_reveal_child(&self, reveal_child: bool) { ... }
    fn set_transition_duration(&self, duration: u32) { ... }
    fn set_transition_type(&self, transition: RevealerTransitionType) { ... }
    fn connect_child_revealed_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
    fn connect_reveal_child_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
    fn connect_transition_duration_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
    fn connect_transition_type_notify<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
}
Trait containing all Revealer methods.

Implementors

Revealer

Provided Methods

fn is_child_revealed(&self) -> bool

Returns whether the child is fully revealed, in other words whether the transition to the revealed state is completed.

Returns

true if the child is fully revealed

fn reveals_child(&self) -> bool

Returns whether the child is currently revealed. See set_reveal_child().

This function returns true as soon as the transition is to the revealed state is started. To learn whether the child is fully revealed (ie the transition is completed), use is_child_revealed().

Returns

true if the child is revealed.

fn transition_duration(&self) -> u32

Returns the amount of time (in milliseconds) that transitions will take.

Returns

the transition duration

fn transition_type(&self) -> RevealerTransitionType

Gets the type of animation that will be used for transitions in self.

Returns

the current transition type of self

fn set_reveal_child(&self, reveal_child: bool)

Tells the Revealer to reveal or conceal its child.

The transition will be animated with the current transition type of self.

reveal_child

true to reveal the child

fn set_transition_duration(&self, duration: u32)

Sets the duration that transitions will take.

duration

the new duration, in milliseconds

fn set_transition_type(&self, transition: RevealerTransitionType)

Sets the type of animation that will be used for transitions in self. Available types include various kinds of fades and slides.

transition

the new transition type

fn connect_child_revealed_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_reveal_child_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_transition_duration_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_transition_type_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors