pub trait RevealerExt: IsA<Revealer> + 'static {
// Provided methods
fn is_child_revealed(&self) -> bool { ... }
fn reveals_child(&self) -> bool { ... }
fn transition_duration(&self) -> u32 { ... }
fn transition_type(&self) -> RevealerTransitionType { ... }
fn set_reveal_child(&self, reveal_child: bool) { ... }
fn set_transition_duration(&self, duration: u32) { ... }
fn set_transition_type(&self, transition: RevealerTransitionType) { ... }
fn connect_child_revealed_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_reveal_child_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_transition_duration_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_transition_type_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Provided Methods
Sourcefn is_child_revealed(&self) -> bool
fn is_child_revealed(&self) -> bool
Sourcefn reveals_child(&self) -> bool
fn reveals_child(&self) -> bool
Returns whether the child is currently
revealed. See set_reveal_child().
This function returns true as soon as the transition
is to the revealed state is started. To learn whether
the child is fully revealed (ie the transition is completed),
use is_child_revealed().
Returns
true if the child is revealed.
Sourcefn transition_duration(&self) -> u32
fn transition_duration(&self) -> u32
Returns the amount of time (in milliseconds) that transitions will take.
Returns
the transition duration
Sourcefn transition_type(&self) -> RevealerTransitionType
fn transition_type(&self) -> RevealerTransitionType
Gets the type of animation that will be used
for transitions in self.
Returns
the current transition type of self
Sourcefn set_reveal_child(&self, reveal_child: bool)
fn set_reveal_child(&self, reveal_child: bool)
Sourcefn set_transition_duration(&self, duration: u32)
fn set_transition_duration(&self, duration: u32)
Sourcefn set_transition_type(&self, transition: RevealerTransitionType)
fn set_transition_type(&self, transition: RevealerTransitionType)
Sets the type of animation that will be used for
transitions in self. Available types include
various kinds of fades and slides.
transition
the new transition type
fn connect_child_revealed_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_reveal_child_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_transition_duration_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_transition_type_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".