pub trait SeparatorToolItemExt:
IsA<SeparatorToolItem>
+ Sealed
+ 'static {
// Provided methods
fn draws(&self) -> bool { ... }
fn set_draw(&self, draw: bool) { ... }
fn connect_draw_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn draws(&self) -> bool
fn draws(&self) -> bool
Returns whether self is drawn as a line, or just blank.
See set_draw().
Returns
true if self is drawn as a line, or just blank.
Sourcefn set_draw(&self, draw: bool)
fn set_draw(&self, draw: bool)
Whether self is drawn as a vertical line, or just blank.
Setting this to false along with ToolItemExt::set_expand() is useful
to create an item that forces following items to the end of the toolbar.
draw
whether self is drawn as a vertical line
fn connect_draw_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".