pub trait ShortcutsWindowExt:
IsA<ShortcutsWindow>
+ Sealed
+ 'static {
// Provided methods
fn section_name(&self) -> Option<GString> { ... }
fn set_section_name(&self, section_name: Option<&str>) { ... }
fn view_name(&self) -> Option<GString> { ... }
fn set_view_name(&self, view_name: Option<&str>) { ... }
fn connect_close<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn emit_close(&self) { ... }
fn connect_search<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn emit_search(&self) { ... }
fn connect_section_name_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_view_name_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn section_name(&self) -> Option<GString>
fn section_name(&self) -> Option<GString>
The name of the section to show.
This should be the section-name of one of the ShortcutsSection
objects that are in this shortcuts window.
Sourcefn set_section_name(&self, section_name: Option<&str>)
fn set_section_name(&self, section_name: Option<&str>)
The name of the section to show.
This should be the section-name of one of the ShortcutsSection
objects that are in this shortcuts window.
Sourcefn view_name(&self) -> Option<GString>
fn view_name(&self) -> Option<GString>
The view name by which to filter the contents.
This should correspond to the view property of some of
the ShortcutsGroup objects that are inside this shortcuts window.
Set this to None to show all groups.
Sourcefn set_view_name(&self, view_name: Option<&str>)
fn set_view_name(&self, view_name: Option<&str>)
The view name by which to filter the contents.
This should correspond to the view property of some of
the ShortcutsGroup objects that are inside this shortcuts window.
Set this to None to show all groups.
Sourcefn connect_close<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_close<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
The ::close signal is a [keybinding signal][GtkBindingSignal] which gets emitted when the user uses a keybinding to close the window.
The default binding for this signal is the Escape key.
fn emit_close(&self)
Sourcefn connect_search<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_search<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
The ::search signal is a [keybinding signal][GtkBindingSignal] which gets emitted when the user uses a keybinding to start a search.
The default binding for this signal is Control-F.
fn emit_search(&self)
fn connect_section_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_view_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".