pub trait TextBufferExtManual:
IsA<TextBuffer>
+ Sealed
+ 'static {
// Provided methods
fn connect_apply_tag<F: Fn(&Self, &TextTag, &mut TextIter, &mut TextIter) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_delete_range<F: Fn(&Self, &mut TextIter, &mut TextIter) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_insert_child_anchor<F: Fn(&Self, &mut TextIter, &TextChildAnchor) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_insert_pixbuf<F: Fn(&Self, &mut TextIter, &Pixbuf) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_insert_text<F: Fn(&Self, &mut TextIter, &str) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_remove_tag<F: Fn(&Self, &TextTag, &mut TextIter, &mut TextIter) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Provided Methods
Sourcefn connect_apply_tag<F: Fn(&Self, &TextTag, &mut TextIter, &mut TextIter) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_apply_tag<F: Fn(&Self, &TextTag, &mut TextIter, &mut TextIter) + 'static>( &self, f: F, ) -> SignalHandlerId
The ::apply-tag signal is emitted to apply a tag to a
range of text in a TextBuffer.
Applying actually occurs in the default handler.
Note that if your handler runs before the default handler it must not
invalidate the start and end iters (or has to revalidate them).
See also:
TextBufferExt::apply_tag(),
gtk_text_buffer_insert_with_tags(),
TextBufferExt::insert_range().
tag
the applied tag
start
the start of the range the tag is applied to
end
the end of the range the tag is applied to
Sourcefn connect_delete_range<F: Fn(&Self, &mut TextIter, &mut TextIter) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_delete_range<F: Fn(&Self, &mut TextIter, &mut TextIter) + 'static>( &self, f: F, ) -> SignalHandlerId
The ::delete-range signal is emitted to delete a range
from a TextBuffer.
Note that if your handler runs before the default handler it must not
invalidate the start and end iters (or has to revalidate them).
The default signal handler revalidates the start and end iters to
both point to the location where text was deleted. Handlers
which run after the default handler (see g_signal_connect_after())
do not have access to the deleted text.
See also: TextBufferExt::delete().
start
the start of the range to be deleted
end
the end of the range to be deleted
Sourcefn connect_insert_child_anchor<F: Fn(&Self, &mut TextIter, &TextChildAnchor) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_insert_child_anchor<F: Fn(&Self, &mut TextIter, &TextChildAnchor) + 'static>( &self, f: F, ) -> SignalHandlerId
The ::insert-child-anchor signal is emitted to insert a
TextChildAnchor in a TextBuffer.
Insertion actually occurs in the default handler.
Note that if your handler runs before the default handler it must
not invalidate the location iter (or has to revalidate it).
The default signal handler revalidates it to be placed after the
inserted anchor.
See also: TextBufferExt::insert_child_anchor().
location
position to insert anchor in textbuffer
anchor
the TextChildAnchor to be inserted
Sourcefn connect_insert_pixbuf<F: Fn(&Self, &mut TextIter, &Pixbuf) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_insert_pixbuf<F: Fn(&Self, &mut TextIter, &Pixbuf) + 'static>( &self, f: F, ) -> SignalHandlerId
The ::insert-pixbuf signal is emitted to insert a gdk_pixbuf::Pixbuf
in a TextBuffer. Insertion actually occurs in the default handler.
Note that if your handler runs before the default handler it must not
invalidate the location iter (or has to revalidate it).
The default signal handler revalidates it to be placed after the
inserted pixbuf.
See also: TextBufferExt::insert_pixbuf().
location
position to insert pixbuf in textbuffer
pixbuf
the gdk_pixbuf::Pixbuf to be inserted
Sourcefn connect_insert_text<F: Fn(&Self, &mut TextIter, &str) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_insert_text<F: Fn(&Self, &mut TextIter, &str) + 'static>( &self, f: F, ) -> SignalHandlerId
The ::insert-text signal is emitted to insert text in a TextBuffer.
Insertion actually occurs in the default handler.
Note that if your handler runs before the default handler it must not
invalidate the location iter (or has to revalidate it).
The default signal handler revalidates it to point to the end of the
inserted text.
See also:
TextBufferExt::insert(),
TextBufferExt::insert_range().
location
position to insert text in textbuffer
text
the UTF-8 text to be inserted
len
length of the inserted text in bytes
Sourcefn connect_remove_tag<F: Fn(&Self, &TextTag, &mut TextIter, &mut TextIter) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_remove_tag<F: Fn(&Self, &TextTag, &mut TextIter, &mut TextIter) + 'static>( &self, f: F, ) -> SignalHandlerId
The ::remove-tag signal is emitted to remove all occurrences of tag from
a range of text in a TextBuffer.
Removal actually occurs in the default handler.
Note that if your handler runs before the default handler it must not
invalidate the start and end iters (or has to revalidate them).
See also:
TextBufferExt::remove_tag().
tag
the tag to be removed
start
the start of the range the tag is removed from
end
the end of the range the tag is removed from
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".