pub trait TextTagExt:
IsA<TextTag>
+ Sealed
+ 'static {
Show 213 methods
// Provided methods
fn changed(&self, size_changed: bool) { ... }
fn event(
&self,
event_object: &impl IsA<Object>,
event: &Event,
iter: &TextIter,
) -> bool { ... }
fn priority(&self) -> i32 { ... }
fn set_priority(&self, priority: i32) { ... }
fn is_accumulative_margin(&self) -> bool { ... }
fn set_accumulative_margin(&self, accumulative_margin: bool) { ... }
fn set_background(&self, background: Option<&str>) { ... }
fn is_background_full_height(&self) -> bool { ... }
fn set_background_full_height(&self, background_full_height: bool) { ... }
fn is_background_full_height_set(&self) -> bool { ... }
fn set_background_full_height_set(&self, background_full_height_set: bool) { ... }
fn background_rgba(&self) -> Option<RGBA> { ... }
fn set_background_rgba(&self, background_rgba: Option<&RGBA>) { ... }
fn is_background_set(&self) -> bool { ... }
fn set_background_set(&self, background_set: bool) { ... }
fn direction(&self) -> TextDirection { ... }
fn set_direction(&self, direction: TextDirection) { ... }
fn is_editable(&self) -> bool { ... }
fn set_editable(&self, editable: bool) { ... }
fn is_editable_set(&self) -> bool { ... }
fn set_editable_set(&self, editable_set: bool) { ... }
fn is_fallback(&self) -> bool { ... }
fn set_fallback(&self, fallback: bool) { ... }
fn is_fallback_set(&self) -> bool { ... }
fn set_fallback_set(&self, fallback_set: bool) { ... }
fn family(&self) -> Option<GString> { ... }
fn set_family(&self, family: Option<&str>) { ... }
fn is_family_set(&self) -> bool { ... }
fn set_family_set(&self, family_set: bool) { ... }
fn font(&self) -> Option<GString> { ... }
fn set_font(&self, font: Option<&str>) { ... }
fn font_desc(&self) -> Option<FontDescription> { ... }
fn set_font_desc(&self, font_desc: Option<&FontDescription>) { ... }
fn font_features(&self) -> Option<GString> { ... }
fn set_font_features(&self, font_features: Option<&str>) { ... }
fn is_font_features_set(&self) -> bool { ... }
fn set_font_features_set(&self, font_features_set: bool) { ... }
fn set_foreground(&self, foreground: Option<&str>) { ... }
fn foreground_rgba(&self) -> Option<RGBA> { ... }
fn set_foreground_rgba(&self, foreground_rgba: Option<&RGBA>) { ... }
fn is_foreground_set(&self) -> bool { ... }
fn set_foreground_set(&self, foreground_set: bool) { ... }
fn indent(&self) -> i32 { ... }
fn set_indent(&self, indent: i32) { ... }
fn is_indent_set(&self) -> bool { ... }
fn set_indent_set(&self, indent_set: bool) { ... }
fn is_invisible(&self) -> bool { ... }
fn set_invisible(&self, invisible: bool) { ... }
fn is_invisible_set(&self) -> bool { ... }
fn set_invisible_set(&self, invisible_set: bool) { ... }
fn justification(&self) -> Justification { ... }
fn set_justification(&self, justification: Justification) { ... }
fn is_justification_set(&self) -> bool { ... }
fn set_justification_set(&self, justification_set: bool) { ... }
fn language(&self) -> Option<GString> { ... }
fn set_language(&self, language: Option<&str>) { ... }
fn is_language_set(&self) -> bool { ... }
fn set_language_set(&self, language_set: bool) { ... }
fn left_margin(&self) -> i32 { ... }
fn set_left_margin(&self, left_margin: i32) { ... }
fn is_left_margin_set(&self) -> bool { ... }
fn set_left_margin_set(&self, left_margin_set: bool) { ... }
fn letter_spacing(&self) -> i32 { ... }
fn set_letter_spacing(&self, letter_spacing: i32) { ... }
fn is_letter_spacing_set(&self) -> bool { ... }
fn set_letter_spacing_set(&self, letter_spacing_set: bool) { ... }
fn name(&self) -> Option<GString> { ... }
fn set_paragraph_background(&self, paragraph_background: Option<&str>) { ... }
fn paragraph_background_rgba(&self) -> Option<RGBA> { ... }
fn set_paragraph_background_rgba(
&self,
paragraph_background_rgba: Option<&RGBA>,
) { ... }
fn is_paragraph_background_set(&self) -> bool { ... }
fn set_paragraph_background_set(&self, paragraph_background_set: bool) { ... }
fn pixels_above_lines(&self) -> i32 { ... }
fn set_pixels_above_lines(&self, pixels_above_lines: i32) { ... }
fn is_pixels_above_lines_set(&self) -> bool { ... }
fn set_pixels_above_lines_set(&self, pixels_above_lines_set: bool) { ... }
fn pixels_below_lines(&self) -> i32 { ... }
fn set_pixels_below_lines(&self, pixels_below_lines: i32) { ... }
fn is_pixels_below_lines_set(&self) -> bool { ... }
fn set_pixels_below_lines_set(&self, pixels_below_lines_set: bool) { ... }
fn pixels_inside_wrap(&self) -> i32 { ... }
fn set_pixels_inside_wrap(&self, pixels_inside_wrap: i32) { ... }
fn is_pixels_inside_wrap_set(&self) -> bool { ... }
fn set_pixels_inside_wrap_set(&self, pixels_inside_wrap_set: bool) { ... }
fn right_margin(&self) -> i32 { ... }
fn set_right_margin(&self, right_margin: i32) { ... }
fn is_right_margin_set(&self) -> bool { ... }
fn set_right_margin_set(&self, right_margin_set: bool) { ... }
fn rise(&self) -> i32 { ... }
fn set_rise(&self, rise: i32) { ... }
fn is_rise_set(&self) -> bool { ... }
fn set_rise_set(&self, rise_set: bool) { ... }
fn scale(&self) -> f64 { ... }
fn set_scale(&self, scale: f64) { ... }
fn is_scale_set(&self) -> bool { ... }
fn set_scale_set(&self, scale_set: bool) { ... }
fn size(&self) -> i32 { ... }
fn set_size(&self, size: i32) { ... }
fn size_points(&self) -> f64 { ... }
fn set_size_points(&self, size_points: f64) { ... }
fn is_size_set(&self) -> bool { ... }
fn set_size_set(&self, size_set: bool) { ... }
fn stretch(&self) -> Stretch { ... }
fn set_stretch(&self, stretch: Stretch) { ... }
fn is_stretch_set(&self) -> bool { ... }
fn set_stretch_set(&self, stretch_set: bool) { ... }
fn is_strikethrough(&self) -> bool { ... }
fn set_strikethrough(&self, strikethrough: bool) { ... }
fn strikethrough_rgba(&self) -> Option<RGBA> { ... }
fn set_strikethrough_rgba(&self, strikethrough_rgba: Option<&RGBA>) { ... }
fn is_strikethrough_rgba_set(&self) -> bool { ... }
fn set_strikethrough_rgba_set(&self, strikethrough_rgba_set: bool) { ... }
fn is_strikethrough_set(&self) -> bool { ... }
fn set_strikethrough_set(&self, strikethrough_set: bool) { ... }
fn style(&self) -> Style { ... }
fn set_style(&self, style: Style) { ... }
fn is_style_set(&self) -> bool { ... }
fn set_style_set(&self, style_set: bool) { ... }
fn tabs(&self) -> Option<TabArray> { ... }
fn set_tabs(&self, tabs: Option<&TabArray>) { ... }
fn is_tabs_set(&self) -> bool { ... }
fn set_tabs_set(&self, tabs_set: bool) { ... }
fn underline(&self) -> Underline { ... }
fn set_underline(&self, underline: Underline) { ... }
fn underline_rgba(&self) -> Option<RGBA> { ... }
fn set_underline_rgba(&self, underline_rgba: Option<&RGBA>) { ... }
fn is_underline_rgba_set(&self) -> bool { ... }
fn set_underline_rgba_set(&self, underline_rgba_set: bool) { ... }
fn is_underline_set(&self) -> bool { ... }
fn set_underline_set(&self, underline_set: bool) { ... }
fn variant(&self) -> Variant { ... }
fn set_variant(&self, variant: Variant) { ... }
fn is_variant_set(&self) -> bool { ... }
fn set_variant_set(&self, variant_set: bool) { ... }
fn weight(&self) -> i32 { ... }
fn set_weight(&self, weight: i32) { ... }
fn is_weight_set(&self) -> bool { ... }
fn set_weight_set(&self, weight_set: bool) { ... }
fn wrap_mode(&self) -> WrapMode { ... }
fn set_wrap_mode(&self, wrap_mode: WrapMode) { ... }
fn wraps_mode_set(&self) -> bool { ... }
fn set_wrap_mode_set(&self, wrap_mode_set: bool) { ... }
fn connect_event<F: Fn(&Self, &Object, &Event, &TextIter) -> Propagation + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_accumulative_margin_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_background_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_background_full_height_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_background_full_height_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_background_rgba_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_background_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_direction_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_editable_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_editable_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_fallback_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_fallback_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_family_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_family_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_font_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_font_desc_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_font_features_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_font_features_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_foreground_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_foreground_rgba_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_foreground_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_indent_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_indent_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_invisible_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_invisible_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_justification_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_justification_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_language_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_language_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_left_margin_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_left_margin_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_letter_spacing_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_letter_spacing_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_paragraph_background_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_paragraph_background_rgba_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_paragraph_background_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_pixels_above_lines_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_pixels_above_lines_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_pixels_below_lines_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_pixels_below_lines_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_pixels_inside_wrap_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_pixels_inside_wrap_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_right_margin_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_right_margin_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_rise_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_rise_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_scale_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_scale_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_size_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_size_points_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_size_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_stretch_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_stretch_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_strikethrough_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_strikethrough_rgba_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_strikethrough_rgba_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_strikethrough_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_style_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_style_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_tabs_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_tabs_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_underline_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_underline_rgba_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_underline_rgba_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_underline_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_variant_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_variant_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_weight_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_weight_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_wrap_mode_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_wrap_mode_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Provided Methods
Sourcefn changed(&self, size_changed: bool)
fn changed(&self, size_changed: bool)
Emits the tag-changed signal on the TextTagTable where
the tag is included.
The signal is already emitted when setting a TextTag property. This
function is useful for a TextTag subclass.
size_changed
whether the change affects the TextView layout.
Sourcefn set_priority(&self, priority: i32)
fn set_priority(&self, priority: i32)
Sets the priority of a TextTag. Valid priorities
start at 0 and go to one less than TextTagTableExt::size().
Each tag in a table has a unique priority; setting the priority
of one tag shifts the priorities of all the other tags in the
table to maintain a unique priority for each tag. Higher priority
tags “win” if two tags both set the same text attribute. When adding
a tag to a tag table, it will be assigned the highest priority in
the table by default; so normally the precedence of a set of tags
is the order in which they were added to the table, or created with
gtk_text_buffer_create_tag(), which adds the tag to the buffer’s table
automatically.
priority
the new priority
Sourcefn is_accumulative_margin(&self) -> bool
fn is_accumulative_margin(&self) -> bool
Sourcefn set_accumulative_margin(&self, accumulative_margin: bool)
fn set_accumulative_margin(&self, accumulative_margin: bool)
fn set_background(&self, background: Option<&str>)
fn is_background_full_height(&self) -> bool
fn set_background_full_height(&self, background_full_height: bool)
fn is_background_full_height_set(&self) -> bool
fn set_background_full_height_set(&self, background_full_height_set: bool)
Sourcefn background_rgba(&self) -> Option<RGBA>
fn background_rgba(&self) -> Option<RGBA>
Background color as a gdk::RGBA.
Sourcefn set_background_rgba(&self, background_rgba: Option<&RGBA>)
fn set_background_rgba(&self, background_rgba: Option<&RGBA>)
Background color as a gdk::RGBA.
fn is_background_set(&self) -> bool
fn set_background_set(&self, background_set: bool)
fn direction(&self) -> TextDirection
fn set_direction(&self, direction: TextDirection)
fn is_editable(&self) -> bool
fn set_editable(&self, editable: bool)
fn is_editable_set(&self) -> bool
fn set_editable_set(&self, editable_set: bool)
Sourcefn is_fallback(&self) -> bool
fn is_fallback(&self) -> bool
Whether font fallback is enabled.
When set to true, other fonts will be substituted
where the current font is missing glyphs.
Sourcefn set_fallback(&self, fallback: bool)
fn set_fallback(&self, fallback: bool)
Whether font fallback is enabled.
When set to true, other fonts will be substituted
where the current font is missing glyphs.
fn is_fallback_set(&self) -> bool
fn set_fallback_set(&self, fallback_set: bool)
fn family(&self) -> Option<GString>
fn set_family(&self, family: Option<&str>)
fn is_family_set(&self) -> bool
fn set_family_set(&self, family_set: bool)
Sourcefn font(&self) -> Option<GString>
fn font(&self) -> Option<GString>
Font description as string, e.g. "Sans Italic 12".
Note that the initial value of this property depends on
the internals of pango::FontDescription.
Sourcefn set_font(&self, font: Option<&str>)
fn set_font(&self, font: Option<&str>)
Font description as string, e.g. "Sans Italic 12".
Note that the initial value of this property depends on
the internals of pango::FontDescription.
fn font_desc(&self) -> Option<FontDescription>
fn set_font_desc(&self, font_desc: Option<&FontDescription>)
Sourcefn font_features(&self) -> Option<GString>
fn font_features(&self) -> Option<GString>
OpenType font features, as a string.
Sourcefn set_font_features(&self, font_features: Option<&str>)
fn set_font_features(&self, font_features: Option<&str>)
OpenType font features, as a string.
fn is_font_features_set(&self) -> bool
fn set_font_features_set(&self, font_features_set: bool)
fn set_foreground(&self, foreground: Option<&str>)
Sourcefn foreground_rgba(&self) -> Option<RGBA>
fn foreground_rgba(&self) -> Option<RGBA>
Foreground color as a gdk::RGBA.
Sourcefn set_foreground_rgba(&self, foreground_rgba: Option<&RGBA>)
fn set_foreground_rgba(&self, foreground_rgba: Option<&RGBA>)
Foreground color as a gdk::RGBA.
fn is_foreground_set(&self) -> bool
fn set_foreground_set(&self, foreground_set: bool)
fn indent(&self) -> i32
fn set_indent(&self, indent: i32)
fn is_indent_set(&self) -> bool
fn set_indent_set(&self, indent_set: bool)
Sourcefn is_invisible(&self) -> bool
fn is_invisible(&self) -> bool
Whether this text is hidden.
Note that there may still be problems with the support for invisible text, in particular when navigating programmatically inside a buffer containing invisible segments.
Sourcefn set_invisible(&self, invisible: bool)
fn set_invisible(&self, invisible: bool)
Whether this text is hidden.
Note that there may still be problems with the support for invisible text, in particular when navigating programmatically inside a buffer containing invisible segments.
fn is_invisible_set(&self) -> bool
fn set_invisible_set(&self, invisible_set: bool)
fn justification(&self) -> Justification
fn set_justification(&self, justification: Justification)
fn is_justification_set(&self) -> bool
fn set_justification_set(&self, justification_set: bool)
Sourcefn language(&self) -> Option<GString>
fn language(&self) -> Option<GString>
The language this text is in, as an ISO code. Pango can use this as a hint when rendering the text. If not set, an appropriate default will be used.
Note that the initial value of this property depends on the current
locale, see also default_language().
Sourcefn set_language(&self, language: Option<&str>)
fn set_language(&self, language: Option<&str>)
The language this text is in, as an ISO code. Pango can use this as a hint when rendering the text. If not set, an appropriate default will be used.
Note that the initial value of this property depends on the current
locale, see also default_language().
fn is_language_set(&self) -> bool
fn set_language_set(&self, language_set: bool)
fn left_margin(&self) -> i32
fn set_left_margin(&self, left_margin: i32)
fn is_left_margin_set(&self) -> bool
fn set_left_margin_set(&self, left_margin_set: bool)
Sourcefn letter_spacing(&self) -> i32
fn letter_spacing(&self) -> i32
Extra spacing between graphemes, in Pango units.
Sourcefn set_letter_spacing(&self, letter_spacing: i32)
fn set_letter_spacing(&self, letter_spacing: i32)
Extra spacing between graphemes, in Pango units.
fn is_letter_spacing_set(&self) -> bool
fn set_letter_spacing_set(&self, letter_spacing_set: bool)
fn name(&self) -> Option<GString>
Sourcefn set_paragraph_background(&self, paragraph_background: Option<&str>)
fn set_paragraph_background(&self, paragraph_background: Option<&str>)
The paragraph background color as a string.
Sourcefn paragraph_background_rgba(&self) -> Option<RGBA>
fn paragraph_background_rgba(&self) -> Option<RGBA>
The paragraph background color as a gdk::RGBA.
Sourcefn set_paragraph_background_rgba(
&self,
paragraph_background_rgba: Option<&RGBA>,
)
fn set_paragraph_background_rgba( &self, paragraph_background_rgba: Option<&RGBA>, )
The paragraph background color as a gdk::RGBA.
fn is_paragraph_background_set(&self) -> bool
fn set_paragraph_background_set(&self, paragraph_background_set: bool)
fn pixels_above_lines(&self) -> i32
fn set_pixels_above_lines(&self, pixels_above_lines: i32)
fn is_pixels_above_lines_set(&self) -> bool
fn set_pixels_above_lines_set(&self, pixels_above_lines_set: bool)
fn pixels_below_lines(&self) -> i32
fn set_pixels_below_lines(&self, pixels_below_lines: i32)
fn is_pixels_below_lines_set(&self) -> bool
fn set_pixels_below_lines_set(&self, pixels_below_lines_set: bool)
fn pixels_inside_wrap(&self) -> i32
fn set_pixels_inside_wrap(&self, pixels_inside_wrap: i32)
fn is_pixels_inside_wrap_set(&self) -> bool
fn set_pixels_inside_wrap_set(&self, pixels_inside_wrap_set: bool)
fn right_margin(&self) -> i32
fn set_right_margin(&self, right_margin: i32)
fn is_right_margin_set(&self) -> bool
fn set_right_margin_set(&self, right_margin_set: bool)
fn rise(&self) -> i32
fn set_rise(&self, rise: i32)
fn is_rise_set(&self) -> bool
fn set_rise_set(&self, rise_set: bool)
fn scale(&self) -> f64
fn set_scale(&self, scale: f64)
fn is_scale_set(&self) -> bool
fn set_scale_set(&self, scale_set: bool)
fn size(&self) -> i32
fn set_size(&self, size: i32)
fn size_points(&self) -> f64
fn set_size_points(&self, size_points: f64)
fn is_size_set(&self) -> bool
fn set_size_set(&self, size_set: bool)
fn stretch(&self) -> Stretch
fn set_stretch(&self, stretch: Stretch)
fn is_stretch_set(&self) -> bool
fn set_stretch_set(&self, stretch_set: bool)
fn is_strikethrough(&self) -> bool
fn set_strikethrough(&self, strikethrough: bool)
Sourcefn strikethrough_rgba(&self) -> Option<RGBA>
fn strikethrough_rgba(&self) -> Option<RGBA>
This property modifies the color of strikeouts. If not set, strikeouts will use the forground color.
Sourcefn set_strikethrough_rgba(&self, strikethrough_rgba: Option<&RGBA>)
fn set_strikethrough_rgba(&self, strikethrough_rgba: Option<&RGBA>)
This property modifies the color of strikeouts. If not set, strikeouts will use the forground color.
Sourcefn is_strikethrough_rgba_set(&self) -> bool
fn is_strikethrough_rgba_set(&self) -> bool
If the strikethrough-rgba property has been set.
Sourcefn set_strikethrough_rgba_set(&self, strikethrough_rgba_set: bool)
fn set_strikethrough_rgba_set(&self, strikethrough_rgba_set: bool)
If the strikethrough-rgba property has been set.
fn is_strikethrough_set(&self) -> bool
fn set_strikethrough_set(&self, strikethrough_set: bool)
fn style(&self) -> Style
fn set_style(&self, style: Style)
fn is_style_set(&self) -> bool
fn set_style_set(&self, style_set: bool)
fn tabs(&self) -> Option<TabArray>
fn set_tabs(&self, tabs: Option<&TabArray>)
fn is_tabs_set(&self) -> bool
fn set_tabs_set(&self, tabs_set: bool)
fn underline(&self) -> Underline
fn set_underline(&self, underline: Underline)
Sourcefn underline_rgba(&self) -> Option<RGBA>
fn underline_rgba(&self) -> Option<RGBA>
This property modifies the color of underlines. If not set, underlines will use the forground color.
If underline is set to pango::Underline::Error, an alternate
color may be applied instead of the foreground. Setting this property
will always override those defaults.
Sourcefn set_underline_rgba(&self, underline_rgba: Option<&RGBA>)
fn set_underline_rgba(&self, underline_rgba: Option<&RGBA>)
This property modifies the color of underlines. If not set, underlines will use the forground color.
If underline is set to pango::Underline::Error, an alternate
color may be applied instead of the foreground. Setting this property
will always override those defaults.
Sourcefn is_underline_rgba_set(&self) -> bool
fn is_underline_rgba_set(&self) -> bool
If the underline-rgba property has been set.
Sourcefn set_underline_rgba_set(&self, underline_rgba_set: bool)
fn set_underline_rgba_set(&self, underline_rgba_set: bool)
If the underline-rgba property has been set.
fn is_underline_set(&self) -> bool
fn set_underline_set(&self, underline_set: bool)
fn variant(&self) -> Variant
fn set_variant(&self, variant: Variant)
fn is_variant_set(&self) -> bool
fn set_variant_set(&self, variant_set: bool)
fn weight(&self) -> i32
fn set_weight(&self, weight: i32)
fn is_weight_set(&self) -> bool
fn set_weight_set(&self, weight_set: bool)
fn wrap_mode(&self) -> WrapMode
fn set_wrap_mode(&self, wrap_mode: WrapMode)
fn wraps_mode_set(&self) -> bool
fn set_wrap_mode_set(&self, wrap_mode_set: bool)
Sourcefn connect_event<F: Fn(&Self, &Object, &Event, &TextIter) -> Propagation + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_event<F: Fn(&Self, &Object, &Event, &TextIter) -> Propagation + 'static>( &self, f: F, ) -> SignalHandlerId
The ::event signal is emitted when an event occurs on a region of the buffer marked with this tag.
object
the object the event was fired from (typically a TextView)
event
the event which triggered the signal
iter
a TextIter pointing at the location the event occurred
Returns
true to stop other handlers from being invoked for the
event. false to propagate the event further.
fn connect_accumulative_margin_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_background_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_background_full_height_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_background_full_height_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_background_rgba_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_background_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_direction_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_editable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_editable_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_fallback_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_fallback_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_family_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_family_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_font_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_font_desc_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_font_features_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_font_features_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_foreground_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_foreground_rgba_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_foreground_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_indent_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_indent_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_invisible_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_invisible_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_justification_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_justification_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_language_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_language_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_left_margin_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_left_margin_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_letter_spacing_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_letter_spacing_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_paragraph_background_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_paragraph_background_rgba_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_paragraph_background_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_pixels_above_lines_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_pixels_above_lines_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_pixels_below_lines_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_pixels_below_lines_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_pixels_inside_wrap_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_pixels_inside_wrap_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_right_margin_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_right_margin_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_rise_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_rise_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_scale_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_scale_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_size_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_size_points_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_size_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_stretch_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_stretch_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_strikethrough_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_strikethrough_rgba_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_strikethrough_rgba_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_strikethrough_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_style_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_style_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_tabs_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_tabs_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_underline_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_underline_rgba_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_underline_rgba_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_underline_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_variant_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_variant_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_weight_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_weight_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_wrap_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_wrap_mode_set_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".