ToolItemGroupExt

Trait ToolItemGroupExt 

pub trait ToolItemGroupExt: IsA<ToolItemGroup> + 'static {
Show 29 methods // Provided methods fn is_collapsed(&self) -> bool { ... } fn drop_item(&self, x: i32, y: i32) -> Option<ToolItem> { ... } fn ellipsize(&self) -> EllipsizeMode { ... } fn header_relief(&self) -> ReliefStyle { ... } fn item_position(&self, item: &impl IsA<ToolItem>) -> i32 { ... } fn label(&self) -> Option<GString> { ... } fn label_widget(&self) -> Option<Widget> { ... } fn n_items(&self) -> u32 { ... } fn nth_item(&self, index: u32) -> Option<ToolItem> { ... } fn insert(&self, item: &impl IsA<ToolItem>, position: i32) { ... } fn set_collapsed(&self, collapsed: bool) { ... } fn set_ellipsize(&self, ellipsize: EllipsizeMode) { ... } fn set_header_relief(&self, style: ReliefStyle) { ... } fn set_item_position(&self, item: &impl IsA<ToolItem>, position: i32) { ... } fn set_label(&self, label: &str) { ... } fn set_label_widget(&self, label_widget: &impl IsA<Widget>) { ... } fn item_expands<T: IsA<ToolItem>>(&self, item: &T) -> bool { ... } fn set_item_expand<T: IsA<ToolItem>>(&self, item: &T, expand: bool) { ... } fn item_fills<T: IsA<ToolItem>>(&self, item: &T) -> bool { ... } fn set_item_fill<T: IsA<ToolItem>>(&self, item: &T, fill: bool) { ... } fn item_is_homogeneous<T: IsA<ToolItem>>(&self, item: &T) -> bool { ... } fn set_item_homogeneous<T: IsA<ToolItem>>( &self, item: &T, homogeneous: bool, ) { ... } fn item_is_new_row<T: IsA<ToolItem>>(&self, item: &T) -> bool { ... } fn set_item_new_row<T: IsA<ToolItem>>(&self, item: &T, new_row: bool) { ... } fn connect_collapsed_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_ellipsize_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_header_relief_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_label_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_label_widget_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all ToolItemGroup methods.

Implementors

ToolItemGroup

Provided Methods

fn is_collapsed(&self) -> bool

Gets whether self is collapsed or expanded.

Returns

true if self is collapsed, false if it is expanded

fn drop_item(&self, x: i32, y: i32) -> Option<ToolItem>

Gets the tool item at position (x, y).

x

the x position

y

the y position

Returns

the ToolItem at position (x, y)

fn ellipsize(&self) -> EllipsizeMode

Gets the ellipsization mode of self.

Returns

the pango::EllipsizeMode of self

fn header_relief(&self) -> ReliefStyle

Gets the relief mode of the header button of self.

Returns

the ReliefStyle

fn item_position(&self, item: &impl IsA<ToolItem>) -> i32

Gets the position of item in self as index.

item

a ToolItem

Returns

the index of item in self or -1 if item is no child of self

fn label(&self) -> Option<GString>

Gets the label of self.

Returns

the label of self. The label is an internal string of self and must not be modified. Note that None is returned if a custom label has been set with set_label_widget()

fn label_widget(&self) -> Option<Widget>

Gets the label widget of self. See set_label_widget().

Returns

the label widget of self

fn n_items(&self) -> u32

Gets the number of tool items in self.

Returns

the number of tool items in self

fn nth_item(&self, index: u32) -> Option<ToolItem>

Gets the tool item at index in group.

index

the index

Returns

the ToolItem at index

fn insert(&self, item: &impl IsA<ToolItem>, position: i32)

Inserts item at position in the list of children of self.

item

the ToolItem to insert into self

position

the position of item in self, starting with 0. The position -1 means end of list.

fn set_collapsed(&self, collapsed: bool)

Sets whether the self should be collapsed or expanded.

collapsed

whether the self should be collapsed or expanded

fn set_ellipsize(&self, ellipsize: EllipsizeMode)

Sets the ellipsization mode which should be used by labels in self.

ellipsize

the pango::EllipsizeMode labels in self should use

fn set_header_relief(&self, style: ReliefStyle)

Set the button relief of the group header. See ButtonExt::set_relief() for details.

style

the ReliefStyle

fn set_item_position(&self, item: &impl IsA<ToolItem>, position: i32)

Sets the position of item in the list of children of self.

item

the ToolItem to move to a new position, should be a child of self.

position

the new position of item in self, starting with 0. The position -1 means end of list.

fn set_label(&self, label: &str)

Sets the label of the tool item group. The label is displayed in the header of the group.

label

the new human-readable label of of the group

fn set_label_widget(&self, label_widget: &impl IsA<Widget>)

Sets the label of the tool item group. The label widget is displayed in the header of the group, in place of the usual label.

label_widget

the widget to be displayed in place of the usual label

fn item_expands<T: IsA<ToolItem>>(&self, item: &T) -> bool

fn set_item_expand<T: IsA<ToolItem>>(&self, item: &T, expand: bool)

fn item_fills<T: IsA<ToolItem>>(&self, item: &T) -> bool

fn set_item_fill<T: IsA<ToolItem>>(&self, item: &T, fill: bool)

fn item_is_homogeneous<T: IsA<ToolItem>>(&self, item: &T) -> bool

fn set_item_homogeneous<T: IsA<ToolItem>>(&self, item: &T, homogeneous: bool)

fn item_is_new_row<T: IsA<ToolItem>>(&self, item: &T) -> bool

fn set_item_new_row<T: IsA<ToolItem>>(&self, item: &T, new_row: bool)

fn connect_collapsed_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_ellipsize_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_header_relief_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_label_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_label_widget_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors