pub trait TreeDragDestExt:
IsA<TreeDragDest>
+ Sealed
+ 'static {
// Provided methods
fn drag_data_received(
&self,
dest: &mut TreePath,
selection_data: &mut SelectionData,
) -> bool { ... }
fn row_drop_possible(
&self,
dest_path: &mut TreePath,
selection_data: &mut SelectionData,
) -> bool { ... }
}Expand description
Provided Methods
Sourcefn drag_data_received(
&self,
dest: &mut TreePath,
selection_data: &mut SelectionData,
) -> bool
fn drag_data_received( &self, dest: &mut TreePath, selection_data: &mut SelectionData, ) -> bool
Asks the TreeDragDest to insert a row before the path dest,
deriving the contents of the row from selection_data. If dest is
outside the tree so that inserting before it is impossible, false
will be returned. Also, false may be returned if the new row is
not created for some model-specific reason. Should robustly handle
a dest no longer found in the model!
dest
row to drop in front of
selection_data
data to drop
Returns
whether a new row was created before position dest
Sourcefn row_drop_possible(
&self,
dest_path: &mut TreePath,
selection_data: &mut SelectionData,
) -> bool
fn row_drop_possible( &self, dest_path: &mut TreePath, selection_data: &mut SelectionData, ) -> bool
Determines whether a drop is possible before the given dest_path,
at the same depth as dest_path. i.e., can we drop the data in
selection_data at that location. dest_path does not have to
exist; the return value will almost certainly be false if the
parent of dest_path doesn’t exist, though.
dest_path
destination row
selection_data
the data being dragged
Returns
true if a drop is possible before dest_path
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".