TreeDragSourceExt

Trait TreeDragSourceExt 

pub trait TreeDragSourceExt:
    IsA<TreeDragSource>
    + Sealed
    + 'static {
    // Provided methods
    fn drag_data_delete(&self, path: &mut TreePath) -> bool { ... }
    fn drag_data_get(
        &self,
        path: &mut TreePath,
        selection_data: &mut SelectionData,
    ) -> bool { ... }
    fn row_draggable(&self, path: &mut TreePath) -> bool { ... }
}
Trait containing all TreeDragSource methods.

Implementors

ListStore, TreeDragSource, TreeModelFilter, TreeModelSort, TreeStore

Provided Methods

fn drag_data_delete(&self, path: &mut TreePath) -> bool

Asks the TreeDragSource to delete the row at path, because it was moved somewhere else via drag-and-drop. Returns false if the deletion fails because path no longer exists, or for some model-specific reason. Should robustly handle a path no longer found in the model!

path

row that was being dragged

Returns

true if the row was successfully deleted

fn drag_data_get( &self, path: &mut TreePath, selection_data: &mut SelectionData, ) -> bool

Asks the TreeDragSource to fill in selection_data with a representation of the row at path. selection_data->target gives the required type of the data. Should robustly handle a path no longer found in the model!

path

row that was dragged

selection_data

a SelectionData to fill with data from the dragged row

Returns

true if data of the required type was provided

fn row_draggable(&self, path: &mut TreePath) -> bool

Asks the TreeDragSource whether a particular row can be used as the source of a DND operation. If the source doesn’t implement this interface, the row is assumed draggable.

path

row on which user is initiating a drag

Returns

true if the row can be dragged

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors