TreeSortableExt

Trait TreeSortableExt 

pub trait TreeSortableExt:
    IsA<TreeSortable>
    + Sealed
    + 'static {
    // Provided methods
    fn has_default_sort_func(&self) -> bool { ... }
    fn sort_column_changed(&self) { ... }
    fn connect_sort_column_changed<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
}
Trait containing all TreeSortable methods.

Implementors

ListStore, TreeModelSort, TreeSortable, TreeStore

Provided Methods

fn has_default_sort_func(&self) -> bool

Returns true if the model has a default sort function. This is used primarily by GtkTreeViewColumns in order to determine if a model can go back to the default state, or not.

Returns

true, if the model has a default sort function

fn sort_column_changed(&self)

Emits a sort-column-changed signal on self.

fn connect_sort_column_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

The ::sort-column-changed signal is emitted when the sort column or sort order of sortable is changed. The signal is emitted before the contents of sortable are resorted.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors