TreeStoreExtManual

Trait TreeStoreExtManual 

pub trait TreeStoreExtManual:
    IsA<TreeStore>
    + Sealed
    + 'static {
    // Provided methods
    fn insert_with_values(
        &self,
        parent: Option<&TreeIter>,
        position: Option<u32>,
        columns_and_values: &[(u32, &dyn ToValue)],
    ) -> TreeIter { ... }
    fn reorder(&self, parent: &TreeIter, new_order: &[u32]) { ... }
    fn set(&self, iter: &TreeIter, columns_and_values: &[(u32, &dyn ToValue)]) { ... }
    fn set_value(&self, iter: &TreeIter, column: u32, value: &Value) { ... }
}

Provided Methods

fn insert_with_values( &self, parent: Option<&TreeIter>, position: Option<u32>, columns_and_values: &[(u32, &dyn ToValue)], ) -> TreeIter

fn reorder(&self, parent: &TreeIter, new_order: &[u32])

Reorders the children of parent in self to follow the order indicated by new_order. Note that this function only works with unsorted stores.

parent

A TreeIter, or None

new_order

an array of integers mapping the new position of each child to its old position before the re-ordering, i.e. new_order``[newpos] = oldpos.

fn set(&self, iter: &TreeIter, columns_and_values: &[(u32, &dyn ToValue)])

Sets the value of one or more cells in the row referenced by iter. The variable argument list should contain integer column numbers, each column number followed by the value to be set. The list is terminated by a -1. For example, to set column 0 with type G_TYPE_STRING to “Foo”, you would write gtk_tree_store_set (store, iter, 0, "Foo", -1).

The value will be referenced by the store if it is a G_TYPE_OBJECT, and it will be copied if it is a G_TYPE_STRING or G_TYPE_BOXED.

iter

A valid TreeIter for the row being modified

fn set_value(&self, iter: &TreeIter, column: u32, value: &Value)

Sets the data in the cell specified by iter and column. The type of value must be convertible to the type of the column.

iter

A valid TreeIter for the row being modified

column

column number to modify

value

new value for the cell

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors