WindowGroupExt

Trait WindowGroupExt 

pub trait WindowGroupExt:
    IsA<WindowGroup>
    + Sealed
    + 'static {
    // Provided methods
    fn add_window(&self, window: &impl IsA<Window>) { ... }
    fn current_device_grab(&self, device: &Device) -> Option<Widget> { ... }
    fn current_grab(&self) -> Option<Widget> { ... }
    fn list_windows(&self) -> Vec<Window> { ... }
    fn remove_window(&self, window: &impl IsA<Window>) { ... }
}
Trait containing all WindowGroup methods.

Implementors

WindowGroup

Provided Methods

fn add_window(&self, window: &impl IsA<Window>)

Adds a window to a WindowGroup.

window

the Window to add

fn current_device_grab(&self, device: &Device) -> Option<Widget>

Returns the current grab widget for device, or None if none.

device

a gdk::Device

Returns

The grab widget, or None

fn current_grab(&self) -> Option<Widget>

Gets the current grab widget of the given group, see WidgetExt::grab_add().

Returns

the current grab widget of the group

fn list_windows(&self) -> Vec<Window>

Returns a list of the GtkWindows that belong to self.

Returns

A newly-allocated list of windows inside the group.

fn remove_window(&self, window: &impl IsA<Window>)

Removes a window from a WindowGroup.

window

the Window to remove

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors