pub struct Builder { /* private fields */ }Expand description
A GtkBuilder is an auxiliary object that reads textual descriptions
of a user interface and instantiates the described objects. To create
a GtkBuilder from a user interface description, call
gtk_builder_new_from_file(), from_resource() or
from_string().
In the (unusual) case that you want to add user interface
descriptions from multiple sources to the same GtkBuilder you can
call new() to get an empty builder and populate it by
(multiple) calls to gtk_builder_add_from_file(),
BuilderExtManual::add_from_resource() or BuilderExtManual::add_from_string().
A GtkBuilder holds a reference to all objects that it has constructed
and drops these references when it is finalized. This finalization can
cause the destruction of non-widget objects or widgets which are not
contained in a toplevel window. For toplevel windows constructed by a
builder, it is the responsibility of the user to call gtk_widget_destroy()
to get rid of them and all the widgets they contain.
The functions gtk_builder_get_object() and BuilderExt::objects()
can be used to access the widgets in the interface by the names assigned
to them inside the UI description. Toplevel windows returned by these
functions will stay around until the user explicitly destroys them
with gtk_widget_destroy(). Other widgets will either be part of a
larger hierarchy constructed by the builder (in which case you should
not have to worry about their lifecycle), or without a parent, in which
case they have to be added to some container to make use of them.
Non-widget objects need to be reffed with g_object_ref() to keep them
beyond the lifespan of the builder.
The function gtk_builder_connect_signals() and variants thereof can be
used to connect handlers to the named signals in the description.
GtkBuilder UI Definitions # {BUILDER-UI}
GtkBuilder parses textual descriptions of user interfaces which are
specified in an XML format which can be roughly described by the
RELAX NG schema below. We refer to these descriptions as “GtkBuilder
UI definitions” or just “UI definitions” if the context is clear.
Do not confuse GtkBuilder UI Definitions with
[GtkUIManager UI Definitions][XML-UI], which are more limited in scope.
It is common to use .ui as the filename extension for files containing
GtkBuilder UI definitions.
The toplevel element is <interface>. It optionally takes a “domain”
attribute, which will make the builder look for translated strings
using dgettext() in the domain specified. This can also be done by
calling BuilderExt::set_translation_domain() on the builder.
Objects are described by <object> elements, which can contain
<property> elements to set properties, <signal> elements which
connect signals to handlers, and <child> elements, which describe
child objects (most often widgets inside a container, but also e.g.
actions in an action group, or columns in a tree model). A <child>
element contains an <object> element which describes the child object.
The target toolkit version(s) are described by <requires> elements,
the “lib” attribute specifies the widget library in question (currently
the only supported value is “gtk+”) and the “version” attribute specifies
the target version in the form <major>`.`<minor>. The builder will error
out if the version requirements are not met.
Typically, the specific kind of object represented by an <object>
element is specified by the “class” attribute. If the type has not
been loaded yet, GTK+ tries to find the get_type() function from the
class name by applying heuristics. This works in most cases, but if
necessary, it is possible to specify the name of the get_type() function
explictly with the “type-func” attribute. As a special case, GtkBuilder
allows to use an object that has been constructed by a GtkUIManager in
another part of the UI definition by specifying the id of the GtkUIManager
in the “constructor” attribute and the name of the object in the “id”
attribute.
Objects may be given a name with the “id” attribute, which allows the
application to retrieve them from the builder with gtk_builder_get_object().
An id is also necessary to use the object as property value in other
parts of the UI definition. GTK+ reserves ids starting and ending
with ___ (3 underscores) for its own purposes.
Setting properties of objects is pretty straightforward with the
<property> element: the “name” attribute specifies the name of the
property, and the content of the element specifies the value.
If the “translatable” attribute is set to a true value, GTK+ uses
gettext() (or dgettext() if the builder has a translation domain set)
to find a translation for the value. This happens before the value
is parsed, so it can be used for properties of any type, but it is
probably most useful for string properties. It is also possible to
specify a context to disambiguate short strings, and comments which
may help the translators.
GtkBuilder can parse textual representations for the most common
property types: characters, strings, integers, floating-point numbers,
booleans (strings like “TRUE”, “t”, “yes”, “y”, “1” are interpreted
as true, strings like “FALSE”, “f”, “no”, “n”, “0” are interpreted
as false), enumerations (can be specified by their name, nick or
integer value), flags (can be specified by their name, nick, integer
value, optionally combined with “|”, e.g. “GTK_VISIBLE|GTK_REALIZED”)
and colors (in a format understood by gdk::RGBA::parse()).
GVariants can be specified in the format understood by g_variant_parse(),
and pixbufs can be specified as a filename of an image file to load.
Objects can be referred to by their name and by default refer to
objects declared in the local xml fragment and objects exposed via
BuilderExt::expose_object(). In general, GtkBuilder allows forward
references to objects — declared in the local xml; an object doesn’t
have to be constructed before it can be referred to. The exception
to this rule is that an object has to be constructed before it can
be used as the value of a construct-only property.
It is also possible to bind a property value to another object’s
property value using the attributes
“bind-source” to specify the source object of the binding,
“bind-property” to specify the source property and optionally
“bind-flags” to specify the binding flags.
Internally builder implements this using GBinding objects.
For more information see ObjectExt::bind_property()
Signal handlers are set up with the <signal> element. The “name”
attribute specifies the name of the signal, and the “handler” attribute
specifies the function to connect to the signal. By default, GTK+ tries
to find the handler using g_module_symbol(), but this can be changed by
passing a custom GtkBuilderConnectFunc to
[BuilderExtManual::connect_signals_full()][crate::prelude::BuilderExtManual::connect_signals_full()]. The remaining attributes, “after”,
“swapped” and “object”, have the same meaning as the corresponding
parameters of the g_signal_connect_object() or
g_signal_connect_data() functions. A “last_modification_time”
attribute is also allowed, but it does not have a meaning to the
builder.
Sometimes it is necessary to refer to widgets which have implicitly
been constructed by GTK+ as part of a composite widget, to set
properties on them or to add further children (e.g. the vbox of
a Dialog). This can be achieved by setting the “internal-child”
property of the <child> element to a true value. Note that GtkBuilder
still requires an <object> element for the internal child, even if it
has already been constructed.
A number of widgets have different places where a child can be added
(e.g. tabs vs. page content in notebooks). This can be reflected in
a UI definition by specifying the “type” attribute on a <child>
The possible values for the “type” attribute are described in the
sections describing the widget-specific portions of UI definitions.
A GtkBuilder UI Definition
⚠️ The following code is in xml ⚠️
<interface>
<object class="GtkDialog" id="dialog1">
<child internal-child="vbox">
<object class="GtkBox" id="vbox1">
<property name="border-width">10</property>
<child internal-child="action_area">
<object class="GtkButtonBox" id="hbuttonbox1">
<property name="border-width">20</property>
<child>
<object class="GtkButton" id="ok_button">
<property name="label">gtk-ok</property>
<property name="use-stock">TRUE</property>
<signal name="clicked" handler="ok_button_clicked"/>
</object>
</child>
</object>
</child>
</object>
</child>
</object>
</interface>Beyond this general structure, several object classes define their
own XML DTD fragments for filling in the ANY placeholders in the DTD
above. Note that a custom element in a <child> element gets parsed by
the custom tag handler of the parent object, while a custom element in
an <object> element gets parsed by the custom tag handler of the object.
These XML fragments are explained in the documentation of the respective objects.
Additionally, since 3.10 a special <template> tag has been added
to the format allowing one to define a widget class’s components.
See the [GtkWidget documentation][composite-templates] for details.
Properties
translation-domain
The translation domain used when translating property values that
have been marked as translatable in interface descriptions.
If the translation domain is None, Builder uses gettext(),
otherwise g_dgettext().
Readable | Writeable
Implements
Implementations
Sourceimpl Builder
impl Builder
pub const NONE: Option<&'static Builder> = None
Sourcepub fn new() -> Builder
pub fn new() -> Builder
Creates a new empty builder object.
This function is only useful if you intend to make multiple calls
to gtk_builder_add_from_file(), BuilderExtManual::add_from_resource()
or BuilderExtManual::add_from_string() in order to merge multiple UI
descriptions into a single builder.
Most users will probably want to use gtk_builder_new_from_file(),
from_resource() or from_string().
Returns
a new (empty) Builder object
Sourcepub fn from_resource(resource_path: &str) -> Builder
pub fn from_resource(resource_path: &str) -> Builder
Sourcepub fn from_string(string: &str) -> Builder
pub fn from_string(string: &str) -> Builder
Builds the user interface described by string (in the
[GtkBuilder UI definition][BUILDER-UI] format).
If string is None-terminated, then length should be -1.
If length is not -1, then it is the length of string.
If there is an error parsing string then the program will be
aborted. You should not attempt to parse user interface description
from untrusted sources.
string
a user interface (XML) description
length
the length of string, or -1
Returns
a Builder containing the interface described by string