pub struct CellRendererAccel { /* private fields */ }Expand description
CellRendererAccel displays a keyboard accelerator (i.e. a key
combination like Control + a). If the cell renderer is editable,
the accelerator can be changed by simply typing the new combination.
The CellRendererAccel cell renderer was added in GTK+ 2.10.
Properties
accel-key
The keyval of the accelerator.
Readable | Writeable
accel-mode
Determines if the edited accelerators are GTK+ accelerators. If they are, consumed modifiers are suppressed, only accelerators accepted by GTK+ are allowed, and the accelerators are rendered in the same way as they are in menus.
Readable | Writeable
accel-mods
The modifier mask of the accelerator.
Readable | Writeable
keycode
The hardware keycode of the accelerator. Note that the hardware keycode is only relevant if the key does not have a keyval. Normally, the keyboard configuration should assign keyvals to all keys.
Readable | Writeable
CellRendererText
align-set
Readable | Writeable
alignment
Specifies how to align the lines of text with respect to each other.
Note that this property describes how to align the lines of text in
case there are several of them. The “xalign” property of CellRenderer,
on the other hand, sets the horizontal alignment of the whole text.
Readable | Writeable
attributes
Readable | Writeable
background
Writeable
background-gdk
Background color as a GdkColor
Readable | Writeable
background-rgba
Background color as a gdk::RGBA
Readable | Writeable
background-set
Readable | Writeable
editable
Readable | Writeable
editable-set
Readable | Writeable
ellipsize
Specifies the preferred place to ellipsize the string, if the cell renderer
does not have enough room to display the entire string. Setting it to
pango::EllipsizeMode::None turns off ellipsizing. See the wrap-width property
for another way of making the text fit into a given width.
Readable | Writeable
ellipsize-set
Readable | Writeable
family
Readable | Writeable
family-set
Readable | Writeable
font
Readable | Writeable
font-desc
Readable | Writeable
foreground
Writeable
foreground-gdk
Foreground color as a GdkColor
Readable | Writeable
foreground-rgba
Foreground color as a gdk::RGBA
Readable | Writeable
foreground-set
Readable | Writeable
language
Readable | Writeable
language-set
Readable | Writeable
markup
Writeable
max-width-chars
The desired maximum width of the cell, in characters. If this property is set to -1, the width will be calculated automatically.
For cell renderers that ellipsize or wrap text; this property
controls the maximum reported width of the cell. The
cell should not receive any greater allocation unless it is
set to expand in its CellLayout and all of the cell’s siblings
have received their natural width.
Readable | Writeable
placeholder-text
The text that will be displayed in the CellRenderer if
editable is true and the cell is empty.
Since 3.6
Readable | Writeable
rise
Readable | Writeable
rise-set
Readable | Writeable
scale
Readable | Writeable
scale-set
Readable | Writeable
single-paragraph-mode
Readable | Writeable
size
Readable | Writeable
size-points
Readable | Writeable
size-set
Readable | Writeable
stretch
Readable | Writeable
stretch-set
Readable | Writeable
strikethrough
Readable | Writeable
strikethrough-set
Readable | Writeable
style
Readable | Writeable
style-set
Readable | Writeable
text
Readable | Writeable
underline
Readable | Writeable
underline-set
Readable | Writeable
variant
Readable | Writeable
variant-set
Readable | Writeable
weight
Readable | Writeable
weight-set
Readable | Writeable
width-chars
The desired width of the cell, in characters. If this property is set to -1, the width will be calculated automatically, otherwise the cell will request either 3 characters or the property value, whichever is greater.
Readable | Writeable
wrap-mode
Specifies how to break the string into multiple lines, if the cell renderer does not have enough room to display the entire string. This property has no effect unless the wrap-width property is set.
Readable | Writeable
wrap-width
Specifies the minimum width at which the text is wrapped. The wrap-mode property can be used to influence at what character positions the line breaks can be placed. Setting wrap-width to -1 turns wrapping off.
Readable | Writeable
CellRenderer
cell-background
Writeable
cell-background-gdk
Cell background as a GdkColor
Readable | Writeable
cell-background-rgba
Cell background as a gdk::RGBA
Readable | Writeable
cell-background-set
Readable | Writeable
editing
Readable
height
Readable | Writeable
is-expanded
Readable | Writeable
is-expander
Readable | Writeable
mode
Readable | Writeable
sensitive
Readable | Writeable
visible
Readable | Writeable
width
Readable | Writeable
xalign
Readable | Writeable
xpad
Readable | Writeable
yalign
Readable | Writeable
ypad
Readable | Writeable
Signals
accel-cleared
Gets emitted when the user has removed the accelerator.
accel-edited
Gets emitted when the user has selected a new accelerator.
CellRendererText
edited
This signal is emitted after renderer has been edited.
It is the responsibility of the application to update the model
and store new_text at the position indicated by path.
CellRenderer
editing-canceled
This signal gets emitted when the user cancels the process of editing a cell. For example, an editable cell renderer could be written to cancel editing when the user presses Escape.
See also: CellRendererExt::stop_editing().
editing-started
This signal gets emitted when a cell starts to be edited.
The intended use of this signal is to do special setup
on editable, e.g. adding a EntryCompletion or setting
up additional columns in a ComboBox.
See CellEditableExt::start_editing() for information on the lifecycle of
the editable and a way to do setup that doesn’t depend on the renderer.
Note that GTK+ doesn’t guarantee that cell renderers will
continue to use the same kind of widget for editing in future
releases, therefore you should check the type of editable
before doing any specific setup, as in the following example:
⚠️ The following code is in C ⚠️
static void
text_editing_started (GtkCellRenderer *cell,
GtkCellEditable *editable,
const gchar *path,
gpointer data)
{
if (GTK_IS_ENTRY (editable))
{
GtkEntry *entry = GTK_ENTRY (editable);
// ... create a GtkEntryCompletion
gtk_entry_set_completion (entry, completion);
}
}Implements
CellRendererAccelExt, CellRendererTextExt, CellRendererExt, glib::ObjectExt
Implementations
Sourceimpl CellRendererAccel
impl CellRendererAccel
pub const NONE: Option<&'static CellRendererAccel> = None
Sourcepub fn new() -> CellRendererAccel
pub fn new() -> CellRendererAccel
Sourcepub fn builder() -> CellRendererAccelBuilder
pub fn builder() -> CellRendererAccelBuilder
Creates a new builder-pattern struct instance to construct CellRendererAccel objects.
This method returns an instance of CellRendererAccelBuilder which can be used to create CellRendererAccel objects.