Dialog

Struct Dialog 

pub struct Dialog { /* private fields */ }
Dialog boxes are a convenient way to prompt the user for a small amount of input, e.g. to display a message, ask a question, or anything else that does not require extensive effort on the user’s part.

GTK+ treats a dialog as a window split vertically. The top section is a GtkVBox, and is where widgets such as a Label or a Entry should be packed. The bottom area is known as the “action area”. This is generally used for packing buttons into the dialog which may perform functions such as cancel, ok, or apply.

Dialog boxes are created with a call to new() or gtk_dialog_new_with_buttons(). gtk_dialog_new_with_buttons() is recommended; it allows you to set the dialog title, some convenient flags, and add simple buttons.

If “dialog” is a newly created dialog, the two primary areas of the window can be accessed through DialogExt::content_area() and gtk_dialog_get_action_area(), as can be seen from the example below.

A “modal” dialog (that is, one which freezes the rest of the application from user input), can be created by calling GtkWindowExt::set_modal() on the dialog. Use the GTK_WINDOW() macro to cast the widget returned from new() into a Window. When using gtk_dialog_new_with_buttons() you can also pass the DialogFlags::MODAL flag to make a dialog modal.

If you add buttons to Dialog using gtk_dialog_new_with_buttons(), DialogExt::add_button(), DialogExtManual::add_buttons(), or DialogExt::add_action_widget(), clicking the button will emit a signal called response with a response ID that you specified. GTK+ will never assign a meaning to positive response IDs; these are entirely user-defined. But for convenience, you can use the response IDs in the ResponseType enumeration (these all have values less than zero). If a dialog receives a delete event, the response signal will be emitted with a response ID of ResponseType::DeleteEvent.

If you want to block waiting for a dialog to return before returning control flow to your code, you can call DialogExt::run(). This function enters a recursive main loop and waits for the user to respond to the dialog, returning the response ID corresponding to the button the user clicked.

For the simple dialog in the following example, in reality you’d probably use MessageDialog to save yourself some effort. But you’d need to create the dialog contents manually if you had more than a simple message in the dialog.

An example for simple GtkDialog usage:

⚠️ The following code is in C ⚠️

// Function to open a dialog box with a message
void
quick_message (GtkWindow *parent, gchar *message)
{
 GtkWidget *dialog, *label, *content_area;
 GtkDialogFlags flags;

 // Create the widgets
 flags = GTK_DIALOG_DESTROY_WITH_PARENT;
 dialog = gtk_dialog_new_with_buttons ("Message",
                                       parent,
                                       flags,
                                       _("_OK"),
                                       GTK_RESPONSE_NONE,
                                       NULL);
 content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 label = gtk_label_new (message);

 // Ensure that the dialog box is destroyed when the user responds

 g_signal_connect_swapped (dialog,
                           "response",
                           G_CALLBACK (gtk_widget_destroy),
                           dialog);

 // Add the label, and show everything we’ve added

 gtk_container_add (GTK_CONTAINER (content_area), label);
 gtk_widget_show_all (dialog);
}

GtkDialog as GtkBuildable

The GtkDialog implementation of the Buildable interface exposes the vbox and action_area as internal children with the names “vbox” and “action_area”.

GtkDialog supports a custom <action-widgets> element, which can contain multiple <action-widget> elements. The “response” attribute specifies a numeric response, and the content of the element is the id of widget (which should be a child of the dialogs action_area). To mark a response as default, set the “default“ attribute of the <action-widget> element to true.

GtkDialog supports adding action widgets by specifying “action“ as the “type“ attribute of a <child> element. The widget will be added either to the action area or the headerbar of the dialog, depending on the “use-header-bar“ property. The response id has to be associated with the action widget using the <action-widgets> element.

An example of a Dialog UI definition fragment:

⚠️ The following code is in xml ⚠️

<object class="GtkDialog" id="dialog1">
  <child type="action">
    <object class="GtkButton" id="button_cancel"/>
  </child>
  <child type="action">
    <object class="GtkButton" id="button_ok">
      <property name="can-default">True</property>
    </object>
  </child>
  <action-widgets>
    <action-widget response="cancel">button_cancel</action-widget>
    <action-widget response="ok" default="true">button_ok</action-widget>
  </action-widgets>
</object>

Properties

use-header-bar

true if the dialog uses a HeaderBar for action buttons instead of the action-area.

For technical reasons, this property is declared as an integer property, but you should only set it to true or false.

Readable | Writeable | Construct Only

Window

accept-focus

Whether the window should receive the input focus.

Readable | Writeable

application

The Application associated with the window.

The application will be kept alive for at least as long as it has any windows associated with it (see ApplicationExtManual::hold() for a way to keep it alive without windows).

Normally, the connection between the application and the window will remain until the window is destroyed, but you can explicitly remove it by setting the :application property to None.

Readable | Writeable

attached-to

The widget to which this window is attached. See GtkWindowExt::set_attached_to().

Examples of places where specifying this relation is useful are for instance a Menu created by a ComboBox, a completion popup window created by Entry or a typeahead search entry created by TreeView.

Readable | Writeable | Construct

decorated

Whether the window should be decorated by the window manager.

Readable | Writeable

default-height

Readable | Writeable

default-width

Readable | Writeable

deletable

Whether the window frame should have a close button.

Readable | Writeable

destroy-with-parent

Readable | Writeable

focus-on-map

Whether the window should receive the input focus when mapped.

Readable | Writeable

focus-visible

Whether ‘focus rectangles’ are currently visible in this window.

This property is maintained by GTK+ based on user input and should not be set by applications.

Readable | Writeable

gravity

The window gravity of the window. See GtkWindowExt::move_() and gdk::Gravity for more details about window gravity.

Readable | Writeable

has-resize-grip

Whether the window has a corner resize grip.

Note that the resize grip is only shown if the window is actually resizable and not maximized. Use resize-grip-visible to find out if the resize grip is currently shown.

Readable | Writeable

has-toplevel-focus

Readable

hide-titlebar-when-maximized

Whether the titlebar should be hidden during maximization.

Readable | Writeable

icon

Readable | Writeable

icon-name

The :icon-name property specifies the name of the themed icon to use as the window icon. See IconTheme for more details.

Readable | Writeable

is-active

Readable

is-maximized

Readable

mnemonics-visible

Whether mnemonics are currently visible in this window.

This property is maintained by GTK+ based on user input, and should not be set by applications.

Readable | Writeable

Readable | Writeable

resizable

Readable | Writeable

resize-grip-visible

Whether a corner resize grip is currently shown.

Readable

role

Readable | Writeable

screen

Readable | Writeable

skip-pager-hint

Readable | Writeable

skip-taskbar-hint

Readable | Writeable

startup-id

The :startup-id is a write-only property for setting window’s startup notification identifier. See GtkWindowExt::set_startup_id() for more details.

Writeable

title

Readable | Writeable

transient-for

The transient parent of the window. See GtkWindowExt::set_transient_for() for more details about transient windows.

Readable | Writeable | Construct

type

Readable | Writeable | Construct Only

type-hint

Readable | Writeable

urgency-hint

Readable | Writeable

window-position

Readable | Writeable

Container

border-width

Readable | Writeable

child

Writeable

resize-mode

Readable | Writeable

Widget

app-paintable

Readable | Writeable

can-default

Readable | Writeable

can-focus

Readable | Writeable

composite-child

Readable

double-buffered

Whether the widget is double buffered.

Readable | Writeable

events

Readable | Writeable

expand

Whether to expand in both directions. Setting this sets both hexpand and vexpand

Readable | Writeable

focus-on-click

Whether the widget should grab focus when it is clicked with the mouse.

This property is only relevant for widgets that can take focus.

Before 3.20, several widgets (GtkButton, GtkFileChooserButton, GtkComboBox) implemented this property individually.

Readable | Writeable

halign

How to distribute horizontal space if widget gets extra space, see Align

Readable | Writeable

has-default

Readable | Writeable

has-focus

Readable | Writeable

has-tooltip

Enables or disables the emission of query-tooltip on widget. A value of true indicates that widget can have a tooltip, in this case the widget will be queried using query-tooltip to determine whether it will provide a tooltip or not.

Note that setting this property to true for the first time will change the event masks of the GdkWindows of this widget to include leave-notify and motion-notify events. This cannot and will not be undone when the property is set to false again.

Readable | Writeable

height-request

Readable | Writeable

hexpand

Whether to expand horizontally. See WidgetExt::set_hexpand().

Readable | Writeable

hexpand-set

Whether to use the hexpand property. See WidgetExt::is_hexpand_set().

Readable | Writeable

is-focus

Readable | Writeable

margin

Sets all four sides’ margin at once. If read, returns max margin on any side.

Readable | Writeable

margin-bottom

Margin on bottom side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writeable

margin-end

Margin on end of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writeable

margin-left

Margin on left side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writeable

margin-right

Margin on right side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writeable

margin-start

Margin on start of widget, horizontally. This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writeable

margin-top

Margin on top side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from WidgetExt::set_size_request() for example.

Readable | Writeable

name

Readable | Writeable

no-show-all

Readable | Writeable

opacity

The requested opacity of the widget. See WidgetExt::set_opacity() for more details about window opacity.

Before 3.8 this was only available in GtkWindow

Readable | Writeable

parent

Readable | Writeable

receives-default

Readable | Writeable

scale-factor

The scale factor of the widget. See WidgetExt::scale_factor() for more details about widget scaling.

Readable

sensitive

Readable | Writeable

style

The style of the widget, which contains information about how it will look (colors, etc).

Readable | Writeable

tooltip-markup

Sets the text of tooltip to be the given string, which is marked up with the [Pango text markup language][PangoMarkupFormat]. Also see Tooltip::set_markup().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

Readable | Writeable

tooltip-text

Sets the text of tooltip to be the given string.

Also see Tooltip::set_text().

This is a convenience property which will take care of getting the tooltip shown if the given string is not None: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

Readable | Writeable

valign

How to distribute vertical space if widget gets extra space, see Align

Readable | Writeable

vexpand

Whether to expand vertically. See WidgetExt::set_vexpand().

Readable | Writeable

vexpand-set

Whether to use the vexpand property. See WidgetExt::is_vexpand_set().

Readable | Writeable

visible

Readable | Writeable

width-request

Readable | Writeable

window

The widget’s window if it is realized, None otherwise.

Readable

Signals

close

The ::close signal is a [keybinding signal][GtkBindingSignal] which gets emitted when the user uses a keybinding to close the dialog.

The default binding for this signal is the Escape key.

Action

response

Emitted when an action widget is clicked, the dialog receives a delete event, or the application programmer calls DialogExt::response(). On a delete event, the response ID is ResponseType::DeleteEvent. Otherwise, it depends on which action widget was clicked.

Window

activate-default

The ::activate-default signal is a [keybinding signal][GtkBindingSignal] which gets emitted when the user activates the default widget of window.

Action

activate-focus

The ::activate-focus signal is a [keybinding signal][GtkBindingSignal] which gets emitted when the user activates the currently focused widget of window.

Action

enable-debugging

The ::enable-debugging signal is a [keybinding signal][GtkBindingSignal] which gets emitted when the user enables or disables interactive debugging. When toggle is true, interactive debugging is toggled on or off, when it is false, the debugger will be pointed at the widget under the pointer.

The default bindings for this signal are Ctrl-Shift-I and Ctrl-Shift-D.

Action

keys-changed

The ::keys-changed signal gets emitted when the set of accelerators or mnemonics that are associated with window changes.

set-focus

This signal is emitted whenever the currently focused widget in this window changes.

Container

add
check-resize
remove
set-focus-child

Widget

accel-closures-changed
button-press-event

The ::button-press-event signal will be emitted when a button (typically from a mouse) is pressed.

To receive this signal, the gdk::Window associated to the widget needs to enable the gdk::EventMask::BUTTON_PRESS_MASK mask.

This signal will be sent to the grab widget if there is one.

button-release-event

The ::button-release-event signal will be emitted when a button (typically from a mouse) is released.

To receive this signal, the gdk::Window associated to the widget needs to enable the gdk::EventMask::BUTTON_RELEASE_MASK mask.

This signal will be sent to the grab widget if there is one.

can-activate-accel

Determines whether an accelerator that activates the signal identified by signal_id can currently be activated. This signal is present to allow applications and derived widgets to override the default Widget handling for determining whether an accelerator can be activated.

child-notify

The ::child-notify signal is emitted for each [child property][child-properties] that has changed on an object. The signal’s detail holds the property name.

Detailed

composited-changed

The ::composited-changed signal is emitted when the composited status of widgets screen changes. See Screen::is_composited().

Action

configure-event

The ::configure-event signal will be emitted when the size, position or stacking of the widget’s window has changed.

To receive this signal, the gdk::Window associated to the widget needs to enable the gdk::EventMask::STRUCTURE_MASK mask. GDK will enable this mask automatically for all new windows.

damage-event

Emitted when a redirected window belonging to widget gets drawn into. The region/area members of the event shows what area of the redirected drawable was drawn into.

delete-event

The ::delete-event signal is emitted if a user requests that a toplevel window is closed. The default handler for this signal destroys the window. Connecting WidgetExtManual::hide_on_delete() to this signal will cause the window to be hidden instead, so that it can later be shown again without reconstructing it.

destroy

Signals that all holders of a reference to the widget should release the reference that they hold. May result in finalization of the widget if all references are released.

This signal is not suitable for saving widget state.

destroy-event

The ::destroy-event signal is emitted when a gdk::Window is destroyed. You rarely get this signal, because most widgets disconnect themselves from their window before they destroy it, so no widget owns the window at destroy time.

To receive this signal, the gdk::Window associated to the widget needs to enable the gdk::EventMask::STRUCTURE_MASK mask. GDK will enable this mask automatically for all new windows.

direction-changed

The ::direction-changed signal is emitted when the text direction of a widget changes.

drag-begin

The ::drag-begin signal is emitted on the drag source when a drag is started. A typical reason to connect to this signal is to set up a custom drag icon with e.g. WidgetExt::drag_source_set_icon_pixbuf().

Note that some widgets set up a drag icon in the default handler of this signal, so you may have to use g_signal_connect_after() to override what the default handler did.

drag-data-delete

The ::drag-data-delete signal is emitted on the drag source when a drag with the action gdk::DragAction::MOVE is successfully completed. The signal handler is responsible for deleting the data that has been dropped. What “delete” means depends on the context of the drag operation.

drag-data-get

The ::drag-data-get signal is emitted on the drag source when the drop site requests the data which is dragged. It is the responsibility of the signal handler to fill data with the data in the format which is indicated by info. See SelectionData::set() and SelectionData::set_text().

drag-data-received

The ::drag-data-received signal is emitted on the drop site when the dragged data has been received. If the data was received in order to determine whether the drop will be accepted, the handler is expected to call gdk_drag_status() and not finish the drag. If the data was received in response to a drag-drop signal (and this is the last target to be received), the handler for this signal is expected to process the received data and then call gtk_drag_finish(), setting the success parameter depending on whether the data was processed successfully.

Applications must create some means to determine why the signal was emitted and therefore whether to call gdk_drag_status() or gtk_drag_finish().

The handler may inspect the selected action with DragContext::selected_action() before calling gtk_drag_finish(), e.g. to implement gdk::DragAction::ASK as shown in the following example:

⚠️ The following code is in C ⚠️

void
drag_data_received (GtkWidget          *widget,
                    GdkDragContext     *context,
                    gint                x,
                    gint                y,
                    GtkSelectionData   *data,
                    guint               info,
                    guint               time)
{
  if ((data->length >= 0) && (data->format == 8))
    {
      GdkDragAction action;

      // handle data here

      action = gdk_drag_context_get_selected_action (context);
      if (action == GDK_ACTION_ASK)
        {
          GtkWidget *dialog;
          gint response;

          dialog = gtk_message_dialog_new (NULL,
                                           GTK_DIALOG_MODAL |
                                           GTK_DIALOG_DESTROY_WITH_PARENT,
                                           GTK_MESSAGE_INFO,
                                           GTK_BUTTONS_YES_NO,
                                           "Move the data ?\n");
          response = gtk_dialog_run (GTK_DIALOG (dialog));
          gtk_widget_destroy (dialog);

          if (response == GTK_RESPONSE_YES)
            action = GDK_ACTION_MOVE;
          else
            action = GDK_ACTION_COPY;
         }

      gtk_drag_finish (context, TRUE, action == GDK_ACTION_MOVE, time);
    }
  else
    gtk_drag_finish (context, FALSE, FALSE, time);
 }
drag-drop

The ::drag-drop signal is emitted on the drop site when the user drops the data onto the widget. The signal handler must determine whether the cursor position is in a drop zone or not. If it is not in a drop zone, it returns false and no further processing is necessary. Otherwise, the handler returns true. In this case, the handler must ensure that gtk_drag_finish() is called to let the source know that the drop is done. The call to gtk_drag_finish() can be done either directly or in a drag-data-received handler which gets triggered by calling WidgetExt::drag_get_data() to receive the data for one or more of the supported targets.

drag-end

The ::drag-end signal is emitted on the drag source when a drag is finished. A typical reason to connect to this signal is to undo things done in drag-begin.

drag-failed

The ::drag-failed signal is emitted on the drag source when a drag has failed. The signal handler may hook custom code to handle a failed DnD operation based on the type of error, it returns true is the failure has been already handled (not showing the default “drag operation failed” animation), otherwise it returns false.

drag-leave

The ::drag-leave signal is emitted on the drop site when the cursor leaves the widget. A typical reason to connect to this signal is to undo things done in drag-motion, e.g. undo highlighting with WidgetExt::drag_unhighlight().

Likewise, the drag-leave signal is also emitted before the ::drag-drop signal, for instance to allow cleaning up of a preview item created in the drag-motion signal handler.

drag-motion

The ::drag-motion signal is emitted on the drop site when the user moves the cursor over the widget during a drag. The signal handler must determine whether the cursor position is in a drop zone or not. If it is not in a drop zone, it returns false and no further processing is necessary. Otherwise, the handler returns true. In this case, the handler is responsible for providing the necessary information for displaying feedback to the user, by calling gdk_drag_status().

If the decision whether the drop will be accepted or rejected can’t be made based solely on the cursor position and the type of the data, the handler may inspect the dragged data by calling WidgetExt::drag_get_data() and defer the gdk_drag_status() call to the drag-data-received handler. Note that you must pass DestDefaults::DROP, DestDefaults::MOTION or DestDefaults::ALL to WidgetExtManual::drag_dest_set() when using the drag-motion signal that way.

Also note that there is no drag-enter signal. The drag receiver has to keep track of whether he has received any drag-motion signals since the last drag-leave and if not, treat the drag-motion signal as an “enter” signal. Upon an “enter”, the handler will typically highlight the drop site with WidgetExt::drag_highlight().

⚠️ The following code is in C ⚠️

static void
drag_motion (GtkWidget      *widget,
             GdkDragContext *context,
             gint            x,
             gint            y,
             guint           time)
{
  GdkAtom target;

  PrivateData *private_data = GET_PRIVATE_DATA (widget);

  if (!private_data->drag_highlight)
   {
     private_data->drag_highlight = 1;
     gtk_drag_highlight (widget);
   }

  target = gtk_drag_dest_find_target (widget, context, NULL);
  if (target == GDK_NONE)
    gdk_drag_status (context, 0, time);
  else
   {
     private_data->pending_status
        = gdk_drag_context_get_suggested_action (context);
     gtk_drag_get_data (widget, context, target, time);
   }

  return TRUE;
}

static void
drag_data_received (GtkWidget        *widget,
                    GdkDragContext   *context,
                    gint              x,
                    gint              y,
                    GtkSelectionData *selection_data,
                    guint             info,
                    guint             time)
{
  PrivateData *private_data = GET_PRIVATE_DATA (widget);

  if (private_data->suggested_action)
   {
     private_data->suggested_action = 0;

     // We are getting this data due to a request in drag_motion,
     // rather than due to a request in drag_drop, so we are just
     // supposed to call gdk_drag_status(), not actually paste in
     // the data.

     str = gtk_selection_data_get_text (selection_data);
     if (!data_is_acceptable (str))
       gdk_drag_status (context, 0, time);
     else
       gdk_drag_status (context,
                        private_data->suggested_action,
                        time);
   }
  else
   {
     // accept the drop
   }
}
draw

This signal is emitted when a widget is supposed to render itself. The widget’s top left corner must be painted at the origin of the passed in context and be sized to the values returned by WidgetExt::allocated_width() and WidgetExt::allocated_height().

Signal handlers connected to this signal can modify the cairo context passed as cr in any way they like and don’t need to restore it. The signal emission takes care of calling cairo_save() before and cairo_restore() after invoking the handler.

The signal handler will get a cr with a clip region already set to the widget’s dirty region, i.e. to the area that needs repainting. Complicated widgets that want to avoid redrawing themselves completely can get the full extents of the clip region with gdk_cairo_get_clip_rectangle(), or they can get a finer-grained representation of the dirty region with cairo_copy_clip_rectangle_list().

enter-notify-event

The ::enter-notify-event will be emitted when the pointer enters the widget’s window.

To receive this signal, the gdk::Window associated to the widget needs to enable the gdk::EventMask::ENTER_NOTIFY_MASK mask.

This signal will be sent to the grab widget if there is one.

event

The GTK+ main loop will emit three signals for each GDK event delivered to a widget: one generic ::event signal, another, more specific, signal that matches the type of event delivered (e.g. key-press-event) and finally a generic event-after signal.

event-after

After the emission of the event signal and (optionally) the second more specific signal, ::event-after will be emitted regardless of the previous two signals handlers return values.

focus
focus-in-event

The ::focus-in-event signal will be emitted when the keyboard focus enters the widget’s window.

To receive this signal, the gdk::Window associated to the widget needs to enable the gdk::EventMask::FOCUS_CHANGE_MASK mask.

focus-out-event

The ::focus-out-event signal will be emitted when the keyboard focus leaves the widget’s window.

To receive this signal, the gdk::Window associated to the widget needs to enable the gdk::EventMask::FOCUS_CHANGE_MASK mask.

grab-broken-event

Emitted when a pointer or keyboard grab on a window belonging to widget gets broken.

On X11, this happens when the grab window becomes unviewable (i.e. it or one of its ancestors is unmapped), or if the same application grabs the pointer or keyboard again.

grab-focus

Action

grab-notify

The ::grab-notify signal is emitted when a widget becomes shadowed by a GTK+ grab (not a pointer or keyboard grab) on another widget, or when it becomes unshadowed due to a grab being removed.

A widget is shadowed by a WidgetExt::grab_add() when the topmost grab widget in the grab stack of its window group is not its ancestor.

hide

The ::hide signal is emitted when widget is hidden, for example with WidgetExt::hide().

hierarchy-changed

The ::hierarchy-changed signal is emitted when the anchored state of a widget changes. A widget is “anchored” when its toplevel ancestor is a Window. This signal is emitted when a widget changes from un-anchored to anchored or vice-versa.

key-press-event

The ::key-press-event signal is emitted when a key is pressed. The signal emission will reoccur at the key-repeat rate when the key is kept pressed.

To receive this signal, the gdk::Window associated to the widget needs to enable the gdk::EventMask::KEY_PRESS_MASK mask.

This signal will be sent to the grab widget if there is one.

key-release-event

The ::key-release-event signal is emitted when a key is released.

To receive this signal, the gdk::Window associated to the widget needs to enable the gdk::EventMask::KEY_RELEASE_MASK mask.

This signal will be sent to the grab widget if there is one.

keynav-failed

Gets emitted if keyboard navigation fails. See WidgetExt::keynav_failed() for details.

leave-notify-event

The ::leave-notify-event will be emitted when the pointer leaves the widget’s window.

To receive this signal, the gdk::Window associated to the widget needs to enable the gdk::EventMask::LEAVE_NOTIFY_MASK mask.

This signal will be sent to the grab widget if there is one.

map

The ::map signal is emitted when widget is going to be mapped, that is when the widget is visible (which is controlled with WidgetExt::set_visible()) and all its parents up to the toplevel widget are also visible. Once the map has occurred, map-event will be emitted.

The ::map signal can be used to determine whether a widget will be drawn, for instance it can resume an animation that was stopped during the emission of unmap.

map-event

The ::map-event signal will be emitted when the widget’s window is mapped. A window is mapped when it becomes visible on the screen.

To receive this signal, the gdk::Window associated to the widget needs to enable the gdk::EventMask::STRUCTURE_MASK mask. GDK will enable this mask automatically for all new windows.

mnemonic-activate

The default handler for this signal activates widget if group_cycling is false, or just makes widget grab focus if group_cycling is true.

motion-notify-event

The ::motion-notify-event signal is emitted when the pointer moves over the widget’s gdk::Window.

To receive this signal, the gdk::Window associated to the widget needs to enable the gdk::EventMask::POINTER_MOTION_MASK mask.

This signal will be sent to the grab widget if there is one.

move-focus

Action

parent-set

The ::parent-set signal is emitted when a new parent has been set on a widget.

This signal gets emitted whenever a widget should pop up a context menu. This usually happens through the standard key binding mechanism; by pressing a certain key while a widget is focused, the user can cause the widget to pop up a menu. For example, the Entry widget creates a menu with clipboard commands. See the [Popup Menu Migration Checklist][checklist-popup-menu] for an example of how to use this signal.

Action

property-notify-event

The ::property-notify-event signal will be emitted when a property on the widget’s window has been changed or deleted.

To receive this signal, the gdk::Window associated to the widget needs to enable the gdk::EventMask::PROPERTY_CHANGE_MASK mask.

proximity-in-event

To receive this signal the gdk::Window associated to the widget needs to enable the gdk::EventMask::PROXIMITY_IN_MASK mask.

This signal will be sent to the grab widget if there is one.

proximity-out-event

To receive this signal the gdk::Window associated to the widget needs to enable the gdk::EventMask::PROXIMITY_OUT_MASK mask.

This signal will be sent to the grab widget if there is one.

query-tooltip

Emitted when has-tooltip is true and the hover timeout has expired with the cursor hovering “above” widget; or emitted when widget got focus in keyboard mode.

Using the given coordinates, the signal handler should determine whether a tooltip should be shown for widget. If this is the case true should be returned, false otherwise. Note that if keyboard_mode is true, the values of x and y are undefined and should not be used.

The signal handler is free to manipulate tooltip with the therefore destined function calls.

realize

The ::realize signal is emitted when widget is associated with a gdk::Window, which means that WidgetExt::realize() has been called or the widget has been mapped (that is, it is going to be drawn).

screen-changed

The ::screen-changed signal gets emitted when the screen of a widget has changed.

scroll-event

The ::scroll-event signal is emitted when a button in the 4 to 7 range is pressed. Wheel mice are usually configured to generate button press events for buttons 4 and 5 when the wheel is turned.

To receive this signal, the gdk::Window associated to the widget needs to enable the gdk::EventMask::SCROLL_MASK mask.

This signal will be sent to the grab widget if there is one.

selection-clear-event

The ::selection-clear-event signal will be emitted when the the widget’s window has lost ownership of a selection.

selection-get
selection-notify-event
selection-received
selection-request-event

The ::selection-request-event signal will be emitted when another client requests ownership of the selection owned by the widget’s window.

show

The ::show signal is emitted when widget is shown, for example with WidgetExt::show().

show-help

Action

size-allocate
state-changed

The ::state-changed signal is emitted when the widget state changes. See gtk_widget_get_state().

state-flags-changed

The ::state-flags-changed signal is emitted when the widget state changes, see WidgetExt::state_flags().

style-set

The ::style-set signal is emitted when a new style has been set on a widget. Note that style-modifying functions like gtk_widget_modify_base() also cause this signal to be emitted.

Note that this signal is emitted for changes to the deprecated GtkStyle. To track changes to the StyleContext associated with a widget, use the style-updated signal.

style-updated

The ::style-updated signal is a convenience signal that is emitted when the changed signal is emitted on the widget’s associated StyleContext as returned by WidgetExt::style_context().

Note that style-modifying functions like gtk_widget_override_color() also cause this signal to be emitted.

touch-event
unmap

The ::unmap signal is emitted when widget is going to be unmapped, which means that either it or any of its parents up to the toplevel widget have been set as hidden.

As ::unmap indicates that a widget will not be shown any longer, it can be used to, for example, stop an animation on the widget.

unmap-event

The ::unmap-event signal will be emitted when the widget’s window is unmapped. A window is unmapped when it becomes invisible on the screen.

To receive this signal, the gdk::Window associated to the widget needs to enable the gdk::EventMask::STRUCTURE_MASK mask. GDK will enable this mask automatically for all new windows.

unrealize

The ::unrealize signal is emitted when the gdk::Window associated with widget is destroyed, which means that WidgetExt::unrealize() has been called or the widget has been unmapped (that is, it is going to be hidden).

visibility-notify-event

The ::visibility-notify-event will be emitted when the widget’s window is obscured or unobscured.

To receive this signal the gdk::Window associated to the widget needs to enable the gdk::EventMask::VISIBILITY_NOTIFY_MASK mask.

window-state-event

The ::window-state-event will be emitted when the state of the toplevel window associated to the widget changes.

To receive this signal the gdk::Window associated to the widget needs to enable the gdk::EventMask::STRUCTURE_MASK mask. GDK will enable this mask automatically for all new windows.

Implements

DialogExt, GtkWindowExt, BinExt, ContainerExt, WidgetExt, glib::ObjectExt, BuildableExt, DialogExtManual, [GtkWindowExtManual][trait@crate::prelude::GtkWindowExtManual], ContainerExtManual, WidgetExtManual, BuildableExtManual

Implementations

Source

impl Dialog

pub const NONE: Option<&'static Dialog> = None

pub fn new() -> Dialog

Creates a new dialog box.

Widgets should not be packed into this Window directly, but into the vbox and action_area, as described above.

Returns

the new dialog as a Widget

pub fn builder() -> DialogBuilder

Creates a new builder-pattern struct instance to construct Dialog objects.

This method returns an instance of DialogBuilder which can be used to create Dialog objects.

Source

impl Dialog

pub fn with_buttons<T: IsA<Window>>( title: Option<&str>, parent: Option<&T>, flags: DialogFlags, buttons: &[(&str, ResponseType)], ) -> Dialog

Creates a new Dialog with title title (or None for the default title; see GtkWindowExt::set_title()) and transient parent parent (or None for none; see GtkWindowExt::set_transient_for()). The flags argument can be used to make the dialog modal (DialogFlags::MODAL) and/or to have it destroyed along with its transient parent (DialogFlags::DESTROY_WITH_PARENT). After flags, button text/response ID pairs should be listed, with a None pointer ending the list. Button text can be arbitrary text. A response ID can be any positive number, or one of the values in the ResponseType enumeration. If the user clicks one of these dialog buttons, Dialog will emit the response signal with the corresponding response ID. If a Dialog receives the delete-event signal, it will emit ::response with a response ID of ResponseType::DeleteEvent. However, destroying a dialog does not emit the ::response signal; so be careful relying on ::response when using the DialogFlags::DESTROY_WITH_PARENT flag. Buttons are from left to right, so the first button in the list will be the leftmost button in the dialog.

Here’s a simple example:

⚠️ The following code is in C ⚠️

 GtkWidget *main_app_window; // Window the dialog should show up on
 GtkWidget *dialog;
 GtkDialogFlags flags = GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT;
 dialog = gtk_dialog_new_with_buttons ("My dialog",
                                       main_app_window,
                                       flags,
                                       _("_OK"),
                                       GTK_RESPONSE_ACCEPT,
                                       _("_Cancel"),
                                       GTK_RESPONSE_REJECT,
                                       NULL);
title

Title of the dialog, or None

parent

Transient parent of the dialog, or None

flags

from DialogFlags

first_button_text

text to go in first button, or None

Returns

a new Dialog