pub struct EntryCompletion { /* private fields */ }Expand description
EntryCompletion is an auxiliary object to be used in conjunction with
Entry to provide the completion functionality. It implements the
CellLayout interface, to allow the user to add extra cells to the
TreeView with completion matches.
“Completion functionality” means that when the user modifies the text
in the entry, EntryCompletion checks which rows in the model match
the current content of the entry, and displays a list of matches.
By default, the matching is done by comparing the entry text
case-insensitively against the text column of the model (see
EntryCompletionExt::set_text_column()), but this can be overridden
with a custom match function (see EntryCompletionExt::set_match_func()).
When the user selects a completion, the content of the entry is
updated. By default, the content of the entry is replaced by the
text column of the model, but this can be overridden by connecting
to the match-selected signal and updating the
entry in the signal handler. Note that you should return true from
the signal handler to suppress the default behaviour.
To add completion functionality to an entry, use EntryExt::set_completion().
In addition to regular completion matches, which will be inserted into the
entry when they are selected, EntryCompletion also allows to display
“actions” in the popup window. Their appearance is similar to menuitems,
to differentiate them clearly from completion strings. When an action is
selected, the action-activated signal is emitted.
GtkEntryCompletion uses a TreeModelFilter model to represent the
subset of the entire model that is currently matching. While the
GtkEntryCompletion signals match-selected and
cursor-on-match take the original model and an
iter pointing to that model as arguments, other callbacks and signals
(such as GtkCellLayoutDataFuncs or apply-attributes)
will generally take the filter model as argument. As long as you are
only calling gtk_tree_model_get(), this will make no difference to
you. If for some reason, you need the original model, use
TreeModelFilterExt::model(). Don’t forget to use
TreeModelFilterExt::convert_iter_to_child_iter() to obtain a
matching iter.
Properties
cell-area
The CellArea used to layout cell renderers in the treeview column.
If no area is specified when creating the entry completion with
EntryCompletion::with_area() a horizontally oriented
CellAreaBox will be used.
Readable | Writeable | Construct Only
inline-completion
Determines whether the common prefix of the possible completions should be inserted automatically in the entry. Note that this requires text-column to be set, even if you are using a custom match function.
Readable | Writeable
inline-selection
Determines whether the possible completions on the popup will appear in the entry as you navigate through them.
Readable | Writeable
minimum-key-length
Readable | Writeable
model
Readable | Writeable
popup-completion
Determines whether the possible completions should be shown in a popup window.
Readable | Writeable
popup-set-width
Determines whether the completions popup window will be resized to the width of the entry.
Readable | Writeable
popup-single-match
Determines whether the completions popup window will shown
for a single possible completion. You probably want to set
this to false if you are using
[inline completion][GtkEntryCompletion–inline-completion].
Readable | Writeable
text-column
The column of the model containing the strings. Note that the strings must be UTF-8.
Readable | Writeable
Signals
action-activated
Gets emitted when an action is activated.
cursor-on-match
Gets emitted when a match from the cursor is on a match
of the list. The default behaviour is to replace the contents
of the entry with the contents of the text column in the row
pointed to by iter.
Note that model is the model that was passed to
EntryCompletionExt::set_model().
insert-prefix
Gets emitted when the inline autocompletion is triggered. The default behaviour is to make the entry display the whole prefix and select the newly inserted part.
Applications may connect to this signal in order to insert only a
smaller part of the prefix into the entry - e.g. the entry used in
the FileChooser inserts only the part of the prefix up to the
next ‘/’.
match-selected
Gets emitted when a match from the list is selected.
The default behaviour is to replace the contents of the
entry with the contents of the text column in the row
pointed to by iter.
Note that model is the model that was passed to
EntryCompletionExt::set_model().
no-matches
Gets emitted when the filter model has zero number of rows in completion_complete method. (In other words when GtkEntryCompletion is out of suggestions)
Implements
EntryCompletionExt, glib::ObjectExt, BuildableExt, CellLayoutExt, EntryCompletionExtManual, BuildableExtManual
Implementations
Sourceimpl EntryCompletion
impl EntryCompletion
pub const NONE: Option<&'static EntryCompletion> = None
Sourcepub fn new() -> EntryCompletion
pub fn new() -> EntryCompletion
Sourcepub fn with_area(area: &impl IsA<CellArea>) -> EntryCompletion
pub fn with_area(area: &impl IsA<CellArea>) -> EntryCompletion
Creates a new EntryCompletion object using the
specified area to layout cells in the underlying
TreeViewColumn for the drop-down menu.
area
the CellArea used to layout cells
Returns
A newly created EntryCompletion object
Sourcepub fn builder() -> EntryCompletionBuilder
pub fn builder() -> EntryCompletionBuilder
Creates a new builder-pattern struct instance to construct EntryCompletion objects.
This method returns an instance of EntryCompletionBuilder which can be used to create EntryCompletion objects.