pub struct EventControllerMotion { /* private fields */ }Available on crate feature
v3_24 only.Expand description
EventControllerMotion is an event controller meant for situations
where you need to track the position of the pointer.
This object was added in 3.24.
Signals
enter
Signals that the pointer has entered the widget.
leave
Signals that pointer has left the widget.
motion
Emitted when the pointer moves inside the widget.
Implements
Implementations
Sourceimpl EventControllerMotion
impl EventControllerMotion
Sourcepub fn new(widget: &impl IsA<Widget>) -> EventControllerMotion
pub fn new(widget: &impl IsA<Widget>) -> EventControllerMotion
Creates a new event controller that will handle motion events
for the given widget.
widget
a Widget
Returns
a new EventControllerMotion
Sourcepub fn connect_enter<F: Fn(&Self, f64, f64) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_enter<F: Fn(&Self, f64, f64) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcepub fn connect_leave<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_leave<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Signals that pointer has left the widget.
Sourcepub fn connect_motion<F: Fn(&Self, f64, f64) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_motion<F: Fn(&Self, f64, f64) + 'static>( &self, f: F, ) -> SignalHandlerId