pub struct FileChooser { /* private fields */ }Expand description
GtkWidget *toggle;
…
toggle = gtk_check_button_new_with_label (“Open file read-only”); gtk_widget_show (toggle); gtk_file_chooser_set_extra_widget (my_file_chooser, toggle); } ]|
If you want to set more than one extra widget in the file
chooser, you can a container such as a Box or a Grid
and include your widgets in it. Then, set the container as
the whole extra widget.
Properties
action
Readable | Writable
create-folders
Whether a file chooser not in FileChooserAction::Open mode
will offer the user to create new folders.
Readable | Writable
do-overwrite-confirmation
Whether a file chooser in FileChooserAction::Save mode
will present an overwrite confirmation dialog if the user
selects a file name that already exists.
Readable | Writable
extra-widget
Readable | Writable
filter
Readable | Writable
local-only
Readable | Writable
preview-widget
Readable | Writable
preview-widget-active
Readable | Writable
select-multiple
Readable | Writable
show-hidden
Readable | Writable
use-preview-label
Readable | Writable
Signals
confirm-overwrite
static GtkFileChooserConfirmation confirm_overwrite_callback (GtkFileChooser *chooser, gpointer data) { char *uri;
uri = gtk_file_chooser_get_uri (chooser);
if (is_uri_read_only (uri)) { if (user_wants_to_replace_read_only_file (uri)) return GTK_FILE_CHOOSER_CONFIRMATION_ACCEPT_FILENAME; else return GTK_FILE_CHOOSER_CONFIRMATION_SELECT_AGAIN; } else return GTK_FILE_CHOOSER_CONFIRMATION_CONFIRM; // fall back to the default dialog }
…
chooser = gtk_file_chooser_dialog_new (…);
gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE); g_signal_connect (chooser, “confirm-overwrite”, G_CALLBACK (confirm_overwrite_callback), NULL);
if (gtk_dialog_run (chooser) == GTK_RESPONSE_ACCEPT) save_to_file (gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser));
gtk_widget_destroy (chooser); ]|
current-folder-changed
This signal is emitted when the current folder in a FileChooser
changes. This can happen due to the user performing some action that
changes folders, such as selecting a bookmark or visiting a folder on the
file list. It can also happen as a result of calling a function to
explicitly change the current folder in a file chooser.
Normally you do not need to connect to this signal, unless you need to keep track of which folder a file chooser is showing.
See also: FileChooserExt::set_current_folder(),
FileChooserExt::current_folder(),
FileChooserExt::set_current_folder_uri(),
FileChooserExt::current_folder_uri().
file-activated
This signal is emitted when the user “activates” a file in the file
chooser. This can happen by double-clicking on a file in the file list, or
by pressing Enter.
Normally you do not need to connect to this signal. It is used internally
by FileChooserDialog to know when to activate the default button in the
dialog.
See also: FileChooserExt::filename(),
FileChooserExt::filenames(), FileChooserExt::uri(),
FileChooserExt::uris().
selection-changed
This signal is emitted when there is a change in the set of selected files
in a FileChooser. This can happen when the user modifies the selection
with the mouse or the keyboard, or when explicitly calling functions to
change the selection.
Normally you do not need to connect to this signal, as it is easier to wait for the file chooser to finish running, and then to get the list of selected files using the functions mentioned below.
See also: FileChooserExt::select_filename(),
FileChooserExt::unselect_filename(), FileChooserExt::filename(),
FileChooserExt::filenames(), FileChooserExt::select_uri(),
FileChooserExt::unselect_uri(), FileChooserExt::uri(),
FileChooserExt::uris().
update-preview
This signal is emitted when the preview in a file chooser should be regenerated. For example, this can happen when the currently selected file changes. You should use this signal if you want your file chooser to have a preview widget.
Once you have installed a preview widget with
FileChooserExt::set_preview_widget(), you should update it when this
signal is emitted. You can use the functions
FileChooserExt::preview_filename() or
FileChooserExt::preview_uri() to get the name of the file to preview.
Your widget may not be able to preview all kinds of files; your callback
must call FileChooserExt::set_preview_widget_active() to inform the file
chooser about whether the preview was generated successfully or not.
Please see the example code in [Using a Preview Widget][gtkfilechooser-preview].
See also: FileChooserExt::set_preview_widget(),
FileChooserExt::set_preview_widget_active(),
FileChooserExt::set_use_preview_label(),
FileChooserExt::preview_filename(),
FileChooserExt::preview_uri().
Implements
FileChooserExt, FileChooserExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl FileChooser
impl FileChooser
pub const NONE: Option<&'static FileChooser> = None