pub struct FileChooserNative { /* private fields */ }Expand description
FileChooserNative is an abstraction of a dialog box suitable
for use with “File/Open” or “File/Save as” commands. By default, this
just uses a FileChooserDialog to implement the actual dialog.
However, on certain platforms, such as Windows and macOS, the native platform
file chooser is used instead. When the application is running in a
sandboxed environment without direct filesystem access (such as Flatpak),
FileChooserNative may call the proper APIs (portals) to let the user
choose a file and make it available to the application.
While the API of FileChooserNative closely mirrors FileChooserDialog, the main
difference is that there is no access to any Window or Widget for the dialog.
This is required, as there may not be one in the case of a platform native dialog.
Showing, hiding and running the dialog is handled by the NativeDialog functions.
Typical usage ## {gtkfilechoosernative-typical-usage}
In the simplest of cases, you can the following code to use
FileChooserDialog to select a file for opening:
GtkFileChooserNative *native;
GtkFileChooserAction action = GTK_FILE_CHOOSER_ACTION_OPEN;
gint res;
native = gtk_file_chooser_native_new ("Open File",
parent_window,
action,
"_Open",
"_Cancel");
res = gtk_native_dialog_run (GTK_NATIVE_DIALOG (native));
if (res == GTK_RESPONSE_ACCEPT)
{
char *filename;
GtkFileChooser *chooser = GTK_FILE_CHOOSER (native);
filename = gtk_file_chooser_get_filename (chooser);
open_file (filename);
g_free (filename);
}
g_object_unref (native);To use a dialog for saving, you can use this:
GtkFileChooserNative *native;
GtkFileChooser *chooser;
GtkFileChooserAction action = GTK_FILE_CHOOSER_ACTION_SAVE;
gint res;
native = gtk_file_chooser_native_new ("Save File",
parent_window,
action,
"_Save",
"_Cancel");
chooser = GTK_FILE_CHOOSER (native);
gtk_file_chooser_set_do_overwrite_confirmation (chooser, TRUE);
if (user_edited_a_new_document)
gtk_file_chooser_set_current_name (chooser,
_("Untitled document"));
else
gtk_file_chooser_set_filename (chooser,
existing_filename);
res = gtk_native_dialog_run (GTK_NATIVE_DIALOG (native));
if (res == GTK_RESPONSE_ACCEPT)
{
char *filename;
filename = gtk_file_chooser_get_filename (chooser);
save_to_file (filename);
g_free (filename);
}
g_object_unref (native);For more information on how to best set up a file dialog, see FileChooserDialog.
Response Codes ## {gtkfilechooserdialognative-responses}
FileChooserNative inherits from NativeDialog, which means it
will return ResponseType::Accept if the user accepted, and
ResponseType::Cancel if he pressed cancel. It can also return
ResponseType::DeleteEvent if the window was unexpectedly closed.
Differences from FileChooserDialog ## {gtkfilechooserdialognative-differences}
There are a few things in the GtkFileChooser API that are not
possible to use with FileChooserNative, as such use would
prohibit the use of a native dialog.
There is no support for the signals that are emitted when the user navigates in the dialog, including:
You can also not use the methods that directly control user navigation:
If you need any of the above you will have to use FileChooserDialog directly.
No operations that change the the dialog work while the dialog is visible. Set all the properties that are required before showing the dialog.
Win32 details ## {gtkfilechooserdialognative-win32}
On windows the IFileDialog implementation (added in Windows Vista) is
used. It supports many of the features that FileChooserDialog
does, but there are some things it does not handle:
-
Extra widgets added with
FileChooserExt::set_extra_widget(). -
Use of custom previews by connecting to
update-preview. -
Any
FileFilteradded using a mimetype or custom filter.
If any of these features are used the regular FileChooserDialog
will be used in place of the native one.
Portal details ## {gtkfilechooserdialognative-portal}
When the org.freedesktop.portal.FileChooser portal is available on the session bus, it is used to bring up an out-of-process file chooser. Depending on the kind of session the application is running in, this may or may not be a GTK+ file chooser. In this situation, the following things are not supported and will be silently ignored:
-
Extra widgets added with
FileChooserExt::set_extra_widget(). -
Use of custom previews by connecting to
update-preview. -
Any
FileFilteradded with a custom filter.
macOS details ## {gtkfilechooserdialognative-macos}
On macOS the NSSavePanel and NSOpenPanel classes are used to provide native
file chooser dialogs. Some features provided by FileChooserDialog are
not supported:
-
Extra widgets added with
FileChooserExt::set_extra_widget(), unless the widget is an instance of GtkLabel, in which case the label text will be used to set the NSSavePanel message instance property. -
Use of custom previews by connecting to
update-preview. -
Any
FileFilteradded with a custom filter. -
Shortcut folders.
Properties
accept-label
The text used for the label on the accept button in the dialog, or
None to use the default text.
Readable | Writeable
cancel-label
The text used for the label on the cancel button in the dialog, or
None to use the default text.
Readable | Writeable
NativeDialog
modal
Whether the window should be modal with respect to its transient parent.
Readable | Writeable
title
The title of the dialog window
Readable | Writeable
transient-for
The transient parent of the dialog, or None for none.
Readable | Writeable | Construct
visible
Whether the window is currenlty visible.
Readable | Writeable
FileChooser
action
Readable | Writeable
create-folders
Whether a file chooser not in FileChooserAction::Open mode
will offer the user to create new folders.
Readable | Writeable
do-overwrite-confirmation
Whether a file chooser in FileChooserAction::Save mode
will present an overwrite confirmation dialog if the user
selects a file name that already exists.
Readable | Writeable
extra-widget
Readable | Writeable
filter
Readable | Writeable
local-only
Readable | Writeable
preview-widget
Readable | Writeable
preview-widget-active
Readable | Writeable
select-multiple
Readable | Writeable
show-hidden
Readable | Writeable
use-preview-label
Readable | Writeable
Implements
NativeDialogExt, glib::ObjectExt, FileChooserExt, NativeDialogExtManual, FileChooserExtManual
Implementations
Sourceimpl FileChooserNative
impl FileChooserNative
Sourcepub fn new(
title: Option<&str>,
parent: Option<&impl IsA<Window>>,
action: FileChooserAction,
accept_label: Option<&str>,
cancel_label: Option<&str>,
) -> FileChooserNative
pub fn new( title: Option<&str>, parent: Option<&impl IsA<Window>>, action: FileChooserAction, accept_label: Option<&str>, cancel_label: Option<&str>, ) -> FileChooserNative
Creates a new FileChooserNative.
title
Title of the native, or None
parent
Transient parent of the native, or None
action
Open or save mode for the dialog
accept_label
text to go in the accept button, or None for the default
cancel_label
text to go in the cancel button, or None for the default
Returns
a new FileChooserNative
Sourcepub fn builder() -> FileChooserNativeBuilder
pub fn builder() -> FileChooserNativeBuilder
Creates a new builder-pattern struct instance to construct FileChooserNative objects.
This method returns an instance of FileChooserNativeBuilder which can be used to create FileChooserNative objects.
Sourcepub fn accept_label(&self) -> Option<GString>
pub fn accept_label(&self) -> Option<GString>
Sourcepub fn cancel_label(&self) -> Option<GString>
pub fn cancel_label(&self) -> Option<GString>
Sourcepub fn set_accept_label(&self, accept_label: Option<&str>)
pub fn set_accept_label(&self, accept_label: Option<&str>)
Sets the custom label text for the accept button.
If characters in label are preceded by an underscore, they are underlined.
If you need a literal underscore character in a label, use “__” (two
underscores). The first underlined character represents a keyboard
accelerator called a mnemonic.
Pressing Alt and that key activates the button.
accept_label
custom label or None for the default
Sourcepub fn set_cancel_label(&self, cancel_label: Option<&str>)
pub fn set_cancel_label(&self, cancel_label: Option<&str>)
Sets the custom label text for the cancel button.
If characters in label are preceded by an underscore, they are underlined.
If you need a literal underscore character in a label, use “__” (two
underscores). The first underlined character represents a keyboard
accelerator called a mnemonic.
Pressing Alt and that key activates the button.
cancel_label
custom label or None for the default
pub fn connect_accept_label_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_cancel_label_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId