Gesture

Struct Gesture 

pub struct Gesture { /* private fields */ }
Gesture is the base object for gesture recognition, although this object is quite generalized to serve as a base for multi-touch gestures, it is suitable to implement single-touch and pointer-based gestures (using the special None gdk::EventSequence value for these).

The number of touches that a Gesture need to be recognized is controlled by the n-points property, if a gesture is keeping track of less or more than that number of sequences, it won’t check wether the gesture is recognized.

As soon as the gesture has the expected number of touches, the gesture will run the check signal regularly on input events until the gesture is recognized, the criteria to consider a gesture as “recognized” is left to Gesture subclasses.

A recognized gesture will then emit the following signals:

  • begin when the gesture is recognized.
  • A number of update, whenever an input event is processed.
  • end when the gesture is no longer recognized.

Event propagation

In order to receive events, a gesture needs to either set a propagation phase through EventControllerExt::set_propagation_phase(), or feed those manually through EventControllerExt::handle_event().

In the capture phase, events are propagated from the toplevel down to the target widget, and gestures that are attached to containers above the widget get a chance to interact with the event before it reaches the target.

After the capture phase, GTK+ emits the traditional button-press-event, button-release-event, touch-event, etc signals. Gestures with the PropagationPhase::Target phase are fed events from the default event handlers.

In the bubble phase, events are propagated up from the target widget to the toplevel, and gestures that are attached to containers above the widget get a chance to interact with events that have not been handled yet.

States of a sequence # {touch-sequence-states}

Whenever input interaction happens, a single event may trigger a cascade of GtkGestures, both across the parents of the widget receiving the event and in parallel within an individual widget. It is a responsibility of the widgets using those gestures to set the state of touch sequences accordingly in order to enable cooperation of gestures around the GdkEventSequences triggering those.

Within a widget, gestures can be grouped through GestureExt::group_with(), grouped gestures synchronize the state of sequences, so calling GestureExt::set_sequence_state() on one will effectively propagate the state throughout the group.

By default, all sequences start out in the EventSequenceState::None state, sequences in this state trigger the gesture event handler, but event propagation will continue unstopped by gestures.

If a sequence enters into the EventSequenceState::Denied state, the gesture group will effectively ignore the sequence, letting events go unstopped through the gesture, but the “slot” will still remain occupied while the touch is active.

If a sequence enters in the EventSequenceState::Claimed state, the gesture group will grab all interaction on the sequence, by:

  • Setting the same sequence to EventSequenceState::Denied on every other gesture group within the widget, and every gesture on parent widgets in the propagation chain.
  • calling cancel on every gesture in widgets underneath in the propagation chain.
  • Stopping event propagation after the gesture group handles the event.

Note: if a sequence is set early to EventSequenceState::Claimed on GDK_TOUCH_BEGIN/GDK_BUTTON_PRESS (so those events are captured before reaching the event widget, this implies PropagationPhase::Capture), one similar event will emulated if the sequence changes to EventSequenceState::Denied. This way event coherence is preserved before event propagation is unstopped again.

Sequence states can’t be changed freely, see GestureExt::set_sequence_state() to know about the possible lifetimes of a gdk::EventSequence.

Touchpad gestures

On the platforms that support it, Gesture will handle transparently touchpad gesture events. The only precautions users of Gesture should do to enable this support are:

This is an Abstract Base Class, you cannot instantiate it.

Properties

n-points

The number of touch points that trigger recognition on this gesture,

Readable | Writeable | Construct Only

window

If non-None, the gesture will only listen for events that happen on this gdk::Window, or a child of it.

Readable | Writeable

EventController

propagation-phase

The propagation phase at which this controller will handle events.

Readable | Writeable

widget

The widget receiving the GdkEvents that the controller will handle.

Readable | Writeable | Construct Only

Signals

begin

This signal is emitted when the gesture is recognized. This means the number of touch sequences matches n-points, and the check handler(s) returned true.

Note: These conditions may also happen when an extra touch (eg. a third touch on a 2-touches gesture) is lifted, in that situation sequence won’t pertain to the current set of active touches, so don’t rely on this being true.

cancel

This signal is emitted whenever a sequence is cancelled. This usually happens on active touches when EventControllerExt::reset() is called on gesture (manually, due to grabs…), or the individual sequence was claimed by parent widgets’ controllers (see GestureExt::set_sequence_state()).

gesture must forget everything about sequence as a reaction to this signal.

end

This signal is emitted when gesture either stopped recognizing the event sequences as something to be handled (the check handler returned false), or the number of touch sequences became higher or lower than n-points.

Note: sequence might not pertain to the group of sequences that were previously triggering recognition on gesture (ie. a just pressed touch sequence that exceeds n-points). This situation may be detected by checking through GestureExt::handles_sequence().

sequence-state-changed

This signal is emitted whenever a sequence state changes. See GestureExt::set_sequence_state() to know more about the expectable sequence lifetimes.

update

This signal is emitted whenever an event is handled while the gesture is recognized. sequence is guaranteed to pertain to the set of active touches.

Implements

GestureExt, EventControllerExt, glib::ObjectExt

Implementations

Source

impl Gesture

pub const NONE: Option<&'static Gesture> = None