GestureSingle

Struct GestureSingle 

pub struct GestureSingle { /* private fields */ }
GestureSingle is a subclass of Gesture, optimized (although not restricted) for dealing with mouse and single-touch gestures. Under interaction, these gestures stick to the first interacting sequence, which is accessible through GestureSingleExt::current_sequence() while the gesture is being interacted with.

By default gestures react to both GDK_BUTTON_PRIMARY and touch events, GestureSingleExt::set_touch_only() can be used to change the touch behavior. Callers may also specify a different mouse button number to interact with through GestureSingleExt::set_button(), or react to any mouse button by setting 0. While the gesture is active, the button being currently pressed can be known through GestureSingleExt::current_button().

Properties

button

Mouse button number to listen to, or 0 to listen for any button.

Readable | Writeable

exclusive

Whether the gesture is exclusive. Exclusive gestures only listen to pointer and pointer emulated events.

Readable | Writeable

touch-only

Whether the gesture handles only touch events.

Readable | Writeable

Gesture

n-points

The number of touch points that trigger recognition on this gesture,

Readable | Writeable | Construct Only

window

If non-None, the gesture will only listen for events that happen on this gdk::Window, or a child of it.

Readable | Writeable

EventController

propagation-phase

The propagation phase at which this controller will handle events.

Readable | Writeable

widget

The widget receiving the GdkEvents that the controller will handle.

Readable | Writeable | Construct Only

Implements

GestureSingleExt, GestureExt, EventControllerExt, glib::ObjectExt

Implementations

Source

impl GestureSingle

pub const NONE: Option<&'static GestureSingle> = None