pub struct IMContext { /* private fields */ }Expand description
IMContext defines the interface for GTK+ input methods. An input method
is used by GTK+ text input widgets like Entry to map from key events to
Unicode character strings.
The default input method can be set programmatically via the
gtk-im-module GtkSettings property. Alternatively, you may set
the GTK_IM_MODULE environment variable as documented in
[Running GTK+ Applications][gtk-running].
The Entry im-module and TextView im-module
properties may also be used to set input methods for specific widget
instances. For instance, a certain entry widget might be expected to contain
certain characters which would be easier to input with a certain input
method.
An input method may consume multiple key events in sequence and finally output the composed result. This is called preediting, and an input method may provide feedback about this process by displaying the intermediate composition states as preedit text. For instance, the default GTK+ input method implements the input of arbitrary Unicode code points by holding down the Control and Shift keys and then typing “U” followed by the hexadecimal digits of the code point. When releasing the Control and Shift keys, preediting ends and the character is inserted as text. Ctrl+Shift+u20AC for example results in the € sign.
Additional input methods can be made available for use by GTK+ widgets as
loadable modules. An input method module is a small shared library which
implements a subclass of IMContext or IMContextSimple and exports
these four functions:
⚠️ The following code is in C ⚠️
void im_module_init(GTypeModule *module);This function should register the GType of the IMContext subclass which
implements the input method by means of g_type_module_register_type(). Note
that g_type_register_static() cannot be used as the type needs to be
registered dynamically.
⚠️ The following code is in C ⚠️
void im_module_exit(void);Here goes any cleanup code your input method might require on module unload.
⚠️ The following code is in C ⚠️
void im_module_list(const GtkIMContextInfo ***contexts, int *n_contexts)
{
*contexts = info_list;
*n_contexts = G_N_ELEMENTS (info_list);
}This function returns the list of input methods provided by the module. The
example implementation above shows a common solution and simply returns a
pointer to statically defined array of GtkIMContextInfo items for each
provided input method.
⚠️ The following code is in C ⚠️
GtkIMContext * im_module_create(const gchar *context_id);This function should return a pointer to a newly created instance of the
IMContext subclass identified by context_id. The context ID is the same
as specified in the GtkIMContextInfo array returned by im_module_list().
After a new loadable input method module has been installed on the system,
the configuration file gtk.immodules needs to be
regenerated by [gtk-query-immodules-3.0][gtk-query-immodules-3.0],
in order for the new input method to become available to GTK+ applications.
This is an Abstract Base Class, you cannot instantiate it.
Properties
input-hints
Readable | Writeable
input-purpose
Readable | Writeable
Signals
commit
The ::commit signal is emitted when a complete input sequence has been entered by the user. This can be a single character immediately after a key press or the final result of preediting.
delete-surrounding
The ::delete-surrounding signal is emitted when the input method needs to delete all or part of the context surrounding the cursor.
preedit-changed
The ::preedit-changed signal is emitted whenever the preedit sequence
currently being entered has changed. It is also emitted at the end of
a preedit sequence, in which case
IMContextExt::preedit_string() returns the empty string.
preedit-end
The ::preedit-end signal is emitted when a preediting sequence has been completed or canceled.
preedit-start
The ::preedit-start signal is emitted when a new preediting sequence starts.
retrieve-surrounding
The ::retrieve-surrounding signal is emitted when the input method
requires the context surrounding the cursor. The callback should set
the input method surrounding context by calling the
IMContextExt::set_surrounding() method.
Implements
Implementations