pub struct IconTheme { /* private fields */ }Expand description
IconTheme provides a facility for looking up icons by name
and size. The main reason for using a name rather than simply
providing a filename is to allow different icons to be used
depending on what “icon theme” is selected
by the user. The operation of icon themes on Linux and Unix
follows the Icon Theme Specification
There is a fallback icon theme, named hicolor, where applications
should install their icons, but additional icon themes can be installed
as operating system vendors and users choose.
Named icons are similar to the deprecated [Stock Items][gtkstock], and the distinction between the two may be a bit confusing. A few things to keep in mind:
-
Stock images usually are used in conjunction with [Stock Items][gtkstock], such as
GTK_STOCK_OKorGTK_STOCK_OPEN. Named icons are easier to set up and therefore are more useful for new icons that an application wants to add, such as application icons or window icons. -
Stock images can only be loaded at the symbolic sizes defined by the
IconSizeenumeration, or by custom sizes defined bygtk_icon_size_register(), while named icons are more flexible and any pixel size can be specified. -
Because stock images are closely tied to stock items, and thus to actions in the user interface, stock images may come in multiple variants for different widget states or writing directions.
A good rule of thumb is that if there is a stock image for what
you want to use, use it, otherwise use a named icon. It turns
out that internally stock images are generally defined in
terms of one or more named icons. (An example of the
more than one case is icons that depend on writing direction;
GTK_STOCK_GO_FORWARD uses the two themed icons
“gtk-stock-go-forward-ltr” and “gtk-stock-go-forward-rtl”.)
In many cases, named themes are used indirectly, via Image
or stock items, rather than directly, but looking up icons
directly is also simple. The IconTheme object acts
as a database of all the icons in the current theme. You
can create new IconTheme objects, but it’s much more
efficient to use the standard icon theme for the gdk::Screen
so that the icon information is shared with other people
looking up icons.
⚠️ The following code is in C ⚠️
GError *error = NULL;
GtkIconTheme *icon_theme;
GdkPixbuf *pixbuf;
icon_theme = gtk_icon_theme_get_default ();
pixbuf = gtk_icon_theme_load_icon (icon_theme,
"my-icon-name", // icon name
48, // icon size
0, // flags
&error);
if (!pixbuf)
{
g_warning ("Couldn’t load icon: %s", error->message);
g_error_free (error);
}
else
{
// Use the pixbuf
g_object_unref (pixbuf);
}Signals
changed
Emitted when the current icon theme is switched or GTK+ detects that a change has occurred in the contents of the current icon theme.
Implements
Implementations
Sourceimpl IconTheme
impl IconTheme
pub const NONE: Option<&'static IconTheme> = None
Sourcepub fn new() -> IconTheme
pub fn new() -> IconTheme
Creates a new icon theme object. Icon theme objects are used
to lookup up an icon by name in a particular icon theme.
Usually, you’ll want to use default()
or for_screen() rather than creating
a new icon theme object for scratch.
Returns
the newly created IconTheme object.
Sourcepub fn default() -> Option<IconTheme>
pub fn default() -> Option<IconTheme>
Gets the icon theme for the default screen. See
for_screen().
Returns
A unique IconTheme associated with
the default screen. This icon theme is associated with
the screen and can be used as long as the screen
is open. Do not ref or unref it.
Sourcepub fn for_screen(screen: &Screen) -> Option<IconTheme>
pub fn for_screen(screen: &Screen) -> Option<IconTheme>
Gets the icon theme object associated with screen; if this
function has not previously been called for the given
screen, a new icon theme object will be created and
associated with the screen. Icon theme objects are
fairly expensive to create, so using this function
is usually a better choice than calling than new()
and setting the screen yourself; by using this function
a single icon theme object will be shared between users.
screen
Returns
A unique IconTheme associated with
the given screen. This icon theme is associated with
the screen and can be used as long as the screen
is open. Do not ref or unref it.