pub struct PaperSize { /* private fields */ }Expand description
GtkPaperSize handles paper sizes. It uses the standard called PWG 5101.1-2002 PWG: Standard for Media Standardized Names to name the paper sizes (and to get the data for the page sizes). In addition to standard paper sizes, GtkPaperSize allows to construct custom paper sizes with arbitrary dimensions.
The PaperSize object stores not only the dimensions (width
and height) of a paper size and its name, it also provides
default [print margins][print-margins].
Printing support has been added in GTK+ 2.10.
Implementations
Sourceimpl PaperSize
impl PaperSize
Sourcepub fn as_ptr(&self) -> *mut GtkPaperSize
pub fn as_ptr(&self) -> *mut GtkPaperSize
Return the inner pointer to the underlying C value.
Sourcepub unsafe fn from_glib_ptr_borrow<'a>(
ptr: *const *const GtkPaperSize,
) -> &'a Self
pub unsafe fn from_glib_ptr_borrow<'a>( ptr: *const *const GtkPaperSize, ) -> &'a Self
Borrows the underlying C value.
Sourcepub unsafe fn from_glib_ptr_borrow_mut<'a>(
ptr: *mut *mut GtkPaperSize,
) -> &'a mut Self
pub unsafe fn from_glib_ptr_borrow_mut<'a>( ptr: *mut *mut GtkPaperSize, ) -> &'a mut Self
Borrows the underlying C value mutably.
Sourceimpl PaperSize
impl PaperSize
Sourcepub fn new_custom(
name: &str,
display_name: &str,
width: f64,
height: f64,
unit: Unit,
) -> PaperSize
pub fn new_custom( name: &str, display_name: &str, width: f64, height: f64, unit: Unit, ) -> PaperSize
Creates a new PaperSize object with the
given parameters.
name
the paper name
display_name
the human-readable name
width
the paper width, in units of unit
height
the paper height, in units of unit
unit
the unit for width and height. not Unit::None.
Returns
a new PaperSize object, use gtk_paper_size_free()
to free it
Sourcepub fn from_gvariant(variant: &Variant) -> PaperSize
pub fn from_gvariant(variant: &Variant) -> PaperSize
Deserialize a paper size from an a{sv} variant in
the format produced by to_gvariant().
variant
an a{sv} glib::Variant
Returns
a new PaperSize object
Sourcepub fn from_ipp(ipp_name: &str, width: f64, height: f64) -> PaperSize
pub fn from_ipp(ipp_name: &str, width: f64, height: f64) -> PaperSize
Creates a new PaperSize object by using
IPP information.
If ipp_name is not a recognized paper name,
width and height are used to
construct a custom PaperSize object.
ipp_name
an IPP paper name
width
the paper width, in points
height
the paper height in points
Returns
a new PaperSize, use gtk_paper_size_free()
to free it
Sourcepub fn from_key_file(
key_file: &KeyFile,
group_name: Option<&str>,
) -> Result<PaperSize, Error>
pub fn from_key_file( key_file: &KeyFile, group_name: Option<&str>, ) -> Result<PaperSize, Error>
Reads a paper size from the group group_name in the key file
key_file.
key_file
the glib::KeyFile to retrieve the papersize from
group_name
the name of the group in the key file to read,
or None to read the first group
Returns
a new PaperSize object with the restored
paper size, or None if an error occurred
Sourcepub fn from_ppd(
ppd_name: &str,
ppd_display_name: &str,
width: f64,
height: f64,
) -> PaperSize
pub fn from_ppd( ppd_name: &str, ppd_display_name: &str, width: f64, height: f64, ) -> PaperSize
Creates a new PaperSize object by using
PPD information.
If ppd_name is not a recognized PPD paper name,
ppd_display_name, width and height are used to
construct a custom PaperSize object.
ppd_name
a PPD paper name
ppd_display_name
the corresponding human-readable name
width
the paper width, in points
height
the paper height in points
Returns
a new PaperSize, use gtk_paper_size_free()
to free it
Sourcepub fn default_bottom_margin(&self, unit: Unit) -> f64
pub fn default_bottom_margin(&self, unit: Unit) -> f64
Gets the default bottom margin for the PaperSize.
unit
the unit for the return value, not Unit::None
Returns
the default bottom margin
Sourcepub fn default_left_margin(&self, unit: Unit) -> f64
pub fn default_left_margin(&self, unit: Unit) -> f64
Gets the default left margin for the PaperSize.
unit
the unit for the return value, not Unit::None
Returns
the default left margin
Sourcepub fn default_right_margin(&self, unit: Unit) -> f64
pub fn default_right_margin(&self, unit: Unit) -> f64
Gets the default right margin for the PaperSize.
unit
the unit for the return value, not Unit::None
Returns
the default right margin
Sourcepub fn default_top_margin(&self, unit: Unit) -> f64
pub fn default_top_margin(&self, unit: Unit) -> f64
Gets the default top margin for the PaperSize.
unit
the unit for the return value, not Unit::None
Returns
the default top margin
Sourcepub fn display_name(&self) -> Option<GString>
pub fn display_name(&self) -> Option<GString>
Sourcepub fn height(&self, unit: Unit) -> f64
pub fn height(&self, unit: Unit) -> f64
Gets the paper height of the PaperSize, in
units of unit.
unit
the unit for the return value, not Unit::None
Returns
the paper height
Sourcepub fn width(&self, unit: Unit) -> f64
pub fn width(&self, unit: Unit) -> f64
Gets the paper width of the PaperSize, in
units of unit.
unit
the unit for the return value, not Unit::None
Returns
the paper width
Sourcepub fn to_gvariant(&mut self) -> Option<Variant>
pub fn to_gvariant(&mut self) -> Option<Variant>
Sourcepub fn to_key_file(&mut self, key_file: &KeyFile, group_name: &str)
pub fn to_key_file(&mut self, key_file: &KeyFile, group_name: &str)
This function adds the paper size from self to key_file.
key_file
the glib::KeyFile to save the paper size to
group_name
the group to add the settings to in key_file