Struct gtk::PlacesOpenFlags
source · [−]pub struct PlacesOpenFlags { /* private fields */ }Implementations
sourceimpl PlacesOpenFlags
impl PlacesOpenFlags
pub const NORMAL: PlacesOpenFlags = _
pub const NEW_TAB: PlacesOpenFlags = _
pub const NEW_WINDOW: PlacesOpenFlags = _
sourcepub const fn empty() -> PlacesOpenFlags
pub const fn empty() -> PlacesOpenFlags
Returns an empty set of flags
sourcepub const fn all() -> PlacesOpenFlags
pub const fn all() -> PlacesOpenFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<PlacesOpenFlags>
pub fn from_bits(bits: u32) -> Option<PlacesOpenFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> PlacesOpenFlags
pub const fn from_bits_truncate(bits: u32) -> PlacesOpenFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> PlacesOpenFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> PlacesOpenFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: PlacesOpenFlags) -> bool
pub const fn intersects(&self, other: PlacesOpenFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: PlacesOpenFlags) -> bool
pub const fn contains(&self, other: PlacesOpenFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: PlacesOpenFlags)
pub fn insert(&mut self, other: PlacesOpenFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: PlacesOpenFlags)
pub fn remove(&mut self, other: PlacesOpenFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: PlacesOpenFlags)
pub fn toggle(&mut self, other: PlacesOpenFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: PlacesOpenFlags, value: bool)
pub fn set(&mut self, other: PlacesOpenFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.