pub struct PrintOperation { /* private fields */ }Expand description
GtkPrintOperation is the high-level, portable printing API.
It looks a bit different than other GTK+ dialogs such as the
FileChooser, since some platforms don’t expose enough
infrastructure to implement a good print dialog. On such
platforms, GtkPrintOperation uses the native print dialog.
On platforms which do not provide a native print dialog, GTK+
uses its own, see GtkPrintUnixDialog.
The typical way to use the high-level printing API is to create
a GtkPrintOperation object with new() when
the user selects to print. Then you set some properties on it,
e.g. the page size, any PrintSettings from previous print
operations, the number of pages, the current page, etc.
Then you start the print operation by calling PrintOperationExt::run().
It will then show a dialog, let the user select a printer and
options. When the user finished the dialog various signals will
be emitted on the PrintOperation, the main one being
draw-page, which you are supposed to catch
and render the page on the provided PrintContext using Cairo.
The high-level printing API
⚠️ The following code is in C ⚠️
static GtkPrintSettings *settings = NULL;
static void
do_print (void)
{
GtkPrintOperation *print;
GtkPrintOperationResult res;
print = gtk_print_operation_new ();
if (settings != NULL)
gtk_print_operation_set_print_settings (print, settings);
g_signal_connect (print, "begin_print", G_CALLBACK (begin_print), NULL);
g_signal_connect (print, "draw_page", G_CALLBACK (draw_page), NULL);
res = gtk_print_operation_run (print, GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG,
GTK_WINDOW (main_window), NULL);
if (res == GTK_PRINT_OPERATION_RESULT_APPLY)
{
if (settings != NULL)
g_object_unref (settings);
settings = g_object_ref (gtk_print_operation_get_print_settings (print));
}
g_object_unref (print);
}By default GtkPrintOperation uses an external application to do
print preview. To implement a custom print preview, an application
must connect to the preview signal. The functions
PrintOperationPreviewExt::render_page(),
PrintOperationPreviewExt::end_preview() and
PrintOperationPreviewExt::is_selected()
are useful when implementing a print preview.
Properties
allow-async
Determines whether the print operation may run asynchronously or not.
Some systems don’t support asynchronous printing, but those that do
will return PrintOperationResult::InProgress as the status, and
emit the done signal when the operation is actually
done.
The Windows port does not support asynchronous operation at all (this
is unlikely to change). On other platforms, all actions except for
PrintOperationAction::Export support asynchronous operation.
Readable | Writeable
current-page
The current page in the document.
If this is set before PrintOperationExt::run(),
the user will be able to select to print only the current page.
Note that this only makes sense for pre-paginated documents.
Readable | Writeable
custom-tab-label
Used as the label of the tab containing custom widgets. Note that this property may be ignored on some platforms.
If this is None, GTK+ uses a default label.
Readable | Writeable
default-page-setup
The PageSetup used by default.
This page setup will be used by PrintOperationExt::run(),
but it can be overridden on a per-page basis by connecting
to the request-page-setup signal.
Readable | Writeable
embed-page-setup
If true, page size combo box and orientation combo box are embedded into page setup page.
Readable | Writeable
export-filename
The name of a file to generate instead of showing the print dialog. Currently, PDF is the only supported format.
The intended use of this property is for implementing “Export to PDF” actions.
“Print to PDF” support is independent of this and is done by letting the user pick the “Print to PDF” item from the list of printers in the print dialog.
Readable | Writeable
has-selection
Determines whether there is a selection in your application. This can allow your application to print the selection. This is typically used to make a “Selection” button sensitive.
Readable | Writeable
job-name
A string used to identify the job (e.g. in monitoring applications like eggcups).
If you don’t set a job name, GTK+ picks a default one by numbering successive print jobs.
Readable | Writeable
n-pages
The number of pages in the document.
This must be set to a positive number
before the rendering starts. It may be set in a
begin-print signal hander.
Note that the page numbers passed to the
request-page-setup and
draw-page signals are 0-based, i.e. if
the user chooses to print all pages, the last ::draw-page signal
will be for page n_pages - 1.
Readable | Writeable
n-pages-to-print
The number of pages that will be printed.
Note that this value is set during print preparation phase
(PrintStatus::Preparing), so this value should never be
get before the data generation phase (PrintStatus::GeneratingData).
You can connect to the status-changed signal
and call PrintOperationExt::n_pages_to_print() when
print status is PrintStatus::GeneratingData.
This is typically used to track the progress of print operation.
Readable
print-settings
The PrintSettings used for initializing the dialog.
Setting this property is typically used to re-establish
print settings from a previous print operation, see
PrintOperationExt::run().
Readable | Writeable
show-progress
Determines whether to show a progress dialog during the print operation.
Readable | Writeable
status
The status of the print operation.
Readable
status-string
A string representation of the status of the print operation.
The string is translated and suitable for displaying the print
status e.g. in a Statusbar.
See the status property for a status value that
is suitable for programmatic use.
Readable
support-selection
If true, the print operation will support print of selection.
This allows the print dialog to show a “Selection” button.
Readable | Writeable
track-print-status
If true, the print operation will try to continue report on
the status of the print job in the printer queues and printer.
This can allow your application to show things like “out of paper”
issues, and when the print job actually reaches the printer.
However, this is often implemented using polling, and should
not be enabled unless needed.
Readable | Writeable
unit
The transformation for the cairo context obtained from
PrintContext is set up in such a way that distances
are measured in units of unit.
Readable | Writeable
use-full-page
If true, the transformation for the cairo context obtained
from PrintContext puts the origin at the top left corner
of the page (which may not be the top left corner of the sheet,
depending on page orientation and the number of pages per sheet).
Otherwise, the origin is at the top left corner of the imageable
area (i.e. inside the margins).
Readable | Writeable
Signals
begin-print
Emitted after the user has finished changing print settings in the dialog, before the actual rendering starts.
A typical use for ::begin-print is to use the parameters from the
PrintContext and paginate the document accordingly, and then
set the number of pages with PrintOperationExt::set_n_pages().
create-custom-widget
Emitted when displaying the print dialog. If you return a widget in a handler for this signal it will be added to a custom tab in the print dialog. You typically return a container widget with multiple widgets in it.
The print dialog owns the returned widget, and its lifetime is not
controlled by the application. However, the widget is guaranteed
to stay around until the custom-widget-apply
signal is emitted on the operation. Then you can read out any
information you need from the widgets.
custom-widget-apply
Emitted right before begin-print if you added
a custom widget in the create-custom-widget handler.
When you get this signal you should read the information from the
custom widgets, as the widgets are not guaraneed to be around at a
later time.
done
Emitted when the print operation run has finished doing everything required for printing.
result gives you information about what happened during the run.
If result is PrintOperationResult::Error then you can call
gtk_print_operation_get_error() for more information.
If you enabled print status tracking then
PrintOperationExt::is_finished() may still return false
after done was emitted.
draw-page
Emitted for every page that is printed. The signal handler
must render the page_nr’s page onto the cairo context obtained
from context using PrintContext::cairo_context().
⚠️ The following code is in C ⚠️
static void
draw_page (GtkPrintOperation *operation,
GtkPrintContext *context,
gint page_nr,
gpointer user_data)
{
cairo_t *cr;
PangoLayout *layout;
gdouble width, text_height;
gint layout_height;
PangoFontDescription *desc;
cr = gtk_print_context_get_cairo_context (context);
width = gtk_print_context_get_width (context);
cairo_rectangle (cr, 0, 0, width, HEADER_HEIGHT);
cairo_set_source_rgb (cr, 0.8, 0.8, 0.8);
cairo_fill (cr);
layout = gtk_print_context_create_pango_layout (context);
desc = pango_font_description_from_string ("sans 14");
pango_layout_set_font_description (layout, desc);
pango_font_description_free (desc);
pango_layout_set_text (layout, "some text", -1);
pango_layout_set_width (layout, width * PANGO_SCALE);
pango_layout_set_alignment (layout, PANGO_ALIGN_CENTER);
pango_layout_get_size (layout, NULL, &layout_height);
text_height = (gdouble)layout_height / PANGO_SCALE;
cairo_move_to (cr, width / 2, (HEADER_HEIGHT - text_height) / 2);
pango_cairo_show_layout (cr, layout);
g_object_unref (layout);
}Use PrintOperationExt::set_use_full_page() and
PrintOperationExt::set_unit() before starting the print operation
to set up the transformation of the cairo context according to your
needs.
end-print
Emitted after all pages have been rendered.
A handler for this signal can clean up any resources that have
been allocated in the begin-print handler.
paginate
Emitted after the begin-print signal, but before
the actual rendering starts. It keeps getting emitted until a connected
signal handler returns true.
The ::paginate signal is intended to be used for paginating a document
in small chunks, to avoid blocking the user interface for a long
time. The signal handler should update the number of pages using
PrintOperationExt::set_n_pages(), and return true if the document
has been completely paginated.
If you don’t need to do pagination in chunks, you can simply do it all in the ::begin-print handler, and set the number of pages from there.
preview
Gets emitted when a preview is requested from the native dialog.
The default handler for this signal uses an external viewer application to preview.
To implement a custom print preview, an application must return
true from its handler for this signal. In order to use the
provided context for the preview implementation, it must be
given a suitable cairo context with PrintContext::set_cairo_context().
The custom preview implementation can use
PrintOperationPreviewExt::is_selected() and
PrintOperationPreviewExt::render_page() to find pages which
are selected for print and render them. The preview must be
finished by calling PrintOperationPreviewExt::end_preview()
(typically in response to the user clicking a close button).
request-page-setup
Emitted once for every page that is printed, to give
the application a chance to modify the page setup. Any changes
done to setup will be in force only for printing this page.
status-changed
Emitted at between the various phases of the print operation.
See PrintStatus for the phases that are being discriminated.
Use PrintOperationExt::status() to find out the current
status.
update-custom-widget
Emitted after change of selected printer. The actual page setup and print settings are passed to the custom widget, which can actualize itself according to this change.
PrintOperationPreview
got-page-size
The ::got-page-size signal is emitted once for each page that gets rendered to the preview.
A handler for this signal should update the context
according to page_setup and set up a suitable cairo
context, using PrintContext::set_cairo_context().
ready
The ::ready signal gets emitted once per preview operation, before the first page is rendered.
A handler for this signal can be used for setup tasks.
Implements
PrintOperationExt, glib::ObjectExt, PrintOperationPreviewExt
Implementations
Sourceimpl PrintOperation
impl PrintOperation
pub const NONE: Option<&'static PrintOperation> = None
Sourcepub fn new() -> PrintOperation
pub fn new() -> PrintOperation
Sourcepub fn builder() -> PrintOperationBuilder
pub fn builder() -> PrintOperationBuilder
Creates a new builder-pattern struct instance to construct PrintOperation objects.
This method returns an instance of PrintOperationBuilder which can be used to create PrintOperation objects.