RecentChooser

Struct RecentChooser 

pub struct RecentChooser { /* private fields */ }
RecentChooser is an interface that can be implemented by widgets displaying the list of recently used files. In GTK+, the main objects that implement this interface are RecentChooserWidget, RecentChooserDialog and RecentChooserMenu.

Recently used files are supported since GTK+ 2.10.

Properties

filter

The RecentFilter object to be used when displaying the recently used resources.

Readable | Writeable

limit

The maximum number of recently used resources to be displayed, or -1 to display all items.

Readable | Writeable

local-only

Whether this RecentChooser should display only local (file:) resources.

Readable | Writeable

recent-manager

The RecentManager instance used by the RecentChooser to display the list of recently used resources.

Writeable | Construct Only

select-multiple

Allow the user to select multiple resources.

Readable | Writeable

show-icons

Whether this RecentChooser should display an icon near the item.

Readable | Writeable

show-not-found

Whether this RecentChooser should display the recently used resources even if not present anymore. Setting this to false will perform a potentially expensive check on every local resource (every remote resource will always be displayed).

Readable | Writeable

show-private

Readable | Writeable

show-tips

Whether this RecentChooser should display a tooltip containing the full path of the recently used resources.

Readable | Writeable

sort-type

Sorting order to be used when displaying the recently used resources.

Readable | Writeable

Signals

item-activated

This signal is emitted when the user “activates” a recent item in the recent chooser. This can happen by double-clicking on an item in the recently used resources list, or by pressing Enter.

selection-changed

This signal is emitted when there is a change in the set of selected recently used resources. This can happen when a user modifies the selection with the mouse or the keyboard, or when explicitly calling functions to change the selection.

Implements

RecentChooserExt

Implementations

Source

impl RecentChooser

pub const NONE: Option<&'static RecentChooser> = None