Rectangle

Struct Rectangle 

pub struct Rectangle { /* private fields */ }
Defines the position and size of a rectangle. It is identical to cairo_rectangle_int_t.

Implementations

Source

impl Rectangle

pub fn as_ptr(&self) -> *mut GdkRectangle

pub unsafe fn from_glib_ptr_borrow<'a>( ptr: *const GdkRectangle, ) -> &'a Rectangle

Borrows the underlying C value.

pub unsafe fn from_glib_ptr_borrow_mut<'a>( ptr: *mut GdkRectangle, ) -> &'a mut Rectangle

Borrows the underlying C value mutably.

Source

impl Rectangle

pub fn intersect(&self, src2: &Rectangle) -> Option<Rectangle>

Calculates the intersection of two rectangles. It is allowed for dest to be the same as either self or src2. If the rectangles do not intersect, dest’s width and height is set to 0 and its x and y values are undefined. If you are only interested in whether the rectangles intersect, but not in the intersecting area itself, pass None for dest.

src2

a Rectangle

Returns

true if the rectangles intersect.

dest

return location for the intersection of self and src2, or None

pub fn union(&self, src2: &Rectangle) -> Rectangle

Calculates the union of two rectangles. The union of rectangles self and src2 is the smallest rectangle which includes both self and src2 within it. It is allowed for dest to be the same as either self or src2.

Note that this function does not ignore ‘empty’ rectangles (ie. with zero width or height).

src2

a Rectangle

Returns
dest

return location for the union of self and src2

Source

impl Rectangle

pub fn new(x: i32, y: i32, width: i32, height: i32) -> Rectangle

pub fn x(&self) -> i32

pub fn y(&self) -> i32

pub fn width(&self) -> i32

pub fn height(&self) -> i32