SelectionData

Struct SelectionData 

pub struct SelectionData { /* private fields */ }

Implementations

Source

impl SelectionData

pub fn as_ptr(&self) -> *mut GtkSelectionData

Return the inner pointer to the underlying C value.

pub unsafe fn from_glib_ptr_borrow<'a>( ptr: *const *const GtkSelectionData, ) -> &'a Self

Borrows the underlying C value.

pub unsafe fn from_glib_ptr_borrow_mut<'a>( ptr: *mut *mut GtkSelectionData, ) -> &'a mut Self

Borrows the underlying C value mutably.

Source

impl SelectionData

pub fn data_type(&self) -> Atom

Retrieves the data type of the selection.

Returns

the data type of the selection.

pub fn display(&self) -> Option<Display>

Retrieves the display of the selection.

Returns

the display of the selection.

pub fn format(&self) -> i32

Retrieves the format of the selection.

Returns

the format of the selection.

pub fn length(&self) -> i32

Retrieves the length of the raw data of the selection.

Returns

the length of the data of the selection.

pub fn pixbuf(&self) -> Option<Pixbuf>

Gets the contents of the selection data as a gdk_pixbuf::Pixbuf.

Returns

if the selection data contained a recognized image type and it could be converted to a gdk_pixbuf::Pixbuf, a newly allocated pixbuf is returned, otherwise None. If the result is non-None it must be freed with g_object_unref().

pub fn selection(&self) -> Atom

Retrieves the selection gdk::Atom of the selection data.

Returns

the selection gdk::Atom of the selection data.

pub fn target(&self) -> Atom

Retrieves the target of the selection.

Returns

the target of the selection.

pub fn targets(&self) -> Option<Vec<Atom>>

Gets the contents of self as an array of targets. This can be used to interpret the results of getting the standard TARGETS target that is always supplied for any selection.

Returns

true if self contains a valid array of targets, otherwise false.

targets

location to store an array of targets. The result stored here must be freed with g_free().

pub fn text(&self) -> Option<GString>

Gets the contents of the selection data as a UTF-8 string.

Returns

if the selection data contained a recognized text type and it could be converted to UTF-8, a newly allocated string containing the converted text, otherwise None. If the result is non-None it must be freed with g_free().

pub fn uris(&self) -> Vec<GString>

Gets the contents of the selection data as array of URIs.

Since 3.24.37, this may involve using the FileTransfer portal to send files between sandboxed apps.

Returns

if the selection data contains a list of URIs, a newly allocated None-terminated string array containing the URIs, otherwise None. If the result is non-None it must be freed with g_strfreev().

pub fn set(&self, type_: &Atom, format: i32, data: &[u8])

Stores new data into a SelectionData object. Should only be called from a selection handler callback. Zero-terminates the stored data.

type_

the type of selection data

format

format (number of bits in a unit)

data

pointer to the data (will be copied)

pub fn set_pixbuf(&self, pixbuf: &Pixbuf) -> bool

Sets the contents of the selection from a gdk_pixbuf::Pixbuf The pixbuf is converted to the form determined by self->target.

pixbuf

a gdk_pixbuf::Pixbuf

Returns

true if the selection was successfully set, otherwise false.

pub fn set_text(&self, str: &str) -> bool

Sets the contents of the selection from a UTF-8 encoded string. The string is converted to the form determined by self->target.

str

a UTF-8 string

len

the length of str, or -1 if str is nul-terminated.

Returns

true if the selection was successfully set, otherwise false.

pub fn set_uris(&self, uris: &[&str]) -> bool

Sets the contents of the selection from a list of URIs. The string is converted to the form determined by self->target.

Since 3.24.37, this may involve using the FileTransfer portal to send files between sandboxed apps.

uris

a None-terminated array of strings holding URIs

Returns

true if the selection was successfully set, otherwise false.

pub fn targets_include_image(&self, writable: bool) -> bool

Given a SelectionData object holding a list of targets, determines if any of the targets in targets can be used to provide a gdk_pixbuf::Pixbuf.

writable

whether to accept only targets for which GTK+ knows how to convert a pixbuf into the format

Returns

true if self holds a list of targets, and a suitable target for images is included, otherwise false.

pub fn targets_include_rich_text(&self, buffer: &impl IsA<TextBuffer>) -> bool

Given a SelectionData object holding a list of targets, determines if any of the targets in targets can be used to provide rich text.

buffer

a TextBuffer

Returns

true if self holds a list of targets, and a suitable target for rich text is included, otherwise false.

pub fn targets_include_text(&self) -> bool

Given a SelectionData object holding a list of targets, determines if any of the targets in targets can be used to provide text.

Returns

true if self holds a list of targets, and a suitable target for text is included, otherwise false.

pub fn targets_include_uri(&self) -> bool

Given a SelectionData object holding a list of targets, determines if any of the targets in targets can be used to provide a list or URIs.

Returns

true if self holds a list of targets, and a suitable target for URI lists is included, otherwise false.

Source

impl SelectionData

pub fn data(&self) -> Vec<u8>

Retrieves the raw data of the selection.

Returns

the raw data of the selection.