Settings

Struct Settings 

pub struct Settings { /* private fields */ }
GtkSettings provide a mechanism to share global settings between applications.

On the X window system, this sharing is realized by an XSettings manager that is usually part of the desktop environment, along with utilities that let the user change these settings. In the absence of an Xsettings manager, GTK+ reads default values for settings from settings.ini files in /etc/gtk-3.0, $XDG_CONFIG_DIRS/gtk-3.0 and $XDG_CONFIG_HOME/gtk-3.0. These files must be valid key files (see glib::KeyFile), and have a section called Settings. Themes can also provide default values for settings by installing a settings.ini file next to their gtk.css file.

Applications can override system-wide settings by setting the property of the GtkSettings object with [ObjectExt::set()][crate::glib::prelude::ObjectExt::set()]. This should be restricted to special cases though; GtkSettings are not meant as an application configuration facility. When doing so, you need to be aware that settings that are specific to individual widgets may not be available before the widget type has been realized at least once. The following example demonstrates a way to do this:

⚠️ The following code is in C ⚠️

  gtk_init (&argc, &argv);

  // make sure the type is realized
  g_type_class_unref (g_type_class_ref (GTK_TYPE_IMAGE_MENU_ITEM));

  g_object_set (gtk_settings_get_default (), "gtk-enable-animations", FALSE, NULL);

There is one GtkSettings instance per screen. It can be obtained with for_screen(), but in many cases, it is more convenient to use WidgetExt::settings(). default() returns the GtkSettings instance for the default screen.

Properties

color-hash

Holds a hash table representation of the gtk-color-scheme setting, mapping color names to GdkColors.

Readable

gtk-alternative-button-order

Readable | Writeable

gtk-alternative-sort-arrows

Controls the direction of the sort indicators in sorted list and tree views. By default an arrow pointing down means the column is sorted in ascending order. When set to true, this order will be inverted.

Readable | Writeable

gtk-application-prefer-dark-theme

Whether the application prefers to use a dark theme. If a GTK+ theme includes a dark variant, it will be used instead of the configured theme.

Some applications benefit from minimizing the amount of light pollution that interferes with the content. Good candidates for dark themes are photo and video editors that make the actual content get all the attention and minimize the distraction of the chrome.

Dark themes should not be used for documents, where large spaces are white/light and the dark chrome creates too much contrast (web browser, text editor…).

Readable | Writeable

gtk-auto-mnemonics

Whether mnemonics should be automatically shown and hidden when the user presses the mnemonic activator.

Readable | Writeable

gtk-button-images

Whether images should be shown on buttons

Readable | Writeable

gtk-can-change-accels

Whether menu accelerators can be changed by pressing a key over the menu item.

Readable | Writeable

gtk-color-palette

Palette to use in the deprecated color selector.

Readable | Writeable

gtk-color-scheme

A palette of named colors for use in themes. The format of the string is

name1: color1
name2: color2
...

Color names must be acceptable as identifiers in the [gtkrc][gtk3-Resource-Files] syntax, and color specifications must be in the format accepted by gdk_color_parse().

Note that due to the way the color tables from different sources are merged, color specifications will be converted to hexadecimal form when getting this property.

Starting with GTK+ 2.12, the entries can alternatively be separated by ‘;’ instead of newlines:

name1: color1; name2: color2; ...

Readable | Writeable

gtk-cursor-aspect-ratio

Readable | Writeable

Whether the cursor should blink.

Also see the gtk-cursor-blink-timeout setting, which allows more flexible control over cursor blinking.

Readable | Writeable

Readable | Writeable

Time after which the cursor stops blinking, in seconds. The timer is reset after each user interaction.

Setting this to zero has the same effect as setting gtk-cursor-blink to false.

Readable | Writeable

gtk-cursor-theme-name

Readable | Writeable

gtk-cursor-theme-size

Readable | Writeable

gtk-decoration-layout

This setting determines which buttons should be put in the titlebar of client-side decorated windows, and whether they should be placed at the left of right.

The format of the string is button names, separated by commas. A colon separates the buttons that should appear on the left from those on the right. Recognized button names are minimize, maximize, close, icon (the window icon) and menu (a menu button for the fallback app menu).

For example, “menu:minimize,maximize,close” specifies a menu on the left, and minimize, maximize and close buttons on the right.

Note that buttons will only be shown when they are meaningful. E.g. a menu button only appears when the desktop shell does not show the app menu, and a close button only appears on a window that can be closed.

Also note that the setting can be overridden with the decoration-layout property.

Readable | Writeable

gtk-dialogs-use-header

Whether builtin GTK+ dialogs such as the file chooser, the color chooser or the font chooser will use a header bar at the top to show action widgets, or an action area at the bottom.

This setting does not affect custom dialogs using GtkDialog directly, or message dialogs.

Readable | Writeable

gtk-dnd-drag-threshold

Readable | Writeable

gtk-double-click-distance

Readable | Writeable

gtk-double-click-time

Readable | Writeable

gtk-enable-accels

Whether menu items should have visible accelerators which can be activated.

Readable | Writeable

gtk-enable-animations

Readable | Writeable

gtk-enable-event-sounds

Whether to play any event sounds at all.

See the Sound Theme Specifications for more information on event sounds and sound themes.

GTK+ itself does not support event sounds, you have to use a loadable module like the one that comes with libcanberra.

Readable | Writeable

gtk-enable-input-feedback-sounds

Whether to play event sounds as feedback to user input.

See the Sound Theme Specifications for more information on event sounds and sound themes.

GTK+ itself does not support event sounds, you have to use a loadable module like the one that comes with libcanberra.

Readable | Writeable

gtk-enable-mnemonics

Whether labels and menu items should have visible mnemonics which can be activated.

Readable | Writeable

gtk-enable-primary-paste

Whether a middle click on a mouse should paste the ‘PRIMARY’ clipboard content at the cursor location.

Readable | Writeable

gtk-enable-tooltips

Whether tooltips should be shown on widgets.

Readable | Writeable

gtk-entry-password-hint-timeout

How long to show the last input character in hidden entries. This value is in milliseconds. 0 disables showing the last char. 600 is a good value for enabling it.

Readable | Writeable

gtk-entry-select-on-focus

Readable | Writeable

gtk-error-bell

When true, keyboard navigation and other input-related errors will cause a beep. Since the error bell is implemented using Window::beep(), the windowing system may offer ways to configure the error bell in many ways, such as flashing the window or similar visual effects.

Readable | Writeable

gtk-fallback-icon-theme

Name of a icon theme to fall back to.

Readable | Writeable

gtk-file-chooser-backend

Name of the GtkFileChooser backend to use by default.

Readable | Writeable

gtk-font-name

The default font to use. GTK+ uses the family name and size from this string.

Readable | Writeable

gtk-fontconfig-timestamp

Readable | Writeable

gtk-icon-sizes

A list of icon sizes. The list is separated by colons, and item has the form:

size-name = width , height

E.g. “gtk-menu=16,16:gtk-button=20,20:gtk-dialog=48,48”. GTK+ itself use the following named icon sizes: gtk-menu, gtk-button, gtk-small-toolbar, gtk-large-toolbar, gtk-dnd, gtk-dialog. Applications can register their own named icon sizes with gtk_icon_size_register().

Readable | Writeable

gtk-icon-theme-name

Readable | Writeable

gtk-im-module

Which IM (input method) module should be used by default. This is the input method that will be used if the user has not explicitly chosen another input method from the IM context menu. This also can be a colon-separated list of input methods, which GTK+ will try in turn until it finds one available on the system.

See IMContext.

Readable | Writeable

gtk-im-preedit-style

How to draw the input method preedit string.

Readable | Writeable

gtk-im-status-style

How to draw the input method statusbar.

Readable | Writeable

gtk-key-theme-name

Readable | Writeable

gtk-keynav-cursor-only

When true, keyboard navigation should be able to reach all widgets by using the cursor keys only. Tab, Shift etc. keys can’t be expected to be present on the used input device.

Readable | Writeable

gtk-keynav-use-caret

Whether GTK+ should make sure that text can be navigated with a caret, even if it is not editable. This is useful when using a screen reader.

Readable | Writeable

gtk-keynav-wrap-around

When true, some widgets will wrap around when doing keyboard navigation, such as menus, menubars and notebooks.

Readable | Writeable

gtk-label-select-on-focus

Readable | Writeable

gtk-long-press-time

The time for a button or touch press to be considered a “long press”.

Readable | Writeable

gtk-menu-bar-accel

Keybinding to activate the menu bar.

Readable | Writeable

gtk-menu-bar-popup-delay

Delay before the submenus of a menu bar appear.

Readable | Writeable

gtk-menu-images

Whether images should be shown in menu items

Readable | Writeable

gtk-menu-popdown-delay

The time before hiding a submenu when the pointer is moving towards the submenu.

Readable | Writeable

gtk-menu-popup-delay

Minimum time the pointer must stay over a menu item before the submenu appear.

Readable | Writeable

gtk-modules

Readable | Writeable

gtk-overlay-scrolling

Whether scrolled windows may use overlayed scrolling indicators. If this is set to false, scrolled windows will have permanent scrollbars.

Readable | Writeable

gtk-primary-button-warps-slider

If the value of this setting is true, clicking the primary button in a Range trough will move the slider, and hence set the range’s value, to the point that you clicked. If it is false, a primary click will cause the slider/value to move by the range’s page-size towards the point clicked.

Whichever action you choose for the primary button, the other action will be available by holding Shift and primary-clicking, or (since GTK+ 3.22.25) clicking the middle mouse button.

Readable | Writeable

gtk-print-backends

A comma-separated list of print backends to use in the print dialog. Available print backends depend on the GTK+ installation, and may include “file”, “cups”, “lpr” or “papi”.

Readable | Writeable

gtk-print-preview-command

A command to run for displaying the print preview. The command should contain a f placeholder, which will get replaced by the path to the pdf file. The command may also contain a s placeholder, which will get replaced by the path to a file containing the print settings in the format produced by PrintSettings::to_file().

The preview application is responsible for removing the pdf file and the print settings file when it is done.

Readable | Writeable

gtk-recent-files-enabled

Whether GTK+ should keep track of items inside the recently used resources list. If set to false, the list will always be empty.

Readable | Writeable

gtk-recent-files-limit

The number of recently used files that should be displayed by default by RecentChooser implementations and by the FileChooser. A value of -1 means every recently used file stored.

Readable | Writeable

gtk-recent-files-max-age

The maximum age, in days, of the items inside the recently used resources list. Items older than this setting will be excised from the list. If set to 0, the list will always be empty; if set to -1, no item will be removed.

Readable | Writeable

gtk-scrolled-window-placement

Where the contents of scrolled windows are located with respect to the scrollbars, if not overridden by the scrolled window’s own placement.

Readable | Writeable

gtk-shell-shows-app-menu

Readable | Writeable

gtk-shell-shows-desktop

Readable | Writeable

gtk-shell-shows-menubar

Readable | Writeable

gtk-show-input-method-menu

Readable | Writeable

gtk-show-unicode-menu

Readable | Writeable

gtk-sound-theme-name

The XDG sound theme to use for event sounds.

See the Sound Theme Specifications for more information on event sounds and sound themes.

GTK+ itself does not support event sounds, you have to use a loadable module like the one that comes with libcanberra.

Readable | Writeable

gtk-split-cursor

Readable | Writeable

gtk-theme-name

Readable | Writeable

gtk-timeout-expand

Readable | Writeable

gtk-timeout-initial

Readable | Writeable

gtk-timeout-repeat

Readable | Writeable

gtk-titlebar-double-click

This setting determines the action to take when a double-click occurs on the titlebar of client-side decorated windows.

Recognized actions are minimize, toggle-maximize, menu, lower or none.

Readable | Writeable

gtk-titlebar-middle-click

This setting determines the action to take when a middle-click occurs on the titlebar of client-side decorated windows.

Recognized actions are minimize, toggle-maximize, menu, lower or none.

Readable | Writeable

gtk-titlebar-right-click

This setting determines the action to take when a right-click occurs on the titlebar of client-side decorated windows.

Recognized actions are minimize, toggle-maximize, menu, lower or none.

Readable | Writeable

gtk-toolbar-icon-size

The size of icons in default toolbars.

Readable | Writeable

gtk-toolbar-style

The size of icons in default toolbars.

Readable | Writeable

gtk-tooltip-browse-mode-timeout

Amount of time, in milliseconds, after which the browse mode will be disabled.

See gtk-tooltip-browse-timeout for more information about browse mode.

Readable | Writeable

gtk-tooltip-browse-timeout

Controls the time after which tooltips will appear when browse mode is enabled, in milliseconds.

Browse mode is enabled when the mouse pointer moves off an object where a tooltip was currently being displayed. If the mouse pointer hits another object before the browse mode timeout expires (see gtk-tooltip-browse-mode-timeout), it will take the amount of milliseconds specified by this setting to popup the tooltip for the new object.

Readable | Writeable

gtk-tooltip-timeout

Time, in milliseconds, after which a tooltip could appear if the cursor is hovering on top of a widget.

Readable | Writeable

gtk-touchscreen-mode

When true, there are no motion notify events delivered on this screen, and widgets can’t use the pointer hovering them for any essential functionality.

Readable | Writeable

gtk-visible-focus

Whether ‘focus rectangles’ should be always visible, never visible, or hidden until the user starts to use the keyboard.

Readable | Writeable

gtk-xft-antialias

Readable | Writeable

gtk-xft-dpi

Readable | Writeable

gtk-xft-hinting

Readable | Writeable

gtk-xft-hintstyle

Readable | Writeable

gtk-xft-rgba

Readable | Writeable

Implements

GtkSettingsExt, glib::ObjectExt, StyleProviderExt

Implementations

Source

impl Settings

pub const NONE: Option<&'static Settings> = None

pub fn default() -> Option<Settings>

Gets the Settings object for the default GDK screen, creating it if necessary. See for_screen().

Returns

a Settings object. If there is no default screen, then returns None.

pub fn for_screen(screen: &Screen) -> Option<Settings>

Gets the Settings object for screen, creating it if necessary.

screen

a gdk::Screen.

Returns

a Settings object.