pub struct TargetEntry { /* private fields */ }Expand description
A TargetEntry represents a single type of
data than can be supplied for by a widget for a selection
or for supplied or received during drag-and-drop.
Implementations
Sourceimpl TargetEntry
impl TargetEntry
Sourcepub fn new(target: &str, flags: TargetFlags, info: u32) -> TargetEntry
pub fn new(target: &str, flags: TargetFlags, info: u32) -> TargetEntry
Makes a new TargetEntry.
target
String identifier for target
flags
Set of flags, see TargetFlags
info
an ID that will be passed back to the application
Returns
a pointer to a new TargetEntry.
Free with gtk_target_entry_free()
pub fn target(&self) -> &str
pub fn flags(&self) -> TargetFlags
pub fn info(&self) -> u32