TargetList

Struct TargetList 

pub struct TargetList { /* private fields */ }
A TargetList-struct is a reference counted list of GtkTargetPair and should be treated as opaque.

Implementations

Source

impl TargetList

pub fn as_ptr(&self) -> *mut GtkTargetList

Return the inner pointer to the underlying C value.

pub unsafe fn from_glib_ptr_borrow<'a>( ptr: *const *const GtkTargetList, ) -> &'a Self

Borrows the underlying C value.

Source

impl TargetList

pub fn add(&self, target: &Atom, flags: u32, info: u32)

Appends another target to a TargetList.

target

the interned atom representing the target

flags

the flags for this target

info

an ID that will be passed back to the application

pub fn add_image_targets(&self, info: u32, writable: bool)

Appends the image targets supported by SelectionData to the target list. All targets are added with the same info.

info

an ID that will be passed back to the application

writable

whether to add only targets for which GTK+ knows how to convert a pixbuf into the format

pub fn add_rich_text_targets( &self, info: u32, deserializable: bool, buffer: &impl IsA<TextBuffer>, )

Appends the rich text targets registered with gtk_text_buffer_register_serialize_format() or gtk_text_buffer_register_deserialize_format() to the target list. All targets are added with the same info.

info

an ID that will be passed back to the application

deserializable

if true, then deserializable rich text formats will be added, serializable formats otherwise.

buffer

a TextBuffer.

pub fn add_text_targets(&self, info: u32)

Appends the text targets supported by SelectionData to the target list. All targets are added with the same info.

info

an ID that will be passed back to the application

pub fn add_uri_targets(&self, info: u32)

Appends the URI targets supported by SelectionData to the target list. All targets are added with the same info.

Since 3.24.37, this includes the application/vnd.portal.files target when possible, to allow sending files between sandboxed apps via the FileTransfer portal.

info

an ID that will be passed back to the application

pub fn find(&self, target: &Atom) -> Option<u32>

Looks up a given target in a TargetList.

target

an interned atom representing the target to search for

Returns

true if the target was found, otherwise false

info

a pointer to the location to store application info for target, or None

pub fn remove(&self, target: &Atom)

Removes a target from a target list.

target

the interned atom representing the target

Source

impl TargetList

pub fn new(targets: &[TargetEntry]) -> Self

Creates a new TargetList from an array of TargetEntry.

targets

Pointer to an array of TargetEntry

Returns

the new TargetList.