TextAttributes

Struct TextAttributes 

pub struct TextAttributes { /* private fields */ }
Using TextAttributes directly should rarely be necessary. It’s primarily useful with TextIter::is_attributes(). As with most GTK+ structs, the fields in this struct should only be read, never modified directly.

Implementations

Source

impl TextAttributes

pub fn as_ptr(&self) -> *mut GtkTextAttributes

Return the inner pointer to the underlying C value.

pub unsafe fn from_glib_ptr_borrow<'a>( ptr: *const *const GtkTextAttributes, ) -> &'a Self

Borrows the underlying C value.

Source

impl TextAttributes

pub fn new() -> TextAttributes

Creates a TextAttributes, which describes a set of properties on some text.

Returns

a new TextAttributes, free with gtk_text_attributes_unref().

pub fn copy(&self) -> Option<TextAttributes>

pub fn copy_values(&self, dest: &TextAttributes)

Copies the values from self to dest so that dest has the same values as self. Frees existing values in dest.

dest

another TextAttributes