pub struct TextMark { /* private fields */ }Expand description
You may wish to begin by reading the text widget conceptual overview which gives an overview of all the objects and data types related to the text widget and how they work together.
A TextMark is like a bookmark in a text buffer; it preserves a position in
the text. You can convert the mark to an iterator using
TextBufferExt::iter_at_mark(). Unlike iterators, marks remain valid across
buffer mutations, because their behavior is defined when text is inserted or
deleted. When text containing a mark is deleted, the mark remains in the
position originally occupied by the deleted text. When text is inserted at a
mark, a mark with “left gravity” will be moved to the
beginning of the newly-inserted text, and a mark with “right
gravity” will be moved to the end.
Note that “left” and “right” here refer to logical direction (left is the toward the start of the buffer); in some languages such as Hebrew the logically-leftmost text is not actually on the left when displayed.
Marks are reference counted, but the reference count only controls the validity
of the memory; marks can be deleted from the buffer at any time with
TextBufferExt::delete_mark(). Once deleted from the buffer, a mark is
essentially useless.
Marks optionally have names; these can be convenient to avoid passing the
TextMark object around.
Marks are typically created using the TextBufferExt::create_mark() function.
Properties
left-gravity
Whether the mark has left gravity. When text is inserted at the mark’s current location, if the mark has left gravity it will be moved to the left of the newly-inserted text, otherwise to the right.
Readable | Writeable | Construct Only
name
The name of the mark or None if the mark is anonymous.
Readable | Writeable | Construct Only
Implements
Implementations
Sourceimpl TextMark
impl TextMark
pub const NONE: Option<&'static TextMark> = None
Sourcepub fn new(name: Option<&str>, left_gravity: bool) -> TextMark
pub fn new(name: Option<&str>, left_gravity: bool) -> TextMark
Creates a text mark. Add it to a buffer using TextBufferExt::add_mark().
If name is None, the mark is anonymous; otherwise, the mark can be
retrieved by name using TextBufferExt::mark(). If a mark has left
gravity, and text is inserted at the mark’s current location, the mark
will be moved to the left of the newly-inserted text. If the mark has
right gravity (left_gravity = false), the mark will end up on the
right of newly-inserted text. The standard left-to-right cursor is a
mark with right gravity (when you type, the cursor stays on the right
side of the text you’re typing).
name
mark name or None
left_gravity
whether the mark should have left gravity
Returns
new TextMark
Sourcepub fn builder() -> TextMarkBuilder
pub fn builder() -> TextMarkBuilder
Creates a new builder-pattern struct instance to construct TextMark objects.
This method returns an instance of TextMarkBuilder which can be used to create TextMark objects.