pub struct TextTag { /* private fields */ }Expand description
You may wish to begin by reading the text widget conceptual overview which gives an overview of all the objects and data types related to the text widget and how they work together.
Tags should be in the TextTagTable for a given TextBuffer
before using them with that buffer.
gtk_text_buffer_create_tag() is the best way to create tags.
See “gtk3-demo” for numerous examples.
For each property of TextTag, there is a “set” property, e.g.
“font-set” corresponds to “font”. These “set” properties reflect
whether a property has been set or not.
They are maintained by GTK+ and you should not set them independently.
Properties
accumulative-margin
Whether the margins accumulate or override each other.
When set to true the margins of this tag are added to the margins
of any other non-accumulative margins present. When set to false
the margins override one another (the default).
Readable | Writable
background
Writable
background-full-height
Readable | Writable
background-full-height-set
Readable | Writable
background-gdk
Background color as a GdkColor.
Readable | Writable
background-rgba
Background color as a gdk::RGBA.
Readable | Writable
background-set
Readable | Writable
direction
Readable | Writable
editable
Readable | Writable
editable-set
Readable | Writable
fallback
Whether font fallback is enabled.
When set to true, other fonts will be substituted
where the current font is missing glyphs.
Readable | Writable
fallback-set
Readable | Writable
family
Readable | Writable
family-set
Readable | Writable
font
Font description as string, e.g. "Sans Italic 12".
Note that the initial value of this property depends on
the internals of pango::FontDescription.
Readable | Writable
font-desc
Readable | Writable
font-features
OpenType font features, as a string.
Readable | Writable
font-features-set
Readable | Writable
foreground
Writable
foreground-gdk
Foreground color as a GdkColor.
Readable | Writable
foreground-rgba
Foreground color as a gdk::RGBA.
Readable | Writable
foreground-set
Readable | Writable
indent
Readable | Writable
indent-set
Readable | Writable
invisible
Whether this text is hidden.
Note that there may still be problems with the support for invisible text, in particular when navigating programmatically inside a buffer containing invisible segments.
Readable | Writable
invisible-set
Readable | Writable
justification
Readable | Writable
justification-set
Readable | Writable
language
The language this text is in, as an ISO code. Pango can use this as a hint when rendering the text. If not set, an appropriate default will be used.
Note that the initial value of this property depends on the current
locale, see also default_language().
Readable | Writable
language-set
Readable | Writable
left-margin
Readable | Writable
left-margin-set
Readable | Writable
letter-spacing
Extra spacing between graphemes, in Pango units.
Readable | Writable
letter-spacing-set
Readable | Writable
name
Readable | Writable | Construct Only
paragraph-background
The paragraph background color as a string.
Writable
paragraph-background-gdk
The paragraph background color as a GdkColor.
Readable | Writable
paragraph-background-rgba
The paragraph background color as a gdk::RGBA.
Readable | Writable
paragraph-background-set
Readable | Writable
pixels-above-lines
Readable | Writable
pixels-above-lines-set
Readable | Writable
pixels-below-lines
Readable | Writable
pixels-below-lines-set
Readable | Writable
pixels-inside-wrap
Readable | Writable
pixels-inside-wrap-set
Readable | Writable
right-margin
Readable | Writable
right-margin-set
Readable | Writable
rise
Readable | Writable
rise-set
Readable | Writable
scale
Readable | Writable
scale-set
Readable | Writable
size
Readable | Writable
size-points
Readable | Writable
size-set
Readable | Writable
stretch
Readable | Writable
stretch-set
Readable | Writable
strikethrough
Readable | Writable
strikethrough-rgba
This property modifies the color of strikeouts. If not set, strikeouts will use the forground color.
Readable | Writable
strikethrough-rgba-set
If the strikethrough-rgba property has been set.
Readable | Writable
strikethrough-set
Readable | Writable
style
Readable | Writable
style-set
Readable | Writable
tabs
Readable | Writable
tabs-set
Readable | Writable
underline
Readable | Writable
underline-rgba
This property modifies the color of underlines. If not set, underlines will use the forground color.
If underline is set to pango::Underline::Error, an alternate
color may be applied instead of the foreground. Setting this property
will always override those defaults.
Readable | Writable
underline-rgba-set
If the underline-rgba property has been set.
Readable | Writable
underline-set
Readable | Writable
variant
Readable | Writable
variant-set
Readable | Writable
weight
Readable | Writable
weight-set
Readable | Writable
wrap-mode
Readable | Writable
wrap-mode-set
Readable | Writable
Signals
event
The ::event signal is emitted when an event occurs on a region of the buffer marked with this tag.
Implements
TextTagExt, [trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl TextTag
impl TextTag
pub const NONE: Option<&'static TextTag> = None
Sourcepub fn builder() -> TextTagBuilder
pub fn builder() -> TextTagBuilder
Creates a new builder-pattern struct instance to construct TextTag objects.
This method returns an instance of TextTagBuilder which can be used to create TextTag objects.