pub struct TextTagTable { /* private fields */ }Expand description
You may wish to begin by reading the text widget conceptual overview which gives an overview of all the objects and data types related to the text widget and how they work together.
GtkTextTagTables as GtkBuildable
The GtkTextTagTable implementation of the GtkBuildable interface
supports adding tags by specifying “tag” as the “type” attribute
of a <child> element.
An example of a UI definition fragment specifying tags:
⚠️ The following code is in xml ⚠️
<object class="GtkTextTagTable">
<child type="tag">
<object class="GtkTextTag"/>
</child>
</object>Signals
tag-added
tag-changed
tag-removed
Implements
TextTagTableExt, glib::ObjectExt, BuildableExt, BuildableExtManual
Implementations
Sourceimpl TextTagTable
impl TextTagTable
pub const NONE: Option<&'static TextTagTable> = None
Sourcepub fn new() -> TextTagTable
pub fn new() -> TextTagTable