Tooltip

Struct Tooltip 

pub struct Tooltip { /* private fields */ }
Basic tooltips can be realized simply by using WidgetExt::set_tooltip_text() or WidgetExt::set_tooltip_markup() without any explicit tooltip object.

When you need a tooltip with a little more fancy contents, like adding an image, or you want the tooltip to have different contents per TreeView row or cell, you will have to do a little more work:

  • Set the has-tooltip property to true, this will make GTK+ monitor the widget for motion and related events which are needed to determine when and where to show a tooltip.

  • Connect to the query-tooltip signal. This signal will be emitted when a tooltip is supposed to be shown. One of the arguments passed to the signal handler is a GtkTooltip object. This is the object that we are about to display as a tooltip, and can be manipulated in your callback using functions like set_icon(). There are functions for setting the tooltip’s markup, setting an image from a named icon, or even putting in a custom widget.

Return true from your query-tooltip handler. This causes the tooltip to be show. If you return false, it will not be shown.

In the probably rare case where you want to have even more control over the tooltip that is about to be shown, you can set your own Window which will be used as tooltip window. This works as follows:

Implements

glib::ObjectExt

Implementations

Source

impl Tooltip

pub fn set_custom(&self, custom_widget: Option<&impl IsA<Widget>>)

Replaces the widget packed into the tooltip with custom_widget. custom_widget does not get destroyed when the tooltip goes away. By default a box with a Image and Label is embedded in the tooltip, which can be configured using set_markup() and set_icon().

custom_widget

a Widget, or None to unset the old custom widget.

pub fn set_icon(&self, pixbuf: Option<&Pixbuf>)

Sets the icon of the tooltip (which is in front of the text) to be pixbuf. If pixbuf is None, the image will be hidden.

pixbuf

a gdk_pixbuf::Pixbuf, or None

pub fn set_icon_from_gicon( &self, gicon: Option<&impl IsA<Icon>>, size: IconSize, )

Sets the icon of the tooltip (which is in front of the text) to be the icon indicated by gicon with the size indicated by size. If gicon is None, the image will be hidden.

gicon

a gio::Icon representing the icon, or None

size

a stock icon size (IconSize)

pub fn set_icon_from_icon_name(&self, icon_name: Option<&str>, size: IconSize)

Sets the icon of the tooltip (which is in front of the text) to be the icon indicated by icon_name with the size indicated by size. If icon_name is None, the image will be hidden.

icon_name

an icon name, or None

size

a stock icon size (IconSize)

pub fn set_markup(&self, markup: Option<&str>)

Sets the text of the tooltip to be markup, which is marked up with the [Pango text markup language][PangoMarkupFormat]. If markup is None, the label will be hidden.

markup

a markup string (see [Pango markup format][PangoMarkupFormat]) or None

pub fn set_text(&self, text: Option<&str>)

Sets the text of the tooltip to be text. If text is None, the label will be hidden. See also set_markup().

text

a text string or None

pub fn set_tip_area(&self, rect: &Rectangle)

Sets the area of the widget, where the contents of this tooltip apply, to be rect (in widget coordinates). This is especially useful for properly setting tooltips on TreeView rows and cells, GtkIconViews, etc.

For setting tooltips on TreeView, please refer to the convenience functions for this: TreeViewExt::set_tooltip_row() and TreeViewExt::set_tooltip_cell().

rect

a gdk::Rectangle

pub fn trigger_tooltip_query(display: &Display)

Triggers a new tooltip query on display, in order to update the current visible tooltip, or to show/hide the current tooltip. This function is useful to call when, for example, the state of the widget changed by a key press.

display

a gdk::Display