pub struct Tooltip { /* private fields */ }Expand description
Basic tooltips can be realized simply by using WidgetExt::set_tooltip_text()
or WidgetExt::set_tooltip_markup() without any explicit tooltip object.
When you need a tooltip with a little more fancy contents, like adding an
image, or you want the tooltip to have different contents per TreeView
row or cell, you will have to do a little more work:
-
Set the
has-tooltipproperty totrue, this will make GTK+ monitor the widget for motion and related events which are needed to determine when and where to show a tooltip. -
Connect to the
query-tooltipsignal. This signal will be emitted when a tooltip is supposed to be shown. One of the arguments passed to the signal handler is a GtkTooltip object. This is the object that we are about to display as a tooltip, and can be manipulated in your callback using functions likeset_icon(). There are functions for setting the tooltip’s markup, setting an image from a named icon, or even putting in a custom widget.
Return true from your query-tooltip handler. This causes the tooltip to be
show. If you return false, it will not be shown.
In the probably rare case where you want to have even more control over the
tooltip that is about to be shown, you can set your own Window which
will be used as tooltip window. This works as follows:
-
Set
has-tooltipand connect toquery-tooltipas before. UseWidgetExt::set_tooltip_window()to set aWindowcreated by you as tooltip window. -
In the
query-tooltipcallback you can access your window usingWidgetExt::tooltip_window()and manipulate as you wish. The semantics of the return value are exactly as before, returntrueto show the window,falseto not show it.
Implements
Implementations
Sourceimpl Tooltip
impl Tooltip
Sourcepub fn set_custom(&self, custom_widget: Option<&impl IsA<Widget>>)
pub fn set_custom(&self, custom_widget: Option<&impl IsA<Widget>>)
Replaces the widget packed into the tooltip with
custom_widget. custom_widget does not get destroyed when the tooltip goes
away.
By default a box with a Image and Label is embedded in
the tooltip, which can be configured using set_markup()
and set_icon().
custom_widget
Sourcepub fn set_icon(&self, pixbuf: Option<&Pixbuf>)
pub fn set_icon(&self, pixbuf: Option<&Pixbuf>)
Sets the icon of the tooltip (which is in front of the text) to be
pixbuf. If pixbuf is None, the image will be hidden.
pixbuf
a gdk_pixbuf::Pixbuf, or None
Sourcepub fn set_icon_from_icon_name(&self, icon_name: Option<&str>, size: IconSize)
pub fn set_icon_from_icon_name(&self, icon_name: Option<&str>, size: IconSize)
Sourcepub fn set_markup(&self, markup: Option<&str>)
pub fn set_markup(&self, markup: Option<&str>)
Sourcepub fn set_text(&self, text: Option<&str>)
pub fn set_text(&self, text: Option<&str>)
Sets the text of the tooltip to be text. If text is None, the label
will be hidden. See also set_markup().
text
a text string or None
Sourcepub fn set_tip_area(&self, rect: &Rectangle)
pub fn set_tip_area(&self, rect: &Rectangle)
Sets the area of the widget, where the contents of this tooltip apply,
to be rect (in widget coordinates). This is especially useful for
properly setting tooltips on TreeView rows and cells, GtkIconViews,
etc.
For setting tooltips on TreeView, please refer to the convenience
functions for this: TreeViewExt::set_tooltip_row() and
TreeViewExt::set_tooltip_cell().
rect
Sourcepub fn trigger_tooltip_query(display: &Display)
pub fn trigger_tooltip_query(display: &Display)
Triggers a new tooltip query on display, in order to update the current
visible tooltip, or to show/hide the current tooltip. This function is
useful to call when, for example, the state of the widget changed by a
key press.
display