pub struct TreeModel { /* private fields */ }Expand description
iter); row_count++; } ]|
The TreeModel interface contains two methods for reference
counting: gtk_tree_model_ref_node() and gtk_tree_model_unref_node().
These two methods are optional to implement. The reference counting
is meant as a way for views to let models know when nodes are being
displayed. TreeView will take a reference on a node when it is
visible, which means the node is either in the toplevel or expanded.
Being displayed does not mean that the node is currently directly
visible to the user in the viewport. Based on this reference counting
scheme a caching model, for example, can decide whether or not to cache
a node based on the reference count. A file-system based model would
not want to keep the entire file hierarchy in memory, but just the
folders that are currently expanded in every current view.
When working with reference counting, the following rules must be taken into account:
-
Never take a reference on a node without owning a reference on its parent. This means that all parent nodes of a referenced node must be referenced as well.
-
Outstanding references on a deleted node are not released. This is not possible because the node has already been deleted by the time the row-deleted signal is received.
-
Models are not obligated to emit a signal on rows of which none of its siblings are referenced. To phrase this differently, signals are only required for levels in which nodes are referenced. For the root level however, signals must be emitted at all times (however the root level is always referenced when any view is attached).
Signals
row-changed
This signal is emitted when a row in the model has changed.
row-deleted
This signal is emitted when a row has been deleted.
Note that no iterator is passed to the signal handler, since the row is already deleted.
This should be called by models after a row has been removed.
The location pointed to by path should be the location that
the row previously was at. It may not be a valid location anymore.
row-has-child-toggled
This signal is emitted when a row has gotten the first child row or lost its last child row.
row-inserted
This signal is emitted when a new row has been inserted in the model.
Note that the row may still be empty at this point, since it is a common pattern to first insert an empty row, and then fill it with the desired values.
rows-reordered
This signal is emitted when the children of a node in the
TreeModel have been reordered.
Note that this signal is not emitted when rows are reordered by DND, since this is implemented by removing and then reinserting the row.
Implements
GLib type: GObject with reference counted clone semantics.
Implementations