pub trait ListBoxImpl:
ListBoxImplExt
+ ContainerImpl
+ WidgetImpl {
// Provided methods
fn activate_cursor_row(&self) { ... }
fn move_cursor(&self, step: MovementStep, count: i32) { ... }
fn row_activated(&self, row: &ListBoxRow) { ... }
fn row_selected(&self, row: Option<&ListBoxRow>) { ... }
fn select_all(&self) { ... }
fn selected_rows_changed(&self) { ... }
fn toggle_cursor_row(&self) { ... }
fn unselect_all(&self) { ... }
}Provided Methods
fn activate_cursor_row(&self)
fn move_cursor(&self, step: MovementStep, count: i32)
fn row_activated(&self, row: &ListBoxRow)
fn row_selected(&self, row: Option<&ListBoxRow>)
Sourcefn select_all(&self)
fn select_all(&self)
Select all children of self, if the selection mode allows it.
fn selected_rows_changed(&self)
fn toggle_cursor_row(&self)
Sourcefn unselect_all(&self)
fn unselect_all(&self)
Unselect all children of self, if the selection mode allows it.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".