pub trait WindowImpl: WindowImplExt + BinImpl {
// Provided methods
fn set_focus(&self, focus: Option<&Widget>) { ... }
fn activate_focus(&self) { ... }
fn activate_default(&self) { ... }
fn keys_changed(&self) { ... }
fn enable_debugging(&self, toggle: bool) -> bool { ... }
}Provided Methods
Sourcefn set_focus(&self, focus: Option<&Widget>)
fn set_focus(&self, focus: Option<&Widget>)
If focus is not the current focus widget, and is focusable, sets
it as the focus widget for the window. If focus is None, unsets
the focus widget for this window. To set the focus to a particular
widget in the toplevel, it is usually more convenient to use
WidgetExt::grab_focus() instead of this function.
focus
widget to be the new focus widget, or None to unset
any focus widget for the toplevel window.
Sourcefn activate_focus(&self)
fn activate_focus(&self)
Activates the current focused widget within the window.
Sourcefn activate_default(&self)
fn activate_default(&self)
Activates the default widget for the window.
Sourcefn keys_changed(&self)
fn keys_changed(&self)
Signal gets emitted when the set of accelerators or mnemonics that are associated with window changes.
Sourcefn enable_debugging(&self, toggle: bool) -> bool
fn enable_debugging(&self, toggle: bool) -> bool
Class handler for the enable-debugging
keybinding signal. Since: 3.14
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".