[−][src]Trait gtk::HeaderBarExt
Required Methods
fn get_custom_title(&self) -> Option<Widget>
Retrieves the custom title widget of the header. See
HeaderBarExt::set_custom_title.
Feature: v3_10
Returns
the custom title widget
of the header, or None if none has been set explicitly.
fn get_decoration_layout(&self) -> Option<String>
Gets the decoration layout set with
HeaderBarExt::set_decoration_layout.
Feature: v3_12
Returns
the decoration layout
fn get_has_subtitle(&self) -> bool
Retrieves whether the header bar reserves space for a subtitle, regardless if one is currently set or not.
Feature: v3_12
Returns
true if the header bar reserves space
for a subtitle
Returns whether this header bar shows the standard window decorations.
Feature: v3_10
Returns
true if the decorations are shown
fn get_subtitle(&self) -> Option<String>
Retrieves the subtitle of the header. See HeaderBarExt::set_subtitle.
Feature: v3_10
Returns
the subtitle of the header, or None if none has
been set explicitly. The returned string is owned by the widget
and must not be modified or freed.
fn get_title(&self) -> Option<String>
Retrieves the title of the header. See HeaderBarExt::set_title.
Feature: v3_10
Returns
the title of the header, or None if none has
been set explicitly. The returned string is owned by the widget
and must not be modified or freed.
fn pack_end<P: IsA<Widget>>(&self, child: &P)
Adds child to self, packed with reference to the
end of the self.
Feature: v3_10
child
the Widget to be added to self
fn pack_start<P: IsA<Widget>>(&self, child: &P)
Adds child to self, packed with reference to the
start of the self.
Feature: v3_10
child
the Widget to be added to self
fn set_custom_title<'a, P: IsA<Widget> + 'a, Q: Into<Option<&'a P>>>(
&self,
title_widget: Q
)
&self,
title_widget: Q
)
Sets a custom title for the HeaderBar.
The title should help a user identify the current view. This
supersedes any title set by HeaderBarExt::set_title or
HeaderBarExt::set_subtitle. To achieve the same style as
the builtin title and subtitle, use the “title” and “subtitle”
style classes.
You should set the custom title to None, for the header title
label to be visible again.
Feature: v3_10
title_widget
a custom widget to use for a title
fn set_decoration_layout<'a, P: Into<Option<&'a str>>>(&self, layout: P)
Sets the decoration layout for this header bar, overriding
the Settings:gtk-decoration-layout setting.
There can be valid reasons for overriding the setting, such as a header bar design that does not allow for buttons to take room on the right, or only offers room for a single close button. Split header bars are another example for overriding the setting.
The format of the string is button names, separated by commas. A colon separates the buttons that should appear on the left from those on the right. Recognized button names are minimize, maximize, close, icon (the window icon) and menu (a menu button for the fallback app menu).
For example, “menu:minimize,maximize,close” specifies a menu on the left, and minimize, maximize and close buttons on the right.
Feature: v3_12
layout
a decoration layout, or None to
unset the layout
fn set_has_subtitle(&self, setting: bool)
Sets whether the header bar should reserve space for a subtitle, even if none is currently set.
Feature: v3_12
setting
true to reserve space for a subtitle
Sets whether this header bar shows the standard window decorations, including close, maximize, and minimize.
Feature: v3_10
setting
true to show standard window decorations
fn set_subtitle<'a, P: Into<Option<&'a str>>>(&self, subtitle: P)
Sets the subtitle of the HeaderBar. The title should give a user
an additional detail to help him identify the current view.
Note that HeaderBar by default reserves room for the subtitle,
even if none is currently set. If this is not desired, set the
HeaderBar:has-subtitle property to false.
Feature: v3_10
subtitle
a subtitle, or None
fn set_title<'a, P: Into<Option<&'a str>>>(&self, title: P)
Sets the title of the HeaderBar. The title should help a user
identify the current view. A good title should not include the
application name.
Feature: v3_10
title
a title, or None
fn get_property_custom_title(&self) -> Option<Widget>
fn set_property_custom_title<P: IsA<Widget> + IsA<Object> + SetValueOptional>(
&self,
custom_title: Option<&P>
)
&self,
custom_title: Option<&P>
)
fn get_property_decoration_layout_set(&self) -> bool
fn set_property_decoration_layout_set(&self, decoration_layout_set: bool)
fn get_property_spacing(&self) -> i32
fn set_property_spacing(&self, spacing: i32)
fn get_property_subtitle(&self) -> Option<String>
fn set_property_subtitle(&self, subtitle: Option<&str>)
fn get_property_title(&self) -> Option<String>
fn set_property_title(&self, title: Option<&str>)
fn get_child_pack_type<T: IsA<Widget>>(&self, item: &T) -> PackType
fn set_child_pack_type<T: IsA<Widget>>(&self, item: &T, pack_type: PackType)
fn get_child_position<T: IsA<Widget>>(&self, item: &T) -> i32
fn set_child_position<T: IsA<Widget>>(&self, item: &T, position: i32)
fn connect_property_custom_title_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerId
&self,
f: F
) -> SignalHandlerId
fn connect_property_decoration_layout_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerId
&self,
f: F
) -> SignalHandlerId
fn connect_property_decoration_layout_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerId
&self,
f: F
) -> SignalHandlerId
fn connect_property_has_subtitle_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerId
&self,
f: F
) -> SignalHandlerId
fn connect_property_spacing_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerId
&self,
f: F
) -> SignalHandlerId
fn connect_property_subtitle_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerId
&self,
f: F
) -> SignalHandlerId
fn connect_property_title_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerId
&self,
f: F
) -> SignalHandlerId
Implementors
impl<O: IsA<HeaderBar> + IsA<Container> + IsA<Object>> HeaderBarExt for O[src]
impl<O: IsA<HeaderBar> + IsA<Container> + IsA<Object>> HeaderBarExt for Ofn get_custom_title(&self) -> Option<Widget>[src]
fn get_custom_title(&self) -> Option<Widget>fn get_decoration_layout(&self) -> Option<String>[src]
fn get_decoration_layout(&self) -> Option<String>fn get_has_subtitle(&self) -> bool[src]
fn get_has_subtitle(&self) -> boolfn get_subtitle(&self) -> Option<String>[src]
fn get_subtitle(&self) -> Option<String>fn get_title(&self) -> Option<String>[src]
fn get_title(&self) -> Option<String>fn pack_end<P: IsA<Widget>>(&self, child: &P)[src]
fn pack_end<P: IsA<Widget>>(&self, child: &P)fn pack_start<P: IsA<Widget>>(&self, child: &P)[src]
fn pack_start<P: IsA<Widget>>(&self, child: &P)fn set_custom_title<'a, P: IsA<Widget> + 'a, Q: Into<Option<&'a P>>>(
&self,
title_widget: Q
)[src]
fn set_custom_title<'a, P: IsA<Widget> + 'a, Q: Into<Option<&'a P>>>(
&self,
title_widget: Q
)fn set_decoration_layout<'a, P: Into<Option<&'a str>>>(&self, layout: P)[src]
fn set_decoration_layout<'a, P: Into<Option<&'a str>>>(&self, layout: P)fn set_has_subtitle(&self, setting: bool)[src]
fn set_has_subtitle(&self, setting: bool)fn set_subtitle<'a, P: Into<Option<&'a str>>>(&self, subtitle: P)[src]
fn set_subtitle<'a, P: Into<Option<&'a str>>>(&self, subtitle: P)fn set_title<'a, P: Into<Option<&'a str>>>(&self, title: P)[src]
fn set_title<'a, P: Into<Option<&'a str>>>(&self, title: P)fn get_property_custom_title(&self) -> Option<Widget>[src]
fn get_property_custom_title(&self) -> Option<Widget>fn set_property_custom_title<P: IsA<Widget> + IsA<Object> + SetValueOptional>(
&self,
custom_title: Option<&P>
)[src]
fn set_property_custom_title<P: IsA<Widget> + IsA<Object> + SetValueOptional>(
&self,
custom_title: Option<&P>
)fn get_property_decoration_layout_set(&self) -> bool[src]
fn get_property_decoration_layout_set(&self) -> boolfn set_property_decoration_layout_set(&self, decoration_layout_set: bool)[src]
fn set_property_decoration_layout_set(&self, decoration_layout_set: bool)fn get_property_spacing(&self) -> i32[src]
fn get_property_spacing(&self) -> i32fn set_property_spacing(&self, spacing: i32)[src]
fn set_property_spacing(&self, spacing: i32)fn get_property_subtitle(&self) -> Option<String>[src]
fn get_property_subtitle(&self) -> Option<String>fn set_property_subtitle(&self, subtitle: Option<&str>)[src]
fn set_property_subtitle(&self, subtitle: Option<&str>)fn get_property_title(&self) -> Option<String>[src]
fn get_property_title(&self) -> Option<String>fn set_property_title(&self, title: Option<&str>)[src]
fn set_property_title(&self, title: Option<&str>)fn get_child_pack_type<T: IsA<Widget>>(&self, item: &T) -> PackType[src]
fn get_child_pack_type<T: IsA<Widget>>(&self, item: &T) -> PackTypefn set_child_pack_type<T: IsA<Widget>>(&self, item: &T, pack_type: PackType)[src]
fn set_child_pack_type<T: IsA<Widget>>(&self, item: &T, pack_type: PackType)fn get_child_position<T: IsA<Widget>>(&self, item: &T) -> i32[src]
fn get_child_position<T: IsA<Widget>>(&self, item: &T) -> i32fn set_child_position<T: IsA<Widget>>(&self, item: &T, position: i32)[src]
fn set_child_position<T: IsA<Widget>>(&self, item: &T, position: i32)fn connect_property_custom_title_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerId[src]
fn connect_property_custom_title_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerIdfn connect_property_decoration_layout_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerId[src]
fn connect_property_decoration_layout_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerIdfn connect_property_decoration_layout_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerId[src]
fn connect_property_decoration_layout_set_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerIdfn connect_property_has_subtitle_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerId[src]
fn connect_property_has_subtitle_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerIdfn connect_property_spacing_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerId[src]
fn connect_property_spacing_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerIdfn connect_property_subtitle_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerId[src]
fn connect_property_subtitle_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerIdfn connect_property_title_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerId[src]
fn connect_property_title_notify<F: Fn(&Self) + 'static>(
&self,
f: F
) -> SignalHandlerId